(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1092207,      23752]*)
(*NotebookOutlinePosition[   1092999,      23780]*)
(*  CellTagsIndexPosition[   1092955,      23776]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Detektor Beauchampa", "Title"],

Cell[TextData["\[CapitalSHacek] Marek Szczerba, 2000"], "Text"],

Cell[CellGroupData[{

Cell["Inicjalizacja", "Section"],

Cell["Wczytanie bibliotek", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< Miscellaneous`Audio`\n<< CCRMA`SCMTheory`\n<< CCRMA`Windows`\n
      \(<< Statistics`MultiDescriptiveStatistics`; \)\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(SetDelayed::"write"\), \( : \ \), 
        "\<\"Tag \\!\\(TraditionalForm\\`FilterOptions\\) in \
\\!\\(TraditionalForm\\`\\(FilterOptions(\\(command_Symbol, opts___\\))\\)\\) \
is Protected.\"\>"}], TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(Correlation::"shdw"\), \( : \ \), 
        "\<\"Symbol \\!\\(TraditionalForm\\`\\\"Correlation\\\"\\) appears in \
multiple contexts \
\\!\\(TraditionalForm\\`\\({\\\"Statistics`MultiDescriptiveStatistics`\\\", \
\\\"SCMTheory`\\\"}\\)\\); definitions in context \
\\!\\(TraditionalForm\\`\\\"Statistics`MultiDescriptiveStatistics`\\\"\\) may \
shadow or be shadowed by other definitions.\"\>"}], TraditionalForm]], 
  "Message"],

Cell[BoxData[
    \(TraditionalForm\`Null\^4\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell[TextData["Akwizycja sygna\[LSlash]u"], "MathCaption"],

Cell[BoxData[
    \(SetDirectory["\<D:\\MIDI\\\>"]; \n
    snd = ReadSoundfile["\<c2orgs.wav\>"]; \)], "Input",
  CellLabel->"In[8]:="],

Cell[CellGroupData[{

Cell[TextData["Parametry okre\.9clane przez u\:017cytkownika"], "Subsection"],

Cell[TextData[
"Cz\:0119stotliwo\.9c\[CAcute] pr\[OAcute]bkowania"], "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"CzP", "=", 
        StyleBox["22050",
          FontColor->RGBColor[1, 0, 0]]}], ";"}]], "Input",
  CellLabel->"In[9]:="],

Cell["Rozmiar okna czasowego", "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"OknoN", "=", 
        StyleBox["512",
          FontColor->RGBColor[1, 0, 0]]}], ";"}]], "Input",
  CellLabel->"In[10]:="],

Cell[TextData["Zak\[LSlash]adka"], "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Zak\[LSlash]adka", "=", 
        StyleBox[
          FractionBox[
            StyleBox["1",
              FontColor->RGBColor[1, 0, 0]], "2"],
          FontColor->RGBColor[1, 0, 0]]}], ";"}]], "Input",
  CellLabel->"In[11]:="],

Cell[TextData["Wsp\[OAcute]\[LSlash]czynnik zeropaddingu"], "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"wZP", "=", 
        StyleBox["3",
          FontColor->RGBColor[1, 0, 0]]}], ";"}]], "Input",
  CellLabel->"In[12]:="],

Cell[TextData["Zakres cz\:0119stotliwo\.9cci"], "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"CzMin", "=", 
        StyleBox["100",
          FontColor->RGBColor[1, 0, 0]]}], ";", "\n", 
      RowBox[{"CzMaks", "=", 
        StyleBox["2000",
          FontColor->RGBColor[1, 0, 0]]}], ";"}]], "Input",
  CellLabel->"In[13]:="],

Cell["Maksymalna liczba analizowanych harmonicznych", "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"MaksHarm", "=", 
        StyleBox["10",
          FontColor->RGBColor[1, 0, 0]]}], ";"}]], "Input",
  CellLabel->"In[9]:="],

Cell["Pr\[OAcute]g szumowy (w dB)", "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PrSz", "=", 
        StyleBox[\(-25\),
          FontColor->RGBColor[1, 0, 0]]}], ";"}]], "Input",
  CellLabel->"In[10]:="],

Cell["Pr\[OAcute]g amplitudowy detekcji maksim\[OAcute]w widma", "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PrAmp", "=", 
        StyleBox[\(-30\),
          FontColor->RGBColor[1, 0, 0]]}], ";"}]], "Input",
  CellLabel->"In[11]:="],

Cell[TextData[{
  "Waga b\[LSlash]\:0119du ",
  Cell[BoxData[
      \(TraditionalForm\`e\_2\)]]
}], "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"W", "=", 
        StyleBox["3",
          FontColor->RGBColor[1, 0, 0]]}], ";"}]], "Input",
  CellLabel->"In[12]:="],

Cell[TextData["Zakres cz\:0119stotliwo\.9cci podstawowej"], "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"CzMin", "=", 
        StyleBox["100",
          FontColor->RGBColor[1, 0, 0]]}], ";", "\n", 
      RowBox[{"CzMax", "=", 
        StyleBox["2000",
          FontColor->RGBColor[1, 0, 0]]}], ";"}]], "Input",
  CellLabel->"In[13]:="],

Cell[TextData[
"Detekcja maksymalnej warto\.9cci bezwzgl\:0119dnej pr\[OAcute]bki w \
sygnale"], "MathCaption"],

Cell[BoxData[
    \(\(MaksPr\[OAcute]bka = Max[Abs[snd]]; \)\)], "Input",
  CellLabel->"In[49]:="],

Cell[TextData[
"Rzeczywista cz\:0119stotliwo\.9c\[CAcute] podstawowa"], "MathCaption"],

Cell[BoxData[
    \(\(RzCzPodst = N[440 \@\( 2\^Wys\)\%12]; \)\)], "Input",
  CellLabel->"In[50]:="],

Cell[TextData[
"Zakres cz\:0119stotliwo\.9cci podstawowej (w pr\[OAcute]bkach)"], 
  "MathCaption"],

Cell[BoxData[
    \(FMin = Floor[CzMin \((\((1 + wZP)\)\ OknoN)\)/CzP]; \n
    FMax = Ceiling[CzMax \((\((1 + wZP)\)\ OknoN)\)/CzP]; \)], "Input",
  CellLabel->"In[51]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Definicje funkcji przetwarzania sygna\[LSlash]u"], "Section"],

Cell["Definicja okna czasowego", "MathCaption"],

Cell[BoxData[
    \(\(FOkna = Function[dane, \n\t\tdane*HammingW[Length[dane]]]; \)\)], 
  "Input",
  CellLabel->"In[17]:="],

Cell["Zeropadding", "MathCaption"],

Cell[BoxData[
    \(\(ZP = 
      Function[{dane, wZP}, \n\t\tWy = dane; \n\t\t
        zera = Table[0, {x, wZP\ Length[dane]}]; \n\t\tAppendTo[Wy, zera]; \n
        \t\tFlatten[Wy]]; \)\)], "Input",
  CellLabel->"In[18]:="],

Cell["Obliczenie widm", "MathCaption"],

Cell[BoxData[
    \(\(OblWidma = 
      Function[dane, \n\t\tTempWy = Abs[Fourier[dane]]; \n\t\t
        Wy = Table[
            TempWy\[LeftDoubleBracket]fx\[RightDoubleBracket], {fx, 
              Length[TempWy]\/2}]; \n\t\t
        For[fi = 1, fi <= FMin, \(fi++\), 
          \(Wy\[LeftDoubleBracket]fi\[RightDoubleBracket] = 0; \)]; \n\t\tWy\n
        \t]; \)\)], "Input",
  CellLabel->"In[19]:="],

Cell["Detekcja maksim\[OAcute]w widma i interpolacja wielomianem 2-stopnia", 
  "MathCaption"],

Cell[BoxData[
    \(\(DetIntMaks = 
      Function[{dane, wsp, licz}, \n\t\tWy = {}; \n\t\t
        For[fi = 1, fi <= Length[dane], \(fi++\), \n\t\t\tfmaks = 0; \n\t\t\t
          For[fj = FMin, 
            fj <= Length[dane\[LeftDoubleBracket]fi\[RightDoubleBracket]], 
            \(fj++\), \n\t\t\t\t
            If[dane\[LeftDoubleBracket]fi, fj\[RightDoubleBracket] > fmaks, 
              fmaks = dane\[LeftDoubleBracket]fi, fj\[RightDoubleBracket]]]; 
          \n\t\t\tfFr = {}; \n\t\t\t
          For[fj = FMin, fj <= FMax, \(fj++\), \n\t\t\t\t
            If[dane\[LeftDoubleBracket]fi, fj\[RightDoubleBracket] > 
                  dane\[LeftDoubleBracket]fi, fj + 1\[RightDoubleBracket] && 
                dane\[LeftDoubleBracket]fi, fj\[RightDoubleBracket] > 
                  dane\[LeftDoubleBracket]fi, fj - 1\[RightDoubleBracket] && 
                20  Log[10, 
                      dane\[LeftDoubleBracket]fi, fj
                          \[RightDoubleBracket]\/fmaks] > wsp, \n\t\t\t\t\t
              fpoly = Fit[{
                    dane\[LeftDoubleBracket]fi, fj - 1\[RightDoubleBracket], 
                    dane\[LeftDoubleBracket]fi, fj\[RightDoubleBracket], 
                    dane\[LeftDoubleBracket]fi, 
                      fj + 1\[RightDoubleBracket]}, {1, x, x\^2}, x]; \n
              \t\t\t\t\t
              AppendTo[
                fFr, {dane\[LeftDoubleBracket]fi, fj
                      \[RightDoubleBracket]\/fmaks, 
                  fj - 2 + x /. 
                    \(FindMinimum[\(-fpoly\), {x, 0}]\)\[LeftDoubleBracket]2
                      \[RightDoubleBracket]}]]]; \n\t\t\t
          If[licz < Length[fFr], \n\t\t\t\tfFr = Sort[fFr, Greater]; \n
            \t\t\t\tfFr = 
              Table[fFr\[LeftDoubleBracket]fj\[RightDoubleBracket], {fj, 
                  licz}]]; \n\t\t\t
          fFr = Table[{fFr\[LeftDoubleBracket]fj, 2\[RightDoubleBracket], 
                fFr\[LeftDoubleBracket]fj, 1\[RightDoubleBracket]}, {fj, 
                Length[fFr]}]; \n\t\t\tAppendTo[Wy, fFr]]; \n\t\tWy]; \)\)], 
  "Input",
  CellLabel->"In[20]:="],

Cell[TextData[{
  "Obliczenie b\[LSlash]\:0119du dopasowania ",
  Cell[BoxData[
      \(TraditionalForm\`e\_1\)]]
}], "MathCaption"],

Cell[BoxData[
    \(\(OblE1 = 
      Function[{dane, wsp}, \n\t\tWy = {}; \n\t\t
        For[fi = 1, fi <= Length[dane], \(fi++\), \n\t\t\teFr = {}; \n\t\t\t
          For[fh = FMin, fh <= FMax, fh = N[fh \@ 2\%12], \n\t\t\t\tfe = 0; \n
            \t\t\t\tfdist = \[Infinity]; \n\t\t\t\t
            For[fj = 1, fj <= wsp, \(fj++\), \n\t\t\t\t\t
              For[fk = 1, 
                fk <= Length[
                    dane\[LeftDoubleBracket]fi\[RightDoubleBracket]], 
                \(fk++\), \n\t\t\t\t\t\t
                If[Abs[dane\[LeftDoubleBracket]fi, fk, 1
                          \[RightDoubleBracket] - fh*fj] < fdist, 
                  fdist = 
                    Abs[dane\[LeftDoubleBracket]fi, fk, 1
                          \[RightDoubleBracket] - fh*fj]]]; \n\t\t\t\t\t
              fe += fdist]; \n\t\t\t\tAppendTo[eFr, fe]]; \n\t\t\t
          AppendTo[Wy, eFr]]; \n\t\tWy]; \)\)], "Input",
  CellLabel->"In[21]:="],

Cell[TextData[{
  "Obliczenie b\[LSlash]\:0119du dopasowania ",
  Cell[BoxData[
      \(TraditionalForm\`e\_2\)]]
}], "MathCaption"],

Cell[BoxData[
    \(\(OblE2 = 
      Function[{dane, wsp}, \n\t\tWy = {}; \n\t\t
        For[fi = 1, fi <= Length[dane], \(fi++\), \n\t\t\teFr = {}; \n\t\t\t
          For[fh = FMin, fh <= FMax, fh = N[fh \@ 2\%12], \n\t\t\t\tfe = 0; \n
            \t\t\t\tfdist = \[Infinity]; \n\t\t\t\t
            For[fk = 1, 
              fk <= Length[dane\[LeftDoubleBracket]fi\[RightDoubleBracket]], 
              \(fk++\), \n\t\t\t\t\tfhfj = fh; \n\t\t\t\t\t
              For[fj = 1, fj <= wsp, \(fj++\), \n\t\t\t\t\t\tfhfj = fh\ fj; \n
                \t\t\t\t\t\t
                If[Abs[dane\[LeftDoubleBracket]fi, fk, 1
                          \[RightDoubleBracket] - fhfj] < fdist, 
                  fdist = 
                    Abs[dane\[LeftDoubleBracket]fi, fk, 1
                          \[RightDoubleBracket] - fhfj]]]; \n\t\t\t\t\t
              fe += fdist]; \n\t\t\t\tAppendTo[eFr, fe]]; \n\t\t\t
          AppendTo[Wy, eFr]]; \n\t\tWy]; \)\)], "Input",
  CellLabel->"In[22]:="],

Cell["Funkcja detekcji minim\[OAcute]w i konwersji do Hz", "MathCaption"],

Cell[BoxData[
    \(\(DetMinK = 
      Function[dane, \n\t\tWy = {}; \n\t\t
        For[fi = 1, fi <= Length[dane], \(fi++\), \n\t\t\t
          fmin = {\[Infinity], 0}; \n\t\t\t
          For[fj = 1, 
            fj <= Length[dane\[LeftDoubleBracket]fi\[RightDoubleBracket]], 
            \(fj++\), \n\t\t\t\t
            If[dane\[LeftDoubleBracket]fi, fj\[RightDoubleBracket] < 
                fmin\[LeftDoubleBracket]1\[RightDoubleBracket], 
              fmin = {dane\[LeftDoubleBracket]fi, fj\[RightDoubleBracket], 
                  fj}]]; \n\t\t\t
          AppendTo[Wy, 
            N[FMin \( CzP\/\(OknoN \((1 + wZP)\)\)\) 
                \@\(2\^fmin\[LeftDoubleBracket]2
                        \[RightDoubleBracket]\)\%12]]]; \n\t\tWy]; \)\)], 
  "Input",
  CellLabel->"In[23]:="],

Cell[TextData["Definicja funkcji b\[LSlash]\:0119du"], "MathCaption"],

Cell[BoxData[
    \(\(FB\[LSlash]\:0119du = 
      Function[{dane, rzcz}, \n\t\tWy = {}; \n\t\t
        For[fi = 1, fi <= Length[dane], \(fi++\), \n\t\t\t
          If[dane\[LeftDoubleBracket]fi\[RightDoubleBracket] > 0, 
            AppendTo[Wy, 
              dane\[LeftDoubleBracket]fi\[RightDoubleBracket] - rzcz]]]; \n
        \t\tWy]; \)\)], "Input",
  CellLabel->"In[24]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Obliczenia", "Section"],

Cell["Obliczenie widma", "MathCaption"],

Cell[BoxData[
    \(i = 0; \nWidma = {}; \n
    While[i <= Length[snd] - OknoN, \n\t
      Ramka = Table[
          snd\[LeftDoubleBracket]x\[RightDoubleBracket], {x, i + 1, 
            i + OknoN}]; \n\t
      If[20  Log[10, Max[Abs[Ramka]]\/MaksPr\[OAcute]bka] >= PrSz, \n\t\t
        Okno = FOkna[Ramka]; \n\t\tZeroP = ZP[Okno, wZP]; \n\t\t
        AppendTo[Widma, OblWidma[ZeroP]]]; \n
      i += Floor[OknoN \((1 - Zak\[LSlash]adka)\)]; ]; \)], "Input",
  CellLabel->"In[52]:="],

Cell["Detekcja maksim\[OAcute]w widma", "MathCaption"],

Cell[BoxData[
    \(\(Maks = DetIntMaks[Widma, PrAmp, MaksHarm]; \)\)], "Input",
  CellLabel->"In[27]:="],

Cell[TextData[{
  "Obliczenie b\[LSlash]\:0119du dopasowania ",
  Cell[BoxData[
      \(TraditionalForm\`e\_1\)]]
}], "MathCaption"],

Cell[BoxData[
    \(\(e1 = OblE1[Maks, 10]; \)\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(\(e2 = OblE2[Maks, 10]; \)\)], "Input",
  CellLabel->"In[29]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot3D[e1 + e2, PlotRange -> {All, All, {0, 200}}]; \)\)], "Input",\

  CellLabel->"In[30]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.24822 .15935 -11.5102 -9 ]
[.24822 .15935 .4898 0 ]
[.50253 .05935 -10.5479 -9 ]
[.50253 .05935 1.45207 0 ]
[.79593 .14064 0 -6.11966 ]
[.79593 .14064 12 2.88034 ]
[.88083 .27065 0 -5.99627 ]
[.88083 .27065 18 3.00373 ]
[.95572 .38534 0 -5.89035 ]
[.95572 .38534 18 3.10965 ]
[.02494 .25992 -6 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -12 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -18 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -18 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -18 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.25709 .16902 m
.26153 .17385 L
s
[(20)] .24822 .15935 .91837 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(40)] .50253 .05935 .75799 1 Mshowa
.125 Mabswid
.08191 .23761 m
.08475 .24034 L
s
.13899 .21527 m
.14177 .21805 L
s
.19737 .19241 m
.20009 .19525 L
s
.31821 .14509 m
.32081 .14804 L
s
.38078 .12059 m
.38331 .1236 L
s
.44485 .0955 m
.4473 .09858 L
s
.57768 .04348 m
.57998 .04668 L
s
.64658 .01651 m
.64878 .01977 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.78358 .14509 m
.77741 .14731 L
s
[(50)] .79593 .14064 -1 .35992 Mshowa
.86838 .27479 m
.86215 .27686 L
s
[(100)] .88083 .27065 -1 .33251 Mshowa
.94318 .38921 m
.93691 .39115 L
s
[(150)] .95572 .38534 -1 .30897 Mshowa
.125 Mabswid
.70714 .02815 m
.70347 .02957 L
s
.72705 .0586 m
.72337 .06 L
s
.74641 .08822 m
.74272 .0896 L
s
.76525 .11704 m
.76155 .11839 L
s
.80144 .17239 m
.79773 .17371 L
s
.81882 .19899 m
.81511 .20029 L
s
.83577 .2249 m
.83204 .22618 L
s
.85228 .25016 m
.84855 .25142 L
s
.88408 .2988 m
.88034 .30003 L
s
.89939 .32223 m
.89565 .32344 L
s
.91434 .3451 m
.91059 .34629 L
s
.92893 .36742 m
.92518 .3686 L
s
.9571 .4105 m
.95333 .41165 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(0)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(50)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(100)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(150)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(200)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.542 .529 .79 r
.40239 .6278 .40414 .63171 .41389 .63453 .41219 .62908 Metetra
.742 .594 .692 r
.41219 .62908 .41389 .63453 .42414 .6222 .42249 .61514 Metetra
.56 .459 .696 r
.42249 .61514 .42414 .6222 .43387 .62912 .43235 .61669 Metetra
.655 .482 .638 r
.43235 .61669 .43387 .62912 .44406 .62084 .44258 .60549 Metetra
.648 .468 .626 r
.44258 .60549 .44406 .62084 .45445 .60235 .45283 .59293 Metetra
.686 .519 .654 r
.45283 .59293 .45445 .60235 .46477 .58547 .46307 .57984 Metetra
.435 .406 .728 r
.46307 .57984 .46477 .58547 .47485 .58136 .47299 .58643 Metetra
.659 .339 .421 r
.47299 .58643 .47485 .58136 .4849 .58293 .48298 .59481 Metetra
.625 .36 .496 r
.48298 .59481 .4849 .58293 .49495 .59198 .49307 .60396 Metetra
.481 .232 .459 r
.49307 .60396 .49495 .59198 .50515 .59355 .50338 .59514 Metetra
.452 0 .039 r
.50338 .59514 .50515 .59355 .51542 .59289 .51367 .59567 Metetra
.844 .516 .431 r
.51367 .59567 .51542 .59289 .52576 .62432 .524 .62837 Metetra
.354 .01 .237 r
.524 .62837 .52576 .62432 .53622 .61799 .53449 .62268 Metetra
.318 0 .256 r
.53449 .62268 .53622 .61799 .54672 .6154 .54499 .61474 Metetra
.537 .856 .997 r
.54499 .61474 .54672 .6154 .55726 .61291 .55555 .61243 Metetra
.933 .851 .738 r
.55555 .61243 .55726 .61291 .56765 .59386 .56595 .59336 Metetra
.936 .846 .729 r
.56595 .59336 .56765 .59386 .57796 .57399 .57628 .57346 Metetra
.92 .868 .772 r
.57628 .57346 .57796 .57399 .58829 .55863 .58662 .55754 Metetra
.85 .39 .039 r
.58662 .55754 .58829 .55863 .59933 .57737 .59766 .5763 Metetra
.864 .414 .07 r
.59766 .5763 .59933 .57737 .61059 .59775 .60893 .5967 Metetra
.875 .436 .099 r
.60893 .5967 .61059 .59775 .6221 .61993 .62043 .61889 Metetra
.931 .808 .702 r
.62043 .61889 .6221 .61993 .63237 .59639 .63073 .59558 Metetra
.893 .473 .165 r
.63073 .59558 .63237 .59639 .64426 .62213 .64261 .62123 Metetra
.949 .614 .351 r
.64261 .62123 .64426 .62213 .65798 .6903 .65632 .68948 Metetra
.843 .378 .043 r
.65632 .68948 .65798 .6903 .67025 .7107 .66857 .70924 Metetra
.934 .783 .67 r
.66857 .70924 .67025 .7107 .68054 .68191 .67887 .68042 Metetra
.936 .78 .662 r
.67887 .68042 .68054 .68191 .69064 .65192 .689 .6504 Metetra
.939 .777 .654 r
.689 .6504 .69064 .65192 .70055 .62071 .69893 .61916 Metetra
.941 .775 .646 r
.69893 .61916 .70055 .62071 .71025 .58824 .70866 .58666 Metetra
.417 .678 .97 r
.70866 .58666 .71025 .58824 .72165 .58781 .72015 .58773 Metetra
.923 .548 .281 r
.72015 .58773 .72165 .58781 .73578 .63101 .73428 .631 Metetra
.927 .557 .29 r
.73428 .631 .73578 .63101 .75054 .67846 .74904 .67853 Metetra
.903 .504 .237 r
.74904 .67853 .75054 .67846 .76496 .71503 .76333 .71325 Metetra
.645 .763 .934 r
.76333 .71325 .76496 .71503 .77687 .71192 .77525 .71013 Metetra
.645 .763 .934 r
.77525 .71013 .77687 .71192 .78883 .70879 .78722 .70699 Metetra
.645 .763 .934 r
.78722 .70699 .78883 .70879 .80083 .70564 .79924 .70384 Metetra
.645 .763 .934 r
.79924 .70384 .80083 .70564 .81289 .70248 .81131 .70067 Metetra
.645 .763 .934 r
.81131 .70067 .81289 .70248 .825 .69931 .82343 .6975 Metetra
.645 .763 .934 r
.82343 .6975 .825 .69931 .83716 .69613 .8356 .69431 Metetra
.645 .763 .934 r
.8356 .69431 .83716 .69613 .84937 .69293 .84782 .6911 Metetra
.645 .763 .934 r
.84782 .6911 .84937 .69293 .86163 .68972 .86009 .68788 Metetra
.645 .763 .934 r
.86009 .68788 .86163 .68972 .87395 .6865 .87242 .68465 Metetra
.645 .763 .934 r
.87242 .68465 .87395 .6865 .88631 .68326 .8848 .68141 Metetra
.645 .763 .934 r
.8848 .68141 .88631 .68326 .89873 .68001 .89723 .67815 Metetra
.645 .763 .934 r
.89723 .67815 .89873 .68001 .9112 .67675 .90971 .67488 Metetra
.645 .763 .934 r
.90971 .67488 .9112 .67675 .92372 .67347 .92225 .67159 Metetra
.645 .763 .934 r
.92225 .67159 .92372 .67347 .9363 .67018 .93483 .66829 Metetra
.645 .763 .934 r
.93483 .66829 .9363 .67018 .94893 .66687 .94748 .66497 Metetra
.645 .763 .934 r
.94748 .66497 .94893 .66687 .96162 .66355 .96018 .66164 Metetra
.645 .763 .934 r
.96018 .66164 .96162 .66355 .97436 .66021 .97293 .6583 Metetra
.645 .763 .934 r
.97293 .6583 .97436 .66021 .98715 .65686 .98573 .65494 Metetra
.645 .763 .934 r
.98573 .65494 .98715 .65686 1 .6535 .9986 .65157 Metetra
.461 0 0 r
.40047 .62868 .40239 .6278 .41219 .62908 .41026 .63042 Metetra
.839 .992 .736 r
.41026 .63042 .41219 .62908 .42249 .61514 .42054 .61788 Metetra
.655 .28 .322 r
.42054 .61788 .42249 .61514 .43235 .61669 .4303 .62404 Metetra
.389 .112 .368 r
.4303 .62404 .43235 .61669 .44258 .60549 .44052 .61473 Metetra
.305 .06 .368 r
.44052 .61473 .44258 .60549 .45283 .59293 .45089 .59841 Metetra
0 0 .131 r
.45089 .59841 .45283 .59293 .46307 .57984 .46123 .58176 Metetra
.46123 .58176 .46307 .57984 .47299 .58643 .47137 .57521 Metetra
.513 .387 .646 r
.47137 .57521 .47299 .58643 .48298 .59481 .48135 .58215 Metetra
.501 .371 .635 r
.48135 .58215 .48298 .59481 .49307 .60396 .49141 .59121 Metetra
.586 .431 .639 r
.49141 .59121 .49307 .60396 .50338 .59514 .50164 .59057 Metetra
.583 .529 .761 r
.50164 .59057 .50338 .59514 .51367 .59567 .51193 .59044 Metetra
.714 .402 0 r
.51193 .59044 .51367 .59567 .524 .62837 .52225 .62308 Metetra
.673 .562 .722 r
.52225 .62308 .524 .62837 .53449 .62268 .53273 .61694 Metetra
.665 .549 .713 r
.53273 .61694 .53449 .62268 .54499 .61474 .54324 .61099 Metetra
.613 .58 .793 r
.54324 .61099 .54499 .61474 .55555 .61243 .55381 .60945 Metetra
.84 .701 .71 r
.55381 .60945 .55555 .61243 .56595 .59336 .56422 .59038 Metetra
.845 .702 .705 r
.56422 .59038 .56595 .59336 .57628 .57346 .57457 .57047 Metetra
.816 .696 .732 r
.57457 .57047 .57628 .57346 .58662 .55754 .58493 .55536 Metetra
.753 .301 0 r
.58493 .55536 .58662 .55754 .59766 .5763 .59597 .57412 Metetra
.786 .34 0 r
.59597 .57412 .59766 .5763 .60893 .5967 .60723 .59452 Metetra
.814 .374 0 r
.60723 .59452 .60893 .5967 .62043 .61889 .61873 .61672 Metetra
.887 .748 .703 r
.61873 .61672 .62043 .61889 .63073 .59558 .62907 .5944 Metetra
.874 .433 .078 r
.62907 .5944 .63073 .59558 .64261 .62123 .64087 .61742 Metetra
.957 .62 .243 r
.64087 .61742 .64261 .62123 .65632 .68948 .65454 .68562 Metetra
0 0 .488 r
.65454 .68562 .65632 .68948 .66857 .70924 .66685 .70708 Metetra
.912 .753 .671 r
.66685 .70708 .66857 .70924 .67887 .68042 .67717 .67825 Metetra
.916 .752 .664 r
.67717 .67825 .67887 .68042 .689 .6504 .68732 .64821 Metetra
.919 .75 .656 r
.68732 .64821 .689 .6504 .69893 .61916 .69727 .61695 Metetra
.922 .749 .649 r
.69727 .61695 .69893 .61916 .70866 .58666 .70702 .58444 Metetra
.528 .654 .915 r
.70702 .58444 .70866 .58666 .72015 .58773 .71847 .58468 Metetra
.894 .516 .058 r
.71847 .58468 .72015 .58773 .73428 .631 .73259 .62793 Metetra
.906 .532 .086 r
.73259 .62793 .73428 .631 .74904 .67853 .74733 .67545 Metetra
.826 .433 0 r
.74733 .67545 .74904 .67853 .76333 .71325 .7617 .71147 Metetra
.645 .763 .934 r
.7617 .71147 .76333 .71325 .77525 .71013 .77363 .70834 Metetra
.645 .763 .934 r
.77363 .70834 .77525 .71013 .78722 .70699 .78561 .70519 Metetra
.645 .763 .934 r
.78561 .70519 .78722 .70699 .79924 .70384 .79764 .70203 Metetra
.645 .763 .934 r
.79764 .70203 .79924 .70384 .81131 .70067 .80972 .69886 Metetra
.645 .763 .934 r
.80972 .69886 .81131 .70067 .82343 .6975 .82185 .69568 Metetra
.645 .763 .934 r
.82185 .69568 .82343 .6975 .8356 .69431 .83403 .69248 Metetra
.645 .763 .934 r
.83403 .69248 .8356 .69431 .84782 .6911 .84627 .68927 Metetra
.645 .763 .934 r
.84627 .68927 .84782 .6911 .86009 .68788 .85855 .68604 Metetra
.645 .763 .934 r
.85855 .68604 .86009 .68788 .87242 .68465 .87089 .6828 Metetra
.645 .763 .934 r
.87089 .6828 .87242 .68465 .8848 .68141 .88328 .67955 Metetra
.645 .763 .934 r
.88328 .67955 .8848 .68141 .89723 .67815 .89572 .67628 Metetra
.645 .763 .934 r
.89572 .67628 .89723 .67815 .90971 .67488 .90821 .673 Metetra
.645 .763 .934 r
.90821 .673 .90971 .67488 .92225 .67159 .92076 .66971 Metetra
.645 .763 .934 r
.92076 .66971 .92225 .67159 .93483 .66829 .93336 .6664 Metetra
.645 .763 .934 r
.93336 .6664 .93483 .66829 .94748 .66497 .94602 .66307 Metetra
.645 .763 .934 r
.94602 .66307 .94748 .66497 .96018 .66164 .95873 .65974 Metetra
.645 .763 .934 r
.95873 .65974 .96018 .66164 .97293 .6583 .97149 .65638 Metetra
.645 .763 .934 r
.97149 .65638 .97293 .6583 .98573 .65494 .98431 .65302 Metetra
.645 .763 .934 r
.98431 .65302 .98573 .65494 .9986 .65157 .99719 .64964 Metetra
.544 .56 .821 r
.3987 .62533 .40047 .62868 .41026 .63042 .40851 .6262 Metetra
.759 .628 .715 r
.40851 .6262 .41026 .63042 .42054 .61788 .41881 .61336 Metetra
.521 .494 .767 r
.41881 .61336 .42054 .61788 .4303 .62404 .42867 .6157 Metetra
.683 .525 .666 r
.42867 .6157 .4303 .62404 .44052 .61473 .43892 .60469 Metetra
.678 .51 .651 r
.43892 .60469 .44052 .61473 .45089 .59841 .4492 .5921 Metetra
.724 .571 .683 r
.4492 .5921 .45089 .59841 .46123 .58176 .45948 .57883 Metetra
.506 .568 .853 r
.45948 .57883 .46123 .58176 .47137 .57521 .46949 .58035 Metetra
.657 .338 .421 r
.46949 .58035 .47137 .57521 .48135 .58215 .47948 .58871 Metetra
.652 .351 .448 r
.47948 .58871 .48135 .58215 .49141 .59121 .48956 .59785 Metetra
.411 .123 .362 r
.48956 .59785 .49141 .59121 .50164 .59057 .49988 .59029 Metetra
.124 0 0 r
.49988 .59029 .50164 .59057 .51193 .59044 .51016 .59203 Metetra
.87 .529 .402 r
.51016 .59203 .51193 .59044 .52225 .62308 .52048 .62475 Metetra
.52048 .62475 .52225 .62308 .53273 .61694 .53099 .6193 Metetra
.53099 .6193 .53273 .61694 .54324 .61099 .5415 .61004 Metetra
.538 .816 .997 r
.5415 .61004 .54324 .61099 .55381 .60945 .55208 .60833 Metetra
.908 .805 .735 r
.55208 .60833 .55381 .60945 .56422 .59038 .56251 .58923 Metetra
.911 .802 .727 r
.56251 .58923 .56422 .59038 .57457 .57047 .57287 .5693 Metetra
.889 .817 .772 r
.57287 .5693 .57457 .57047 .58493 .55536 .58325 .55413 Metetra
.844 .383 .013 r
.58325 .55413 .58493 .55536 .59597 .57412 .59429 .5729 Metetra
.859 .408 .047 r
.59429 .5729 .59597 .57412 .60723 .59452 .60555 .59332 Metetra
.872 .431 .078 r
.60555 .59332 .60723 .59452 .61873 .61672 .61705 .61553 Metetra
.924 .802 .707 r
.61705 .61553 .61873 .61672 .62907 .5944 .6274 .59297 Metetra
.871 .431 .051 r
.6274 .59297 .62907 .5944 .64087 .61742 .63921 .61648 Metetra
.949 .614 .35 r
.63921 .61648 .64087 .61742 .65454 .68562 .65287 .68475 Metetra
.845 .381 .041 r
.65287 .68475 .65454 .68562 .66685 .70708 .66512 .70476 Metetra
.907 .746 .671 r
.66512 .70476 .66685 .70708 .67717 .67825 .67547 .6759 Metetra
.911 .745 .664 r
.67547 .6759 .67717 .67825 .68732 .64821 .68563 .64585 Metetra
.914 .744 .657 r
.68563 .64585 .68732 .64821 .69727 .61695 .69561 .61457 Metetra
.918 .743 .65 r
.69561 .61457 .69727 .61695 .70702 .58444 .70537 .58204 Metetra
.423 .584 .907 r
.70537 .58204 .70702 .58444 .71847 .58468 .71696 .58463 Metetra
.923 .548 .283 r
.71696 .58463 .71847 .58468 .73259 .62793 .73108 .62796 Metetra
.926 .556 .292 r
.73108 .62796 .73259 .62793 .74733 .67545 .74582 .67556 Metetra
.901 .501 .236 r
.74582 .67556 .74733 .67545 .7617 .71147 .76007 .70968 Metetra
.645 .763 .934 r
.76007 .70968 .7617 .71147 .77363 .70834 .77201 .70654 Metetra
.645 .763 .934 r
.77201 .70654 .77363 .70834 .78561 .70519 .784 .70339 Metetra
.645 .763 .934 r
.784 .70339 .78561 .70519 .79764 .70203 .79604 .70022 Metetra
.645 .763 .934 r
.79604 .70022 .79764 .70203 .80972 .69886 .80813 .69704 Metetra
.645 .763 .934 r
.80813 .69704 .80972 .69886 .82185 .69568 .82027 .69385 Metetra
.645 .763 .934 r
.82027 .69385 .82185 .69568 .83403 .69248 .83247 .69064 Metetra
.645 .763 .934 r
.83247 .69064 .83403 .69248 .84627 .68927 .84471 .68742 Metetra
.645 .763 .934 r
.84471 .68742 .84627 .68927 .85855 .68604 .85701 .68419 Metetra
.645 .763 .934 r
.85701 .68419 .85855 .68604 .87089 .6828 .86936 .68094 Metetra
.645 .763 .934 r
.86936 .68094 .87089 .6828 .88328 .67955 .88176 .67768 Metetra
.645 .763 .934 r
.88176 .67768 .88328 .67955 .89572 .67628 .89421 .67441 Metetra
.645 .763 .934 r
.89421 .67441 .89572 .67628 .90821 .673 .90672 .67112 Metetra
.645 .763 .934 r
.90672 .67112 .90821 .673 .92076 .66971 .91928 .66782 Metetra
.645 .763 .934 r
.91928 .66782 .92076 .66971 .93336 .6664 .93189 .6645 Metetra
.645 .763 .934 r
.93189 .6645 .93336 .6664 .94602 .66307 .94456 .66117 Metetra
.645 .763 .934 r
.94456 .66117 .94602 .66307 .95873 .65974 .95728 .65782 Metetra
.645 .763 .934 r
.95728 .65782 .95873 .65974 .97149 .65638 .97006 .65446 Metetra
.645 .763 .934 r
.97006 .65446 .97149 .65638 .98431 .65302 .98289 .65109 Metetra
.645 .763 .934 r
.98289 .65109 .98431 .65302 .99719 .64964 .99578 .6477 Metetra
.124 0 0 r
.3968 .62523 .3987 .62533 .40851 .6262 .40662 .6263 Metetra
.895 .932 .834 r
.40662 .6263 .40851 .6262 .41881 .61336 .4169 .6145 Metetra
.646 .185 .143 r
.4169 .6145 .41881 .61336 .42867 .6157 .42668 .61992 Metetra
.163 0 .142 r
.42668 .61992 .42867 .6157 .43892 .60469 .43693 .61017 Metetra
.048 0 .153 r
.43693 .61017 .43892 .60469 .4492 .5921 .44731 .59478 Metetra
.704 .872 .471 r
.44731 .59478 .4492 .5921 .45948 .57883 .45768 .57815 Metetra
.786 .888 .919 r
.45768 .57815 .45948 .57883 .46949 .58035 .46784 .57149 Metetra
.47 .376 .667 r
.46784 .57149 .46949 .58035 .47948 .58871 .4778 .5798 Metetra
.459 .369 .666 r
.4778 .5798 .47948 .58871 .48956 .59785 .48787 .58887 Metetra
.603 .467 .668 r
.48787 .58887 .48956 .59785 .49988 .59029 .49813 .58677 Metetra
.538 .55 .815 r
.49813 .58677 .49988 .59029 .51016 .59203 .50842 .58791 Metetra
.851 .492 0 r
.50842 .58791 .51016 .59203 .52048 .62475 .51872 .62059 Metetra
.69 .602 .753 r
.51872 .62059 .52048 .62475 .53099 .6193 .52923 .61446 Metetra
.694 .584 .729 r
.52923 .61446 .53099 .6193 .5415 .61004 .53975 .60713 Metetra
.601 .621 .844 r
.53975 .60713 .5415 .61004 .55208 .60833 .55033 .60599 Metetra
.862 .733 .719 r
.55033 .60599 .55208 .60833 .56251 .58923 .56078 .58688 Metetra
.866 .733 .713 r
.56078 .58688 .56251 .58923 .57287 .5693 .57116 .56694 Metetra
.839 .732 .746 r
.57116 .56694 .57287 .5693 .58325 .55413 .58155 .55185 Metetra
.739 .291 0 r
.58155 .55185 .58325 .55413 .59429 .5729 .59259 .57062 Metetra
.774 .331 0 r
.59259 .57062 .59429 .5729 .60555 .59332 .60384 .59103 Metetra
.804 .367 0 r
.60384 .59103 .60555 .59332 .61705 .61553 .61533 .61325 Metetra
.881 .743 .705 r
.61533 .61325 .61705 .61553 .6274 .59297 .62573 .59143 Metetra
.85 .4 0 r
.62573 .59143 .6274 .59297 .63921 .61648 .63748 .61335 Metetra
.96 .622 .274 r
.63748 .61335 .63921 .61648 .65287 .68475 .65111 .68161 Metetra
0 0 .378 r
.65111 .68161 .65287 .68475 .66512 .70476 .66341 .70282 Metetra
.919 .763 .671 r
.66341 .70282 .66512 .70476 .67547 .6759 .67377 .67395 Metetra
.922 .761 .664 r
.67377 .67395 .67547 .6759 .68563 .64585 .68396 .64387 Metetra
.926 .759 .656 r
.68396 .64387 .68563 .64585 .69561 .61457 .69395 .61257 Metetra
.929 .757 .649 r
.69395 .61257 .69561 .61457 .70537 .58204 .70374 .58002 Metetra
.425 .626 .937 r
.70374 .58002 .70537 .58204 .71696 .58463 .7153 .58186 Metetra
.906 .525 .088 r
.7153 .58186 .71696 .58463 .73108 .62796 .7294 .62518 Metetra
.915 .539 .113 r
.7294 .62518 .73108 .62796 .74582 .67556 .74413 .67278 Metetra
.842 .441 0 r
.74413 .67278 .74582 .67556 .76007 .70968 .75843 .70789 Metetra
.645 .763 .934 r
.75843 .70789 .76007 .70968 .77201 .70654 .77038 .70474 Metetra
.645 .763 .934 r
.77038 .70474 .77201 .70654 .784 .70339 .78238 .70158 Metetra
.645 .763 .934 r
.78238 .70158 .784 .70339 .79604 .70022 .79443 .69841 Metetra
.645 .763 .934 r
.79443 .69841 .79604 .70022 .80813 .69704 .80654 .69522 Metetra
.645 .763 .934 r
.80654 .69522 .80813 .69704 .82027 .69385 .81869 .69202 Metetra
.645 .763 .934 r
.81869 .69202 .82027 .69385 .83247 .69064 .83089 .68881 Metetra
.645 .763 .934 r
.83089 .68881 .83247 .69064 .84471 .68742 .84315 .68558 Metetra
.645 .763 .934 r
.84315 .68558 .84471 .68742 .85701 .68419 .85546 .68234 Metetra
.645 .763 .934 r
.85546 .68234 .85701 .68419 .86936 .68094 .86782 .67908 Metetra
.645 .763 .934 r
.86782 .67908 .86936 .68094 .88176 .67768 .88023 .67581 Metetra
.645 .763 .934 r
.88023 .67581 .88176 .67768 .89421 .67441 .8927 .67253 Metetra
.645 .763 .934 r
.8927 .67253 .89421 .67441 .90672 .67112 .90521 .66923 Metetra
.645 .763 .934 r
.90521 .66923 .90672 .67112 .91928 .66782 .91779 .66592 Metetra
.645 .763 .934 r
.91779 .66592 .91928 .66782 .93189 .6645 .93041 .6626 Metetra
.645 .763 .934 r
.93041 .6626 .93189 .6645 .94456 .66117 .94309 .65926 Metetra
.645 .763 .934 r
.94309 .65926 .94456 .66117 .95728 .65782 .95583 .6559 Metetra
.645 .763 .934 r
.95583 .6559 .95728 .65782 .97006 .65446 .96862 .65254 Metetra
.645 .763 .934 r
.96862 .65254 .97006 .65446 .98289 .65109 .98146 .64915 Metetra
.645 .763 .934 r
.98146 .64915 .98289 .65109 .99578 .6477 .99436 .64576 Metetra
.568 .572 .817 r
.39502 .62187 .3968 .62523 .40662 .6263 .40487 .622 Metetra
.747 .621 .719 r
.40487 .622 .40662 .6263 .4169 .6145 .41515 .61043 Metetra
.542 .523 .784 r
.41515 .61043 .4169 .6145 .42668 .61992 .42505 .61174 Metetra
.684 .527 .667 r
.42505 .61174 .42668 .61992 .43693 .61017 .43532 .60072 Metetra
.683 .517 .655 r
.43532 .60072 .43693 .61017 .44731 .59478 .44563 .5881 Metetra
.717 .563 .679 r
.44563 .5881 .44731 .59478 .45768 .57815 .45593 .57495 Metetra
.477 .535 .838 r
.45593 .57495 .45768 .57815 .46784 .57149 .46593 .57741 Metetra
.65 .341 .435 r
.46593 .57741 .46784 .57149 .4778 .5798 .47592 .58577 Metetra
.657 .348 .438 r
.47592 .58577 .4778 .5798 .48787 .58887 .48601 .59491 Metetra
.355 .061 .321 r
.48601 .59491 .48787 .58887 .49813 .58677 .49636 .58606 Metetra
0 .393 .72 r
.49636 .58606 .49813 .58677 .50842 .58791 .50664 .58956 Metetra
.868 .528 .404 r
.50664 .58956 .50842 .58791 .51872 .62059 .51694 .62234 Metetra
.51694 .62234 .51872 .62059 .52923 .61446 .52747 .61578 Metetra
.524 .866 .606 r
.52747 .61578 .52923 .61446 .53975 .60713 .53801 .60685 Metetra
.403 .838 .948 r
.53801 .60685 .53975 .60713 .55033 .60599 .5486 .60481 Metetra
.906 .802 .734 r
.5486 .60481 .55033 .60599 .56078 .58688 .55906 .58568 Metetra
.909 .799 .726 r
.55906 .58568 .56078 .58688 .57116 .56694 .56946 .56572 Metetra
.886 .813 .772 r
.56946 .56572 .57116 .56694 .58155 .55185 .57987 .55058 Metetra
.843 .38 .006 r
.57987 .55058 .58155 .55185 .59259 .57062 .5909 .56936 Metetra
.858 .406 .04 r
.5909 .56936 .59259 .57062 .60384 .59103 .60215 .58979 Metetra
.871 .429 .072 r
.60215 .58979 .60384 .59103 .61533 .61325 .61364 .61202 Metetra
.924 .799 .704 r
.61364 .61202 .61533 .61325 .62573 .59143 .62403 .58901 Metetra
.813 .386 0 r
.62403 .58901 .62573 .59143 .63748 .61335 .63585 .61333 Metetra
.94 .608 .374 r
.63585 .61333 .63748 .61335 .65111 .68161 .64947 .6817 Metetra
.837 .386 .15 r
.64947 .6817 .65111 .68161 .66341 .70282 .66166 .7001 Metetra
.895 .731 .67 r
.66166 .7001 .66341 .70282 .67377 .67395 .67204 .67121 Metetra
.9 .73 .663 r
.67204 .67121 .67377 .67395 .68396 .64387 .68225 .64113 Metetra
.904 .73 .657 r
.68225 .64113 .68396 .64387 .69395 .61257 .69226 .60982 Metetra
.907 .73 .65 r
.69226 .60982 .69395 .61257 .70374 .58002 .70207 .57726 Metetra
.34 .504 .874 r
.70207 .57726 .70374 .58002 .7153 .58186 .71379 .58208 Metetra
.92 .547 .296 r
.71379 .58208 .7153 .58186 .7294 .62518 .72789 .62549 Metetra
.923 .555 .304 r
.72789 .62549 .7294 .62518 .74413 .67278 .74263 .67317 Metetra
.894 .494 .248 r
.74263 .67317 .74413 .67278 .75843 .70789 .75679 .70609 Metetra
.645 .763 .934 r
.75679 .70609 .75843 .70789 .77038 .70474 .76875 .70294 Metetra
.645 .763 .934 r
.76875 .70294 .77038 .70474 .78238 .70158 .78076 .69977 Metetra
.645 .763 .934 r
.78076 .69977 .78238 .70158 .79443 .69841 .79282 .69659 Metetra
.645 .763 .934 r
.79282 .69659 .79443 .69841 .80654 .69522 .80494 .69339 Metetra
.645 .763 .934 r
.80494 .69339 .80654 .69522 .81869 .69202 .8171 .69018 Metetra
.645 .763 .934 r
.8171 .69018 .81869 .69202 .83089 .68881 .82932 .68696 Metetra
.645 .763 .934 r
.82932 .68696 .83089 .68881 .84315 .68558 .84159 .68373 Metetra
.645 .763 .934 r
.84159 .68373 .84315 .68558 .85546 .68234 .85391 .68048 Metetra
.645 .763 .934 r
.85391 .68048 .85546 .68234 .86782 .67908 .86628 .67722 Metetra
.645 .763 .934 r
.86628 .67722 .86782 .67908 .88023 .67581 .8787 .67394 Metetra
.645 .763 .934 r
.8787 .67394 .88023 .67581 .8927 .67253 .89118 .67065 Metetra
.645 .763 .934 r
.89118 .67065 .8927 .67253 .90521 .66923 .90371 .66734 Metetra
.645 .763 .934 r
.90371 .66734 .90521 .66923 .91779 .66592 .91629 .66402 Metetra
.645 .763 .934 r
.91629 .66402 .91779 .66592 .93041 .6626 .92893 .66069 Metetra
.645 .763 .934 r
.92893 .66069 .93041 .6626 .94309 .65926 .94162 .65734 Metetra
.645 .763 .934 r
.94162 .65734 .94309 .65926 .95583 .6559 .95437 .65398 Metetra
.645 .763 .934 r
.95437 .65398 .95583 .6559 .96862 .65254 .96717 .65061 Metetra
.645 .763 .934 r
.96717 .65061 .96862 .65254 .98146 .64915 .98003 .64721 Metetra
.645 .763 .934 r
.98003 .64721 .98146 .64915 .99436 .64576 .99295 .64381 Metetra
.106 .647 .847 r
.39312 .62151 .39502 .62187 .40487 .622 .40297 .6219 Metetra
.875 .924 .855 r
.40297 .6219 .40487 .622 .41515 .61043 .41324 .61133 Metetra
.574 .072 .024 r
.41324 .61133 .41515 .61043 .42505 .61174 .42307 .61505 Metetra
.022 0 0 r
.42307 .61505 .42505 .61174 .43532 .60072 .43334 .60556 Metetra
.004 0 .097 r
.43334 .60556 .43532 .60072 .44563 .5881 .44371 .59125 Metetra
.44371 .59125 .44563 .5881 .45593 .57495 .45411 .57441 Metetra
.73 .909 .957 r
.45411 .57441 .45593 .57495 .46593 .57741 .46426 .56916 Metetra
.459 .376 .675 r
.46426 .56916 .46593 .57741 .47592 .58577 .47424 .57747 Metetra
.446 .367 .674 r
.47424 .57747 .47592 .58577 .48601 .59491 .48431 .58656 Metetra
.623 .486 .674 r
.48431 .58656 .48601 .59491 .49636 .58606 .4946 .58267 Metetra
.464 .519 .83 r
.4946 .58267 .49636 .58606 .50664 .58956 .50489 .58565 Metetra
.871 .505 .014 r
.50489 .58565 .50664 .58956 .51694 .62234 .51517 .61839 Metetra
.721 .624 .75 r
.51517 .61839 .51694 .62234 .52747 .61578 .5257 .61029 Metetra
.66 .551 .721 r
.5257 .61029 .52747 .61578 .53801 .60685 .53625 .60499 Metetra
.632 .728 .917 r
.53625 .60499 .53801 .60685 .5486 .60481 .54685 .60264 Metetra
.868 .743 .722 r
.54685 .60264 .5486 .60481 .55906 .58568 .55733 .5835 Metetra
.873 .742 .716 r
.55733 .5835 .55906 .58568 .56946 .56572 .56774 .56352 Metetra
.847 .743 .749 r
.56774 .56352 .56946 .56572 .57987 .55058 .57816 .5482 Metetra
.724 .281 0 r
.57816 .5482 .57987 .55058 .5909 .56936 .58919 .56698 Metetra
.762 .322 0 r
.58919 .56698 .5909 .56936 .60215 .58979 .60044 .58741 Metetra
.794 .359 0 r
.60044 .58741 .60215 .58979 .61364 .61202 .61192 .60964 Metetra
.884 .738 .695 r
.61192 .60964 .61364 .61202 .62403 .58901 .62231 .58622 Metetra
.789 .375 0 r
.62231 .58622 .62403 .58901 .63585 .61333 .63416 .61146 Metetra
.956 .619 .322 r
.63416 .61146 .63585 .61333 .64947 .6817 .64775 .67987 Metetra
.74 .265 0 r
.64775 .67987 .64947 .6817 .66166 .7001 .65993 .69815 Metetra
.919 .762 .671 r
.65993 .69815 .66166 .7001 .67204 .67121 .67034 .66924 Metetra
.922 .76 .664 r
.67034 .66924 .67204 .67121 .68225 .64113 .68056 .63913 Metetra
.925 .759 .656 r
.68056 .63913 .68225 .64113 .69226 .60982 .6906 .6078 Metetra
.928 .757 .649 r
.6906 .6078 .69226 .60982 .70207 .57726 .70043 .57522 Metetra
.267 .537 .919 r
.70043 .57522 .70207 .57726 .71379 .58208 .71213 .57939 Metetra
.909 .527 .097 r
.71213 .57939 .71379 .58208 .72789 .62549 .72621 .62279 Metetra
.918 .541 .121 r
.72621 .62279 .72789 .62549 .74263 .67317 .74093 .67048 Metetra
.837 .431 0 r
.74093 .67048 .74263 .67317 .75679 .70609 .75514 .70429 Metetra
.645 .763 .934 r
.75514 .70429 .75679 .70609 .76875 .70294 .76711 .70113 Metetra
.645 .763 .934 r
.76711 .70113 .76875 .70294 .78076 .69977 .77914 .69795 Metetra
.645 .763 .934 r
.77914 .69795 .78076 .69977 .79282 .69659 .79121 .69476 Metetra
.645 .763 .934 r
.79121 .69476 .79282 .69659 .80494 .69339 .80334 .69156 Metetra
.645 .763 .934 r
.80334 .69156 .80494 .69339 .8171 .69018 .81551 .68834 Metetra
.645 .763 .934 r
.81551 .68834 .8171 .69018 .82932 .68696 .82774 .68512 Metetra
.645 .763 .934 r
.82774 .68512 .82932 .68696 .84159 .68373 .84002 .68187 Metetra
.645 .763 .934 r
.84002 .68187 .84159 .68373 .85391 .68048 .85235 .67862 Metetra
.645 .763 .934 r
.85235 .67862 .85391 .68048 .86628 .67722 .86473 .67534 Metetra
.645 .763 .934 r
.86473 .67534 .86628 .67722 .8787 .67394 .87717 .67206 Metetra
.645 .763 .934 r
.87717 .67206 .8787 .67394 .89118 .67065 .88966 .66876 Metetra
.645 .763 .934 r
.88966 .66876 .89118 .67065 .90371 .66734 .9022 .66545 Metetra
.645 .763 .934 r
.9022 .66545 .90371 .66734 .91629 .66402 .9148 .66212 Metetra
.645 .763 .934 r
.9148 .66212 .91629 .66402 .92893 .66069 .92745 .65878 Metetra
.645 .763 .934 r
.92745 .65878 .92893 .66069 .94162 .65734 .94015 .65542 Metetra
.645 .763 .934 r
.94015 .65542 .94162 .65734 .95437 .65398 .95291 .65205 Metetra
.645 .763 .934 r
.95291 .65205 .95437 .65398 .96717 .65061 .96573 .64867 Metetra
.645 .763 .934 r
.96573 .64867 .96717 .65061 .98003 .64721 .9786 .64527 Metetra
.645 .763 .934 r
.9786 .64527 .98003 .64721 .99295 .64381 .99152 .64186 Metetra
.574 .593 .835 r
.39132 .61846 .39312 .62151 .40297 .6219 .4012 .61827 Metetra
.754 .644 .739 r
.4012 .61827 .40297 .6219 .41324 .61133 .41147 .60776 Metetra
.555 .555 .808 r
.41147 .60776 .41324 .61133 .42307 .61505 .42139 .60837 Metetra
.697 .551 .685 r
.42139 .60837 .42307 .61505 .43334 .60556 .43168 .59798 Metetra
.702 .544 .671 r
.43168 .59798 .43334 .60556 .44371 .59125 .44201 .58534 Metetra
.733 .583 .687 r
.44201 .58534 .44371 .59125 .45411 .57441 .45234 .57172 Metetra
.494 .583 .873 r
.45234 .57172 .45411 .57441 .46426 .56916 .46237 .57321 Metetra
.669 .329 .389 r
.46237 .57321 .46426 .56916 .47424 .57747 .47237 .58156 Metetra
.677 .338 .393 r
.47237 .58156 .47424 .57747 .48431 .58656 .48245 .5907 Metetra
.211 0 .166 r
.48245 .5907 .48431 .58656 .4946 .58267 .49282 .58177 Metetra
0 .316 .686 r
.49282 .58177 .4946 .58267 .50489 .58565 .50311 .5864 Metetra
.889 .538 .375 r
.50311 .5864 .50489 .58565 .51517 .61839 .51339 .6192 Metetra
.678 .971 .783 r
.51339 .6192 .51517 .61839 .5257 .61029 .52393 .61069 Metetra
.604 .953 .86 r
.52393 .61069 .5257 .61029 .53625 .60499 .5345 .60457 Metetra
.556 .892 .984 r
.5345 .60457 .53625 .60499 .54685 .60264 .5451 .60143 Metetra
.905 .8 .734 r
.5451 .60143 .54685 .60264 .55733 .5835 .5556 .58227 Metetra
.908 .797 .726 r
.5556 .58227 .55733 .5835 .56774 .56352 .56603 .56227 Metetra
.888 .81 .766 r
.56603 .56227 .56774 .56352 .57816 .5482 .57646 .54667 Metetra
.828 .364 0 r
.57646 .54667 .57816 .5482 .58919 .56698 .58749 .56546 Metetra
.847 .392 0 r
.58749 .56546 .58919 .56698 .60044 .58741 .59873 .5859 Metetra
.863 .418 .031 r
.59873 .5859 .60044 .58741 .61192 .60964 .61022 .60814 Metetra
.918 .781 .694 r
.61022 .60814 .61192 .60964 .62231 .58622 .6206 .58368 Metetra
.849 .434 0 r
.6206 .58368 .62231 .58622 .63416 .61146 .63251 .61118 Metetra
.943 .609 .368 r
.63251 .61118 .63416 .61146 .64775 .67987 .64609 .67969 Metetra
.812 .335 .069 r
.64609 .67969 .64775 .67987 .65993 .69815 .65819 .69575 Metetra
.905 .744 .671 r
.65819 .69575 .65993 .69815 .67034 .66924 .66861 .66682 Metetra
.909 .743 .664 r
.66861 .66682 .67034 .66924 .68056 .63913 .67886 .6367 Metetra
.913 .742 .657 r
.67886 .6367 .68056 .63913 .6906 .6078 .68891 .60535 Metetra
.916 .741 .65 r
.68891 .60535 .6906 .6078 .70043 .57522 .69876 .57276 Metetra
.201 .45 .873 r
.69876 .57276 .70043 .57522 .71213 .57939 .71058 .57899 Metetra
.926 .549 .264 r
.71058 .57899 .71213 .57939 .72621 .62279 .72466 .62245 Metetra
.93 .557 .274 r
.72466 .62245 .72621 .62279 .74093 .67048 .73938 .67021 Metetra
.899 .487 .196 r
.73938 .67021 .74093 .67048 .75514 .70429 .75349 .70248 Metetra
.645 .763 .934 r
.75349 .70248 .75514 .70429 .76711 .70113 .76547 .69931 Metetra
.645 .763 .934 r
.76547 .69931 .76711 .70113 .77914 .69795 .77751 .69613 Metetra
.645 .763 .934 r
.77751 .69613 .77914 .69795 .79121 .69476 .78959 .69293 Metetra
.645 .763 .934 r
.78959 .69293 .79121 .69476 .80334 .69156 .80173 .68972 Metetra
.645 .763 .934 r
.80173 .68972 .80334 .69156 .81551 .68834 .81392 .6865 Metetra
.645 .763 .934 r
.81392 .6865 .81551 .68834 .82774 .68512 .82615 .68326 Metetra
.645 .763 .934 r
.82615 .68326 .82774 .68512 .84002 .68187 .83845 .68001 Metetra
.645 .763 .934 r
.83845 .68001 .84002 .68187 .85235 .67862 .85079 .67675 Metetra
.645 .763 .934 r
.85079 .67675 .85235 .67862 .86473 .67534 .86318 .67347 Metetra
.645 .763 .934 r
.86318 .67347 .86473 .67534 .87717 .67206 .87563 .67018 Metetra
.645 .763 .934 r
.87563 .67018 .87717 .67206 .88966 .66876 .88813 .66687 Metetra
.645 .763 .934 r
.88813 .66687 .88966 .66876 .9022 .66545 .90069 .66355 Metetra
.645 .763 .934 r
.90069 .66355 .9022 .66545 .9148 .66212 .9133 .66021 Metetra
.645 .763 .934 r
.9133 .66021 .9148 .66212 .92745 .65878 .92596 .65686 Metetra
.645 .763 .934 r
.92596 .65686 .92745 .65878 .94015 .65542 .93868 .6535 Metetra
.645 .763 .934 r
.93868 .6535 .94015 .65542 .95291 .65205 .95145 .65012 Metetra
.645 .763 .934 r
.95145 .65012 .95291 .65205 .96573 .64867 .96428 .64673 Metetra
.645 .763 .934 r
.96428 .64673 .96573 .64867 .9786 .64527 .97716 .64332 Metetra
.645 .763 .934 r
.97716 .64332 .9786 .64527 .99152 .64186 .9901 .6399 Metetra
.362 .709 .986 r
.38945 .61732 .39132 .61846 .4012 .61827 .3993 .61794 Metetra
.868 .899 .853 r
.3993 .61794 .4012 .61827 .41147 .60776 .40958 .60749 Metetra
.303 0 0 r
.40958 .60749 .41147 .60776 .42139 .60837 .41945 .61033 Metetra
.41945 .61033 .42139 .60837 .43168 .59798 .42973 .6008 Metetra
.42973 .6008 .43168 .59798 .44201 .58534 .44009 .58813 Metetra
.75 .889 .486 r
.44009 .58813 .44201 .58534 .45234 .57172 .45054 .57016 Metetra
.668 .765 .923 r
.45054 .57016 .45234 .57172 .46237 .57321 .46067 .56694 Metetra
.405 .373 .71 r
.46067 .56694 .46237 .57321 .47237 .58156 .47065 .57526 Metetra
.386 .361 .708 r
.47065 .57526 .47237 .58156 .48245 .5907 .48072 .58436 Metetra
.648 .527 .702 r
.48072 .58436 .48245 .5907 .49282 .58177 .49105 .57934 Metetra
.364 .543 .897 r
.49105 .57934 .49282 .58177 .50311 .5864 .50135 .58267 Metetra
.885 .515 .041 r
.50135 .58267 .50311 .5864 .51339 .6192 .51161 .61545 Metetra
.732 .636 .753 r
.51161 .61545 .51339 .6192 .52393 .61069 .52216 .60679 Metetra
.666 .601 .773 r
.52216 .60679 .52393 .61069 .5345 .60457 .53273 .60249 Metetra
.645 .709 .894 r
.53273 .60249 .5345 .60457 .5451 .60143 .54335 .59982 Metetra
.889 .775 .729 r
.54335 .59982 .5451 .60143 .5556 .58227 .55386 .58064 Metetra
.893 .773 .722 r
.55386 .58064 .5556 .58227 .56603 .56227 .56431 .56063 Metetra
.877 .779 .749 r
.56431 .56063 .56603 .56227 .57646 .54667 .57474 .54403 Metetra
.675 .247 0 r
.57474 .54403 .57646 .54667 .58749 .56546 .58576 .56281 Metetra
.72 .293 0 r
.58576 .56281 .58749 .56546 .59873 .5859 .597 .58324 Metetra
.759 .334 0 r
.597 .58324 .59873 .5859 .61022 .60814 .60848 .60548 Metetra
.877 .726 .691 r
.60848 .60548 .61022 .60814 .6206 .58368 .6189 .58163 Metetra
.874 .452 .03 r
.6189 .58163 .6206 .58368 .63251 .61118 .63078 .60859 Metetra
.959 .621 .296 r
.63078 .60859 .63251 .61118 .64609 .67969 .64433 .6771 Metetra
0 0 .428 r
.64433 .6771 .64609 .67969 .65819 .69575 .65648 .69442 Metetra
.939 .79 .67 r
.65648 .69442 .65819 .69575 .66861 .66682 .66693 .66547 Metetra
.941 .787 .662 r
.66693 .66547 .66861 .66682 .67886 .6367 .6772 .63532 Metetra
.944 .784 .654 r
.6772 .63532 .67886 .6367 .68891 .60535 .68728 .60394 Metetra
.946 .781 .645 r
.68728 .60394 .68891 .60535 .69876 .57276 .69715 .57131 Metetra
.065 .487 .892 r
.69715 .57131 .69876 .57276 .71058 .57899 .70888 .57592 Metetra
.896 .518 .063 r
.70888 .57592 .71058 .57899 .72466 .62245 .72295 .61937 Metetra
.907 .534 .09 r
.72295 .61937 .72466 .62245 .73938 .67021 .73765 .66711 Metetra
.8 .404 0 r
.73765 .66711 .73938 .67021 .75349 .70248 .75184 .70067 Metetra
.645 .763 .934 r
.75184 .70067 .75349 .70248 .76547 .69931 .76383 .6975 Metetra
.645 .763 .934 r
.76383 .6975 .76547 .69931 .77751 .69613 .77588 .69431 Metetra
.645 .763 .934 r
.77588 .69431 .77751 .69613 .78959 .69293 .78797 .6911 Metetra
.645 .763 .934 r
.78797 .6911 .78959 .69293 .80173 .68972 .80012 .68788 Metetra
.645 .763 .934 r
.80012 .68788 .80173 .68972 .81392 .6865 .81232 .68465 Metetra
.645 .763 .934 r
.81232 .68465 .81392 .6865 .82615 .68326 .82457 .68141 Metetra
.645 .763 .934 r
.82457 .68141 .82615 .68326 .83845 .68001 .83687 .67815 Metetra
.645 .763 .934 r
.83687 .67815 .83845 .68001 .85079 .67675 .84922 .67488 Metetra
.645 .763 .934 r
.84922 .67488 .85079 .67675 .86318 .67347 .86163 .67159 Metetra
.645 .763 .934 r
.86163 .67159 .86318 .67347 .87563 .67018 .87409 .66829 Metetra
.645 .763 .934 r
.87409 .66829 .87563 .67018 .88813 .66687 .8866 .66497 Metetra
.645 .763 .934 r
.8866 .66497 .88813 .66687 .90069 .66355 .89917 .66164 Metetra
.645 .763 .934 r
.89917 .66164 .90069 .66355 .9133 .66021 .91179 .6583 Metetra
.645 .763 .934 r
.91179 .6583 .9133 .66021 .92596 .65686 .92447 .65494 Metetra
.645 .763 .934 r
.92447 .65494 .92596 .65686 .93868 .6535 .9372 .65157 Metetra
.645 .763 .934 r
.9372 .65157 .93868 .6535 .95145 .65012 .94998 .64818 Metetra
.645 .763 .934 r
.94998 .64818 .95145 .65012 .96428 .64673 .96282 .64478 Metetra
.645 .763 .934 r
.96282 .64478 .96428 .64673 .97716 .64332 .97572 .64137 Metetra
.645 .763 .934 r
.97572 .64137 .97716 .64332 .9901 .6399 .98867 .63794 Metetra
.479 .517 .818 r
.38766 .61378 .38945 .61732 .3993 .61794 .39744 .61643 Metetra
.85 .772 .776 r
.39744 .61643 .3993 .61794 .40958 .60749 .40783 .60302 Metetra
.482 .474 .772 r
.40783 .60302 .40958 .60749 .41945 .61033 .41768 .60651 Metetra
.754 .639 .733 r
.41768 .60651 .41945 .61033 .42973 .6008 .428 .59554 Metetra
.737 .596 .699 r
.428 .59554 .42973 .6008 .44009 .58813 .43836 .58287 Metetra
.761 .609 .689 r
.43836 .58287 .44009 .58813 .45054 .57016 .44878 .56674 Metetra
.505 .537 .823 r
.44878 .56674 .45054 .57016 .46067 .56694 .45881 .56868 Metetra
.704 .292 .264 r
.45881 .56868 .46067 .56694 .47065 .57526 .4688 .57703 Metetra
.715 .307 .274 r
.4688 .57703 .47065 .57526 .48072 .58436 .47889 .58616 Metetra
.47889 .58616 .48072 .58436 .49105 .57934 .48924 .58015 Metetra
.308 0 0 r
.48924 .58015 .49105 .57934 .50135 .58267 .49958 .58035 Metetra
.932 .551 .195 r
.49958 .58035 .50135 .58267 .51161 .61545 .50983 .61313 Metetra
.7 .705 .851 r
.50983 .61313 .51161 .61545 .52216 .60679 .52038 .60849 Metetra
.52038 .60849 .52216 .60679 .53273 .60249 .53097 .59994 Metetra
.565 .636 .88 r
.53097 .59994 .53273 .60249 .54335 .59982 .5416 .59961 Metetra
.942 .871 .738 r
.5416 .59961 .54335 .59982 .55386 .58064 .55213 .58041 Metetra
.945 .865 .729 r
.55213 .58041 .55386 .58064 .56431 .56063 .5626 .56036 Metetra
.943 .87 .736 r
.5626 .56036 .56431 .56063 .57474 .54403 .57302 .54117 Metetra
.628 .217 0 r
.57302 .54117 .57474 .54403 .58576 .56281 .58403 .55993 Metetra
.68 .266 0 r
.58403 .55993 .58576 .56281 .597 .58324 .59527 .58036 Metetra
.725 .31 0 r
.59527 .58036 .597 .58324 .60848 .60548 .60674 .60259 Metetra
.857 .715 .705 r
.60674 .60259 .60848 .60548 .6189 .58163 .61725 .58179 Metetra
.869 .452 .226 r
.61725 .58179 .6189 .58163 .63078 .60859 .62901 .60445 Metetra
.955 .62 .231 r
.62901 .60445 .63078 .60859 .64433 .6771 .64252 .67289 Metetra
0 0 .504 r
.64252 .67289 .64433 .6771 .65648 .69442 .65484 .69492 Metetra
.985 .876 .642 r
.65484 .69492 .65648 .69442 .66693 .66547 .66531 .66591 Metetra
.986 .868 .633 r
.66531 .66591 .66693 .66547 .6772 .63532 .67561 .6357 Metetra
.987 .86 .624 r
.67561 .6357 .6772 .63532 .68728 .60394 .68571 .60426 Metetra
.988 .852 .616 r
.68571 .60426 .68728 .60394 .69715 .57131 .69561 .57157 Metetra
.179 0 0 r
.69561 .57157 .69715 .57131 .70888 .57592 .70715 .57223 Metetra
.863 .495 0 r
.70715 .57223 .70888 .57592 .72295 .61937 .7212 .61564 Metetra
.88 .515 .032 r
.7212 .61564 .72295 .61937 .73765 .66711 .73588 .66335 Metetra
.756 .383 0 r
.73588 .66335 .73765 .66711 .75184 .70067 .75018 .69886 Metetra
.645 .763 .934 r
.75018 .69886 .75184 .70067 .76383 .6975 .76218 .69568 Metetra
.645 .763 .934 r
.76218 .69568 .76383 .6975 .77588 .69431 .77424 .69248 Metetra
.645 .763 .934 r
.77424 .69248 .77588 .69431 .78797 .6911 .78635 .68927 Metetra
.645 .763 .934 r
.78635 .68927 .78797 .6911 .80012 .68788 .7985 .68604 Metetra
.645 .763 .934 r
.7985 .68604 .80012 .68788 .81232 .68465 .81071 .6828 Metetra
.645 .763 .934 r
.81071 .6828 .81232 .68465 .82457 .68141 .82298 .67955 Metetra
.645 .763 .934 r
.82298 .67955 .82457 .68141 .83687 .67815 .83529 .67628 Metetra
.645 .763 .934 r
.83529 .67628 .83687 .67815 .84922 .67488 .84766 .673 Metetra
.645 .763 .934 r
.84766 .673 .84922 .67488 .86163 .67159 .86007 .66971 Metetra
.645 .763 .934 r
.86007 .66971 .86163 .67159 .87409 .66829 .87255 .6664 Metetra
.645 .763 .934 r
.87255 .6664 .87409 .66829 .8866 .66497 .88507 .66307 Metetra
.645 .763 .934 r
.88507 .66307 .8866 .66497 .89917 .66164 .89765 .65974 Metetra
.645 .763 .934 r
.89765 .65974 .89917 .66164 .91179 .6583 .91028 .65638 Metetra
.645 .763 .934 r
.91028 .65638 .91179 .6583 .92447 .65494 .92297 .65302 Metetra
.645 .763 .934 r
.92297 .65302 .92447 .65494 .9372 .65157 .93571 .64964 Metetra
.645 .763 .934 r
.93571 .64964 .9372 .65157 .94998 .64818 .94851 .64624 Metetra
.645 .763 .934 r
.94851 .64624 .94998 .64818 .96282 .64478 .96136 .64283 Metetra
.645 .763 .934 r
.96136 .64283 .96282 .64478 .97572 .64137 .97427 .63941 Metetra
.645 .763 .934 r
.97427 .63941 .97572 .64137 .98867 .63794 .98724 .63597 Metetra
.214 .633 .953 r
.38578 .61266 .38766 .61378 .39744 .61643 .39559 .6144 Metetra
.814 .738 .78 r
.39559 .6144 .39744 .61643 .40783 .60302 .40593 .60291 Metetra
.398 0 0 r
.40593 .60291 .40783 .60302 .41768 .60651 .41579 .60612 Metetra
.866 .898 .855 r
.41579 .60612 .41768 .60651 .428 .59554 .42612 .59575 Metetra
.906 .94 .819 r
.42612 .59575 .428 .59554 .43836 .58287 .4365 .58306 Metetra
.94 .891 .753 r
.4365 .58306 .43836 .58287 .44878 .56674 .44697 .56544 Metetra
.495 .744 .983 r
.44697 .56544 .44878 .56674 .45881 .56868 .45705 .56498 Metetra
.201 .343 .784 r
.45705 .56498 .45881 .56868 .4688 .57703 .46704 .57332 Metetra
.156 .315 .774 r
.46704 .57332 .4688 .57703 .47889 .58616 .47712 .58243 Metetra
.69 .617 .769 r
.47712 .58243 .47889 .58616 .48924 .58015 .48748 .57684 Metetra
.492 .54 .834 r
.48748 .57684 .48924 .58015 .49958 .58035 .49779 .57899 Metetra
.929 .554 .271 r
.49779 .57899 .49958 .58035 .50983 .61313 .50803 .61179 Metetra
.767 .816 .891 r
.50803 .61179 .50983 .61313 .52038 .60849 .51861 .60523 Metetra
.719 .653 .783 r
.51861 .60523 .52038 .60849 .53097 .59994 .5292 .5984 Metetra
.545 .738 .965 r
.5292 .5984 .53097 .59994 .5416 .59961 .53983 .59748 Metetra
.87 .745 .722 r
.53983 .59748 .5416 .59961 .55213 .58041 .55038 .57826 Metetra
.874 .745 .716 r
.55038 .57826 .55213 .58041 .5626 .56036 .56087 .5582 Metetra
.869 .745 .724 r
.56087 .5582 .5626 .56036 .57302 .54117 .5713 .53939 Metetra
.808 .345 0 r
.5713 .53939 .57302 .54117 .58403 .55993 .58232 .55817 Metetra
.831 .377 0 r
.58232 .55817 .58403 .55993 .59527 .58036 .59355 .5786 Metetra
.85 .405 0 r
.59355 .5786 .59527 .58036 .60674 .60259 .60502 .60084 Metetra
.9 .773 .712 r
.60502 .60084 .60674 .60259 .61725 .58179 .61553 .57925 Metetra
.796 .37 0 r
.61553 .57925 .61725 .58179 .62901 .60445 .62732 .60317 Metetra
.952 .616 .341 r
.62732 .60317 .62901 .60445 .64252 .67289 .64081 .67168 Metetra
.831 .361 0 r
.64081 .67168 .64252 .67289 .65484 .69492 .65305 .69169 Metetra
.882 .713 .668 r
.65305 .69169 .65484 .69492 .66531 .66591 .66354 .66267 Metetra
.886 .714 .662 r
.66354 .66267 .66531 .66591 .67561 .6357 .67386 .63246 Metetra
.891 .714 .656 r
.67386 .63246 .67561 .6357 .68571 .60426 .68398 .60102 Metetra
.895 .714 .65 r
.68398 .60102 .68571 .60426 .69561 .57157 .6939 .56833 Metetra
.456 .535 .849 r
.6939 .56833 .69561 .57157 .70715 .57223 .70557 .57145 Metetra
.929 .548 .243 r
.70557 .57145 .70715 .57223 .7212 .61564 .71962 .61492 Metetra
.932 .557 .254 r
.71962 .61492 .7212 .61564 .73588 .66335 .73429 .66269 Metetra
.906 .496 .177 r
.73429 .66269 .73588 .66335 .75018 .69886 .74851 .69704 Metetra
.645 .763 .934 r
.74851 .69704 .75018 .69886 .76218 .69568 .76053 .69385 Metetra
.645 .763 .934 r
.76053 .69385 .76218 .69568 .77424 .69248 .7726 .69064 Metetra
.645 .763 .934 r
.7726 .69064 .77424 .69248 .78635 .68927 .78472 .68742 Metetra
.645 .763 .934 r
.78472 .68742 .78635 .68927 .7985 .68604 .79689 .68419 Metetra
.645 .763 .934 r
.79689 .68419 .7985 .68604 .81071 .6828 .80911 .68094 Metetra
.645 .763 .934 r
.80911 .68094 .81071 .6828 .82298 .67955 .82138 .67768 Metetra
.645 .763 .934 r
.82138 .67768 .82298 .67955 .83529 .67628 .83371 .67441 Metetra
.645 .763 .934 r
.83371 .67441 .83529 .67628 .84766 .673 .84608 .67112 Metetra
.645 .763 .934 r
.84608 .67112 .84766 .673 .86007 .66971 .85851 .66782 Metetra
.645 .763 .934 r
.85851 .66782 .86007 .66971 .87255 .6664 .871 .6645 Metetra
.645 .763 .934 r
.871 .6645 .87255 .6664 .88507 .66307 .88354 .66117 Metetra
.645 .763 .934 r
.88354 .66117 .88507 .66307 .89765 .65974 .89613 .65782 Metetra
.645 .763 .934 r
.89613 .65782 .89765 .65974 .91028 .65638 .90877 .65446 Metetra
.645 .763 .934 r
.90877 .65446 .91028 .65638 .92297 .65302 .92147 .65109 Metetra
.645 .763 .934 r
.92147 .65109 .92297 .65302 .93571 .64964 .93423 .6477 Metetra
.645 .763 .934 r
.93423 .6477 .93571 .64964 .94851 .64624 .94704 .6443 Metetra
.645 .763 .934 r
.94704 .6443 .94851 .64624 .96136 .64283 .9599 .64088 Metetra
.645 .763 .934 r
.9599 .64088 .96136 .64283 .97427 .63941 .97283 .63744 Metetra
.645 .763 .934 r
.97283 .63744 .97427 .63941 .98724 .63597 .9858 .634 Metetra
.328 .662 .973 r
.3839 .61131 .38578 .61266 .39559 .6144 .39373 .61268 Metetra
.832 .759 .782 r
.39373 .61268 .39559 .6144 .40593 .60291 .40411 .60046 Metetra
.395 .558 .897 r
.40411 .60046 .40593 .60291 .41579 .60612 .41398 .60322 Metetra
.776 .682 .76 r
.41398 .60322 .41579 .60612 .42612 .59575 .42433 .59259 Metetra
.787 .675 .74 r
.42433 .59259 .42612 .59575 .4365 .58306 .43471 .5799 Metetra
.81 .681 .722 r
.43471 .5799 .4365 .58306 .44697 .56544 .44515 .56419 Metetra
.406 .714 .986 r
.44515 .56419 .44697 .56544 .45705 .56498 .45523 .56463 Metetra
.692 .152 0 r
.45523 .56463 .45705 .56498 .46704 .57332 .46522 .57297 Metetra
.717 .188 0 r
.46522 .57297 .46704 .57332 .47712 .58243 .4753 .5821 Metetra
.765 .94 .94 r
.4753 .5821 .47712 .58243 .48748 .57684 .48568 .57562 Metetra
.244 .636 .96 r
.48568 .57562 .48748 .57684 .49779 .57899 .49601 .57747 Metetra
.93 .555 .26 r
.49601 .57747 .49779 .57899 .50803 .61179 .50624 .6103 Metetra
.756 .797 .886 r
.50624 .6103 .50803 .61179 .51861 .60523 .51682 .60406 Metetra
.795 .838 .884 r
.51682 .60406 .51861 .60523 .5292 .5984 .52742 .59647 Metetra
.596 .71 .924 r
.52742 .59647 .5292 .5984 .53983 .59748 .53806 .59498 Metetra
.858 .727 .717 r
.53806 .59498 .53983 .59748 .55038 .57826 .54863 .57575 Metetra
.862 .727 .712 r
.54863 .57575 .55038 .57826 .56087 .5582 .55913 .55568 Metetra
.848 .726 .729 r
.55913 .55568 .56087 .5582 .5713 .53939 .5696 .53845 Metetra
.854 .396 .065 r
.5696 .53845 .5713 .53939 .58232 .55817 .58061 .55724 Metetra
.866 .419 .094 r
.58061 .55724 .58232 .55817 .59355 .5786 .59185 .57769 Metetra
.877 .439 .121 r
.59185 .57769 .59355 .5786 .60502 .60084 .60331 .59995 Metetra
.934 .823 .711 r
.60331 .59995 .60502 .60084 .61553 .57925 .61382 .5776 Metetra
.869 .432 .036 r
.61382 .5776 .61553 .57925 .62732 .60317 .62562 .60188 Metetra
.952 .616 .34 r
.62562 .60188 .62732 .60317 .64081 .67168 .63909 .67045 Metetra
.827 .357 0 r
.63909 .67045 .64081 .67168 .65305 .69169 .65133 .69028 Metetra
.936 .787 .67 r
.65133 .69028 .65305 .69169 .66354 .66267 .66184 .66124 Metetra
.939 .784 .662 r
.66184 .66124 .66354 .66267 .67386 .63246 .67218 .631 Metetra
.942 .781 .654 r
.67218 .631 .67386 .63246 .68398 .60102 .68233 .59953 Metetra
.944 .778 .646 r
.68233 .59953 .68398 .60102 .6939 .56833 .69227 .5668 Metetra
.261 .604 .953 r
.69227 .5668 .6939 .56833 .70557 .57145 .70393 .56955 Metetra
.926 .542 .166 r
.70393 .56955 .70557 .57145 .71962 .61492 .71797 .61304 Metetra
.932 .553 .184 r
.71797 .61304 .71962 .61492 .73429 .66269 .73263 .66084 Metetra
.888 .473 .061 r
.73263 .66084 .73429 .66269 .74851 .69704 .74685 .69522 Metetra
.645 .763 .934 r
.74685 .69522 .74851 .69704 .76053 .69385 .75888 .69202 Metetra
.645 .763 .934 r
.75888 .69202 .76053 .69385 .7726 .69064 .77095 .68881 Metetra
.645 .763 .934 r
.77095 .68881 .7726 .69064 .78472 .68742 .78308 .68558 Metetra
.645 .763 .934 r
.78308 .68558 .78472 .68742 .79689 .68419 .79526 .68234 Metetra
.645 .763 .934 r
.79526 .68234 .79689 .68419 .80911 .68094 .8075 .67908 Metetra
.645 .763 .934 r
.8075 .67908 .80911 .68094 .82138 .67768 .81978 .67581 Metetra
.645 .763 .934 r
.81978 .67581 .82138 .67768 .83371 .67441 .83212 .67253 Metetra
.645 .763 .934 r
.83212 .67253 .83371 .67441 .84608 .67112 .84451 .66923 Metetra
.645 .763 .934 r
.84451 .66923 .84608 .67112 .85851 .66782 .85695 .66592 Metetra
.645 .763 .934 r
.85695 .66592 .85851 .66782 .871 .6645 .86945 .6626 Metetra
.645 .763 .934 r
.86945 .6626 .871 .6645 .88354 .66117 .882 .65926 Metetra
.645 .763 .934 r
.882 .65926 .88354 .66117 .89613 .65782 .8946 .6559 Metetra
.645 .763 .934 r
.8946 .6559 .89613 .65782 .90877 .65446 .90726 .65254 Metetra
.645 .763 .934 r
.90726 .65254 .90877 .65446 .92147 .65109 .91997 .64915 Metetra
.645 .763 .934 r
.91997 .64915 .92147 .65109 .93423 .6477 .93274 .64576 Metetra
.645 .763 .934 r
.93274 .64576 .93423 .6477 .94704 .6443 .94556 .64234 Metetra
.645 .763 .934 r
.94556 .64234 .94704 .6443 .9599 .64088 .95844 .63892 Metetra
.645 .763 .934 r
.95844 .63892 .9599 .64088 .97283 .63744 .97137 .63548 Metetra
.645 .763 .934 r
.97137 .63548 .97283 .63744 .9858 .634 .98436 .63202 Metetra
.417 .646 .952 r
.38203 .60954 .3839 .61131 .39373 .61268 .39187 .61084 Metetra
.821 .751 .786 r
.39187 .61084 .39373 .61268 .40411 .60046 .40223 .59934 Metetra
.053 .533 .89 r
.40223 .59934 .40411 .60046 .41398 .60322 .41211 .6022 Metetra
.845 .829 .831 r
.41211 .6022 .41398 .60322 .42433 .59259 .42246 .59172 Metetra
.873 .833 .804 r
.42246 .59172 .42433 .59259 .43471 .5799 .43287 .57901 Metetra
.898 .813 .757 r
.43287 .57901 .43471 .5799 .44515 .56419 .44335 .56227 Metetra
.539 .682 .931 r
.44335 .56227 .44515 .56419 .45523 .56463 .45344 .562 Metetra
0 .273 .778 r
.45344 .562 .45523 .56463 .46522 .57297 .46343 .57033 Metetra
0 .226 .747 r
.46343 .57033 .46522 .57297 .4753 .5821 .47351 .57945 Metetra
.724 .686 .813 r
.47351 .57945 .4753 .5821 .48568 .57562 .4839 .57328 Metetra
.407 .578 .908 r
.4839 .57328 .48568 .57562 .49601 .57747 .49422 .57575 Metetra
.932 .555 .245 r
.49422 .57575 .49601 .57747 .50624 .6103 .50444 .60858 Metetra
.76 .775 .865 r
.50444 .60858 .50624 .6103 .51682 .60406 .51503 .60191 Metetra
.757 .734 .832 r
.51503 .60191 .51682 .60406 .52742 .59647 .52565 .59469 Metetra
.579 .721 .94 r
.52565 .59469 .52742 .59647 .53806 .59498 .53629 .59343 Metetra
.892 .78 .73 r
.53629 .59343 .53806 .59498 .54863 .57575 .54688 .57418 Metetra
.896 .778 .723 r
.54688 .57418 .54863 .57575 .55913 .55568 .55739 .55409 Metetra
.887 .782 .74 r
.55739 .55409 .55913 .55568 .5696 .53845 .56787 .53624 Metetra
.757 .304 0 r
.56787 .53624 .5696 .53845 .58061 .55724 .57888 .55503 Metetra
.789 .343 0 r
.57888 .55503 .58061 .55724 .59185 .57769 .59011 .57549 Metetra
.817 .377 0 r
.59011 .57549 .59185 .57769 .60331 .59995 .60158 .59775 Metetra
.886 .749 .705 r
.60158 .59775 .60331 .59995 .61382 .5776 .61211 .57569 Metetra
.854 .417 0 r
.61211 .57569 .61382 .5776 .62562 .60188 .6239 .59979 Metetra
.957 .62 .315 r
.6239 .59979 .62562 .60188 .63909 .67045 .63735 .66839 Metetra
.744 .282 0 r
.63735 .66839 .63909 .67045 .65133 .69028 .64957 .68799 Metetra
.909 .749 .671 r
.64957 .68799 .65133 .69028 .66184 .66124 .66011 .65893 Metetra
.913 .748 .664 r
.66011 .65893 .66184 .66124 .67218 .631 .67046 .62867 Metetra
.916 .747 .656 r
.67046 .62867 .67218 .631 .68233 .59953 .68063 .59718 Metetra
.92 .746 .649 r
.68063 .59718 .68233 .59953 .69227 .5668 .69059 .56444 Metetra
.358 .556 .909 r
.69059 .56444 .69227 .5668 .70393 .56955 .7023 .56796 Metetra
.929 .545 .189 r
.7023 .56796 .70393 .56955 .71797 .61304 .71633 .61148 Metetra
.933 .555 .206 r
.71633 .61148 .71797 .61304 .73263 .66084 .73098 .65931 Metetra
.895 .48 .093 r
.73098 .65931 .73263 .66084 .74685 .69522 .74518 .69339 Metetra
.645 .763 .934 r
.74518 .69339 .74685 .69522 .75888 .69202 .75722 .69018 Metetra
.645 .763 .934 r
.75722 .69018 .75888 .69202 .77095 .68881 .76931 .68696 Metetra
.645 .763 .934 r
.76931 .68696 .77095 .68881 .78308 .68558 .78145 .68373 Metetra
.645 .763 .934 r
.78145 .68373 .78308 .68558 .79526 .68234 .79364 .68048 Metetra
.645 .763 .934 r
.79364 .68048 .79526 .68234 .8075 .67908 .80588 .67722 Metetra
.645 .763 .934 r
.80588 .67722 .8075 .67908 .81978 .67581 .81818 .67394 Metetra
.645 .763 .934 r
.81818 .67394 .81978 .67581 .83212 .67253 .83053 .67065 Metetra
.645 .763 .934 r
.83053 .67065 .83212 .67253 .84451 .66923 .84293 .66734 Metetra
.645 .763 .934 r
.84293 .66734 .84451 .66923 .85695 .66592 .85538 .66402 Metetra
.645 .763 .934 r
.85538 .66402 .85695 .66592 .86945 .6626 .86789 .66069 Metetra
.645 .763 .934 r
.86789 .66069 .86945 .6626 .882 .65926 .88045 .65734 Metetra
.645 .763 .934 r
.88045 .65734 .882 .65926 .8946 .6559 .89307 .65398 Metetra
.645 .763 .934 r
.89307 .65398 .8946 .6559 .90726 .65254 .90574 .65061 Metetra
.645 .763 .934 r
.90574 .65061 .90726 .65254 .91997 .64915 .91846 .64721 Metetra
.645 .763 .934 r
.91846 .64721 .91997 .64915 .93274 .64576 .93124 .64381 Metetra
.645 .763 .934 r
.93124 .64381 .93274 .64576 .94556 .64234 .94408 .64039 Metetra
.645 .763 .934 r
.94408 .64039 .94556 .64234 .95844 .63892 .95697 .63695 Metetra
.645 .763 .934 r
.95697 .63695 .95844 .63892 .97137 .63548 .96992 .6335 Metetra
.645 .763 .934 r
.96992 .6335 .97137 .63548 .98436 .63202 .98292 .63004 Metetra
.312 .632 .963 r
.38015 .60802 .38203 .60954 .39187 .61084 .38997 .60988 Metetra
.87 .819 .796 r
.38997 .60988 .39187 .61084 .40223 .59934 .40041 .59683 Metetra
.348 .528 .891 r
.40041 .59683 .40223 .59934 .41211 .6022 .41026 .60032 Metetra
.811 .751 .797 r
.41026 .60032 .41211 .6022 .42246 .59172 .42063 .58984 Metetra
.832 .751 .774 r
.42063 .58984 .42246 .59172 .43287 .57901 .43104 .57711 Metetra
.857 .748 .742 r
.43104 .57711 .43287 .57901 .44335 .56227 .44153 .56074 Metetra
.515 .721 .966 r
.44153 .56074 .44335 .56227 .45344 .562 .45163 .56036 Metetra
0 .102 .587 r
.45163 .56036 .45344 .562 .46343 .57033 .46162 .5687 Metetra
0 .042 .526 r
.46162 .5687 .46343 .57033 .47351 .57945 .47171 .57781 Metetra
.733 .774 .886 r
.47171 .57781 .47351 .57945 .4839 .57328 .48209 .57245 Metetra
.266 .702 .963 r
.48209 .57245 .4839 .57328 .49422 .57575 .49244 .57309 Metetra
.928 .548 .165 r
.49244 .57309 .49422 .57575 .50444 .60858 .50264 .60592 Metetra
.717 .686 .82 r
.50264 .60592 .50444 .60858 .51503 .60191 .51324 .60011 Metetra
.768 .769 .853 r
.51324 .60011 .51503 .60191 .52565 .59469 .52386 .59286 Metetra
.592 .721 .933 r
.52386 .59286 .52565 .59469 .53629 .59343 .53452 .59136 Metetra
.873 .749 .723 r
.53452 .59136 .53629 .59343 .54688 .57418 .54512 .57209 Metetra
.877 .749 .717 r
.54512 .57209 .54688 .57418 .55739 .55409 .55565 .55199 Metetra
.864 .75 .736 r
.55565 .55199 .55739 .55409 .56787 .53624 .56615 .53468 Metetra
.827 .363 0 r
.56615 .53468 .56787 .53624 .57888 .55503 .57716 .55348 Metetra
.846 .392 0 r
.57716 .55348 .57888 .55503 .59011 .57549 .58839 .57395 Metetra
.862 .417 .029 r
.58839 .57395 .59011 .57549 .60158 .59775 .59985 .59622 Metetra
.911 .785 .709 r
.59985 .59622 .60158 .59775 .61211 .57569 .61039 .57384 Metetra
.86 .424 .005 r
.61039 .57384 .61211 .57569 .6239 .59979 .62219 .59816 Metetra
.955 .618 .33 r
.62219 .59816 .6239 .59979 .63735 .66839 .63561 .66681 Metetra
.817 .351 0 r
.63561 .66681 .63735 .66839 .64957 .68799 .64787 .68745 Metetra
.962 .828 .664 r
.64787 .68745 .64957 .68799 .66011 .65893 .65843 .65835 Metetra
.964 .823 .655 r
.65843 .65835 .66011 .65893 .67046 .62867 .66881 .62804 Metetra
.965 .817 .646 r
.66881 .62804 .67046 .62867 .68063 .59718 .67901 .59651 Metetra
.967 .812 .638 r
.67901 .59651 .68063 .59718 .69059 .56444 .689 .56373 Metetra
.156 .65 .915 r
.689 .56373 .69059 .56444 .7023 .56796 .70059 .56495 Metetra
.899 .521 .071 r
.70059 .56495 .7023 .56796 .71633 .61148 .71461 .60846 Metetra
.91 .536 .098 r
.71461 .60846 .71633 .61148 .73098 .65931 .72924 .65627 Metetra
.828 .431 0 r
.72924 .65627 .73098 .65931 .74518 .69339 .7435 .69156 Metetra
.645 .763 .934 r
.7435 .69156 .74518 .69339 .75722 .69018 .75555 .68834 Metetra
.645 .763 .934 r
.75555 .68834 .75722 .69018 .76931 .68696 .76765 .68512 Metetra
.645 .763 .934 r
.76765 .68512 .76931 .68696 .78145 .68373 .77981 .68187 Metetra
.645 .763 .934 r
.77981 .68187 .78145 .68373 .79364 .68048 .79201 .67862 Metetra
.645 .763 .934 r
.79201 .67862 .79364 .68048 .80588 .67722 .80426 .67534 Metetra
.645 .763 .934 r
.80426 .67534 .80588 .67722 .81818 .67394 .81657 .67206 Metetra
.645 .763 .934 r
.81657 .67206 .81818 .67394 .83053 .67065 .82893 .66876 Metetra
.645 .763 .934 r
.82893 .66876 .83053 .67065 .84293 .66734 .84135 .66545 Metetra
.645 .763 .934 r
.84135 .66545 .84293 .66734 .85538 .66402 .85381 .66212 Metetra
.645 .763 .934 r
.85381 .66212 .85538 .66402 .86789 .66069 .86633 .65878 Metetra
.645 .763 .934 r
.86633 .65878 .86789 .66069 .88045 .65734 .8789 .65542 Metetra
.645 .763 .934 r
.8789 .65542 .88045 .65734 .89307 .65398 .89153 .65205 Metetra
.645 .763 .934 r
.89153 .65205 .89307 .65398 .90574 .65061 .90421 .64867 Metetra
.645 .763 .934 r
.90421 .64867 .90574 .65061 .91846 .64721 .91695 .64527 Metetra
.645 .763 .934 r
.91695 .64527 .91846 .64721 .93124 .64381 .92974 .64186 Metetra
.645 .763 .934 r
.92974 .64186 .93124 .64381 .94408 .64039 .94259 .63843 Metetra
.645 .763 .934 r
.94259 .63843 .94408 .64039 .95697 .63695 .9555 .63498 Metetra
.645 .763 .934 r
.9555 .63498 .95697 .63695 .96992 .6335 .96846 .63152 Metetra
.645 .763 .934 r
.96846 .63152 .96992 .6335 .98292 .63004 .98148 .62805 Metetra
.388 .61 .938 r
.37828 .60606 .38015 .60802 .38997 .60988 .38811 .60801 Metetra
.837 .749 .766 r
.38811 .60801 .38997 .60988 .40041 .59683 .39857 .59446 Metetra
.359 .549 .903 r
.39857 .59446 .40041 .59683 .41026 .60032 .40844 .59754 Metetra
.781 .69 .764 r
.40844 .59754 .41026 .60032 .42063 .58984 .41882 .58687 Metetra
.794 .685 .745 r
.41882 .58687 .42063 .58984 .43104 .57711 .42924 .57414 Metetra
.813 .69 .728 r
.42924 .57414 .43104 .57711 .44153 .56074 .43972 .55881 Metetra
.46 .648 .94 r
.43972 .55881 .44153 .56074 .45163 .56036 .44979 .55979 Metetra
.671 .12 0 r
.44979 .55979 .45163 .56036 .46162 .5687 .45979 .56814 Metetra
.701 .161 0 r
.45979 .56814 .46162 .5687 .47171 .57781 .46988 .57726 Metetra
.759 .913 .943 r
.46988 .57726 .47171 .57781 .48209 .57245 .48028 .57115 Metetra
.418 .717 .986 r
.48028 .57115 .48209 .57245 .49244 .57309 .49064 .5715 Metetra
.931 .555 .256 r
.49064 .5715 .49244 .57309 .50264 .60592 .50084 .60435 Metetra
.738 .788 .893 r
.50084 .60435 .50264 .60592 .51324 .60011 .51144 .59875 Metetra
.785 .816 .877 r
.51144 .59875 .51324 .60011 .52386 .59286 .52208 .59135 Metetra
.588 .758 .96 r
.52208 .59135 .52386 .59286 .53452 .59136 .53274 .58962 Metetra
.885 .769 .728 r
.53274 .58962 .53452 .59136 .54512 .57209 .54336 .57034 Metetra
.889 .767 .721 r
.54336 .57034 .54512 .57209 .55565 .55199 .55391 .55023 Metetra
.877 .771 .742 r
.55391 .55023 .55565 .55199 .56615 .53468 .56442 .53294 Metetra
.812 .349 0 r
.56442 .53294 .56615 .53468 .57716 .55348 .57543 .55175 Metetra
.835 .381 0 r
.57543 .55175 .57716 .55348 .58839 .57395 .58666 .57222 Metetra
.853 .408 0 r
.58666 .57222 .58839 .57395 .59985 .59622 .59811 .5945 Metetra
.905 .774 .706 r
.59811 .5945 .59985 .59622 .61039 .57384 .60867 .57183 Metetra
.857 .424 0 r
.60867 .57183 .61039 .57384 .62219 .59816 .62047 .59669 Metetra
.953 .617 .335 r
.62047 .59669 .62219 .59816 .63561 .66681 .63387 .66538 Metetra
.826 .36 0 r
.63387 .66538 .63561 .66681 .64787 .68745 .64613 .68594 Metetra
.934 .783 .67 r
.64613 .68594 .64787 .68745 .65843 .65835 .65671 .65681 Metetra
.936 .78 .662 r
.65671 .65681 .65843 .65835 .66881 .62804 .66712 .62648 Metetra
.939 .778 .654 r
.66712 .62648 .66881 .62804 .67901 .59651 .67734 .59492 Metetra
.942 .775 .646 r
.67734 .59492 .67901 .59651 .689 .56373 .68735 .56211 Metetra
.427 .684 .971 r
.68735 .56211 .689 .56373 .70059 .56495 .69894 .56296 Metetra
.925 .541 .16 r
.69894 .56296 .70059 .56495 .71461 .60846 .71294 .60649 Metetra
.931 .552 .179 r
.71294 .60649 .71461 .60846 .72924 .65627 .72756 .65433 Metetra
.89 .479 .063 r
.72756 .65433 .72924 .65627 .7435 .69156 .74183 .68972 Metetra
.645 .763 .934 r
.74183 .68972 .7435 .69156 .75555 .68834 .75389 .6865 Metetra
.645 .763 .934 r
.75389 .6865 .75555 .68834 .76765 .68512 .766 .68326 Metetra
.645 .763 .934 r
.766 .68326 .76765 .68512 .77981 .68187 .77816 .68001 Metetra
.645 .763 .934 r
.77816 .68001 .77981 .68187 .79201 .67862 .79038 .67675 Metetra
.645 .763 .934 r
.79038 .67675 .79201 .67862 .80426 .67534 .80264 .67347 Metetra
.645 .763 .934 r
.80264 .67347 .80426 .67534 .81657 .67206 .81496 .67018 Metetra
.645 .763 .934 r
.81496 .67018 .81657 .67206 .82893 .66876 .82733 .66687 Metetra
.645 .763 .934 r
.82733 .66687 .82893 .66876 .84135 .66545 .83976 .66355 Metetra
.645 .763 .934 r
.83976 .66355 .84135 .66545 .85381 .66212 .85224 .66021 Metetra
.645 .763 .934 r
.85224 .66021 .85381 .66212 .86633 .65878 .86477 .65686 Metetra
.645 .763 .934 r
.86477 .65686 .86633 .65878 .8789 .65542 .87735 .6535 Metetra
.645 .763 .934 r
.87735 .6535 .8789 .65542 .89153 .65205 .88999 .65012 Metetra
.645 .763 .934 r
.88999 .65012 .89153 .65205 .90421 .64867 .90269 .64673 Metetra
.645 .763 .934 r
.90269 .64673 .90421 .64867 .91695 .64527 .91544 .64332 Metetra
.645 .763 .934 r
.91544 .64332 .91695 .64527 .92974 .64186 .92824 .6399 Metetra
.645 .763 .934 r
.92824 .6399 .92974 .64186 .94259 .63843 .9411 .63646 Metetra
.645 .763 .934 r
.9411 .63646 .94259 .63843 .9555 .63498 .95402 .63301 Metetra
.645 .763 .934 r
.95402 .63301 .9555 .63498 .96846 .63152 .96699 .62954 Metetra
.645 .763 .934 r
.96699 .62954 .96846 .63152 .98148 .62805 .98003 .62606 Metetra
.091 .568 .905 r
.37637 .60501 .37828 .60606 .38811 .60801 .38618 .60738 Metetra
.891 .841 .789 r
.38618 .60738 .38811 .60801 .39857 .59446 .39669 .59313 Metetra
0 .419 .829 r
.39669 .59313 .39857 .59446 .40844 .59754 .40653 .59744 Metetra
.865 .934 .867 r
.40653 .59744 .40844 .59754 .41882 .58687 .4169 .58736 Metetra
.905 .964 .814 r
.4169 .58736 .41882 .58687 .42924 .57414 .42734 .57461 Metetra
.944 .917 .757 r
.42734 .57461 .42924 .57414 .43972 .55881 .43788 .55756 Metetra
.581 .784 .976 r
.43788 .55756 .43972 .55881 .44979 .55979 .44803 .55578 Metetra
.237 .349 .776 r
.44803 .55578 .44979 .55979 .45979 .56814 .45802 .56411 Metetra
.197 .323 .767 r
.45802 .56411 .45979 .56814 .46988 .57726 .4681 .57322 Metetra
.655 .589 .768 r
.4681 .57322 .46988 .57726 .48028 .57115 .47848 .56941 Metetra
.568 .719 .944 r
.47848 .56941 .48028 .57115 .49064 .5715 .48886 .56836 Metetra
.916 .538 .116 r
.48886 .56836 .49064 .5715 .50084 .60435 .49904 .60119 Metetra
.703 .653 .797 r
.49904 .60119 .50084 .60435 .51144 .59875 .50965 .59549 Metetra
.704 .648 .791 r
.50965 .59549 .51144 .59875 .52208 .59135 .52029 .58958 Metetra
.619 .739 .932 r
.52029 .58958 .52208 .59135 .53274 .58962 .53096 .58741 Metetra
.868 .743 .722 r
.53096 .58741 .53274 .58962 .54336 .57034 .54159 .56812 Metetra
.873 .742 .715 r
.54159 .56812 .54336 .57034 .55391 .55023 .55215 .54799 Metetra
.856 .743 .738 r
.55215 .54799 .55391 .55023 .56442 .53294 .56269 .53116 Metetra
.809 .346 0 r
.56269 .53116 .56442 .53294 .57543 .55175 .5737 .54997 Metetra
.832 .378 0 r
.5737 .54997 .57543 .55175 .58666 .57222 .58492 .57045 Metetra
.851 .406 0 r
.58492 .57045 .58666 .57222 .59811 .5945 .59637 .59274 Metetra
.906 .771 .702 r
.59637 .59274 .59811 .5945 .60867 .57183 .60693 .56947 Metetra
.844 .419 0 r
.60693 .56947 .60867 .57183 .62047 .59669 .61875 .59516 Metetra
.954 .617 .334 r
.61875 .59516 .62047 .59669 .63387 .66538 .63213 .66391 Metetra
.829 .365 0 r
.63213 .66391 .63387 .66538 .64613 .68594 .64441 .68492 Metetra
.948 .805 .668 r
.64441 .68492 .64613 .68594 .65671 .65681 .65501 .65576 Metetra
.951 .801 .66 r
.65501 .65576 .65671 .65681 .66712 .62648 .66544 .62539 Metetra
.953 .797 .651 r
.66544 .62539 .66712 .62648 .67734 .59492 .67568 .59379 Metetra
.955 .793 .643 r
.67568 .59379 .67734 .59492 .68735 .56211 .68572 .56094 Metetra
.485 .776 .996 r
.68572 .56094 .68735 .56211 .69894 .56296 .69723 .56002 Metetra
.902 .523 .079 r
.69723 .56002 .69894 .56296 .71294 .60649 .71122 .60354 Metetra
.913 .538 .105 r
.71122 .60354 .71294 .60649 .72756 .65433 .72582 .65137 Metetra
.846 .449 0 r
.72582 .65137 .72756 .65433 .74183 .68972 .74014 .68788 Metetra
.645 .763 .934 r
.74014 .68788 .74183 .68972 .75389 .6865 .75222 .68465 Metetra
.645 .763 .934 r
.75222 .68465 .75389 .6865 .766 .68326 .76434 .68141 Metetra
.645 .763 .934 r
.76434 .68141 .766 .68326 .77816 .68001 .77651 .67815 Metetra
.645 .763 .934 r
.77651 .67815 .77816 .68001 .79038 .67675 .78874 .67488 Metetra
.645 .763 .934 r
.78874 .67488 .79038 .67675 .80264 .67347 .80102 .67159 Metetra
.645 .763 .934 r
.80102 .67159 .80264 .67347 .81496 .67018 .81335 .66829 Metetra
.645 .763 .934 r
.81335 .66829 .81496 .67018 .82733 .66687 .82573 .66497 Metetra
.645 .763 .934 r
.82573 .66497 .82733 .66687 .83976 .66355 .83817 .66164 Metetra
.645 .763 .934 r
.83817 .66164 .83976 .66355 .85224 .66021 .85066 .6583 Metetra
.645 .763 .934 r
.85066 .6583 .85224 .66021 .86477 .65686 .8632 .65494 Metetra
.645 .763 .934 r
.8632 .65494 .86477 .65686 .87735 .6535 .8758 .65157 Metetra
.645 .763 .934 r
.8758 .65157 .87735 .6535 .88999 .65012 .88845 .64818 Metetra
.645 .763 .934 r
.88845 .64818 .88999 .65012 .90269 .64673 .90116 .64478 Metetra
.645 .763 .934 r
.90116 .64478 .90269 .64673 .91544 .64332 .91392 .64137 Metetra
.645 .763 .934 r
.91392 .64137 .91544 .64332 .92824 .6399 .92674 .63794 Metetra
.645 .763 .934 r
.92674 .63794 .92824 .6399 .9411 .63646 .93961 .63449 Metetra
.645 .763 .934 r
.93961 .63449 .9411 .63646 .95402 .63301 .95254 .63103 Metetra
.645 .763 .934 r
.95254 .63103 .95402 .63301 .96699 .62954 .96553 .62755 Metetra
.645 .763 .934 r
.96553 .62755 .96699 .62954 .98003 .62606 .97857 .62406 Metetra
.405 .584 .914 r
.37451 .60275 .37637 .60501 .38618 .60738 .38433 .60498 Metetra
.827 .717 .743 r
.38433 .60498 .38618 .60738 .39669 .59313 .39487 .59012 Metetra
.423 .525 .857 r
.39487 .59012 .39669 .59313 .40653 .59744 .40475 .59322 Metetra
.742 .623 .727 r
.40475 .59322 .40653 .59744 .4169 .58736 .41514 .58254 Metetra
.747 .611 .707 r
.41514 .58254 .4169 .58736 .42734 .57461 .42559 .56979 Metetra
.759 .617 .701 r
.42559 .56979 .42734 .57461 .43788 .55756 .43606 .55547 Metetra
.436 .619 .928 r
.43606 .55547 .43788 .55756 .44803 .55578 .44614 .55703 Metetra
.71 .272 .208 r
.44614 .55703 .44803 .55578 .45802 .56411 .45614 .56538 Metetra
.723 .29 .221 r
.45614 .56538 .45802 .56411 .4681 .57322 .46623 .57451 Metetra
.46623 .57451 .4681 .57322 .47848 .56941 .47666 .56844 Metetra
.474 .789 .999 r
.47666 .56844 .47848 .56941 .48886 .56836 .48705 .5675 Metetra
.921 .552 .302 r
.48705 .5675 .48886 .56836 .49904 .60119 .49722 .60036 Metetra
.727 .881 .952 r
.49722 .60036 .49904 .60119 .50965 .59549 .50784 .59512 Metetra
.779 .941 .932 r
.50784 .59512 .50965 .59549 .52029 .58958 .51849 .58809 Metetra
.62 .773 .954 r
.51849 .58809 .52029 .58958 .53096 .58741 .52917 .58569 Metetra
.886 .77 .728 r
.52917 .58569 .53096 .58741 .54159 .56812 .53982 .56638 Metetra
.89 .768 .721 r
.53982 .56638 .54159 .56812 .55215 .54799 .5504 .54623 Metetra
.873 .773 .749 r
.5504 .54623 .55215 .54799 .56269 .53116 .56096 .52966 Metetra
.831 .367 0 r
.56096 .52966 .56269 .53116 .5737 .54997 .57196 .54848 Metetra
.849 .395 .006 r
.57196 .54848 .5737 .54997 .58492 .57045 .58318 .56897 Metetra
.865 .42 .041 r
.58318 .56897 .58492 .57045 .59637 .59274 .59463 .59128 Metetra
.917 .787 .701 r
.59463 .59128 .59637 .59274 .60693 .56947 .60521 .56769 Metetra
.879 .452 .054 r
.60521 .56769 .60693 .56947 .61875 .59516 .61703 .59379 Metetra
.953 .616 .338 r
.61703 .59379 .61875 .59516 .63213 .66391 .63039 .6626 Metetra
.835 .369 0 r
.63039 .6626 .63213 .66391 .64441 .68492 .64265 .6833 Metetra
.93 .778 .671 r
.64265 .6833 .64441 .68492 .65501 .65576 .65328 .65411 Metetra
.933 .776 .663 r
.65328 .65411 .65501 .65576 .66544 .62539 .66374 .62372 Metetra
.936 .773 .655 r
.66374 .62372 .66544 .62539 .67568 .59379 .674 .59209 Metetra
.939 .771 .647 r
.674 .59209 .67568 .59379 .68572 .56094 .68406 .55921 Metetra
.539 .724 .959 r
.68406 .55921 .68572 .56094 .69723 .56002 .69558 .55843 Metetra
.929 .545 .19 r
.69558 .55843 .69723 .56002 .71122 .60354 .70956 .60197 Metetra
.933 .555 .206 r
.70956 .60197 .71122 .60354 .72582 .65137 .72416 .64984 Metetra
.904 .494 .115 r
.72416 .64984 .72582 .65137 .74014 .68788 .73846 .68604 Metetra
.645 .763 .934 r
.73846 .68604 .74014 .68788 .75222 .68465 .75054 .6828 Metetra
.645 .763 .934 r
.75054 .6828 .75222 .68465 .76434 .68141 .76267 .67955 Metetra
.645 .763 .934 r
.76267 .67955 .76434 .68141 .77651 .67815 .77486 .67628 Metetra
.645 .763 .934 r
.77486 .67628 .77651 .67815 .78874 .67488 .7871 .673 Metetra
.645 .763 .934 r
.7871 .673 .78874 .67488 .80102 .67159 .79939 .66971 Metetra
.645 .763 .934 r
.79939 .66971 .80102 .67159 .81335 .66829 .81173 .6664 Metetra
.645 .763 .934 r
.81173 .6664 .81335 .66829 .82573 .66497 .82412 .66307 Metetra
.645 .763 .934 r
.82412 .66307 .82573 .66497 .83817 .66164 .83657 .65974 Metetra
.645 .763 .934 r
.83657 .65974 .83817 .66164 .85066 .6583 .84907 .65638 Metetra
.645 .763 .934 r
.84907 .65638 .85066 .6583 .8632 .65494 .86163 .65302 Metetra
.645 .763 .934 r
.86163 .65302 .8632 .65494 .8758 .65157 .87424 .64964 Metetra
.645 .763 .934 r
.87424 .64964 .8758 .65157 .88845 .64818 .8869 .64624 Metetra
.645 .763 .934 r
.8869 .64624 .88845 .64818 .90116 .64478 .89962 .64283 Metetra
.645 .763 .934 r
.89962 .64283 .90116 .64478 .91392 .64137 .9124 .63941 Metetra
.645 .763 .934 r
.9124 .63941 .91392 .64137 .92674 .63794 .92523 .63597 Metetra
.645 .763 .934 r
.92523 .63597 .92674 .63794 .93961 .63449 .93811 .63251 Metetra
.645 .763 .934 r
.93811 .63251 .93961 .63449 .95254 .63103 .95106 .62904 Metetra
.645 .763 .934 r
.95106 .62904 .95254 .63103 .96553 .62755 .96406 .62556 Metetra
.645 .763 .934 r
.96406 .62556 .96553 .62755 .97857 .62406 .97711 .62206 Metetra
0 .49 .789 r
.37257 .60205 .37451 .60275 .38433 .60498 .38239 .60445 Metetra
.898 .848 .786 r
.38239 .60445 .38433 .60498 .39487 .59012 .39295 .58974 Metetra
.495 0 0 r
.39295 .58974 .39487 .59012 .40475 .59322 .40277 .59465 Metetra
.659 .94 .678 r
.40277 .59465 .40475 .59322 .41514 .58254 .41316 .5847 Metetra
.636 .88 .534 r
.41316 .5847 .41514 .58254 .42559 .56979 .42363 .57192 Metetra
.866 .96 .622 r
.42363 .57192 .42559 .56979 .43606 .55547 .43421 .55445 Metetra
.643 .834 .974 r
.43421 .55445 .43606 .55547 .44614 .55703 .44441 .55135 Metetra
.371 .367 .725 r
.44441 .55135 .44614 .55703 .45614 .56538 .4544 .55967 Metetra
.347 .352 .723 r
.4544 .55967 .45614 .56538 .46623 .57451 .46448 .56877 Metetra
.624 .524 .721 r
.46448 .56877 .46623 .57451 .47666 .56844 .47486 .56591 Metetra
.616 .657 .868 r
.47486 .56591 .47666 .56844 .48705 .5675 .48526 .56417 Metetra
.91 .534 .098 r
.48526 .56417 .48705 .5675 .49722 .60036 .49541 .59702 Metetra
.695 .641 .791 r
.49541 .59702 .49722 .60036 .50784 .59512 .50604 .59153 Metetra
.697 .63 .778 r
.50604 .59153 .50784 .59512 .51849 .58809 .5167 .58566 Metetra
.632 .676 .874 r
.5167 .58566 .51849 .58809 .52917 .58569 .52738 .58334 Metetra
.864 .736 .72 r
.52738 .58334 .52917 .58569 .53982 .56638 .53805 .56402 Metetra
.868 .736 .714 r
.53805 .56402 .53982 .56638 .5504 .54623 .54864 .54386 Metetra
.847 .736 .741 r
.54864 .54386 .5504 .54623 .56096 .52966 .55922 .52774 Metetra
.797 .336 0 r
.55922 .52774 .56096 .52966 .57196 .54848 .57022 .54657 Metetra
.822 .37 0 r
.57022 .54657 .57196 .54848 .58318 .56897 .58144 .56707 Metetra
.844 .399 0 r
.58144 .56707 .58318 .56897 .59463 .59128 .59288 .58938 Metetra
.902 .765 .7 r
.59288 .58938 .59463 .59128 .60521 .56769 .60348 .5659 Metetra
.875 .444 .043 r
.60348 .5659 .60521 .56769 .61703 .59379 .61528 .59141 Metetra
.959 .621 .306 r
.61528 .59141 .61703 .59379 .63039 .6626 .62861 .66023 Metetra
.751 .305 0 r
.62861 .66023 .63039 .6626 .64265 .6833 .6409 .68172 Metetra
.932 .78 .671 r
.6409 .68172 .64265 .6833 .65328 .65411 .65155 .6525 Metetra
.935 .778 .663 r
.65155 .6525 .65328 .65411 .66374 .62372 .66203 .62208 Metetra
.937 .775 .655 r
.66203 .62208 .66374 .62372 .674 .59209 .67231 .59043 Metetra
.94 .772 .647 r
.67231 .59043 .674 .59209 .68406 .55921 .6824 .55752 Metetra
.587 .748 .954 r
.6824 .55752 .68406 .55921 .69558 .55843 .69388 .55574 Metetra
.911 .529 .104 r
.69388 .55574 .69558 .55843 .70956 .60197 .70785 .59929 Metetra
.92 .543 .127 r
.70785 .59929 .70956 .60197 .72416 .64984 .72243 .64715 Metetra
.867 .467 .002 r
.72243 .64715 .72416 .64984 .73846 .68604 .73677 .68419 Metetra
.645 .763 .934 r
.73677 .68419 .73846 .68604 .75054 .6828 .74886 .68094 Metetra
.645 .763 .934 r
.74886 .68094 .75054 .6828 .76267 .67955 .76101 .67768 Metetra
.645 .763 .934 r
.76101 .67768 .76267 .67955 .77486 .67628 .7732 .67441 Metetra
.645 .763 .934 r
.7732 .67441 .77486 .67628 .7871 .673 .78545 .67112 Metetra
.645 .763 .934 r
.78545 .67112 .7871 .673 .79939 .66971 .79775 .66782 Metetra
.645 .763 .934 r
.79775 .66782 .79939 .66971 .81173 .6664 .81011 .6645 Metetra
.645 .763 .934 r
.81011 .6645 .81173 .6664 .82412 .66307 .82251 .66117 Metetra
.645 .763 .934 r
.82251 .66117 .82412 .66307 .83657 .65974 .83497 .65782 Metetra
.645 .763 .934 r
.83497 .65782 .83657 .65974 .84907 .65638 .84749 .65446 Metetra
.645 .763 .934 r
.84749 .65446 .84907 .65638 .86163 .65302 .86005 .65109 Metetra
.645 .763 .934 r
.86005 .65109 .86163 .65302 .87424 .64964 .87268 .6477 Metetra
.645 .763 .934 r
.87268 .6477 .87424 .64964 .8869 .64624 .88535 .6443 Metetra
.645 .763 .934 r
.88535 .6443 .8869 .64624 .89962 .64283 .89808 .64088 Metetra
.645 .763 .934 r
.89808 .64088 .89962 .64283 .9124 .63941 .91087 .63744 Metetra
.645 .763 .934 r
.91087 .63744 .9124 .63941 .92523 .63597 .92372 .634 Metetra
.645 .763 .934 r
.92372 .634 .92523 .63597 .93811 .63251 .93661 .63053 Metetra
.645 .763 .934 r
.93661 .63053 .93811 .63251 .95106 .62904 .94957 .62705 Metetra
.645 .763 .934 r
.94957 .62705 .95106 .62904 .96406 .62556 .96258 .62356 Metetra
.645 .763 .934 r
.96258 .62356 .96406 .62556 .97711 .62206 .97565 .62005 Metetra
.454 .582 .892 r
.37071 .59952 .37257 .60205 .38239 .60445 .38056 .60138 Metetra
.806 .684 .729 r
.38056 .60138 .38239 .60445 .39295 .58974 .39113 .58651 Metetra
.447 .522 .842 r
.39113 .58651 .39295 .58974 .40277 .59465 .40102 .58941 Metetra
.723 .59 .706 r
.40102 .58941 .40277 .59465 .41316 .5847 .41144 .5785 Metetra
.722 .573 .687 r
.41144 .5785 .41316 .5847 .42363 .57192 .42192 .56573 Metetra
.728 .577 .685 r
.42192 .56573 .42363 .57192 .43421 .55445 .43239 .55219 Metetra
.438 .602 .915 r
.43239 .55219 .43421 .55445 .44441 .55135 .44247 .55396 Metetra
.687 .306 .319 r
.44247 .55396 .44441 .55135 .4544 .55967 .45248 .56231 Metetra
.697 .318 .326 r
.45248 .56231 .4544 .55967 .46448 .56877 .46257 .57145 Metetra
.114 0 0 r
.46257 .57145 .46448 .56877 .47486 .56591 .47303 .56486 Metetra
.464 .774 .997 r
.47303 .56486 .47486 .56591 .48526 .56417 .48343 .56417 Metetra
.905 .544 .344 r
.48343 .56417 .48526 .56417 .49541 .59702 .49358 .59707 Metetra
.609 .947 .93 r
.49358 .59707 .49541 .59702 .50604 .59153 .50422 .59203 Metetra
.715 .987 .852 r
.50422 .59203 .50604 .59153 .5167 .58566 .5149 .58407 Metetra
.623 .763 .946 r
.5149 .58407 .5167 .58566 .52738 .58334 .52559 .58167 Metetra
.888 .774 .729 r
.52559 .58167 .52738 .58334 .53805 .56402 .53627 .56233 Metetra
.892 .772 .722 r
.53627 .56233 .53805 .56402 .54864 .54386 .54689 .54215 Metetra
.87 .779 .758 r
.54689 .54215 .54864 .54386 .55922 .52774 .55748 .52637 Metetra
.839 .376 0 r
.55748 .52637 .55922 .52774 .57022 .54657 .56848 .54521 Metetra
.855 .402 .029 r
.56848 .54521 .57022 .54657 .58144 .56707 .57969 .56572 Metetra
.869 .426 .062 r
.57969 .56572 .58144 .56707 .59288 .58938 .59114 .58805 Metetra
.922 .794 .702 r
.59114 .58805 .59288 .58938 .60348 .5659 .60175 .56445 Metetra
.885 .455 .087 r
.60175 .56445 .60348 .5659 .61528 .59141 .61355 .58993 Metetra
.953 .617 .335 r
.61355 .58993 .61528 .59141 .62861 .66023 .62686 .6588 Metetra
.829 .363 0 r
.62686 .6588 .62861 .66023 .6409 .68172 .63912 .67958 Metetra
.915 .757 .671 r
.63912 .67958 .6409 .68172 .65155 .6525 .64979 .65034 Metetra
.918 .755 .664 r
.64979 .65034 .65155 .6525 .66203 .62208 .66029 .6199 Metetra
.922 .754 .656 r
.66029 .6199 .66203 .62208 .67231 .59043 .6706 .58823 Metetra
.925 .752 .649 r
.6706 .58823 .67231 .59043 .6824 .55752 .68071 .5553 Metetra
.551 .673 .919 r
.68071 .5553 .6824 .55752 .69388 .55574 .69226 .55484 Metetra
.929 .548 .235 r
.69226 .55484 .69388 .55574 .70785 .59929 .70622 .59843 Metetra
.933 .557 .247 r
.70622 .59843 .70785 .59929 .72243 .64715 .7208 .64635 Metetra
.909 .503 .177 r
.7208 .64635 .72243 .64715 .73677 .68419 .73507 .68234 Metetra
.645 .763 .934 r
.73507 .68234 .73677 .68419 .74886 .68094 .74718 .67908 Metetra
.645 .763 .934 r
.74718 .67908 .74886 .68094 .76101 .67768 .75933 .67581 Metetra
.645 .763 .934 r
.75933 .67581 .76101 .67768 .7732 .67441 .77154 .67253 Metetra
.645 .763 .934 r
.77154 .67253 .7732 .67441 .78545 .67112 .7838 .66923 Metetra
.645 .763 .934 r
.7838 .66923 .78545 .67112 .79775 .66782 .79611 .66592 Metetra
.645 .763 .934 r
.79611 .66592 .79775 .66782 .81011 .6645 .80848 .6626 Metetra
.645 .763 .934 r
.80848 .6626 .81011 .6645 .82251 .66117 .8209 .65926 Metetra
.645 .763 .934 r
.8209 .65926 .82251 .66117 .83497 .65782 .83337 .6559 Metetra
.645 .763 .934 r
.83337 .6559 .83497 .65782 .84749 .65446 .8459 .65254 Metetra
.645 .763 .934 r
.8459 .65254 .84749 .65446 .86005 .65109 .85848 .64915 Metetra
.645 .763 .934 r
.85848 .64915 .86005 .65109 .87268 .6477 .87111 .64576 Metetra
.645 .763 .934 r
.87111 .64576 .87268 .6477 .88535 .6443 .8838 .64234 Metetra
.645 .763 .934 r
.8838 .64234 .88535 .6443 .89808 .64088 .89654 .63892 Metetra
.645 .763 .934 r
.89654 .63892 .89808 .64088 .91087 .63744 .90934 .63548 Metetra
.645 .763 .934 r
.90934 .63548 .91087 .63744 .92372 .634 .9222 .63202 Metetra
.645 .763 .934 r
.9222 .63202 .92372 .634 .93661 .63053 .93511 .62855 Metetra
.645 .763 .934 r
.93511 .62855 .93661 .63053 .94957 .62705 .94808 .62506 Metetra
.645 .763 .934 r
.94808 .62506 .94957 .62705 .96258 .62356 .96111 .62156 Metetra
.645 .763 .934 r
.96111 .62156 .96258 .62356 .97565 .62005 .97419 .61804 Metetra
0 .493 .747 r
.36876 .59903 .37071 .59952 .38056 .60138 .37861 .60092 Metetra
.897 .857 .794 r
.37861 .60092 .38056 .60138 .39113 .58651 .38917 .58675 Metetra
.592 .047 0 r
.38917 .58675 .39113 .58651 .40102 .58941 .39899 .59178 Metetra
.39899 .59178 .40102 .58941 .41144 .5785 .40941 .58174 Metetra
.40941 .58174 .41144 .5785 .42192 .56573 .41994 .5682 Metetra
.784 .925 .552 r
.41994 .5682 .42192 .56573 .43239 .55219 .43053 .5513 Metetra
.688 .861 .964 r
.43053 .5513 .43239 .55219 .44247 .55396 .44076 .54719 Metetra
.413 .369 .7 r
.44076 .54719 .44247 .55396 .45248 .56231 .45075 .55551 Metetra
.395 .357 .698 r
.45075 .55551 .45248 .56231 .46257 .57145 .46084 .5646 Metetra
.616 .5 .698 r
.46084 .5646 .46257 .57145 .47303 .56486 .47123 .5618 Metetra
.597 .611 .837 r
.47123 .5618 .47303 .56486 .48343 .56417 .48164 .56072 Metetra
.906 .531 .087 r
.48164 .56072 .48343 .56417 .49358 .59707 .49177 .5936 Metetra
.693 .635 .786 r
.49177 .5936 .49358 .59707 .50422 .59203 .50241 .58808 Metetra
.702 .619 .76 r
.50241 .58808 .50422 .59203 .5149 .58407 .51309 .58134 Metetra
.625 .651 .856 r
.51309 .58134 .5149 .58407 .52559 .58167 .52379 .57926 Metetra
.862 .733 .719 r
.52379 .57926 .52559 .58167 .53627 .56233 .53449 .55991 Metetra
.866 .733 .713 r
.53449 .55991 .53627 .56233 .54689 .54215 .54512 .53972 Metetra
.839 .732 .746 r
.54512 .53972 .54689 .54215 .55748 .52637 .55573 .52436 Metetra
.787 .328 0 r
.55573 .52436 .55748 .52637 .56848 .54521 .56673 .5432 Metetra
.814 .362 0 r
.56673 .5432 .56848 .54521 .57969 .56572 .57794 .56372 Metetra
.837 .393 0 r
.57794 .56372 .57969 .56572 .59114 .58805 .58938 .58605 Metetra
.898 .76 .701 r
.58938 .58605 .59114 .58805 .60175 .56445 .60002 .56284 Metetra
.872 .435 .046 r
.60002 .56284 .60175 .56445 .61355 .58993 .61179 .58718 Metetra
.96 .622 .293 r
.61179 .58718 .61355 .58993 .62686 .6588 .62506 .65605 Metetra
.695 .268 0 r
.62506 .65605 .62686 .6588 .63912 .67958 .63735 .67763 Metetra
.921 .765 .671 r
.63735 .67763 .63912 .67958 .64979 .65034 .64804 .64837 Metetra
.924 .763 .663 r
.64804 .64837 .64979 .65034 .66029 .6199 .65856 .6179 Metetra
.927 .761 .656 r
.65856 .6179 .66029 .6199 .6706 .58823 .66889 .58621 Metetra
.93 .759 .648 r
.66889 .58621 .6706 .58823 .68071 .5553 .67902 .55326 Metetra
.564 .698 .931 r
.67902 .55326 .68071 .5553 .69226 .55484 .69056 .55232 Metetra
.916 .533 .119 r
.69056 .55232 .69226 .55484 .70622 .59843 .70451 .59591 Metetra
.924 .546 .142 r
.70451 .59591 .70622 .59843 .7208 .64635 .71907 .64384 Metetra
.874 .47 .018 r
.71907 .64384 .7208 .64635 .73507 .68234 .73337 .68048 Metetra
.645 .763 .934 r
.73337 .68048 .73507 .68234 .74718 .67908 .74549 .67722 Metetra
.645 .763 .934 r
.74549 .67722 .74718 .67908 .75933 .67581 .75766 .67394 Metetra
.645 .763 .934 r
.75766 .67394 .75933 .67581 .77154 .67253 .76988 .67065 Metetra
.645 .763 .934 r
.76988 .67065 .77154 .67253 .7838 .66923 .78215 .66734 Metetra
.645 .763 .934 r
.78215 .66734 .7838 .66923 .79611 .66592 .79447 .66402 Metetra
.645 .763 .934 r
.79447 .66402 .79611 .66592 .80848 .6626 .80685 .66069 Metetra
.645 .763 .934 r
.80685 .66069 .80848 .6626 .8209 .65926 .81928 .65734 Metetra
.645 .763 .934 r
.81928 .65734 .8209 .65926 .83337 .6559 .83176 .65398 Metetra
.645 .763 .934 r
.83176 .65398 .83337 .6559 .8459 .65254 .8443 .65061 Metetra
.645 .763 .934 r
.8443 .65061 .8459 .65254 .85848 .64915 .85689 .64721 Metetra
.645 .763 .934 r
.85689 .64721 .85848 .64915 .87111 .64576 .86954 .64381 Metetra
.645 .763 .934 r
.86954 .64381 .87111 .64576 .8838 .64234 .88224 .64039 Metetra
.645 .763 .934 r
.88224 .64039 .8838 .64234 .89654 .63892 .895 .63695 Metetra
.645 .763 .934 r
.895 .63695 .89654 .63892 .90934 .63548 .90781 .6335 Metetra
.645 .763 .934 r
.90781 .6335 .90934 .63548 .9222 .63202 .92068 .63004 Metetra
.645 .763 .934 r
.92068 .63004 .9222 .63202 .93511 .62855 .9336 .62656 Metetra
.645 .763 .934 r
.9336 .62656 .93511 .62855 .94808 .62506 .94659 .62306 Metetra
.645 .763 .934 r
.94659 .62306 .94808 .62506 .96111 .62156 .95962 .61955 Metetra
.645 .763 .934 r
.95962 .61955 .96111 .62156 .97419 .61804 .97272 .61602 Metetra
.472 .559 .863 r
.36691 .59612 .36876 .59903 .37861 .60092 .37676 .59809 Metetra
.815 .696 .733 r
.37676 .59809 .37861 .60092 .38917 .58675 .38737 .58297 Metetra
.453 .492 .809 r
.38737 .58297 .38917 .58675 .39899 .59178 .39725 .58634 Metetra
.722 .586 .702 r
.39725 .58634 .39899 .59178 .40941 .58174 .4077 .57521 Metetra
.717 .566 .683 r
.4077 .57521 .40941 .58174 .41994 .5682 .41821 .56241 Metetra
.736 .587 .69 r
.41821 .56241 .41994 .5682 .43053 .5513 .42871 .54866 Metetra
.485 .589 .883 r
.42871 .54866 .43053 .5513 .44076 .54719 .43881 .55011 Metetra
.682 .309 .334 r
.43881 .55011 .44076 .54719 .45075 .55551 .44882 .55846 Metetra
.691 .321 .34 r
.44882 .55846 .45075 .55551 .46084 .5646 .45891 .5676 Metetra
.19 0 .044 r
.45891 .5676 .46084 .5646 .47123 .5618 .46938 .56134 Metetra
.343 .79 .956 r
.46938 .56134 .47123 .5618 .48164 .56072 .4798 .5603 Metetra
.913 .548 .324 r
.4798 .5603 .48164 .56072 .49177 .5936 .48992 .59322 Metetra
.637 .922 .977 r
.48992 .59322 .49177 .5936 .50241 .58808 .50058 .58892 Metetra
.71 .98 .785 r
.50058 .58892 .50241 .58808 .51309 .58134 .51128 .57977 Metetra
.592 .755 .956 r
.51128 .57977 .51309 .58134 .52379 .57926 .52199 .57797 Metetra
.903 .798 .734 r
.52199 .57797 .52379 .57926 .53449 .55991 .5327 .5586 Metetra
.907 .795 .726 r
.5327 .5586 .53449 .55991 .54512 .53972 .54336 .53839 Metetra
.886 .807 .766 r
.54336 .53839 .54512 .53972 .55573 .52436 .55398 .52264 Metetra
.817 .353 0 r
.55398 .52264 .55573 .52436 .56673 .5432 .56497 .54149 Metetra
.838 .384 0 r
.56497 .54149 .56673 .5432 .57794 .56372 .57618 .56202 Metetra
.856 .411 .008 r
.57618 .56202 .57794 .56372 .58938 .58605 .58762 .58436 Metetra
.908 .777 .706 r
.58762 .58436 .58938 .58605 .60002 .56284 .59829 .56151 Metetra
.876 .438 .075 r
.59829 .56151 .60002 .56284 .61179 .58718 .61004 .58536 Metetra
.956 .618 .325 r
.61004 .58536 .61179 .58718 .62506 .65605 .62329 .65427 Metetra
.822 .364 0 r
.62329 .65427 .62506 .65605 .63735 .67763 .63558 .67616 Metetra
.935 .785 .67 r
.63558 .67616 .63735 .67763 .64804 .64837 .6463 .64686 Metetra
.938 .783 .662 r
.6463 .64686 .64804 .64837 .65856 .6179 .65684 .61637 Metetra
.941 .78 .654 r
.65684 .61637 .65856 .6179 .66889 .58621 .6672 .58464 Metetra
.943 .777 .646 r
.6672 .58464 .66889 .58621 .67902 .55326 .67735 .55166 Metetra
.532 .74 .971 r
.67735 .55166 .67902 .55326 .69056 .55232 .68891 .55076 Metetra
.929 .545 .193 r
.68891 .55076 .69056 .55232 .70451 .59591 .70284 .59439 Metetra
.934 .555 .209 r
.70284 .59439 .70451 .59591 .71907 .64384 .7174 .64235 Metetra
.904 .495 .12 r
.7174 .64235 .71907 .64384 .73337 .68048 .73167 .67862 Metetra
.645 .763 .934 r
.73167 .67862 .73337 .68048 .74549 .67722 .7438 .67534 Metetra
.645 .763 .934 r
.7438 .67534 .74549 .67722 .75766 .67394 .75598 .67206 Metetra
.645 .763 .934 r
.75598 .67206 .75766 .67394 .76988 .67065 .76821 .66876 Metetra
.645 .763 .934 r
.76821 .66876 .76988 .67065 .78215 .66734 .78049 .66545 Metetra
.645 .763 .934 r
.78049 .66545 .78215 .66734 .79447 .66402 .79283 .66212 Metetra
.645 .763 .934 r
.79283 .66212 .79447 .66402 .80685 .66069 .80521 .65878 Metetra
.645 .763 .934 r
.80521 .65878 .80685 .66069 .81928 .65734 .81766 .65542 Metetra
.645 .763 .934 r
.81766 .65542 .81928 .65734 .83176 .65398 .83015 .65205 Metetra
.645 .763 .934 r
.83015 .65205 .83176 .65398 .8443 .65061 .8427 .64867 Metetra
.645 .763 .934 r
.8427 .64867 .8443 .65061 .85689 .64721 .85531 .64527 Metetra
.645 .763 .934 r
.85531 .64527 .85689 .64721 .86954 .64381 .86796 .64186 Metetra
.645 .763 .934 r
.86796 .64186 .86954 .64381 .88224 .64039 .88068 .63843 Metetra
.645 .763 .934 r
.88068 .63843 .88224 .64039 .895 .63695 .89345 .63498 Metetra
.645 .763 .934 r
.89345 .63498 .895 .63695 .90781 .6335 .90627 .63152 Metetra
.645 .763 .934 r
.90627 .63152 .90781 .6335 .92068 .63004 .91915 .62805 Metetra
.645 .763 .934 r
.91915 .62805 .92068 .63004 .9336 .62656 .93209 .62456 Metetra
.645 .763 .934 r
.93209 .62456 .9336 .62656 .94659 .62306 .94509 .62106 Metetra
.645 .763 .934 r
.94509 .62106 .94659 .62306 .95962 .61955 .95814 .61754 Metetra
.645 .763 .934 r
.95814 .61754 .95962 .61955 .97272 .61602 .97125 .614 Metetra
0 .503 .759 r
.36494 .59562 .36691 .59612 .37676 .59809 .37481 .59747 Metetra
.891 .843 .791 r
.37481 .59747 .37676 .59809 .38737 .58297 .38539 .58325 Metetra
.603 .063 0 r
.38539 .58325 .38737 .58297 .39725 .58634 .39522 .58844 Metetra
.39522 .58844 .39725 .58634 .4077 .57521 .40566 .57827 Metetra
.40566 .57827 .4077 .57521 .41821 .56241 .41622 .56458 Metetra
.84 .956 .613 r
.41622 .56458 .41821 .56241 .42871 .54866 .42684 .54777 Metetra
.694 .862 .962 r
.42684 .54777 .42871 .54866 .43881 .55011 .43709 .54351 Metetra
.406 .368 .704 r
.43709 .54351 .43881 .55011 .44882 .55846 .44709 .55183 Metetra
.387 .356 .702 r
.44709 .55183 .44882 .55846 .45891 .5676 .45717 .56092 Metetra
.616 .503 .702 r
.45717 .56092 .45891 .5676 .46938 .56134 .46758 .55816 Metetra
.598 .605 .83 r
.46758 .55816 .46938 .56134 .4798 .5603 .478 .55705 Metetra
.915 .537 .111 r
.478 .55705 .4798 .5603 .48992 .59322 .4881 .58996 Metetra
.693 .645 .798 r
.4881 .58996 .48992 .59322 .50058 .58892 .49877 .58472 Metetra
.706 .612 .75 r
.49877 .58472 .50058 .58892 .51128 .57977 .50947 .57736 Metetra
.615 .674 .883 r
.50947 .57736 .51128 .57977 .52199 .57797 .52018 .57553 Metetra
.861 .732 .719 r
.52018 .57553 .52199 .57797 .5327 .5586 .53092 .55614 Metetra
.866 .732 .713 r
.53092 .55614 .5327 .5586 .54336 .53839 .54158 .53592 Metetra
.838 .731 .746 r
.54158 .53592 .54336 .53839 .55398 .52264 .55222 .52067 Metetra
.792 .332 0 r
.55222 .52067 .55398 .52264 .56497 .54149 .56321 .53952 Metetra
.818 .366 0 r
.56321 .53952 .56497 .54149 .57618 .56202 .57442 .56005 Metetra
.84 .396 0 r
.57442 .56005 .57618 .56202 .58762 .58436 .58585 .5824 Metetra
.898 .763 .704 r
.58585 .5824 .58762 .58436 .59829 .56151 .59654 .55949 Metetra
.843 .403 0 r
.59654 .55949 .59829 .56151 .61004 .58536 .60828 .58306 Metetra
.958 .62 .31 r
.60828 .58306 .61004 .58536 .62329 .65427 .6215 .65199 Metetra
.775 .328 0 r
.6215 .65199 .62329 .65427 .63558 .67616 .6338 .674 Metetra
.915 .757 .671 r
.6338 .674 .63558 .67616 .6463 .64686 .64453 .64469 Metetra
.918 .755 .663 r
.64453 .64469 .6463 .64686 .65684 .61637 .6551 .61417 Metetra
.922 .754 .656 r
.6551 .61417 .65684 .61637 .6672 .58464 .66548 .58243 Metetra
.925 .752 .649 r
.66548 .58243 .6672 .58464 .67735 .55166 .67565 .54942 Metetra
.572 .682 .915 r
.67565 .54942 .67735 .55166 .68891 .55076 .68721 .54845 Metetra
.92 .537 .137 r
.68721 .54845 .68891 .55076 .70284 .59439 .70114 .59208 Metetra
.927 .549 .158 r
.70114 .59208 .70284 .59439 .7174 .64235 .71568 .64006 Metetra
.884 .479 .044 r
.71568 .64006 .7174 .64235 .73167 .67862 .72996 .67675 Metetra
.645 .763 .934 r
.72996 .67675 .73167 .67862 .7438 .67534 .7421 .67347 Metetra
.645 .763 .934 r
.7421 .67347 .7438 .67534 .75598 .67206 .75429 .67018 Metetra
.645 .763 .934 r
.75429 .67018 .75598 .67206 .76821 .66876 .76653 .66687 Metetra
.645 .763 .934 r
.76653 .66687 .76821 .66876 .78049 .66545 .77883 .66355 Metetra
.645 .763 .934 r
.77883 .66355 .78049 .66545 .79283 .66212 .79118 .66021 Metetra
.645 .763 .934 r
.79118 .66021 .79283 .66212 .80521 .65878 .80358 .65686 Metetra
.645 .763 .934 r
.80358 .65686 .80521 .65878 .81766 .65542 .81603 .6535 Metetra
.645 .763 .934 r
.81603 .6535 .81766 .65542 .83015 .65205 .82854 .65012 Metetra
.645 .763 .934 r
.82854 .65012 .83015 .65205 .8427 .64867 .8411 .64673 Metetra
.645 .763 .934 r
.8411 .64673 .8427 .64867 .85531 .64527 .85371 .64332 Metetra
.645 .763 .934 r
.85371 .64332 .85531 .64527 .86796 .64186 .86639 .6399 Metetra
.645 .763 .934 r
.86639 .6399 .86796 .64186 .88068 .63843 .87911 .63646 Metetra
.645 .763 .934 r
.87911 .63646 .88068 .63843 .89345 .63498 .89189 .63301 Metetra
.645 .763 .934 r
.89189 .63301 .89345 .63498 .90627 .63152 .90473 .62954 Metetra
.645 .763 .934 r
.90473 .62954 .90627 .63152 .91915 .62805 .91763 .62606 Metetra
.645 .763 .934 r
.91763 .62606 .91915 .62805 .93209 .62456 .93058 .62256 Metetra
.645 .763 .934 r
.93058 .62256 .93209 .62456 .94509 .62106 .94358 .61905 Metetra
.645 .763 .934 r
.94358 .61905 .94509 .62106 .95814 .61754 .95665 .61552 Metetra
.645 .763 .934 r
.95665 .61552 .95814 .61754 .97125 .614 .96977 .61197 Metetra
.428 .518 .848 r
.3631 .59246 .36494 .59562 .37481 .59747 .37291 .59556 Metetra
.853 .745 .743 r
.37291 .59556 .37481 .59747 .38539 .58325 .3836 .57923 Metetra
.401 .45 .796 r
.3836 .57923 .38539 .58325 .39522 .58844 .39343 .58407 Metetra
.742 .62 .723 r
.39343 .58407 .39522 .58844 .40566 .57827 .40391 .573 Metetra
.739 .598 .7 r
.40391 .573 .40566 .57827 .41622 .56458 .41444 .56017 Metetra
.776 .634 .704 r
.41444 .56017 .41622 .56458 .42684 .54777 .42503 .54476 Metetra
.545 .589 .848 r
.42503 .54476 .42684 .54777 .43709 .54351 .43516 .54516 Metetra
.702 .281 .244 r
.43516 .54516 .43709 .54351 .44709 .55183 .44517 .5535 Metetra
.714 .298 .255 r
.44517 .5535 .44709 .55183 .45717 .56092 .45526 .56262 Metetra
.076 0 0 r
.45526 .56262 .45717 .56092 .46758 .55816 .46571 .55832 Metetra
.37 .838 .858 r
.46571 .55832 .46758 .55816 .478 .55705 .47617 .55526 Metetra
.932 .554 .242 r
.47617 .55526 .478 .55705 .4881 .58996 .48627 .58818 Metetra
.657 .75 .919 r
.48627 .58818 .4881 .58996 .49877 .58472 .49693 .58505 Metetra
.807 .994 .869 r
.49693 .58505 .49877 .58472 .50947 .57736 .50766 .57581 Metetra
.547 .743 .967 r
.50766 .57581 .50947 .57736 .52018 .57553 .51837 .57476 Metetra
.923 .833 .738 r
.51837 .57476 .52018 .57553 .53092 .55614 .52912 .55535 Metetra
.926 .828 .729 r
.52912 .55535 .53092 .55614 .54158 .53592 .53981 .5351 Metetra
.913 .844 .762 r
.53981 .5351 .54158 .53592 .55222 .52067 .55046 .51824 Metetra
.731 .286 0 r
.55046 .51824 .55222 .52067 .56321 .53952 .56144 .53709 Metetra
.768 .327 0 r
.56144 .53709 .56321 .53952 .57442 .56005 .57264 .55762 Metetra
.799 .364 0 r
.57264 .55762 .57442 .56005 .58585 .5824 .58407 .57997 Metetra
.878 .74 .706 r
.58407 .57997 .58585 .5824 .59654 .55949 .5948 .55807 Metetra
.863 .417 .039 r
.5948 .55807 .59654 .55949 .60828 .58306 .60651 .58073 Metetra
.958 .621 .309 r
.60651 .58073 .60828 .58306 .6215 .65199 .61971 .64967 Metetra
.809 .37 0 r
.61971 .64967 .6215 .65199 .6338 .674 .63206 .67369 Metetra
.968 .839 .661 r
.63206 .67369 .6338 .674 .64453 .64469 .64282 .64433 Metetra
.97 .833 .652 r
.64282 .64433 .64453 .64469 .6551 .61417 .65342 .61377 Metetra
.971 .828 .643 r
.65342 .61377 .6551 .61417 .66548 .58243 .66382 .58197 Metetra
.973 .822 .634 r
.66382 .58197 .66548 .58243 .67565 .54942 .67402 .54892 Metetra
.551 .893 .982 r
.67402 .54892 .67565 .54942 .68721 .54845 .68548 .54548 Metetra
.903 .524 .082 r
.68548 .54548 .68721 .54845 .70114 .59208 .69939 .58911 Metetra
.914 .539 .108 r
.69939 .58911 .70114 .59208 .71568 .64006 .71391 .63708 Metetra
.857 .462 0 r
.71391 .63708 .71568 .64006 .72996 .67675 .72825 .67488 Metetra
.645 .763 .934 r
.72825 .67488 .72996 .67675 .7421 .67347 .7404 .67159 Metetra
.645 .763 .934 r
.7404 .67159 .7421 .67347 .75429 .67018 .7526 .66829 Metetra
.645 .763 .934 r
.7526 .66829 .75429 .67018 .76653 .66687 .76486 .66497 Metetra
.645 .763 .934 r
.76486 .66497 .76653 .66687 .77883 .66355 .77716 .66164 Metetra
.645 .763 .934 r
.77716 .66164 .77883 .66355 .79118 .66021 .78952 .6583 Metetra
.645 .763 .934 r
.78952 .6583 .79118 .66021 .80358 .65686 .80193 .65494 Metetra
.645 .763 .934 r
.80193 .65494 .80358 .65686 .81603 .6535 .8144 .65157 Metetra
.645 .763 .934 r
.8144 .65157 .81603 .6535 .82854 .65012 .82692 .64818 Metetra
.645 .763 .934 r
.82692 .64818 .82854 .65012 .8411 .64673 .83949 .64478 Metetra
.645 .763 .934 r
.83949 .64478 .8411 .64673 .85371 .64332 .85212 .64137 Metetra
.645 .763 .934 r
.85212 .64137 .85371 .64332 .86639 .6399 .8648 .63794 Metetra
.645 .763 .934 r
.8648 .63794 .86639 .6399 .87911 .63646 .87754 .63449 Metetra
.645 .763 .934 r
.87754 .63449 .87911 .63646 .89189 .63301 .89034 .63103 Metetra
.645 .763 .934 r
.89034 .63103 .89189 .63301 .90473 .62954 .90319 .62755 Metetra
.645 .763 .934 r
.90319 .62755 .90473 .62954 .91763 .62606 .91609 .62406 Metetra
.645 .763 .934 r
.91609 .62406 .91763 .62606 .93058 .62256 .92906 .62055 Metetra
.645 .763 .934 r
.92906 .62055 .93058 .62256 .94358 .61905 .94208 .61703 Metetra
.645 .763 .934 r
.94208 .61703 .94358 .61905 .95665 .61552 .95516 .61349 Metetra
.645 .763 .934 r
.95516 .61349 .95665 .61552 .96977 .61197 .96829 .60994 Metetra
0 .509 .824 r
.36114 .59165 .3631 .59246 .37291 .59556 .37098 .5941 Metetra
.864 .776 .763 r
.37098 .5941 .37291 .59556 .3836 .57923 .38164 .57896 Metetra
.54 0 0 r
.38164 .57896 .3836 .57923 .39343 .58407 .39146 .58416 Metetra
.866 .953 .865 r
.39146 .58416 .39343 .58407 .40391 .573 .40193 .57388 Metetra
.889 .988 .793 r
.40193 .57388 .40391 .573 .41444 .56017 .41248 .56103 Metetra
.947 .942 .746 r
.41248 .56103 .41444 .56017 .42503 .54476 .42315 .54372 Metetra
.636 .833 .976 r
.42315 .54372 .42503 .54476 .43516 .54516 .43339 .54071 Metetra
.276 .353 .762 r
.43339 .54071 .43516 .54516 .44517 .5535 .44338 .54903 Metetra
.241 .331 .756 r
.44338 .54903 .44517 .5535 .45526 .56262 .45347 .55813 Metetra
.632 .563 .758 r
.45347 .55813 .45526 .56262 .46571 .55832 .46389 .55526 Metetra
.626 .627 .831 r
.46389 .55526 .46571 .55832 .47617 .55526 .47435 .55313 Metetra
.933 .554 .217 r
.47435 .55313 .47617 .55526 .48627 .58818 .48443 .58605 Metetra
.705 .729 .869 r
.48443 .58605 .48627 .58818 .49693 .58505 .49511 .58128 Metetra
.712 .631 .765 r
.49511 .58128 .49693 .58505 .50766 .57581 .50583 .57415 Metetra
.599 .747 .948 r
.50583 .57415 .50766 .57581 .51837 .57476 .51656 .57227 Metetra
.86 .73 .718 r
.51656 .57227 .51837 .57476 .52912 .55535 .52733 .55285 Metetra
.864 .73 .712 r
.52733 .55285 .52912 .55535 .53981 .5351 .53803 .53259 Metetra
.841 .729 .74 r
.53803 .53259 .53981 .5351 .55046 .51824 .54869 .5166 Metetra
.824 .359 0 r
.54869 .5166 .55046 .51824 .56144 .53709 .55968 .53546 Metetra
.843 .389 0 r
.55968 .53546 .56144 .53709 .57264 .55762 .57088 .556 Metetra
.86 .415 .022 r
.57088 .556 .57264 .55762 .58407 .57997 .5823 .57836 Metetra
.911 .782 .706 r
.5823 .57836 .58407 .57997 .5948 .55807 .59303 .55538 Metetra
.791 .368 0 r
.59303 .55538 .5948 .55807 .60651 .58073 .60477 .57954 Metetra
.951 .615 .344 r
.60477 .57954 .60651 .58073 .61971 .64967 .61795 .64856 Metetra
.86 .408 .054 r
.61795 .64856 .61971 .64967 .63206 .67369 .63025 .67106 Metetra
.901 .738 .67 r
.63025 .67106 .63206 .67369 .64282 .64433 .64103 .64169 Metetra
.905 .737 .663 r
.64103 .64169 .64282 .64433 .65342 .61377 .65164 .61111 Metetra
.909 .737 .656 r
.65164 .61111 .65342 .61377 .66382 .58197 .66207 .5793 Metetra
.913 .736 .649 r
.66207 .5793 .66382 .58197 .67402 .54892 .67229 .54624 Metetra
.625 .665 .869 r
.67229 .54624 .67402 .54892 .68548 .54548 .68381 .54396 Metetra
.929 .545 .197 r
.68381 .54396 .68548 .54548 .69939 .58911 .69771 .58762 Metetra
.934 .555 .212 r
.69771 .58762 .69939 .58911 .71391 .63708 .71223 .63563 Metetra
.909 .503 .134 r
.71223 .63563 .71391 .63708 .72825 .67488 .72654 .673 Metetra
.645 .763 .934 r
.72654 .673 .72825 .67488 .7404 .67159 .7387 .66971 Metetra
.645 .763 .934 r
.7387 .66971 .7404 .67159 .7526 .66829 .75091 .6664 Metetra
.645 .763 .934 r
.75091 .6664 .7526 .66829 .76486 .66497 .76318 .66307 Metetra
.645 .763 .934 r
.76318 .66307 .76486 .66497 .77716 .66164 .77549 .65974 Metetra
.645 .763 .934 r
.77549 .65974 .77716 .66164 .78952 .6583 .78786 .65638 Metetra
.645 .763 .934 r
.78786 .65638 .78952 .6583 .80193 .65494 .80029 .65302 Metetra
.645 .763 .934 r
.80029 .65302 .80193 .65494 .8144 .65157 .81276 .64964 Metetra
.645 .763 .934 r
.81276 .64964 .8144 .65157 .82692 .64818 .8253 .64624 Metetra
.645 .763 .934 r
.8253 .64624 .82692 .64818 .83949 .64478 .83788 .64283 Metetra
.645 .763 .934 r
.83788 .64283 .83949 .64478 .85212 .64137 .85052 .63941 Metetra
.645 .763 .934 r
.85052 .63941 .85212 .64137 .8648 .63794 .86322 .63597 Metetra
.645 .763 .934 r
.86322 .63597 .8648 .63794 .87754 .63449 .87597 .63251 Metetra
.645 .763 .934 r
.87597 .63251 .87754 .63449 .89034 .63103 .88878 .62904 Metetra
.645 .763 .934 r
.88878 .62904 .89034 .63103 .90319 .62755 .90164 .62556 Metetra
.645 .763 .934 r
.90164 .62556 .90319 .62755 .91609 .62406 .91456 .62206 Metetra
.645 .763 .934 r
.91456 .62206 .91609 .62406 .92906 .62055 .92753 .61854 Metetra
.645 .763 .934 r
.92753 .61854 .92906 .62055 .94208 .61703 .94057 .61501 Metetra
.645 .763 .934 r
.94057 .61501 .94208 .61703 .95516 .61349 .95366 .61146 Metetra
.645 .763 .934 r
.95366 .61146 .95516 .61349 .96829 .60994 .96681 .6079 Metetra
.344 .501 .871 r
.35927 .58882 .36114 .59165 .37098 .5941 .36905 .59273 Metetra
.876 .777 .749 r
.36905 .59273 .37098 .5941 .38164 .57896 .3798 .57577 Metetra
.285 .437 .838 r
.3798 .57577 .38164 .57896 .39146 .58416 .38961 .58125 Metetra
.775 .686 .765 r
.38961 .58125 .39146 .58416 .40193 .57388 .40009 .57081 Metetra
.793 .683 .744 r
.40009 .57081 .40193 .57388 .41248 .56103 .41065 .55796 Metetra
.822 .69 .719 r
.41065 .55796 .41248 .56103 .42315 .54372 .42133 .54088 Metetra
.583 .619 .853 r
.42133 .54088 .42315 .54372 .43339 .54071 .4315 .54015 Metetra
.671 .12 0 r
.4315 .54015 .43339 .54071 .44338 .54903 .4415 .54848 Metetra
.7 .16 0 r
.4415 .54848 .44338 .54903 .45347 .55813 .4516 .55759 Metetra
.543 .874 .992 r
.4516 .55759 .45347 .55813 .46389 .55526 .46203 .5549 Metetra
.643 .924 .975 r
.46203 .5549 .46389 .55526 .47435 .55313 .47253 .55056 Metetra
.93 .55 .18 r
.47253 .55056 .47435 .55313 .48443 .58605 .48259 .58348 Metetra
.67 .681 .852 r
.48259 .58348 .48443 .58605 .49511 .58128 .49327 .57982 Metetra
.766 .808 .887 r
.49327 .57982 .49511 .58128 .50583 .57415 .504 .57314 Metetra
.527 .81 .998 r
.504 .57314 .50583 .57415 .51656 .57227 .51474 .57149 Metetra
.922 .832 .738 r
.51474 .57149 .51656 .57227 .52733 .55285 .52553 .55204 Metetra
.926 .828 .729 r
.52553 .55204 .52733 .55285 .53803 .53259 .53625 .53176 Metetra
.917 .838 .751 r
.53625 .53176 .53803 .53259 .54869 .5166 .54692 .51386 Metetra
.676 .249 0 r
.54692 .51386 .54869 .5166 .55968 .53546 .5579 .53271 Metetra
.721 .295 0 r
.5579 .53271 .55968 .53546 .57088 .556 .56909 .55324 Metetra
.76 .336 0 r
.56909 .55324 .57088 .556 .5823 .57836 .58051 .5756 Metetra
.871 .725 .698 r
.58051 .5756 .5823 .57836 .59303 .55538 .59126 .55291 Metetra
.827 .4 0 r
.59126 .55291 .59303 .55538 .60477 .57954 .60301 .57783 Metetra
.955 .618 .329 r
.60301 .57783 .60477 .57954 .61795 .64856 .61616 .64689 Metetra
.852 .405 0 r
.61616 .64689 .61795 .64856 .63025 .67106 .6285 .67072 Metetra
.968 .838 .662 r
.6285 .67072 .63025 .67106 .64103 .64169 .63931 .6413 Metetra
.969 .832 .652 r
.63931 .6413 .64103 .64169 .65164 .61111 .64995 .61068 Metetra
.971 .827 .644 r
.64995 .61068 .65164 .61111 .66207 .5793 .6604 .57882 Metetra
.972 .821 .635 r
.6604 .57882 .66207 .5793 .67229 .54624 .67065 .54571 Metetra
.665 .928 .972 r
.67065 .54571 .67229 .54624 .68381 .54396 .68206 .54065 Metetra
.89 .515 .051 r
.68206 .54065 .68381 .54396 .69771 .58762 .69594 .58429 Metetra
.903 .531 .079 r
.69594 .58429 .69771 .58762 .71223 .63563 .71044 .63228 Metetra
.842 .456 0 r
.71044 .63228 .71223 .63563 .72654 .673 .72482 .67112 Metetra
.645 .763 .934 r
.72482 .67112 .72654 .673 .7387 .66971 .73699 .66782 Metetra
.645 .763 .934 r
.73699 .66782 .7387 .66971 .75091 .6664 .74921 .6645 Metetra
.645 .763 .934 r
.74921 .6645 .75091 .6664 .76318 .66307 .76149 .66117 Metetra
.645 .763 .934 r
.76149 .66117 .76318 .66307 .77549 .65974 .77382 .65782 Metetra
.645 .763 .934 r
.77382 .65782 .77549 .65974 .78786 .65638 .7862 .65446 Metetra
.645 .763 .934 r
.7862 .65446 .78786 .65638 .80029 .65302 .79864 .65109 Metetra
.645 .763 .934 r
.79864 .65109 .80029 .65302 .81276 .64964 .81113 .6477 Metetra
.645 .763 .934 r
.81113 .6477 .81276 .64964 .8253 .64624 .82367 .6443 Metetra
.645 .763 .934 r
.82367 .6443 .8253 .64624 .83788 .64283 .83627 .64088 Metetra
.645 .763 .934 r
.83627 .64088 .83788 .64283 .85052 .63941 .84892 .63744 Metetra
.645 .763 .934 r
.84892 .63744 .85052 .63941 .86322 .63597 .86163 .634 Metetra
.645 .763 .934 r
.86163 .634 .86322 .63597 .87597 .63251 .87439 .63053 Metetra
.645 .763 .934 r
.87439 .63053 .87597 .63251 .88878 .62904 .88721 .62705 Metetra
.645 .763 .934 r
.88721 .62705 .88878 .62904 .90164 .62556 .90009 .62356 Metetra
.645 .763 .934 r
.90009 .62356 .90164 .62556 .91456 .62206 .91302 .62005 Metetra
.645 .763 .934 r
.91302 .62005 .91456 .62206 .92753 .61854 .92601 .61653 Metetra
.645 .763 .934 r
.92601 .61653 .92753 .61854 .94057 .61501 .93906 .61299 Metetra
.645 .763 .934 r
.93906 .61299 .94057 .61501 .95366 .61146 .95216 .60943 Metetra
.645 .763 .934 r
.95216 .60943 .95366 .61146 .96681 .6079 .96532 .60586 Metetra
0 .505 .84 r
.35731 .5879 .35927 .58882 .36905 .59273 .36715 .5906 Metetra
.841 .734 .745 r
.36715 .5906 .36905 .59273 .3798 .57577 .37785 .57503 Metetra
.388 0 0 r
.37785 .57503 .3798 .57577 .38961 .58125 .38769 .57987 Metetra
.825 .798 .826 r
.38769 .57987 .38961 .58125 .40009 .57081 .39817 .56979 Metetra
.868 .822 .801 r
.39817 .56979 .40009 .57081 .41065 .55796 .40875 .55692 Metetra
.893 .805 .754 r
.40875 .55692 .41065 .55796 .42133 .54088 .41944 .53989 Metetra
.588 .827 .99 r
.41944 .53989 .42133 .54088 .4315 .54015 .42967 .53757 Metetra
0 .257 .767 r
.42967 .53757 .4315 .54015 .4415 .54848 .43967 .54589 Metetra
0 .207 .732 r
.43967 .54589 .4415 .54848 .4516 .55759 .44976 .555 Metetra
.654 .67 .853 r
.44976 .555 .4516 .55759 .46203 .5549 .4602 .55196 Metetra
.638 .639 .835 r
.4602 .55196 .46203 .5549 .47253 .55056 .47068 .5494 Metetra
.925 .553 .285 r
.47068 .5494 .47253 .55056 .48259 .58348 .48074 .58235 Metetra
.73 .844 .935 r
.48074 .58235 .48259 .58348 .49327 .57982 .49144 .57709 Metetra
.712 .685 .822 r
.49144 .57709 .49327 .57982 .504 .57314 .50217 .57137 Metetra
.634 .748 .93 r
.50217 .57137 .504 .57314 .51474 .57149 .51292 .56877 Metetra
.853 .719 .715 r
.51292 .56877 .51474 .57149 .52553 .55204 .52372 .54931 Metetra
.857 .72 .71 r
.52372 .54931 .52553 .55204 .53625 .53176 .53446 .52902 Metetra
.836 .717 .734 r
.53446 .52902 .53625 .53176 .54692 .51386 .54515 .51271 Metetra
.848 .387 .034 r
.54515 .51271 .54692 .51386 .5579 .53271 .55613 .53158 Metetra
.862 .411 .066 r
.55613 .53158 .5579 .53271 .56909 .55324 .56732 .55212 Metetra
.874 .433 .095 r
.56732 .55212 .56909 .55324 .58051 .5756 .57874 .57449 Metetra
.931 .808 .701 r
.57874 .57449 .58051 .5756 .59126 .55291 .58948 .55055 Metetra
.853 .43 0 r
.58948 .55055 .59126 .55291 .60301 .57783 .60126 .57682 Metetra
.949 .614 .349 r
.60126 .57682 .60301 .57783 .61616 .64689 .61439 .64595 Metetra
.857 .402 .064 r
.61439 .64595 .61616 .64689 .6285 .67072 .62667 .66768 Metetra
.89 .723 .669 r
.62667 .66768 .6285 .67072 .63931 .6413 .6375 .63826 Metetra
.894 .723 .662 r
.6375 .63826 .63931 .6413 .64995 .61068 .64816 .60763 Metetra
.899 .723 .656 r
.64816 .60763 .64995 .61068 .6604 .57882 .65863 .57576 Metetra
.903 .723 .649 r
.65863 .57576 .6604 .57882 .67065 .54571 .6689 .54264 Metetra
.638 .645 .84 r
.6689 .54264 .67065 .54571 .68206 .54065 .68042 .53984 Metetra
.928 .547 .241 r
.68042 .53984 .68206 .54065 .69594 .58429 .69429 .58353 Metetra
.932 .556 .253 r
.69429 .58353 .69594 .58429 .71044 .63228 .70878 .63158 Metetra
.913 .511 .196 r
.70878 .63158 .71044 .63228 .72482 .67112 .72309 .66923 Metetra
.645 .763 .934 r
.72309 .66923 .72482 .67112 .73699 .66782 .73528 .66592 Metetra
.645 .763 .934 r
.73528 .66592 .73699 .66782 .74921 .6645 .74751 .6626 Metetra
.645 .763 .934 r
.74751 .6626 .74921 .6645 .76149 .66117 .7598 .65926 Metetra
.645 .763 .934 r
.7598 .65926 .76149 .66117 .77382 .65782 .77214 .6559 Metetra
.645 .763 .934 r
.77214 .6559 .77382 .65782 .7862 .65446 .78453 .65254 Metetra
.645 .763 .934 r
.78453 .65254 .7862 .65446 .79864 .65109 .79698 .64915 Metetra
.645 .763 .934 r
.79698 .64915 .79864 .65109 .81113 .6477 .80948 .64576 Metetra
.645 .763 .934 r
.80948 .64576 .81113 .6477 .82367 .6443 .82204 .64234 Metetra
.645 .763 .934 r
.82204 .64234 .82367 .6443 .83627 .64088 .83465 .63892 Metetra
.645 .763 .934 r
.83465 .63892 .83627 .64088 .84892 .63744 .84731 .63548 Metetra
.645 .763 .934 r
.84731 .63548 .84892 .63744 .86163 .634 .86003 .63202 Metetra
.645 .763 .934 r
.86003 .63202 .86163 .634 .87439 .63053 .87281 .62855 Metetra
.645 .763 .934 r
.87281 .62855 .87439 .63053 .88721 .62705 .88564 .62506 Metetra
.645 .763 .934 r
.88564 .62506 .88721 .62705 .90009 .62356 .89853 .62156 Metetra
.645 .763 .934 r
.89853 .62156 .90009 .62356 .91302 .62005 .91148 .61804 Metetra
.645 .763 .934 r
.91148 .61804 .91302 .62005 .92601 .61653 .92448 .61451 Metetra
.645 .763 .934 r
.92448 .61451 .92601 .61653 .93906 .61299 .93754 .61096 Metetra
.645 .763 .934 r
.93754 .61096 .93906 .61299 .95216 .60943 .95066 .60739 Metetra
.645 .763 .934 r
.95066 .60739 .95216 .60943 .96532 .60586 .96383 .60381 Metetra
.33 .524 .894 r
.35542 .58538 .35731 .5879 .36715 .5906 .36522 .58889 Metetra
.859 .759 .751 r
.36522 .58889 .36715 .5906 .37785 .57503 .37595 .57288 Metetra
.137 .454 .884 r
.37595 .57288 .37785 .57503 .38769 .57987 .3858 .57769 Metetra
.793 .732 .796 r
.3858 .57769 .38769 .57987 .39817 .56979 .39629 .56782 Metetra
.831 .748 .773 r
.39629 .56782 .39817 .56979 .40875 .55692 .40688 .55494 Metetra
.861 .745 .733 r
.40688 .55494 .40875 .55692 .41944 .53989 .4176 .53727 Metetra
.602 .645 .866 r
.4176 .53727 .41944 .53989 .42967 .53757 .4278 .53592 Metetra
0 .096 .577 r
.4278 .53592 .42967 .53757 .43967 .54589 .43781 .54424 Metetra
.483 0 0 r
.43781 .54424 .43967 .54589 .44976 .555 .4479 .55335 Metetra
.644 .759 .932 r
.4479 .55335 .44976 .555 .4602 .55196 .45835 .55054 Metetra
.66 .793 .945 r
.45835 .55054 .4602 .55196 .47068 .5494 .46884 .54724 Metetra
.933 .554 .216 r
.46884 .54724 .47068 .5494 .48074 .58235 .47889 .5802 Metetra
.721 .731 .859 r
.47889 .5802 .48074 .58235 .49144 .57709 .4896 .57473 Metetra
.685 .705 .862 r
.4896 .57473 .49144 .57709 .50217 .57137 .50033 .57055 Metetra
.582 .856 .995 r
.50033 .57055 .50217 .57137 .51292 .56877 .51109 .5678 Metetra
.916 .82 .737 r
.51109 .5678 .51292 .56877 .52372 .54931 .52191 .54832 Metetra
.919 .816 .728 r
.52191 .54832 .52372 .54931 .53446 .52902 .53267 .528 Metetra
.911 .825 .749 r
.53267 .528 .53446 .52902 .54515 .51271 .54337 .50997 Metetra
.679 .251 0 r
.54337 .50997 .54515 .51271 .55613 .53158 .55435 .52883 Metetra
.724 .297 0 r
.55435 .52883 .55613 .53158 .56732 .55212 .56553 .54937 Metetra
.762 .338 0 r
.56553 .54937 .56732 .55212 .57874 .57449 .57694 .57173 Metetra
.877 .726 .691 r
.57694 .57173 .57874 .57449 .58948 .55055 .5877 .5476 Metetra
.827 .421 0 r
.5877 .5476 .58948 .55055 .60126 .57682 .5995 .57547 Metetra
.952 .616 .34 r
.5995 .57547 .60126 .57682 .61439 .64595 .61261 .64467 Metetra
.846 .386 .01 r
.61261 .64467 .61439 .64595 .62667 .66768 .62488 .66627 Metetra
.938 .789 .67 r
.62488 .66627 .62667 .66768 .6375 .63826 .63574 .63681 Metetra
.94 .786 .662 r
.63574 .63681 .6375 .63826 .64816 .60763 .64642 .60615 Metetra
.943 .783 .654 r
.64642 .60615 .64816 .60763 .65863 .57576 .65692 .57426 Metetra
.945 .78 .646 r
.65692 .57426 .65863 .57576 .6689 .54264 .66721 .5411 Metetra
.664 .799 .947 r
.66721 .5411 .6689 .54264 .68042 .53984 .67869 .53736 Metetra
.918 .535 .126 r
.67869 .53736 .68042 .53984 .69429 .58353 .69256 .58106 Metetra
.925 .547 .148 r
.69256 .58106 .69429 .58353 .70878 .63158 .70703 .62912 Metetra
.886 .486 .047 r
.70703 .62912 .70878 .63158 .72309 .66923 .72137 .66734 Metetra
.645 .763 .934 r
.72137 .66734 .72309 .66923 .73528 .66592 .73356 .66402 Metetra
.645 .763 .934 r
.73356 .66402 .73528 .66592 .74751 .6626 .74581 .66069 Metetra
.645 .763 .934 r
.74581 .66069 .74751 .6626 .7598 .65926 .75811 .65734 Metetra
.645 .763 .934 r
.75811 .65734 .7598 .65926 .77214 .6559 .77046 .65398 Metetra
.645 .763 .934 r
.77046 .65398 .77214 .6559 .78453 .65254 .78286 .65061 Metetra
.645 .763 .934 r
.78286 .65061 .78453 .65254 .79698 .64915 .79532 .64721 Metetra
.645 .763 .934 r
.79532 .64721 .79698 .64915 .80948 .64576 .80784 .64381 Metetra
.645 .763 .934 r
.80784 .64381 .80948 .64576 .82204 .64234 .8204 .64039 Metetra
.645 .763 .934 r
.8204 .64039 .82204 .64234 .83465 .63892 .83302 .63695 Metetra
.645 .763 .934 r
.83302 .63695 .83465 .63892 .84731 .63548 .8457 .6335 Metetra
.645 .763 .934 r
.8457 .6335 .84731 .63548 .86003 .63202 .85843 .63004 Metetra
.645 .763 .934 r
.85843 .63004 .86003 .63202 .87281 .62855 .87122 .62656 Metetra
.645 .763 .934 r
.87122 .62656 .87281 .62855 .88564 .62506 .88407 .62306 Metetra
.645 .763 .934 r
.88407 .62306 .88564 .62506 .89853 .62156 .89697 .61955 Metetra
.645 .763 .934 r
.89697 .61955 .89853 .62156 .91148 .61804 .90993 .61602 Metetra
.645 .763 .934 r
.90993 .61602 .91148 .61804 .92448 .61451 .92294 .61248 Metetra
.645 .763 .934 r
.92294 .61248 .92448 .61451 .93754 .61096 .93602 .60892 Metetra
.645 .763 .934 r
.93602 .60892 .93754 .61096 .95066 .60739 .94915 .60535 Metetra
.645 .763 .934 r
.94915 .60535 .95066 .60739 .96383 .60381 .96234 .60176 Metetra
.028 .547 .866 r
.35344 .58449 .35542 .58538 .36522 .58889 .36331 .58675 Metetra
.837 .734 .751 r
.36331 .58675 .36522 .58889 .37595 .57288 .37401 .57188 Metetra
0 .316 .691 r
.37401 .57188 .37595 .57288 .3858 .57769 .38387 .57638 Metetra
.828 .806 .83 r
.38387 .57638 .3858 .57769 .39629 .56782 .39438 .56633 Metetra
.849 .784 .787 r
.39438 .56633 .39629 .56782 .40688 .55494 .40498 .55343 Metetra
.875 .774 .746 r
.40498 .55343 .40688 .55494 .4176 .53727 .4157 .53636 Metetra
.596 .841 .991 r
.4157 .53636 .4176 .53727 .4278 .53592 .42595 .53379 Metetra
0 .189 .703 r
.42595 .53379 .4278 .53592 .43781 .54424 .43595 .54211 Metetra
0 .132 .652 r
.43595 .54211 .43781 .54424 .4479 .55335 .44605 .55121 Metetra
.668 .714 .883 r
.44605 .55121 .4479 .55335 .45835 .55054 .45651 .54779 Metetra
.611 .643 .857 r
.45651 .54779 .45835 .55054 .46884 .54724 .46698 .54613 Metetra
.925 .552 .288 r
.46698 .54613 .46884 .54724 .47889 .5802 .47702 .57912 Metetra
.747 .853 .928 r
.47702 .57912 .47889 .5802 .4896 .57473 .48775 .57331 Metetra
.74 .811 .908 r
.48775 .57331 .4896 .57473 .50033 .57055 .4985 .56765 Metetra
.64 .648 .842 r
.4985 .56765 .50033 .57055 .51109 .5678 .50927 .56494 Metetra
.848 .713 .713 r
.50927 .56494 .51109 .5678 .52191 .54832 .5201 .54545 Metetra
.853 .714 .708 r
.5201 .54545 .52191 .54832 .53267 .528 .53087 .52512 Metetra
.83 .71 .732 r
.53087 .52512 .53267 .528 .54337 .50997 .5416 .50901 Metetra
.853 .395 .066 r
.5416 .50901 .54337 .50997 .55435 .52883 .55257 .52788 Metetra
.865 .417 .095 r
.55257 .52788 .55435 .52883 .56553 .54937 .56376 .54844 Metetra
.876 .438 .121 r
.56376 .54844 .56553 .54937 .57694 .57173 .57517 .57083 Metetra
.939 .819 .7 r
.57517 .57083 .57694 .57173 .5877 .5476 .58595 .54673 Metetra
.894 .474 .167 r
.58595 .54673 .5877 .5476 .5995 .57547 .59772 .5731 Metetra
.958 .621 .309 r
.59772 .5731 .5995 .57547 .61261 .64467 .61079 .64232 Metetra
.748 .299 0 r
.61079 .64232 .61261 .64467 .62488 .66627 .62305 .66338 Metetra
.895 .729 .669 r
.62305 .66338 .62488 .66627 .63574 .63681 .63392 .63391 Metetra
.899 .729 .663 r
.63392 .63391 .63574 .63681 .64642 .60615 .64462 .60324 Metetra
.903 .729 .656 r
.64462 .60324 .64642 .60615 .65692 .57426 .65514 .57133 Metetra
.907 .728 .649 r
.65514 .57133 .65692 .57426 .66721 .5411 .66546 .53817 Metetra
.606 .64 .858 r
.66546 .53817 .66721 .5411 .67869 .53736 .67704 .5365 Metetra
.929 .547 .238 r
.67704 .5365 .67869 .53736 .69256 .58106 .6909 .58025 Metetra
.932 .556 .25 r
.6909 .58025 .69256 .58106 .70703 .62912 .70537 .62836 Metetra
.911 .508 .188 r
.70537 .62836 .70703 .62912 .72137 .66734 .71963 .66545 Metetra
.645 .763 .934 r
.71963 .66545 .72137 .66734 .73356 .66402 .73184 .66212 Metetra
.645 .763 .934 r
.73184 .66212 .73356 .66402 .74581 .66069 .7441 .65878 Metetra
.645 .763 .934 r
.7441 .65878 .74581 .66069 .75811 .65734 .75641 .65542 Metetra
.645 .763 .934 r
.75641 .65542 .75811 .65734 .77046 .65398 .76877 .65205 Metetra
.645 .763 .934 r
.76877 .65205 .77046 .65398 .78286 .65061 .78119 .64867 Metetra
.645 .763 .934 r
.78119 .64867 .78286 .65061 .79532 .64721 .79366 .64527 Metetra
.645 .763 .934 r
.79366 .64527 .79532 .64721 .80784 .64381 .80618 .64186 Metetra
.645 .763 .934 r
.80618 .64186 .80784 .64381 .8204 .64039 .81876 .63843 Metetra
.645 .763 .934 r
.81876 .63843 .8204 .64039 .83302 .63695 .8314 .63498 Metetra
.645 .763 .934 r
.8314 .63498 .83302 .63695 .8457 .6335 .84409 .63152 Metetra
.645 .763 .934 r
.84409 .63152 .8457 .6335 .85843 .63004 .85683 .62805 Metetra
.645 .763 .934 r
.85683 .62805 .85843 .63004 .87122 .62656 .86963 .62456 Metetra
.645 .763 .934 r
.86963 .62456 .87122 .62656 .88407 .62306 .88249 .62106 Metetra
.645 .763 .934 r
.88249 .62106 .88407 .62306 .89697 .61955 .89541 .61754 Metetra
.645 .763 .934 r
.89541 .61754 .89697 .61955 .90993 .61602 .90838 .614 Metetra
.645 .763 .934 r
.90838 .614 .90993 .61602 .92294 .61248 .92141 .61045 Metetra
.645 .763 .934 r
.92141 .61045 .92294 .61248 .93602 .60892 .93449 .60688 Metetra
.645 .763 .934 r
.93449 .60688 .93602 .60892 .94915 .60535 .94764 .6033 Metetra
.645 .763 .934 r
.94764 .6033 .94915 .60535 .96234 .60176 .96084 .5997 Metetra
.411 .581 .909 r
.35154 .58211 .35344 .58449 .36331 .58675 .36141 .58428 Metetra
.819 .715 .75 r
.36141 .58428 .36331 .58675 .37401 .57188 .37208 .57037 Metetra
.02 .464 .874 r
.37208 .57037 .37401 .57188 .38387 .57638 .38196 .57441 Metetra
.806 .749 .8 r
.38196 .57441 .38387 .57638 .39438 .56633 .39249 .56409 Metetra
.821 .732 .766 r
.39249 .56409 .39438 .56633 .40498 .55343 .40311 .55118 Metetra
.85 .731 .732 r
.40311 .55118 .40498 .55343 .4157 .53636 .41385 .53391 Metetra
.606 .662 .878 r
.41385 .53391 .4157 .53636 .42595 .53379 .42407 .53238 Metetra
.501 0 0 r
.42407 .53238 .42595 .53379 .43595 .54211 .43408 .5407 Metetra
.556 .016 0 r
.43408 .5407 .43595 .54211 .44605 .55121 .44417 .54981 Metetra
.7 .803 .928 r
.44417 .54981 .44605 .55121 .45651 .54779 .45466 .54549 Metetra
.558 .659 .904 r
.45466 .54549 .45651 .54779 .46698 .54613 .46512 .54499 Metetra
.925 .552 .287 r
.46512 .54499 .46698 .54613 .47702 .57912 .47515 .57801 Metetra
.751 .85 .924 r
.47515 .57801 .47702 .57912 .48775 .57331 .48589 .57207 Metetra
.76 .835 .909 r
.48589 .57207 .48775 .57331 .4985 .56765 .49666 .56574 Metetra
.61 .725 .927 r
.49666 .56574 .4985 .56765 .50927 .56494 .50743 .56374 Metetra
.907 .805 .735 r
.50743 .56374 .50927 .56494 .5201 .54545 .51828 .54423 Metetra
.911 .802 .727 r
.51828 .54423 .5201 .54545 .53087 .52512 .52908 .52388 Metetra
.899 .811 .753 r
.52908 .52388 .53087 .52512 .5416 .50901 .53981 .50651 Metetra
.726 .283 0 r
.53981 .50651 .5416 .50901 .55257 .52788 .55078 .52539 Metetra
.763 .324 0 r
.55078 .52539 .55257 .52788 .56376 .54844 .56196 .54594 Metetra
.796 .361 0 r
.56196 .54594 .56376 .54844 .57517 .57083 .57336 .56833 Metetra
.882 .738 .698 r
.57336 .56833 .57517 .57083 .58595 .54673 .58418 .54514 Metetra
.881 .45 .072 r
.58418 .54514 .58595 .54673 .59772 .5731 .59592 .57053 Metetra
.959 .621 .302 r
.59592 .57053 .59772 .5731 .61079 .64232 .60897 .63975 Metetra
.716 .275 0 r
.60897 .63975 .61079 .64232 .62305 .66338 .62122 .66072 Metetra
.901 .738 .67 r
.62122 .66072 .62305 .66338 .63392 .63391 .63211 .63124 Metetra
.905 .737 .663 r
.63211 .63124 .63392 .63391 .64462 .60324 .64283 .60055 Metetra
.909 .737 .656 r
.64283 .60055 .64462 .60324 .65514 .57133 .65337 .56863 Metetra
.913 .736 .649 r
.65337 .56863 .65514 .57133 .66546 .53817 .66371 .53546 Metetra
.553 .633 .884 r
.66371 .53546 .66546 .53817 .67704 .5365 .67537 .53526 Metetra
.93 .547 .216 r
.67537 .53526 .67704 .5365 .6909 .58025 .68922 .57905 Metetra
.934 .556 .23 r
.68922 .57905 .6909 .58025 .70537 .62836 .70368 .62722 Metetra
.908 .5 .151 r
.70368 .62722 .70537 .62836 .71963 .66545 .7179 .66355 Metetra
.645 .763 .934 r
.7179 .66355 .71963 .66545 .73184 .66212 .73012 .66021 Metetra
.645 .763 .934 r
.73012 .66021 .73184 .66212 .7441 .65878 .74238 .65686 Metetra
.645 .763 .934 r
.74238 .65686 .7441 .65878 .75641 .65542 .75471 .6535 Metetra
.645 .763 .934 r
.75471 .6535 .75641 .65542 .76877 .65205 .76708 .65012 Metetra
.645 .763 .934 r
.76708 .65012 .76877 .65205 .78119 .64867 .77951 .64673 Metetra
.645 .763 .934 r
.77951 .64673 .78119 .64867 .79366 .64527 .79199 .64332 Metetra
.645 .763 .934 r
.79199 .64332 .79366 .64527 .80618 .64186 .80453 .6399 Metetra
.645 .763 .934 r
.80453 .6399 .80618 .64186 .81876 .63843 .81712 .63646 Metetra
.645 .763 .934 r
.81712 .63646 .81876 .63843 .8314 .63498 .82977 .63301 Metetra
.645 .763 .934 r
.82977 .63301 .8314 .63498 .84409 .63152 .84247 .62954 Metetra
.645 .763 .934 r
.84247 .62954 .84409 .63152 .85683 .62805 .85523 .62606 Metetra
.645 .763 .934 r
.85523 .62606 .85683 .62805 .86963 .62456 .86804 .62256 Metetra
.645 .763 .934 r
.86804 .62256 .86963 .62456 .88249 .62106 .88091 .61905 Metetra
.645 .763 .934 r
.88091 .61905 .88249 .62106 .89541 .61754 .89384 .61552 Metetra
.645 .763 .934 r
.89384 .61552 .89541 .61754 .90838 .614 .90682 .61197 Metetra
.645 .763 .934 r
.90682 .61197 .90838 .614 .92141 .61045 .91986 .60841 Metetra
.645 .763 .934 r
.91986 .60841 .92141 .61045 .93449 .60688 .93296 .60484 Metetra
.645 .763 .934 r
.93296 .60484 .93449 .60688 .94764 .6033 .94612 .60124 Metetra
.645 .763 .934 r
.94612 .60124 .94764 .6033 .96084 .5997 .95934 .59764 Metetra
.105 .594 .906 r
.34956 .58116 .35154 .58211 .36141 .58428 .35945 .58305 Metetra
.868 .797 .778 r
.35945 .58305 .36141 .58428 .37208 .57037 .37015 .5687 Metetra
.022 .444 .87 r
.37015 .5687 .37208 .57037 .38196 .57441 .38002 .57316 Metetra
.831 .812 .832 r
.38002 .57316 .38196 .57441 .39249 .56409 .39055 .56305 Metetra
.868 .821 .8 r
.39055 .56305 .39249 .56409 .40311 .55118 .40119 .55013 Metetra
.893 .804 .753 r
.40119 .55013 .40311 .55118 .41385 .53391 .41194 .53291 Metetra
.638 .839 .978 r
.41194 .53291 .41385 .53391 .42407 .53238 .42222 .52978 Metetra
0 .255 .766 r
.42222 .52978 .42407 .53238 .43408 .5407 .43223 .5381 Metetra
0 .205 .73 r
.43223 .5381 .43408 .5407 .44417 .54981 .44232 .5472 Metetra
.666 .675 .849 r
.44232 .5472 .44417 .54981 .45466 .54549 .4528 .54368 Metetra
.562 .716 .944 r
.4528 .54368 .45466 .54549 .46512 .54499 .46328 .54266 Metetra
.932 .553 .203 r
.46328 .54266 .46512 .54499 .47515 .57801 .47329 .57568 Metetra
.727 .719 .843 r
.47329 .57568 .47515 .57801 .48589 .57207 .48404 .56969 Metetra
.729 .717 .84 r
.48404 .56969 .48589 .57207 .49666 .56574 .49482 .56358 Metetra
.637 .708 .899 r
.49482 .56358 .49666 .56574 .50743 .56374 .5056 .561 Metetra
.853 .72 .715 r
.5056 .561 .50743 .56374 .51828 .54423 .51646 .54149 Metetra
.857 .72 .71 r
.51646 .54149 .51828 .54423 .52908 .52388 .52727 .52113 Metetra
.832 .717 .738 r
.52727 .52113 .52908 .52388 .53981 .50651 .53803 .50534 Metetra
.847 .386 .032 r
.53803 .50534 .53981 .50651 .55078 .52539 .549 .52423 Metetra
.862 .41 .064 r
.549 .52423 .55078 .52539 .56196 .54594 .56017 .5448 Metetra
.874 .432 .094 r
.56017 .5448 .56196 .54594 .57336 .56833 .57157 .56721 Metetra
.931 .808 .701 r
.57157 .56721 .57336 .56833 .58418 .54514 .5824 .54326 Metetra
.874 .444 .038 r
.5824 .54326 .58418 .54514 .59592 .57053 .59415 .569 Metetra
.953 .617 .335 r
.59415 .569 .59592 .57053 .60897 .63975 .60717 .63828 Metetra
.829 .364 0 r
.60717 .63828 .60897 .63975 .62122 .66072 .61941 .65921 Metetra
.935 .786 .67 r
.61941 .65921 .62122 .66072 .63211 .63124 .63033 .6297 Metetra
.938 .783 .662 r
.63033 .6297 .63211 .63124 .64283 .60055 .64108 .59899 Metetra
.941 .78 .654 r
.64108 .59899 .64283 .60055 .65337 .56863 .65164 .56704 Metetra
.943 .777 .646 r
.65164 .56704 .65337 .56863 .66371 .53546 .66201 .53383 Metetra
.527 .738 .972 r
.66201 .53383 .66371 .53546 .67537 .53526 .67364 .53297 Metetra
.922 .538 .142 r
.67364 .53297 .67537 .53526 .68922 .57905 .68748 .57677 Metetra
.928 .55 .163 r
.68748 .57677 .68922 .57905 .70368 .62722 .70193 .62495 Metetra
.886 .48 .05 r
.70193 .62495 .70368 .62722 .7179 .66355 .71616 .66164 Metetra
.645 .763 .934 r
.71616 .66164 .7179 .66355 .73012 .66021 .72839 .6583 Metetra
.645 .763 .934 r
.72839 .6583 .73012 .66021 .74238 .65686 .74067 .65494 Metetra
.645 .763 .934 r
.74067 .65494 .74238 .65686 .75471 .6535 .753 .65157 Metetra
.645 .763 .934 r
.753 .65157 .75471 .6535 .76708 .65012 .76539 .64818 Metetra
.645 .763 .934 r
.76539 .64818 .76708 .65012 .77951 .64673 .77783 .64478 Metetra
.645 .763 .934 r
.77783 .64478 .77951 .64673 .79199 .64332 .79032 .64137 Metetra
.645 .763 .934 r
.79032 .64137 .79199 .64332 .80453 .6399 .80287 .63794 Metetra
.645 .763 .934 r
.80287 .63794 .80453 .6399 .81712 .63646 .81547 .63449 Metetra
.645 .763 .934 r
.81547 .63449 .81712 .63646 .82977 .63301 .82813 .63103 Metetra
.645 .763 .934 r
.82813 .63103 .82977 .63301 .84247 .62954 .84085 .62755 Metetra
.645 .763 .934 r
.84085 .62755 .84247 .62954 .85523 .62606 .85362 .62406 Metetra
.645 .763 .934 r
.85362 .62406 .85523 .62606 .86804 .62256 .86644 .62055 Metetra
.645 .763 .934 r
.86644 .62055 .86804 .62256 .88091 .61905 .87933 .61703 Metetra
.645 .763 .934 r
.87933 .61703 .88091 .61905 .89384 .61552 .89227 .61349 Metetra
.645 .763 .934 r
.89227 .61349 .89384 .61552 .90682 .61197 .90526 .60994 Metetra
.645 .763 .934 r
.90526 .60994 .90682 .61197 .91986 .60841 .91832 .60637 Metetra
.645 .763 .934 r
.91832 .60637 .91986 .60841 .93296 .60484 .93143 .60278 Metetra
.645 .763 .934 r
.93143 .60278 .93296 .60484 .94612 .60124 .9446 .59918 Metetra
.645 .763 .934 r
.9446 .59918 .94612 .60124 .95934 .59764 .95783 .59557 Metetra
.475 .614 .908 r
.34764 .57879 .34956 .58116 .35945 .58305 .35757 .57995 Metetra
.79 .681 .744 r
.35757 .57995 .35945 .58305 .37015 .5687 .36821 .56725 Metetra
.108 .53 .912 r
.36821 .56725 .37015 .5687 .38002 .57316 .37814 .57047 Metetra
.784 .7 .772 r
.37814 .57047 .38002 .57316 .39055 .56305 .3887 .55985 Metetra
.79 .678 .741 r
.3887 .55985 .39055 .56305 .40119 .55013 .39934 .54692 Metetra
.814 .685 .721 r
.39934 .54692 .40119 .55013 .41194 .53291 .41008 .53056 Metetra
.593 .667 .89 r
.41008 .53056 .41194 .53291 .42222 .52978 .42031 .52932 Metetra
.679 .132 0 r
.42031 .52932 .42222 .52978 .43223 .5381 .43032 .53765 Metetra
.706 .17 0 r
.43032 .53765 .43223 .5381 .44232 .5472 .44041 .54676 Metetra
.73 .929 .956 r
.44041 .54676 .44232 .5472 .4528 .54368 .45096 .54105 Metetra
.483 .596 .89 r
.45096 .54105 .4528 .54368 .46328 .54266 .46139 .54239 Metetra
.91 .546 .331 r
.46139 .54239 .46328 .54266 .47329 .57568 .47139 .57546 Metetra
.737 .955 .944 r
.47139 .57546 .47329 .57568 .48404 .56969 .48216 .56906 Metetra
.798 .91 .917 r
.48216 .56906 .48404 .56969 .49482 .56358 .49297 .56148 Metetra
.609 .706 .913 r
.49297 .56148 .49482 .56358 .5056 .561 .50375 .55959 Metetra
.9 .792 .733 r
.50375 .55959 .5056 .561 .51646 .54149 .51464 .54005 Metetra
.903 .79 .725 r
.51464 .54005 .51646 .54149 .52727 .52113 .52547 .51967 Metetra
.886 .799 .758 r
.52547 .51967 .52727 .52113 .53803 .50534 .53624 .50318 Metetra
.775 .319 0 r
.53624 .50318 .53803 .50534 .549 .52423 .5472 .52207 Metetra
.805 .355 0 r
.5472 .52207 .549 .52423 .56017 .5448 .55837 .54264 Metetra
.829 .387 0 r
.55837 .54264 .56017 .5448 .57157 .56721 .56977 .56505 Metetra
.893 .755 .702 r
.56977 .56505 .57157 .56721 .5824 .54326 .58063 .54198 Metetra
.881 .446 .095 r
.58063 .54198 .5824 .54326 .59415 .569 .59234 .56643 Metetra
.959 .621 .302 r
.59234 .56643 .59415 .569 .60717 .63828 .60534 .63571 Metetra
.693 .25 0 r
.60534 .63571 .60717 .63828 .61941 .65921 .61756 .65584 Metetra
.882 .713 .667 r
.61756 .65584 .61941 .65921 .63033 .6297 .62849 .62633 Metetra
.887 .713 .661 r
.62849 .62633 .63033 .6297 .64108 .59899 .63926 .59561 Metetra
.891 .714 .655 r
.63926 .59561 .64108 .59899 .65164 .56704 .64984 .56366 Metetra
.895 .714 .649 r
.64984 .56366 .65164 .56704 .66201 .53383 .66022 .53045 Metetra
.488 .551 .847 r
.66022 .53045 .66201 .53383 .67364 .53297 .672 .53257 Metetra
.925 .547 .263 r
.672 .53257 .67364 .53297 .68748 .57677 .68583 .57644 Metetra
.929 .555 .273 r
.68583 .57644 .68748 .57677 .70193 .62495 .70027 .6247 Metetra
.904 .499 .21 r
.70027 .6247 .70193 .62495 .71616 .66164 .71441 .65974 Metetra
.645 .763 .934 r
.71441 .65974 .71616 .66164 .72839 .6583 .72665 .65638 Metetra
.645 .763 .934 r
.72665 .65638 .72839 .6583 .74067 .65494 .73894 .65302 Metetra
.645 .763 .934 r
.73894 .65302 .74067 .65494 .753 .65157 .75129 .64964 Metetra
.645 .763 .934 r
.75129 .64964 .753 .65157 .76539 .64818 .76369 .64624 Metetra
.645 .763 .934 r
.76369 .64624 .76539 .64818 .77783 .64478 .77614 .64283 Metetra
.645 .763 .934 r
.77614 .64283 .77783 .64478 .79032 .64137 .78865 .63941 Metetra
.645 .763 .934 r
.78865 .63941 .79032 .64137 .80287 .63794 .80121 .63597 Metetra
.645 .763 .934 r
.80121 .63597 .80287 .63794 .81547 .63449 .81382 .63251 Metetra
.645 .763 .934 r
.81382 .63251 .81547 .63449 .82813 .63103 .82649 .62904 Metetra
.645 .763 .934 r
.82649 .62904 .82813 .63103 .84085 .62755 .83922 .62556 Metetra
.645 .763 .934 r
.83922 .62556 .84085 .62755 .85362 .62406 .852 .62206 Metetra
.645 .763 .934 r
.852 .62206 .85362 .62406 .86644 .62055 .86484 .61854 Metetra
.645 .763 .934 r
.86484 .61854 .86644 .62055 .87933 .61703 .87774 .61501 Metetra
.645 .763 .934 r
.87774 .61501 .87933 .61703 .89227 .61349 .89069 .61146 Metetra
.645 .763 .934 r
.89069 .61146 .89227 .61349 .90526 .60994 .9037 .6079 Metetra
.645 .763 .934 r
.9037 .6079 .90526 .60994 .91832 .60637 .91677 .60432 Metetra
.645 .763 .934 r
.91677 .60432 .91832 .60637 .93143 .60278 .92989 .60073 Metetra
.645 .763 .934 r
.92989 .60073 .93143 .60278 .9446 .59918 .94308 .59712 Metetra
.645 .763 .934 r
.94308 .59712 .9446 .59918 .95783 .59557 .95632 .59349 Metetra
.211 .619 .951 r
.34567 .57753 .34764 .57879 .35757 .57995 .35556 .57947 Metetra
.897 .857 .794 r
.35556 .57947 .35757 .57995 .36821 .56725 .36629 .56509 Metetra
.15 .464 .889 r
.36629 .56509 .36821 .56725 .37814 .57047 .37616 .56972 Metetra
.852 .863 .849 r
.37616 .56972 .37814 .57047 .3887 .55985 .38673 .55941 Metetra
.891 .877 .815 r
.38673 .55941 .3887 .55985 .39934 .54692 .39739 .54646 Metetra
.916 .846 .76 r
.39739 .54646 .39934 .54692 .41008 .53056 .40818 .52916 Metetra
.651 .789 .948 r
.40818 .52916 .41008 .53056 .42031 .52932 .41847 .52612 Metetra
.074 .307 .789 r
.41847 .52612 .42031 .52932 .43032 .53765 .42848 .53443 Metetra
.015 .268 .769 r
.42848 .53443 .43032 .53765 .44041 .54676 .43857 .54353 Metetra
.658 .632 .812 r
.43857 .54353 .44041 .54676 .45096 .54105 .44907 .53999 Metetra
.488 .787 .998 r
.44907 .53999 .45096 .54105 .46139 .54239 .45956 .53894 Metetra
.91 .535 .098 r
.45956 .53894 .46139 .54239 .47139 .57546 .46954 .57199 Metetra
.693 .638 .789 r
.46954 .57199 .47139 .57546 .48216 .56906 .48031 .56642 Metetra
.737 .701 .817 r
.48031 .56642 .48216 .56906 .49297 .56148 .49111 .55946 Metetra
.617 .717 .917 r
.49111 .55946 .49297 .56148 .50375 .55959 .50191 .55734 Metetra
.87 .744 .722 r
.50191 .55734 .50375 .55959 .51464 .54005 .51281 .53779 Metetra
.874 .744 .716 r
.51281 .53779 .51464 .54005 .52547 .51967 .52365 .5174 Metetra
.851 .745 .747 r
.52365 .5174 .52547 .51967 .53624 .50318 .53444 .50142 Metetra
.817 .353 0 r
.53444 .50142 .53624 .50318 .5472 .52207 .5454 .52032 Metetra
.838 .384 0 r
.5454 .52032 .5472 .52207 .55837 .54264 .55657 .54091 Metetra
.856 .411 .008 r
.55657 .54091 .55837 .54264 .56977 .56505 .56796 .56333 Metetra
.909 .777 .704 r
.56796 .56333 .56977 .56505 .58063 .54198 .57884 .53995 Metetra
.856 .421 0 r
.57884 .53995 .58063 .54198 .59234 .56643 .59055 .56459 Metetra
.955 .618 .326 r
.59055 .56459 .59234 .56643 .60534 .63571 .60352 .63391 Metetra
.818 .357 0 r
.60352 .63391 .60534 .63571 .61756 .65584 .61578 .65548 Metetra
.967 .838 .662 r
.61578 .65548 .61756 .65584 .62849 .62633 .62674 .62593 Metetra
.969 .832 .653 r
.62674 .62593 .62849 .62633 .63926 .59561 .63753 .59516 Metetra
.97 .826 .644 r
.63753 .59516 .63926 .59561 .64984 .56366 .64814 .56316 Metetra
.972 .821 .635 r
.64814 .56316 .64984 .56366 .66022 .53045 .65855 .5299 Metetra
.319 .774 .952 r
.65855 .5299 .66022 .53045 .672 .53257 .67021 .52901 Metetra
.882 .509 .034 r
.67021 .52901 .672 .53257 .68583 .57644 .68403 .57285 Metetra
.896 .527 .064 r
.68403 .57285 .68583 .57644 .70027 .6247 .69845 .62108 Metetra
.804 .422 0 r
.69845 .62108 .70027 .6247 .71441 .65974 .71266 .65782 Metetra
.645 .763 .934 r
.71266 .65782 .71441 .65974 .72665 .65638 .72491 .65446 Metetra
.645 .763 .934 r
.72491 .65446 .72665 .65638 .73894 .65302 .73722 .65109 Metetra
.645 .763 .934 r
.73722 .65109 .73894 .65302 .75129 .64964 .74957 .6477 Metetra
.645 .763 .934 r
.74957 .6477 .75129 .64964 .76369 .64624 .76198 .6443 Metetra
.645 .763 .934 r
.76198 .6443 .76369 .64624 .77614 .64283 .77445 .64088 Metetra
.645 .763 .934 r
.77445 .64088 .77614 .64283 .78865 .63941 .78697 .63744 Metetra
.645 .763 .934 r
.78697 .63744 .78865 .63941 .80121 .63597 .79954 .634 Metetra
.645 .763 .934 r
.79954 .634 .80121 .63597 .81382 .63251 .81217 .63053 Metetra
.645 .763 .934 r
.81217 .63053 .81382 .63251 .82649 .62904 .82485 .62705 Metetra
.645 .763 .934 r
.82485 .62705 .82649 .62904 .83922 .62556 .83759 .62356 Metetra
.645 .763 .934 r
.83759 .62356 .83922 .62556 .852 .62206 .85038 .62005 Metetra
.645 .763 .934 r
.85038 .62005 .852 .62206 .86484 .61854 .86324 .61653 Metetra
.645 .763 .934 r
.86324 .61653 .86484 .61854 .87774 .61501 .87614 .61299 Metetra
.645 .763 .934 r
.87614 .61299 .87774 .61501 .89069 .61146 .88911 .60943 Metetra
.645 .763 .934 r
.88911 .60943 .89069 .61146 .9037 .6079 .90213 .60586 Metetra
.645 .763 .934 r
.90213 .60586 .9037 .6079 .91677 .60432 .91521 .60227 Metetra
.645 .763 .934 r
.91521 .60227 .91677 .60432 .92989 .60073 .92835 .59867 Metetra
.645 .763 .934 r
.92835 .59867 .92989 .60073 .94308 .59712 .94155 .59505 Metetra
.645 .763 .934 r
.94155 .59505 .94308 .59712 .95632 .59349 .95481 .59141 Metetra
.488 .626 .912 r
.34374 .57521 .34567 .57753 .35556 .57947 .3537 .57606 Metetra
.778 .666 .74 r
.3537 .57606 .35556 .57947 .36629 .56509 .36434 .56377 Metetra
.122 .557 .92 r
.36434 .56377 .36629 .56509 .37616 .56972 .37429 .56653 Metetra
.769 .673 .757 r
.37429 .56653 .37616 .56972 .38673 .55941 .38488 .55591 Metetra
.782 .665 .735 r
.38488 .55591 .38673 .55941 .39739 .54646 .39555 .54296 Metetra
.804 .672 .718 r
.39555 .54296 .39739 .54646 .40818 .52916 .4063 .52689 Metetra
.579 .669 .901 r
.4063 .52689 .40818 .52916 .41847 .52612 .41653 .52592 Metetra
.696 .164 0 r
.41653 .52592 .41847 .52612 .42848 .53443 .42655 .53425 Metetra
.719 .198 0 r
.42655 .53425 .42848 .53443 .43857 .54353 .43665 .54336 Metetra
.734 .957 .944 r
.43665 .54336 .43857 .54353 .44907 .53999 .44722 .5371 Metetra
.465 .566 .873 r
.44722 .5371 .44907 .53999 .45956 .53894 .45765 .53907 Metetra
.902 .541 .348 r
.45765 .53907 .45956 .53894 .46954 .57199 .46763 .57217 Metetra
.71 .979 .909 r
.46763 .57217 .46954 .57199 .48031 .56642 .47843 .56527 Metetra
.786 .848 .898 r
.47843 .56527 .48031 .56642 .49111 .55946 .48925 .55797 Metetra
.601 .773 .962 r
.48925 .55797 .49111 .55946 .50191 .55734 .50005 .5558 Metetra
.895 .784 .731 r
.50005 .5558 .50191 .55734 .51281 .53779 .51098 .53623 Metetra
.899 .782 .724 r
.51098 .53623 .51281 .53779 .52365 .5174 .52184 .51582 Metetra
.88 .791 .757 r
.52184 .51582 .52365 .5174 .53444 .50142 .53264 .49941 Metetra
.793 .333 0 r
.53264 .49941 .53444 .50142 .5454 .52032 .5436 .51831 Metetra
.819 .367 0 r
.5436 .51831 .5454 .52032 .55657 .54091 .55476 .5389 Metetra
.841 .397 0 r
.55476 .5389 .55657 .54091 .56796 .56333 .56615 .56133 Metetra
.9 .763 .702 r
.56615 .56133 .56796 .56333 .57884 .53995 .57704 .53788 Metetra
.859 .427 0 r
.57704 .53788 .57884 .53995 .59055 .56459 .58876 .56293 Metetra
.954 .617 .331 r
.58876 .56293 .59055 .56459 .60352 .63391 .6017 .6323 Metetra
.797 .321 0 r
.6017 .6323 .60352 .63391 .61578 .65548 .6139 .6517 Metetra
.872 .7 .666 r
.6139 .6517 .61578 .65548 .62674 .62593 .62488 .62215 Metetra
.877 .7 .66 r
.62488 .62215 .62674 .62593 .63753 .59516 .6357 .59138 Metetra
.881 .701 .654 r
.6357 .59138 .63753 .59516 .64814 .56316 .64632 .55939 Metetra
.886 .702 .648 r
.64632 .55939 .64814 .56316 .65855 .5299 .65675 .52613 Metetra
.474 .521 .826 r
.65675 .52613 .65855 .5299 .67021 .52901 .66857 .52905 Metetra
.921 .545 .284 r
.66857 .52905 .67021 .52901 .68403 .57285 .68239 .57297 Metetra
.924 .553 .293 r
.68239 .57297 .68403 .57285 .69845 .62108 .69681 .62129 Metetra
.898 .497 .238 r
.69681 .62129 .69845 .62108 .71266 .65782 .71091 .6559 Metetra
.645 .763 .934 r
.71091 .6559 .71266 .65782 .72491 .65446 .72317 .65254 Metetra
.645 .763 .934 r
.72317 .65254 .72491 .65446 .73722 .65109 .73549 .64915 Metetra
.645 .763 .934 r
.73549 .64915 .73722 .65109 .74957 .6477 .74786 .64576 Metetra
.645 .763 .934 r
.74786 .64576 .74957 .6477 .76198 .6443 .76028 .64234 Metetra
.645 .763 .934 r
.76028 .64234 .76198 .6443 .77445 .64088 .77275 .63892 Metetra
.645 .763 .934 r
.77275 .63892 .77445 .64088 .78697 .63744 .78528 .63548 Metetra
.645 .763 .934 r
.78528 .63548 .78697 .63744 .79954 .634 .79787 .63202 Metetra
.645 .763 .934 r
.79787 .63202 .79954 .634 .81217 .63053 .81051 .62855 Metetra
.645 .763 .934 r
.81051 .62855 .81217 .63053 .82485 .62705 .8232 .62506 Metetra
.645 .763 .934 r
.8232 .62506 .82485 .62705 .83759 .62356 .83595 .62156 Metetra
.645 .763 .934 r
.83595 .62156 .83759 .62356 .85038 .62005 .84876 .61804 Metetra
.645 .763 .934 r
.84876 .61804 .85038 .62005 .86324 .61653 .86163 .61451 Metetra
.645 .763 .934 r
.86163 .61451 .86324 .61653 .87614 .61299 .87455 .61096 Metetra
.645 .763 .934 r
.87455 .61096 .87614 .61299 .88911 .60943 .88752 .60739 Metetra
.645 .763 .934 r
.88752 .60739 .88911 .60943 .90213 .60586 .90056 .60381 Metetra
.645 .763 .934 r
.90056 .60381 .90213 .60586 .91521 .60227 .91365 .60021 Metetra
.645 .763 .934 r
.91365 .60021 .91521 .60227 .92835 .59867 .92681 .5966 Metetra
.645 .763 .934 r
.92681 .5966 .92835 .59867 .94155 .59505 .94002 .59297 Metetra
.645 .763 .934 r
.94002 .59297 .94155 .59505 .95481 .59141 .95329 .58933 Metetra
.339 .633 .961 r
.34178 .57354 .34374 .57521 .3537 .57606 .3517 .57526 Metetra
.878 .836 .801 r
.3517 .57526 .3537 .57606 .36434 .56377 .3624 .56191 Metetra
.104 .475 .895 r
.3624 .56191 .36434 .56377 .37429 .56653 .37229 .56616 Metetra
.865 .903 .858 r
.37229 .56616 .37429 .56653 .38488 .55591 .38289 .55565 Metetra
.896 .894 .818 r
.38289 .55565 .38488 .55591 .39555 .54296 .39358 .54267 Metetra
.924 .857 .758 r
.39358 .54267 .39555 .54296 .4063 .52689 .40441 .52503 Metetra
.635 .732 .918 r
.40441 .52503 .4063 .52689 .41653 .52592 .4147 .52253 Metetra
.109 .316 .789 r
.4147 .52253 .41653 .52592 .42655 .53425 .42471 .53085 Metetra
.054 .28 .771 r
.42471 .53085 .42655 .53425 .43665 .54336 .4348 .53995 Metetra
.671 .628 .798 r
.4348 .53995 .43665 .54336 .44722 .5371 .44533 .53568 Metetra
.439 .718 .984 r
.44533 .53568 .44722 .5371 .45765 .53907 .45581 .53586 Metetra
.919 .542 .125 r
.45581 .53586 .45765 .53907 .46763 .57217 .46577 .56894 Metetra
.703 .654 .799 r
.46577 .56894 .46763 .57217 .47843 .56527 .47656 .56312 Metetra
.762 .744 .836 r
.47656 .56312 .47843 .56527 .48925 .55797 .4874 .55558 Metetra
.599 .675 .894 r
.4874 .55558 .48925 .55797 .50005 .5558 .4982 .55407 Metetra
.888 .773 .729 r
.4982 .55407 .50005 .5558 .51098 .53623 .50914 .53448 Metetra
.892 .772 .722 r
.50914 .53448 .51098 .53623 .52184 .51582 .52002 .51405 Metetra
.876 .777 .749 r
.52002 .51405 .52184 .51582 .53264 .49941 .53084 .49711 Metetra
.76 .307 0 r
.53084 .49711 .53264 .49941 .5436 .51831 .54179 .51602 Metetra
.792 .345 0 r
.54179 .51602 .5436 .51831 .55476 .5389 .55295 .5366 Metetra
.819 .379 0 r
.55295 .5366 .55476 .5389 .56615 .56133 .56433 .55903 Metetra
.887 .75 .704 r
.56433 .55903 .56615 .56133 .57704 .53788 .57526 .53642 Metetra
.871 .431 .057 r
.57526 .53642 .57704 .53788 .58876 .56293 .58694 .56013 Metetra
.96 .622 .295 r
.58694 .56013 .58876 .56293 .6017 .6323 .59985 .6295 Metetra
.694 .265 0 r
.59985 .6295 .6017 .6323 .6139 .6517 .6121 .65088 Metetra
.955 .817 .667 r
.6121 .65088 .6139 .6517 .62488 .62215 .62311 .62128 Metetra
.957 .812 .658 r
.62311 .62128 .62488 .62215 .6357 .59138 .63395 .59048 Metetra
.959 .808 .65 r
.63395 .59048 .6357 .59138 .64632 .55939 .6446 .55844 Metetra
.961 .803 .641 r
.6446 .55844 .64632 .55939 .65675 .52613 .65506 .52514 Metetra
.292 .708 .973 r
.65506 .52514 .65675 .52613 .66857 .52905 .66679 .52579 Metetra
.896 .52 .064 r
.66679 .52579 .66857 .52905 .68239 .57297 .68059 .5697 Metetra
.908 .535 .092 r
.68059 .5697 .68239 .57297 .69681 .62129 .69499 .618 Metetra
.824 .432 0 r
.69499 .618 .69681 .62129 .71091 .6559 .70915 .65398 Metetra
.645 .763 .934 r
.70915 .65398 .71091 .6559 .72317 .65254 .72143 .65061 Metetra
.645 .763 .934 r
.72143 .65061 .72317 .65254 .73549 .64915 .73375 .64721 Metetra
.645 .763 .934 r
.73375 .64721 .73549 .64915 .74786 .64576 .74613 .64381 Metetra
.645 .763 .934 r
.74613 .64381 .74786 .64576 .76028 .64234 .75857 .64039 Metetra
.645 .763 .934 r
.75857 .64039 .76028 .64234 .77275 .63892 .77105 .63695 Metetra
.645 .763 .934 r
.77105 .63695 .77275 .63892 .78528 .63548 .78359 .6335 Metetra
.645 .763 .934 r
.78359 .6335 .78528 .63548 .79787 .63202 .79619 .63004 Metetra
.645 .763 .934 r
.79619 .63004 .79787 .63202 .81051 .62855 .80884 .62656 Metetra
.645 .763 .934 r
.80884 .62656 .81051 .62855 .8232 .62506 .82155 .62306 Metetra
.645 .763 .934 r
.82155 .62306 .8232 .62506 .83595 .62156 .83431 .61955 Metetra
.645 .763 .934 r
.83431 .61955 .83595 .62156 .84876 .61804 .84713 .61602 Metetra
.645 .763 .934 r
.84713 .61602 .84876 .61804 .86163 .61451 .86001 .61248 Metetra
.645 .763 .934 r
.86001 .61248 .86163 .61451 .87455 .61096 .87295 .60892 Metetra
.645 .763 .934 r
.87295 .60892 .87455 .61096 .88752 .60739 .88594 .60535 Metetra
.645 .763 .934 r
.88594 .60535 .88752 .60739 .90056 .60381 .89899 .60176 Metetra
.645 .763 .934 r
.89899 .60176 .90056 .60381 .91365 .60021 .91209 .59815 Metetra
.645 .763 .934 r
.91209 .59815 .91365 .60021 .92681 .5966 .92526 .59453 Metetra
.645 .763 .934 r
.92526 .59453 .92681 .5966 .94002 .59297 .93848 .59089 Metetra
.645 .763 .934 r
.93848 .59089 .94002 .59297 .95329 .58933 .95177 .58724 Metetra
.481 .635 .922 r
.33984 .57133 .34178 .57354 .3517 .57526 .34981 .57214 Metetra
.783 .679 .75 r
.34981 .57214 .3517 .57526 .3624 .56191 .36045 .56021 Metetra
.272 .594 .949 r
.36045 .56021 .3624 .56191 .37229 .56616 .37043 .56264 Metetra
.76 .657 .748 r
.37043 .56264 .37229 .56616 .38289 .55565 .38104 .55195 Metetra
.776 .657 .73 r
.38104 .55195 .38289 .55565 .39358 .54267 .39173 .53897 Metetra
.799 .665 .715 r
.39173 .53897 .39358 .54267 .40441 .52503 .40252 .5229 Metetra
.544 .671 .92 r
.40252 .5229 .40441 .52503 .4147 .52253 .41274 .52252 Metetra
.703 .183 0 r
.41274 .52252 .4147 .52253 .42471 .53085 .42276 .53085 Metetra
.724 .214 .011 r
.42276 .53085 .42471 .53085 .4348 .53995 .43286 .53997 Metetra
.738 .972 .928 r
.43286 .53997 .4348 .53995 .44533 .53568 .44347 .53321 Metetra
.402 .572 .906 r
.44347 .53321 .44533 .53568 .45581 .53586 .4539 .53567 Metetra
.908 .544 .334 r
.4539 .53567 .45581 .53586 .46577 .56894 .46385 .56881 Metetra
.762 .965 .93 r
.46385 .56881 .46577 .56894 .47656 .56312 .47468 .56167 Metetra
.778 .813 .881 r
.47468 .56167 .47656 .56312 .4874 .55558 .48552 .5544 Metetra
.571 .806 .988 r
.48552 .5544 .4874 .55558 .4982 .55407 .49634 .55234 Metetra
.888 .774 .729 r
.49634 .55234 .4982 .55407 .50914 .53448 .5073 .53273 Metetra
.892 .772 .722 r
.5073 .53273 .50914 .53448 .52002 .51405 .5182 .51228 Metetra
.876 .778 .749 r
.5182 .51228 .52002 .51405 .53084 .49711 .52903 .4953 Metetra
.813 .349 0 r
.52903 .4953 .53084 .49711 .54179 .51602 .53998 .51421 Metetra
.835 .381 0 r
.53998 .51421 .54179 .51602 .55295 .5366 .55114 .5348 Metetra
.853 .408 0 r
.55114 .5348 .55295 .5366 .56433 .55903 .56251 .55724 Metetra
.907 .774 .704 r
.56251 .55724 .56433 .55903 .57526 .53642 .57345 .53391 Metetra
.831 .404 0 r
.57345 .53391 .57526 .53642 .58694 .56013 .58516 .55906 Metetra
.95 .614 .348 r
.58516 .55906 .58694 .56013 .59985 .6295 .59804 .62851 Metetra
.828 .352 0 r
.59804 .62851 .59985 .6295 .6121 .65088 .61023 .64761 Metetra
.885 .717 .668 r
.61023 .64761 .6121 .65088 .62311 .62128 .62126 .61801 Metetra
.89 .717 .662 r
.62126 .61801 .62311 .62128 .63395 .59048 .63212 .5872 Metetra
.894 .718 .655 r
.63212 .5872 .63395 .59048 .6446 .55844 .64279 .55515 Metetra
.898 .718 .649 r
.64279 .55515 .6446 .55844 .65506 .52514 .65327 .52185 Metetra
.424 .524 .855 r
.65327 .52185 .65506 .52514 .66679 .52579 .66513 .52539 Metetra
.925 .546 .263 r
.66513 .52539 .66679 .52579 .68059 .5697 .67892 .56937 Metetra
.929 .555 .273 r
.67892 .56937 .68059 .5697 .69499 .618 .69332 .61774 Metetra
.902 .494 .205 r
.69332 .61774 .69499 .618 .70915 .65398 .70739 .65205 Metetra
.645 .763 .934 r
.70739 .65205 .70915 .65398 .72143 .65061 .71968 .64867 Metetra
.645 .763 .934 r
.71968 .64867 .72143 .65061 .73375 .64721 .73201 .64527 Metetra
.645 .763 .934 r
.73201 .64527 .73375 .64721 .74613 .64381 .7444 .64186 Metetra
.645 .763 .934 r
.7444 .64186 .74613 .64381 .75857 .64039 .75685 .63843 Metetra
.645 .763 .934 r
.75685 .63843 .75857 .64039 .77105 .63695 .76935 .63498 Metetra
.645 .763 .934 r
.76935 .63498 .77105 .63695 .78359 .6335 .7819 .63152 Metetra
.645 .763 .934 r
.7819 .63152 .78359 .6335 .79619 .63004 .79451 .62805 Metetra
.645 .763 .934 r
.79451 .62805 .79619 .63004 .80884 .62656 .80718 .62456 Metetra
.645 .763 .934 r
.80718 .62456 .80884 .62656 .82155 .62306 .8199 .62106 Metetra
.645 .763 .934 r
.8199 .62106 .82155 .62306 .83431 .61955 .83267 .61754 Metetra
.645 .763 .934 r
.83267 .61754 .83431 .61955 .84713 .61602 .8455 .614 Metetra
.645 .763 .934 r
.8455 .614 .84713 .61602 .86001 .61248 .85839 .61045 Metetra
.645 .763 .934 r
.85839 .61045 .86001 .61248 .87295 .60892 .87134 .60688 Metetra
.645 .763 .934 r
.87134 .60688 .87295 .60892 .88594 .60535 .88434 .6033 Metetra
.645 .763 .934 r
.88434 .6033 .88594 .60535 .89899 .60176 .89741 .5997 Metetra
.645 .763 .934 r
.89741 .5997 .89899 .60176 .91209 .59815 .91053 .59608 Metetra
.645 .763 .934 r
.91053 .59608 .91209 .59815 .92526 .59453 .92371 .59245 Metetra
.645 .763 .934 r
.92371 .59245 .92526 .59453 .93848 .59089 .93694 .5888 Metetra
.645 .763 .934 r
.93694 .5888 .93848 .59089 .95177 .58724 .95024 .58514 Metetra
.443 .654 .949 r
.33788 .56943 .33984 .57133 .34981 .57214 .34785 .57035 Metetra
.821 .762 .797 r
.34785 .57035 .34981 .57214 .36045 .56021 .35847 .55915 Metetra
.031 .532 .875 r
.35847 .55915 .36045 .56021 .37043 .56264 .36844 .56182 Metetra
.849 .857 .847 r
.36844 .56182 .37043 .56264 .38104 .55195 .37905 .55149 Metetra
.89 .876 .815 r
.37905 .55149 .38104 .55195 .39173 .53897 .38976 .53849 Metetra
.917 .843 .756 r
.38976 .53849 .39173 .53897 .40252 .5229 .40063 .52081 Metetra
.596 .695 .912 r
.40063 .52081 .40252 .5229 .41274 .52252 .41089 .5193 Metetra
.069 .304 .788 r
.41089 .5193 .41274 .52252 .42276 .53085 .42091 .52762 Metetra
.01 .265 .768 r
.42091 .52762 .42276 .53085 .43286 .53997 .43101 .53672 Metetra
.706 .652 .794 r
.43101 .53672 .43286 .53997 .44347 .53321 .4416 .53073 Metetra
.373 .557 .905 r
.4416 .53073 .44347 .53321 .4539 .53567 .45202 .53361 Metetra
.933 .554 .228 r
.45202 .53361 .4539 .53567 .46385 .56881 .46196 .56676 Metetra
.771 .754 .838 r
.46196 .56676 .46385 .56881 .47468 .56167 .47281 .5589 Metetra
.718 .688 .82 r
.47281 .5589 .47468 .56167 .48552 .5544 .48365 .55283 Metetra
.594 .764 .96 r
.48365 .55283 .48552 .5544 .49634 .55234 .49447 .55083 Metetra
.897 .787 .732 r
.49447 .55083 .49634 .55234 .5073 .53273 .50545 .53121 Metetra
.901 .785 .724 r
.50545 .53121 .5073 .53273 .5182 .51228 .51637 .51073 Metetra
.89 .791 .744 r
.51637 .51073 .5182 .51228 .52903 .4953 .52722 .49279 Metetra
.73 .286 0 r
.52722 .49279 .52903 .4953 .53998 .51421 .53816 .51169 Metetra
.767 .327 0 r
.53816 .51169 .53998 .51421 .55114 .5348 .54931 .53228 Metetra
.798 .364 0 r
.54931 .53228 .55114 .5348 .56251 .55724 .56068 .55472 Metetra
.882 .739 .699 r
.56068 .55472 .56251 .55724 .57345 .53391 .57164 .53147 Metetra
.843 .417 0 r
.57164 .53147 .57345 .53391 .58516 .55906 .58335 .55713 Metetra
.956 .619 .324 r
.58335 .55713 .58516 .55906 .59804 .62851 .5962 .62661 Metetra
.753 .277 0 r
.5962 .62661 .59804 .62851 .61023 .64761 .60838 .64528 Metetra
.912 .752 .671 r
.60838 .64528 .61023 .64761 .62126 .61801 .61943 .61566 Metetra
.915 .751 .663 r
.61943 .61566 .62126 .61801 .63212 .5872 .63031 .58483 Metetra
.919 .75 .656 r
.63031 .58483 .63212 .5872 .64279 .55515 .64101 .55277 Metetra
.922 .749 .649 r
.64101 .55277 .64279 .55515 .65327 .52185 .65151 .51945 Metetra
.303 .533 .908 r
.65151 .51945 .65327 .52185 .66513 .52539 .6634 .52353 Metetra
.927 .543 .176 r
.6634 .52353 .66513 .52539 .67892 .56937 .67718 .56753 Metetra
.933 .554 .194 r
.67718 .56753 .67892 .56937 .69332 .61774 .69156 .61593 Metetra
.889 .472 .069 r
.69156 .61593 .69332 .61774 .70739 .65205 .70563 .65012 Metetra
.645 .763 .934 r
.70563 .65012 .70739 .65205 .71968 .64867 .71792 .64673 Metetra
.645 .763 .934 r
.71792 .64673 .71968 .64867 .73201 .64527 .73027 .64332 Metetra
.645 .763 .934 r
.73027 .64332 .73201 .64527 .7444 .64186 .74267 .6399 Metetra
.645 .763 .934 r
.74267 .6399 .7444 .64186 .75685 .63843 .75513 .63646 Metetra
.645 .763 .934 r
.75513 .63646 .75685 .63843 .76935 .63498 .76764 .63301 Metetra
.645 .763 .934 r
.76764 .63301 .76935 .63498 .7819 .63152 .78021 .62954 Metetra
.645 .763 .934 r
.78021 .62954 .7819 .63152 .79451 .62805 .79283 .62606 Metetra
.645 .763 .934 r
.79283 .62606 .79451 .62805 .80718 .62456 .8055 .62256 Metetra
.645 .763 .934 r
.8055 .62256 .80718 .62456 .8199 .62106 .81824 .61905 Metetra
.645 .763 .934 r
.81824 .61905 .8199 .62106 .83267 .61754 .83102 .61552 Metetra
.645 .763 .934 r
.83102 .61552 .83267 .61754 .8455 .614 .84387 .61197 Metetra
.645 .763 .934 r
.84387 .61197 .8455 .614 .85839 .61045 .85677 .60841 Metetra
.645 .763 .934 r
.85677 .60841 .85839 .61045 .87134 .60688 .86973 .60484 Metetra
.645 .763 .934 r
.86973 .60484 .87134 .60688 .88434 .6033 .88275 .60124 Metetra
.645 .763 .934 r
.88275 .60124 .88434 .6033 .89741 .5997 .89582 .59764 Metetra
.645 .763 .934 r
.89582 .59764 .89741 .5997 .91053 .59608 .90896 .59401 Metetra
.645 .763 .934 r
.90896 .59401 .91053 .59608 .92371 .59245 .92215 .59037 Metetra
.645 .763 .934 r
.92215 .59037 .92371 .59245 .93694 .5888 .9354 .58671 Metetra
.645 .763 .934 r
.9354 .58671 .93694 .5888 .95024 .58514 .94871 .58304 Metetra
.463 .664 .949 r
.33592 .56753 .33788 .56943 .34785 .57035 .3459 .56816 Metetra
.809 .734 .782 r
.3459 .56816 .34785 .57035 .35847 .55915 .35654 .55676 Metetra
.424 .591 .912 r
.35654 .55676 .35847 .55915 .36844 .56182 .36656 .55867 Metetra
.77 .676 .759 r
.36656 .55867 .36844 .56182 .37905 .55149 .37718 .54807 Metetra
.784 .669 .737 r
.37718 .54807 .37905 .55149 .38976 .53849 .3879 .53507 Metetra
.807 .676 .72 r
.3879 .53507 .38976 .53849 .40063 .52081 .39872 .51899 Metetra
.499 .689 .952 r
.39872 .51899 .40063 .52081 .41089 .5193 .40894 .51901 Metetra
.689 .151 0 r
.40894 .51901 .41089 .5193 .42091 .52762 .41896 .52734 Metetra
.714 .187 0 r
.41896 .52734 .42091 .52762 .43101 .53672 .42906 .53645 Metetra
.784 .948 .928 r
.42906 .53645 .43101 .53672 .4416 .53073 .4397 .52917 Metetra
.162 .551 .928 r
.4397 .52917 .4416 .53073 .45202 .53361 .45012 .53233 Metetra
.927 .553 .279 r
.45012 .53233 .45202 .53361 .46196 .56676 .46005 .5655 Metetra
.794 .834 .882 r
.46005 .5655 .46196 .56676 .47281 .5589 .47091 .55766 Metetra
.765 .838 .908 r
.47091 .55766 .47281 .5589 .48365 .55283 .48177 .5511 Metetra
.617 .752 .942 r
.48177 .5511 .48365 .55283 .49447 .55083 .4926 .54876 Metetra
.876 .755 .725 r
.4926 .54876 .49447 .55083 .50545 .53121 .5036 .52911 Metetra
.881 .754 .718 r
.5036 .52911 .50545 .53121 .51637 .51073 .51454 .50863 Metetra
.866 .756 .74 r
.51454 .50863 .51637 .51073 .52722 .49279 .5254 .49125 Metetra
.832 .368 0 r
.5254 .49125 .52722 .49279 .53816 .51169 .53635 .51016 Metetra
.85 .396 .009 r
.53635 .51016 .53816 .51169 .54931 .53228 .54749 .53077 Metetra
.865 .421 .044 r
.54749 .53077 .54931 .53228 .56068 .55472 .55886 .55322 Metetra
.918 .789 .703 r
.55886 .55322 .56068 .55472 .57164 .53147 .56983 .5295 Metetra
.874 .446 .038 r
.56983 .5295 .57164 .53147 .58335 .55713 .58154 .55565 Metetra
.953 .616 .337 r
.58154 .55565 .58335 .55713 .5962 .62661 .59437 .62518 Metetra
.79 .304 0 r
.59437 .62518 .5962 .62661 .60838 .64528 .60654 .64336 Metetra
.924 .769 .671 r
.60654 .64336 .60838 .64528 .61943 .61566 .61761 .61371 Metetra
.927 .767 .663 r
.61761 .61371 .61943 .61566 .63031 .58483 .62852 .58286 Metetra
.93 .765 .656 r
.62852 .58286 .63031 .58483 .64101 .55277 .63924 .55078 Metetra
.933 .763 .648 r
.63924 .55078 .64101 .55277 .65151 .51945 .64976 .51743 Metetra
.205 .519 .916 r
.64976 .51743 .65151 .51945 .6634 .52353 .66167 .52185 Metetra
.929 .544 .189 r
.66167 .52185 .6634 .52353 .67718 .56753 .67544 .56587 Metetra
.933 .555 .205 r
.67544 .56587 .67718 .56753 .69156 .61593 .68981 .61431 Metetra
.892 .474 .085 r
.68981 .61431 .69156 .61593 .70563 .65012 .70385 .64818 Metetra
.645 .763 .934 r
.70385 .64818 .70563 .65012 .71792 .64673 .71616 .64478 Metetra
.645 .763 .934 r
.71616 .64478 .71792 .64673 .73027 .64332 .72852 .64137 Metetra
.645 .763 .934 r
.72852 .64137 .73027 .64332 .74267 .6399 .74094 .63794 Metetra
.645 .763 .934 r
.74094 .63794 .74267 .6399 .75513 .63646 .7534 .63449 Metetra
.645 .763 .934 r
.7534 .63449 .75513 .63646 .76764 .63301 .76593 .63103 Metetra
.645 .763 .934 r
.76593 .63103 .76764 .63301 .78021 .62954 .77851 .62755 Metetra
.645 .763 .934 r
.77851 .62755 .78021 .62954 .79283 .62606 .79114 .62406 Metetra
.645 .763 .934 r
.79114 .62406 .79283 .62606 .8055 .62256 .80383 .62055 Metetra
.645 .763 .934 r
.80383 .62055 .8055 .62256 .81824 .61905 .81657 .61703 Metetra
.645 .763 .934 r
.81657 .61703 .81824 .61905 .83102 .61552 .82937 .61349 Metetra
.645 .763 .934 r
.82937 .61349 .83102 .61552 .84387 .61197 .84223 .60994 Metetra
.645 .763 .934 r
.84223 .60994 .84387 .61197 .85677 .60841 .85515 .60637 Metetra
.645 .763 .934 r
.85515 .60637 .85677 .60841 .86973 .60484 .86812 .60278 Metetra
.645 .763 .934 r
.86812 .60278 .86973 .60484 .88275 .60124 .88115 .59918 Metetra
.645 .763 .934 r
.88115 .59918 .88275 .60124 .89582 .59764 .89424 .59557 Metetra
.645 .763 .934 r
.89424 .59557 .89582 .59764 .90896 .59401 .90738 .59193 Metetra
.645 .763 .934 r
.90738 .59193 .90896 .59401 .92215 .59037 .92059 .58828 Metetra
.645 .763 .934 r
.92059 .58828 .92215 .59037 .9354 .58671 .93385 .58462 Metetra
.645 .763 .934 r
.93385 .58462 .9354 .58671 .94871 .58304 .94718 .58093 Metetra
.488 .667 .942 r
.33395 .56556 .33592 .56753 .3459 .56816 .34395 .56592 Metetra
.791 .729 .795 r
.34395 .56592 .3459 .56816 .35654 .55676 .35454 .55599 Metetra
.072 .592 .877 r
.35454 .55599 .35654 .55676 .36656 .55867 .36457 .55761 Metetra
.839 .833 .84 r
.36457 .55761 .36656 .55867 .37718 .54807 .37519 .54738 Metetra
.882 .854 .81 r
.37519 .54738 .37718 .54807 .3879 .53507 .38593 .53436 Metetra
.908 .828 .756 r
.38593 .53436 .3879 .53507 .39872 .51899 .39682 .51685 Metetra
.567 .68 .916 r
.39682 .51685 .39872 .51899 .40894 .51901 .40708 .516 Metetra
.014 .287 .784 r
.40708 .516 .40894 .51901 .41896 .52734 .41709 .52432 Metetra
0 .244 .758 r
.41709 .52432 .41896 .52734 .42906 .53645 .42719 .53343 Metetra
.73 .673 .794 r
.42719 .53343 .42906 .53645 .4397 .52917 .43784 .52625 Metetra
.31 .481 .867 r
.43784 .52625 .4397 .52917 .45012 .53233 .44823 .53082 Metetra
.929 .554 .266 r
.44823 .53082 .45012 .53233 .46005 .5655 .45815 .56402 Metetra
.811 .809 .849 r
.45815 .56402 .46005 .5655 .47091 .55766 .46904 .55485 Metetra
.699 .68 .828 r
.46904 .55485 .47091 .55766 .48177 .5511 .47988 .54968 Metetra
.608 .788 .968 r
.47988 .54968 .48177 .5511 .4926 .54876 .49073 .54727 Metetra
.898 .789 .732 r
.49073 .54727 .4926 .54876 .5036 .52911 .50174 .5276 Metetra
.902 .786 .723 r
.50174 .5276 .5036 .52911 .51454 .50863 .5127 .50689 Metetra
.884 .779 .74 r
.5127 .50689 .51454 .50863 .5254 .49125 .52358 .48874 Metetra
.732 .288 0 r
.52358 .48874 .5254 .49125 .53635 .51016 .53452 .50765 Metetra
.769 .329 0 r
.53452 .50765 .53635 .51016 .54749 .53077 .54566 .52825 Metetra
.8 .365 0 r
.54566 .52825 .54749 .53077 .55886 .55322 .55702 .5507 Metetra
.885 .74 .696 r
.55702 .5507 .55886 .55322 .56983 .5295 .56801 .52688 Metetra
.848 .43 0 r
.56801 .52688 .56983 .5295 .58154 .55565 .57973 .5539 Metetra
.955 .618 .329 r
.57973 .5539 .58154 .55565 .59437 .62518 .59253 .62348 Metetra
.733 .242 0 r
.59253 .62348 .59437 .62518 .60654 .64336 .60467 .64038 Metetra
.894 .728 .669 r
.60467 .64038 .60654 .64336 .61761 .61371 .61576 .61073 Metetra
.898 .728 .662 r
.61576 .61073 .61761 .61371 .62852 .58286 .62669 .57986 Metetra
.902 .728 .656 r
.62669 .57986 .62852 .58286 .63924 .55078 .63743 .54777 Metetra
.906 .727 .649 r
.63743 .54777 .63924 .55078 .64976 .51743 .64797 .51442 Metetra
.257 .448 .857 r
.64797 .51442 .64976 .51743 .66167 .52185 .65996 .52062 Metetra
.929 .546 .218 r
.65996 .52062 .66167 .52185 .67544 .56587 .67372 .56468 Metetra
.933 .556 .231 r
.67372 .56468 .67544 .56587 .68981 .61431 .68808 .61317 Metetra
.897 .477 .123 r
.68808 .61317 .68981 .61431 .70385 .64818 .70208 .64624 Metetra
.645 .763 .934 r
.70208 .64624 .70385 .64818 .71616 .64478 .7144 .64283 Metetra
.645 .763 .934 r
.7144 .64283 .71616 .64478 .72852 .64137 .72677 .63941 Metetra
.645 .763 .934 r
.72677 .63941 .72852 .64137 .74094 .63794 .7392 .63597 Metetra
.645 .763 .934 r
.7392 .63597 .74094 .63794 .7534 .63449 .75168 .63251 Metetra
.645 .763 .934 r
.75168 .63251 .7534 .63449 .76593 .63103 .76421 .62904 Metetra
.645 .763 .934 r
.76421 .62904 .76593 .63103 .77851 .62755 .7768 .62556 Metetra
.645 .763 .934 r
.7768 .62556 .77851 .62755 .79114 .62406 .78945 .62206 Metetra
.645 .763 .934 r
.78945 .62206 .79114 .62406 .80383 .62055 .80215 .61854 Metetra
.645 .763 .934 r
.80215 .61854 .80383 .62055 .81657 .61703 .8149 .61501 Metetra
.645 .763 .934 r
.8149 .61501 .81657 .61703 .82937 .61349 .82772 .61146 Metetra
.645 .763 .934 r
.82772 .61146 .82937 .61349 .84223 .60994 .84059 .6079 Metetra
.645 .763 .934 r
.84059 .6079 .84223 .60994 .85515 .60637 .85352 .60432 Metetra
.645 .763 .934 r
.85352 .60432 .85515 .60637 .86812 .60278 .8665 .60073 Metetra
.645 .763 .934 r
.8665 .60073 .86812 .60278 .88115 .59918 .87954 .59712 Metetra
.645 .763 .934 r
.87954 .59712 .88115 .59918 .89424 .59557 .89265 .59349 Metetra
.645 .763 .934 r
.89265 .59349 .89424 .59557 .90738 .59193 .90581 .58985 Metetra
.645 .763 .934 r
.90581 .58985 .90738 .59193 .92059 .58828 .91902 .58619 Metetra
.645 .763 .934 r
.91902 .58619 .92059 .58828 .93385 .58462 .9323 .58251 Metetra
.645 .763 .934 r
.9323 .58251 .93385 .58462 .94718 .58093 .94564 .57882 Metetra
.451 .674 .959 r
.33197 .56378 .33395 .56556 .34395 .56592 .34197 .56438 Metetra
.831 .783 .807 r
.34197 .56438 .34395 .56592 .35454 .55599 .35262 .55323 Metetra
.453 .571 .883 r
.35262 .55323 .35454 .55599 .36457 .55761 .36264 .55514 Metetra
.793 .717 .78 r
.36264 .55514 .36457 .55761 .37519 .54738 .3733 .54439 Metetra
.798 .691 .747 r
.3733 .54439 .37519 .54738 .38593 .53436 .38405 .53137 Metetra
.821 .696 .727 r
.38405 .53137 .38593 .53436 .39682 .51685 .3949 .51511 Metetra
.481 .693 .961 r
.3949 .51511 .39682 .51685 .40708 .516 .40513 .51526 Metetra
.646 .088 0 r
.40513 .51526 .40708 .516 .41709 .52432 .41515 .52358 Metetra
.68 .132 0 r
.41515 .52358 .41709 .52432 .42719 .53343 .42525 .5327 Metetra
.797 .893 .913 r
.42525 .5327 .42719 .53343 .43784 .52625 .43592 .52526 Metetra
0 .456 .811 r
.43592 .52526 .43784 .52625 .44823 .53082 .44634 .5287 Metetra
.933 .554 .224 r
.44634 .5287 .44823 .53082 .45815 .56402 .45624 .5619 Metetra
.766 .749 .837 r
.45624 .5619 .45815 .56402 .46904 .55485 .46712 .55417 Metetra
.781 .907 .928 r
.46712 .55417 .46904 .55485 .47988 .54968 .47801 .5471 Metetra
.616 .667 .876 r
.47801 .5471 .47988 .54968 .49073 .54727 .48885 .54512 Metetra
.874 .752 .724 r
.48885 .54512 .49073 .54727 .50174 .5276 .49989 .52544 Metetra
.878 .751 .717 r
.49989 .52544 .50174 .5276 .5127 .50689 .51086 .50492 Metetra
.873 .765 .74 r
.51086 .50492 .5127 .50689 .52358 .48874 .52176 .48719 Metetra
.832 .367 0 r
.52176 .48719 .52358 .48874 .53452 .50765 .5327 .50611 Metetra
.85 .395 .009 r
.5327 .50611 .53452 .50765 .54566 .52825 .54383 .52673 Metetra
.865 .42 .043 r
.54383 .52673 .54566 .52825 .55702 .5507 .55519 .54919 Metetra
.916 .79 .707 r
.55519 .54919 .55702 .5507 .56801 .52688 .5662 .52591 Metetra
.889 .462 .145 r
.5662 .52591 .56801 .52688 .57973 .5539 .57789 .55133 Metetra
.959 .621 .304 r
.57789 .55133 .57973 .5539 .59253 .62348 .59067 .62092 Metetra
.645 .198 0 r
.59067 .62092 .59253 .62348 .60467 .64038 .60284 .63935 Metetra
.95 .808 .669 r
.60284 .63935 .60467 .64038 .61576 .61073 .61396 .60966 Metetra
.952 .804 .66 r
.61396 .60966 .61576 .61073 .62669 .57986 .62491 .57876 Metetra
.954 .8 .652 r
.62491 .57876 .62669 .57986 .63743 .54777 .63568 .54662 Metetra
.956 .796 .643 r
.63568 .54662 .63743 .54777 .64797 .51442 .64625 .51323 Metetra
0 .426 .819 r
.64625 .51323 .64797 .51442 .65996 .52062 .65818 .51801 Metetra
.917 .535 .123 r
.65818 .51801 .65996 .52062 .67372 .56468 .67193 .56208 Metetra
.925 .547 .145 r
.67193 .56208 .67372 .56468 .68808 .61317 .68628 .61057 Metetra
.853 .442 0 r
.68628 .61057 .68808 .61317 .70208 .64624 .7003 .6443 Metetra
.645 .763 .934 r
.7003 .6443 .70208 .64624 .7144 .64283 .71263 .64088 Metetra
.645 .763 .934 r
.71263 .64088 .7144 .64283 .72677 .63941 .72501 .63744 Metetra
.645 .763 .934 r
.72501 .63744 .72677 .63941 .7392 .63597 .73745 .634 Metetra
.645 .763 .934 r
.73745 .634 .7392 .63597 .75168 .63251 .74994 .63053 Metetra
.645 .763 .934 r
.74994 .63053 .75168 .63251 .76421 .62904 .76249 .62705 Metetra
.645 .763 .934 r
.76249 .62705 .76421 .62904 .7768 .62556 .77509 .62356 Metetra
.645 .763 .934 r
.77509 .62356 .7768 .62556 .78945 .62206 .78775 .62005 Metetra
.645 .763 .934 r
.78775 .62005 .78945 .62206 .80215 .61854 .80046 .61653 Metetra
.645 .763 .934 r
.80046 .61653 .80215 .61854 .8149 .61501 .81323 .61299 Metetra
.645 .763 .934 r
.81323 .61299 .8149 .61501 .82772 .61146 .82606 .60943 Metetra
.645 .763 .934 r
.82606 .60943 .82772 .61146 .84059 .6079 .83894 .60586 Metetra
.645 .763 .934 r
.83894 .60586 .84059 .6079 .85352 .60432 .85188 .60227 Metetra
.645 .763 .934 r
.85188 .60227 .85352 .60432 .8665 .60073 .86488 .59867 Metetra
.645 .763 .934 r
.86488 .59867 .8665 .60073 .87954 .59712 .87794 .59505 Metetra
.645 .763 .934 r
.87794 .59505 .87954 .59712 .89265 .59349 .89105 .59141 Metetra
.645 .763 .934 r
.89105 .59141 .89265 .59349 .90581 .58985 .90422 .58776 Metetra
.645 .763 .934 r
.90422 .58776 .90581 .58985 .91902 .58619 .91746 .58409 Metetra
.645 .763 .934 r
.91746 .58409 .91902 .58619 .9323 .58251 .93075 .58041 Metetra
.645 .763 .934 r
.93075 .58041 .9323 .58251 .94564 .57882 .9441 .5767 Metetra
.474 .668 .948 r
.33 .56186 .33197 .56378 .34197 .56438 .34 .56234 Metetra
.805 .745 .797 r
.34 .56234 .34197 .56438 .35262 .55323 .35063 .55185 Metetra
.242 .624 .958 r
.35063 .55185 .35262 .55323 .36264 .55514 .36066 .55376 Metetra
.834 .801 .82 r
.36066 .55376 .36264 .55514 .3733 .54439 .37133 .54298 Metetra
.854 .793 .791 r
.37133 .54298 .3733 .54439 .38405 .53137 .3821 .52994 Metetra
.878 .782 .752 r
.3821 .52994 .38405 .53137 .3949 .51511 .39299 .51309 Metetra
.522 .676 .934 r
.39299 .51309 .3949 .51511 .40513 .51526 .40323 .51295 Metetra
0 .206 .722 r
.40323 .51295 .40513 .51526 .41515 .52358 .41325 .52127 Metetra
0 .15 .675 r
.41325 .52127 .41515 .52358 .42525 .5327 .42335 .53038 Metetra
.756 .726 .825 r
.42335 .53038 .42525 .5327 .43592 .52526 .43403 .52291 Metetra
.253 .507 .902 r
.43403 .52291 .43592 .52526 .44634 .5287 .44444 .52701 Metetra
.931 .554 .255 r
.44444 .52701 .44634 .5287 .45624 .5619 .45433 .56024 Metetra
.783 .792 .859 r
.45433 .56024 .45624 .5619 .46712 .55417 .46522 .55234 Metetra
.768 .775 .859 r
.46522 .55234 .46712 .55417 .47801 .5471 .47612 .545 Metetra
.593 .703 .92 r
.47612 .545 .47801 .5471 .48885 .54512 .48697 .54342 Metetra
.89 .777 .73 r
.48697 .54342 .48885 .54512 .49989 .52544 .49802 .52372 Metetra
.894 .775 .723 r
.49802 .52372 .49989 .52544 .51086 .50492 .50901 .50318 Metetra
.884 .779 .74 r
.50901 .50318 .51086 .50492 .52176 .48719 .51993 .48497 Metetra
.773 .318 0 r
.51993 .48497 .52176 .48719 .5327 .50611 .53086 .50389 Metetra
.803 .354 0 r
.53086 .50389 .5327 .50611 .54383 .52673 .542 .52451 Metetra
.828 .387 0 r
.542 .52451 .54383 .52673 .55519 .54919 .55335 .54697 Metetra
.891 .755 .705 r
.55335 .54697 .55519 .54919 .5662 .52591 .56439 .52421 Metetra
.872 .436 .046 r
.56439 .52421 .5662 .52591 .57789 .55133 .57606 .5489 Metetra
.958 .621 .309 r
.57606 .5489 .57789 .55133 .59067 .62092 .58881 .61851 Metetra
.673 .216 0 r
.58881 .61851 .59067 .62092 .60284 .63935 .60097 .63694 Metetra
.91 .75 .67 r
.60097 .63694 .60284 .63935 .61396 .60966 .61211 .60723 Metetra
.914 .749 .663 r
.61211 .60723 .61396 .60966 .62491 .57876 .62309 .57631 Metetra
.917 .748 .656 r
.62309 .57631 .62491 .57876 .63568 .54662 .63388 .54416 Metetra
.921 .747 .649 r
.63388 .54416 .63568 .54662 .64625 .51323 .64447 .51075 Metetra
.204 .468 .885 r
.64447 .51075 .64625 .51323 .65818 .51801 .65645 .51637 Metetra
.929 .545 .192 r
.65645 .51637 .65818 .51801 .67193 .56208 .67018 .56047 Metetra
.933 .555 .208 r
.67018 .56047 .67193 .56208 .68628 .61057 .68452 .609 Metetra
.891 .471 .084 r
.68452 .609 .68628 .61057 .7003 .6443 .69852 .64234 Metetra
.645 .763 .934 r
.69852 .64234 .7003 .6443 .71263 .64088 .71086 .63892 Metetra
.645 .763 .934 r
.71086 .63892 .71263 .64088 .72501 .63744 .72325 .63548 Metetra
.645 .763 .934 r
.72325 .63548 .72501 .63744 .73745 .634 .7357 .63202 Metetra
.645 .763 .934 r
.7357 .63202 .73745 .634 .74994 .63053 .74821 .62855 Metetra
.645 .763 .934 r
.74821 .62855 .74994 .63053 .76249 .62705 .76076 .62506 Metetra
.645 .763 .934 r
.76076 .62506 .76249 .62705 .77509 .62356 .77338 .62156 Metetra
.645 .763 .934 r
.77338 .62156 .77509 .62356 .78775 .62005 .78605 .61804 Metetra
.645 .763 .934 r
.78605 .61804 .78775 .62005 .80046 .61653 .79877 .61451 Metetra
.645 .763 .934 r
.79877 .61451 .80046 .61653 .81323 .61299 .81156 .61096 Metetra
.645 .763 .934 r
.81156 .61096 .81323 .61299 .82606 .60943 .82439 .60739 Metetra
.645 .763 .934 r
.82439 .60739 .82606 .60943 .83894 .60586 .83729 .60381 Metetra
.645 .763 .934 r
.83729 .60381 .83894 .60586 .85188 .60227 .85024 .60021 Metetra
.645 .763 .934 r
.85024 .60021 .85188 .60227 .86488 .59867 .86325 .5966 Metetra
.645 .763 .934 r
.86325 .5966 .86488 .59867 .87794 .59505 .87632 .59297 Metetra
.645 .763 .934 r
.87632 .59297 .87794 .59505 .89105 .59141 .88945 .58933 Metetra
.645 .763 .934 r
.88945 .58933 .89105 .59141 .90422 .58776 .90264 .58567 Metetra
.645 .763 .934 r
.90264 .58567 .90422 .58776 .91746 .58409 .91588 .58199 Metetra
.645 .763 .934 r
.91588 .58199 .91746 .58409 .93075 .58041 .92919 .57829 Metetra
.645 .763 .934 r
.92919 .57829 .93075 .58041 .9441 .5767 .94256 .57458 Metetra
.376 .667 .971 r
.328 .56028 .33 .56186 .34 .56234 .33797 .56138 Metetra
.861 .831 .816 r
.33797 .56138 .34 .56234 .35063 .55185 .3487 .54933 Metetra
.372 .553 .902 r
.3487 .54933 .35063 .55185 .36066 .55376 .35868 .55212 Metetra
.824 .779 .81 r
.35868 .55212 .36066 .55376 .37133 .54298 .36937 .54132 Metetra
.844 .774 .783 r
.36937 .54132 .37133 .54298 .3821 .52994 .38015 .52826 Metetra
.869 .767 .748 r
.38015 .52826 .3821 .52994 .39299 .51309 .39106 .51144 Metetra
.52 .721 .965 r
.39106 .51144 .39299 .51309 .40323 .51295 .40132 .51088 Metetra
0 .166 .675 r
.40132 .51088 .40323 .51295 .41325 .52127 .41134 .5192 Metetra
0 .107 .621 r
.41134 .5192 .41325 .52127 .42335 .53038 .42144 .52831 Metetra
.743 .744 .853 r
.42144 .52831 .42335 .53038 .43403 .52291 .4321 .52193 Metetra
.089 .58 .9 r
.4321 .52193 .43403 .52291 .44444 .52701 .44256 .52409 Metetra
.927 .549 .159 r
.44256 .52409 .44444 .52701 .45433 .56024 .45244 .55731 Metetra
.727 .682 .807 r
.45244 .55731 .45433 .56024 .46522 .55234 .46332 .55047 Metetra
.772 .772 .853 r
.46332 .55047 .46522 .55234 .47612 .545 .47423 .54286 Metetra
.594 .7 .916 r
.47423 .54286 .47612 .545 .48697 .54342 .48509 .54126 Metetra
.874 .751 .724 r
.48509 .54126 .48697 .54342 .49802 .52372 .49616 .52155 Metetra
.878 .751 .717 r
.49616 .52155 .49802 .52372 .50901 .50318 .50717 .50099 Metetra
.865 .752 .736 r
.50717 .50099 .50901 .50318 .51993 .48497 .5181 .48323 Metetra
.82 .356 0 r
.5181 .48323 .51993 .48497 .53086 .50389 .52903 .50216 Metetra
.84 .386 0 r
.52903 .50216 .53086 .50389 .542 .52451 .54016 .52278 Metetra
.858 .413 .014 r
.54016 .52278 .542 .52451 .55335 .54697 .55151 .54525 Metetra
.908 .781 .709 r
.55151 .54525 .55335 .54697 .56439 .52421 .56256 .52246 Metetra
.868 .43 .034 r
.56256 .52246 .56439 .52421 .57606 .5489 .57423 .54685 Metetra
.956 .619 .321 r
.57423 .54685 .57606 .5489 .58881 .61851 .58695 .61649 Metetra
.768 .301 0 r
.58695 .61649 .58881 .61851 .60097 .63694 .59914 .63633 Metetra
.961 .827 .665 r
.59914 .63633 .60097 .63694 .61211 .60723 .61031 .60658 Metetra
.963 .822 .657 r
.61031 .60658 .61211 .60723 .62309 .57631 .62131 .57561 Metetra
.965 .817 .648 r
.62131 .57561 .62309 .57631 .63388 .54416 .63213 .54341 Metetra
.966 .812 .639 r
.63213 .54341 .63388 .54416 .64447 .51075 .64275 .50996 Metetra
0 .49 .811 r
.64275 .50996 .64447 .51075 .65645 .51637 .65464 .51313 Metetra
.9 .522 .072 r
.65464 .51313 .65645 .51637 .67018 .56047 .66836 .55722 Metetra
.911 .538 .099 r
.66836 .55722 .67018 .56047 .68452 .609 .68268 .60573 Metetra
.816 .42 0 r
.68268 .60573 .68452 .609 .69852 .64234 .69673 .64039 Metetra
.645 .763 .934 r
.69673 .64039 .69852 .64234 .71086 .63892 .70908 .63695 Metetra
.645 .763 .934 r
.70908 .63695 .71086 .63892 .72325 .63548 .72149 .6335 Metetra
.645 .763 .934 r
.72149 .6335 .72325 .63548 .7357 .63202 .73395 .63004 Metetra
.645 .763 .934 r
.73395 .63004 .7357 .63202 .74821 .62855 .74646 .62656 Metetra
.645 .763 .934 r
.74646 .62656 .74821 .62855 .76076 .62506 .75903 .62306 Metetra
.645 .763 .934 r
.75903 .62306 .76076 .62506 .77338 .62156 .77166 .61955 Metetra
.645 .763 .934 r
.77166 .61955 .77338 .62156 .78605 .61804 .78434 .61602 Metetra
.645 .763 .934 r
.78434 .61602 .78605 .61804 .79877 .61451 .79708 .61248 Metetra
.645 .763 .934 r
.79708 .61248 .79877 .61451 .81156 .61096 .80987 .60892 Metetra
.645 .763 .934 r
.80987 .60892 .81156 .61096 .82439 .60739 .82273 .60535 Metetra
.645 .763 .934 r
.82273 .60535 .82439 .60739 .83729 .60381 .83563 .60176 Metetra
.645 .763 .934 r
.83563 .60176 .83729 .60381 .85024 .60021 .8486 .59815 Metetra
.645 .763 .934 r
.8486 .59815 .85024 .60021 .86325 .5966 .86162 .59453 Metetra
.645 .763 .934 r
.86162 .59453 .86325 .5966 .87632 .59297 .87471 .59089 Metetra
.645 .763 .934 r
.87471 .59089 .87632 .59297 .88945 .58933 .88785 .58724 Metetra
.645 .763 .934 r
.88785 .58724 .88945 .58933 .90264 .58567 .90105 .58357 Metetra
.645 .763 .934 r
.90105 .58357 .90264 .58567 .91588 .58199 .91431 .57988 Metetra
.645 .763 .934 r
.91431 .57988 .91588 .58199 .92919 .57829 .92763 .57617 Metetra
.645 .763 .934 r
.92763 .57617 .92919 .57829 .94256 .57458 .94101 .57245 Metetra
.431 .637 .942 r
.32602 .55825 .328 .56028 .33797 .56138 .33599 .55944 Metetra
.83 .752 .778 r
.33599 .55944 .33797 .56138 .3487 .54933 .34677 .54673 Metetra
.407 .564 .898 r
.34677 .54673 .3487 .54933 .35868 .55212 .35677 .54912 Metetra
.779 .687 .762 r
.35677 .54912 .35868 .55212 .36937 .54132 .36748 .53808 Metetra
.791 .679 .742 r
.36748 .53808 .36937 .54132 .38015 .52826 .37827 .52502 Metetra
.809 .684 .727 r
.37827 .52502 .38015 .52826 .39106 .51144 .38913 .50947 Metetra
.449 .651 .946 r
.38913 .50947 .39106 .51144 .40132 .51088 .39935 .51037 Metetra
.672 .122 0 r
.39935 .51037 .40132 .51088 .41134 .5192 .40937 .5187 Metetra
.7 .161 0 r
.40937 .5187 .41134 .5192 .42144 .52831 .41948 .52782 Metetra
.787 .923 .927 r
.41948 .52782 .42144 .52831 .4321 .52193 .43017 .52063 Metetra
.243 .638 .96 r
.43017 .52063 .4321 .52193 .44256 .52409 .44065 .52238 Metetra
.931 .554 .254 r
.44065 .52238 .44256 .52409 .45244 .55731 .45051 .55561 Metetra
.753 .788 .881 r
.45051 .55561 .45244 .55731 .46332 .55047 .4614 .54913 Metetra
.795 .829 .878 r
.4614 .54913 .46332 .55047 .47423 .54286 .47233 .54115 Metetra
.589 .747 .952 r
.47233 .54115 .47423 .54286 .48509 .54126 .4832 .53933 Metetra
.882 .764 .727 r
.4832 .53933 .48509 .54126 .49616 .52155 .49429 .5196 Metetra
.886 .763 .72 r
.49429 .5196 .49616 .52155 .50717 .50099 .50531 .49903 Metetra
.873 .766 .742 r
.50531 .49903 .50717 .50099 .5181 .48323 .51626 .48147 Metetra
.82 .355 0 r
.51626 .48147 .5181 .48323 .52903 .50216 .52719 .50041 Metetra
.84 .386 0 r
.52719 .50041 .52903 .50216 .54016 .52278 .53832 .52105 Metetra
.858 .412 .014 r
.53832 .52105 .54016 .52278 .55151 .54525 .54966 .54353 Metetra
.909 .78 .707 r
.54966 .54353 .55151 .54525 .56256 .52246 .56074 .52044 Metetra
.86 .425 .004 r
.56074 .52044 .56256 .52246 .57423 .54685 .5724 .54523 Metetra
.954 .617 .333 r
.5724 .54523 .57423 .54685 .58695 .61649 .58509 .61493 Metetra
.809 .336 0 r
.58509 .61493 .58695 .61649 .59914 .63633 .59728 .63481 Metetra
.936 .787 .671 r
.59728 .63481 .59914 .63633 .61031 .60658 .60848 .60503 Metetra
.939 .784 .662 r
.60848 .60503 .61031 .60658 .62131 .57561 .6195 .57403 Metetra
.941 .781 .654 r
.6195 .57403 .62131 .57561 .63213 .54341 .63035 .5418 Metetra
.944 .778 .646 r
.63035 .5418 .63213 .54341 .64275 .50996 .641 .50831 Metetra
.263 .605 .954 r
.641 .50831 .64275 .50996 .65464 .51313 .65288 .51096 Metetra
.925 .541 .157 r
.65288 .51096 .65464 .51313 .66836 .55722 .66658 .55506 Metetra
.93 .552 .176 r
.66658 .55506 .66836 .55722 .68268 .60573 .68088 .6036 Metetra
.883 .469 .045 r
.68088 .6036 .68268 .60573 .69673 .64039 .69493 .63843 Metetra
.645 .763 .934 r
.69493 .63843 .69673 .64039 .70908 .63695 .7073 .63498 Metetra
.645 .763 .934 r
.7073 .63498 .70908 .63695 .72149 .6335 .71972 .63152 Metetra
.645 .763 .934 r
.71972 .63152 .72149 .6335 .73395 .63004 .73219 .62805 Metetra
.645 .763 .934 r
.73219 .62805 .73395 .63004 .74646 .62656 .74472 .62456 Metetra
.645 .763 .934 r
.74472 .62456 .74646 .62656 .75903 .62306 .7573 .62106 Metetra
.645 .763 .934 r
.7573 .62106 .75903 .62306 .77166 .61955 .76994 .61754 Metetra
.645 .763 .934 r
.76994 .61754 .77166 .61955 .78434 .61602 .78263 .614 Metetra
.645 .763 .934 r
.78263 .614 .78434 .61602 .79708 .61248 .79538 .61045 Metetra
.645 .763 .934 r
.79538 .61045 .79708 .61248 .80987 .60892 .80819 .60688 Metetra
.645 .763 .934 r
.80819 .60688 .80987 .60892 .82273 .60535 .82105 .6033 Metetra
.645 .763 .934 r
.82105 .6033 .82273 .60535 .83563 .60176 .83397 .5997 Metetra
.645 .763 .934 r
.83397 .5997 .83563 .60176 .8486 .59815 .84695 .59608 Metetra
.645 .763 .934 r
.84695 .59608 .8486 .59815 .86162 .59453 .85999 .59245 Metetra
.645 .763 .934 r
.85999 .59245 .86162 .59453 .87471 .59089 .87309 .5888 Metetra
.645 .763 .934 r
.87309 .5888 .87471 .59089 .88785 .58724 .88624 .58514 Metetra
.645 .763 .934 r
.88624 .58514 .88785 .58724 .90105 .58357 .89945 .58146 Metetra
.645 .763 .934 r
.89945 .58146 .90105 .58357 .91431 .57988 .91273 .57776 Metetra
.645 .763 .934 r
.91273 .57776 .91431 .57988 .92763 .57617 .92606 .57405 Metetra
.645 .763 .934 r
.92606 .57405 .92763 .57617 .94101 .57245 .93945 .57032 Metetra
.162 .607 .935 r
.32398 .55709 .32602 .55825 .33599 .55944 .33392 .55904 Metetra
.897 .869 .803 r
.33392 .55904 .33599 .55944 .34677 .54673 .34478 .54508 Metetra
.071 .485 .893 r
.34478 .54508 .34677 .54673 .35677 .54912 .35471 .54896 Metetra
.863 .929 .868 r
.35471 .54896 .35677 .54912 .36748 .53808 .3654 .53869 Metetra
.902 .971 .812 r
.3654 .53869 .36748 .53808 .37827 .52502 .37621 .5256 Metetra
.944 .923 .757 r
.37621 .5256 .37827 .52502 .38913 .50947 .38718 .50808 Metetra
.593 .78 .969 r
.38718 .50808 .38913 .50947 .39935 .51037 .39752 .50603 Metetra
.237 .34 .767 r
.39752 .50603 .39935 .51037 .40937 .5187 .40753 .51434 Metetra
.197 .315 .759 r
.40753 .51434 .40937 .5187 .41948 .52782 .41763 .52344 Metetra
.657 .584 .761 r
.41763 .52344 .41948 .52782 .43017 .52063 .42824 .5191 Metetra
.494 .731 .977 r
.42824 .5191 .43017 .52063 .44065 .52238 .43879 .51868 Metetra
.904 .532 .083 r
.43879 .51868 .44065 .52238 .45051 .55561 .44863 .55188 Metetra
.703 .633 .776 r
.44863 .55188 .45051 .55561 .4614 .54913 .45952 .54533 Metetra
.689 .624 .779 r
.45952 .54533 .4614 .54913 .47233 .54115 .47042 .5396 Metetra
.618 .777 .957 r
.47042 .5396 .47233 .54115 .4832 .53933 .48131 .53706 Metetra
.871 .746 .722 r
.48131 .53706 .4832 .53933 .49429 .5196 .49241 .51732 Metetra
.875 .746 .716 r
.49241 .51732 .49429 .5196 .50531 .49903 .50346 .49673 Metetra
.859 .747 .739 r
.50346 .49673 .50531 .49903 .51626 .48147 .51442 .47949 Metetra
.8 .339 0 r
.51442 .47949 .51626 .48147 .52719 .50041 .52535 .49843 Metetra
.825 .372 0 r
.52535 .49843 .52719 .50041 .53832 .52105 .53647 .51907 Metetra
.846 .401 0 r
.53647 .51907 .53832 .52105 .54966 .54353 .54781 .54156 Metetra
.904 .766 .7 r
.54781 .54156 .54966 .54353 .56074 .52044 .55889 .51752 Metetra
.818 .405 0 r
.55889 .51752 .56074 .52044 .5724 .54523 .57057 .54396 Metetra
.951 .615 .343 r
.57057 .54396 .5724 .54523 .58509 .61493 .58323 .61372 Metetra
.835 .367 0 r
.58323 .61372 .58509 .61493 .59728 .63481 .59544 .63416 Metetra
.96 .826 .666 r
.59544 .63416 .59728 .63481 .60848 .60503 .60666 .60433 Metetra
.962 .821 .657 r
.60666 .60433 .60848 .60503 .6195 .57403 .61772 .5733 Metetra
.964 .816 .648 r
.61772 .5733 .6195 .57403 .63035 .5418 .62859 .54102 Metetra
.965 .811 .639 r
.62859 .54102 .63035 .5418 .641 .50831 .63927 .50749 Metetra
.312 .742 .971 r
.63927 .50749 .641 .50831 .65288 .51096 .65105 .50739 Metetra
.887 .513 .043 r
.65105 .50739 .65288 .51096 .66658 .55506 .66474 .55146 Metetra
.9 .53 .072 r
.66474 .55146 .66658 .55506 .68088 .6036 .67902 .59997 Metetra
.807 .423 0 r
.67902 .59997 .68088 .6036 .69493 .63843 .69314 .63646 Metetra
.645 .763 .934 r
.69314 .63646 .69493 .63843 .7073 .63498 .70551 .63301 Metetra
.645 .763 .934 r
.70551 .63301 .7073 .63498 .71972 .63152 .71794 .62954 Metetra
.645 .763 .934 r
.71794 .62954 .71972 .63152 .73219 .62805 .73043 .62606 Metetra
.645 .763 .934 r
.73043 .62606 .73219 .62805 .74472 .62456 .74297 .62256 Metetra
.645 .763 .934 r
.74297 .62256 .74472 .62456 .7573 .62106 .75556 .61905 Metetra
.645 .763 .934 r
.75556 .61905 .7573 .62106 .76994 .61754 .76821 .61552 Metetra
.645 .763 .934 r
.76821 .61552 .76994 .61754 .78263 .614 .78092 .61197 Metetra
.645 .763 .934 r
.78092 .61197 .78263 .614 .79538 .61045 .79368 .60841 Metetra
.645 .763 .934 r
.79368 .60841 .79538 .61045 .80819 .60688 .8065 .60484 Metetra
.645 .763 .934 r
.8065 .60484 .80819 .60688 .82105 .6033 .81938 .60124 Metetra
.645 .763 .934 r
.81938 .60124 .82105 .6033 .83397 .5997 .83231 .59764 Metetra
.645 .763 .934 r
.83231 .59764 .83397 .5997 .84695 .59608 .8453 .59401 Metetra
.645 .763 .934 r
.8453 .59401 .84695 .59608 .85999 .59245 .85835 .59037 Metetra
.645 .763 .934 r
.85835 .59037 .85999 .59245 .87309 .5888 .87146 .58671 Metetra
.645 .763 .934 r
.87146 .58671 .87309 .5888 .88624 .58514 .88463 .58304 Metetra
.645 .763 .934 r
.88463 .58304 .88624 .58514 .89945 .58146 .89785 .57935 Metetra
.645 .763 .934 r
.89785 .57935 .89945 .58146 .91273 .57776 .91114 .57564 Metetra
.645 .763 .934 r
.91114 .57564 .91273 .57776 .92606 .57405 .92449 .57192 Metetra
.645 .763 .934 r
.92449 .57192 .92606 .57405 .93945 .57032 .9379 .56818 Metetra
.432 .601 .917 r
.32201 .55473 .32398 .55709 .33392 .55904 .33197 .55637 Metetra
.816 .709 .746 r
.33197 .55637 .33392 .55904 .34478 .54508 .34286 .54206 Metetra
.441 .545 .866 r
.34286 .54206 .34478 .54508 .35471 .54896 .35287 .54444 Metetra
.738 .617 .725 r
.35287 .54444 .35471 .54896 .3654 .53869 .36359 .53363 Metetra
.746 .609 .705 r
.36359 .53363 .3654 .53869 .37621 .5256 .3744 .52055 Metetra
.758 .615 .7 r
.3744 .52055 .37621 .5256 .38718 .50808 .38526 .5059 Metetra
.433 .622 .931 r
.38526 .5059 .38718 .50808 .39752 .50603 .39546 .5073 Metetra
.702 .256 .189 r
.39546 .5073 .39752 .50603 .40753 .51434 .40549 .51564 Metetra
.716 .275 .203 r
.40549 .51564 .40753 .51434 .41763 .52344 .4156 .52476 Metetra
.4156 .52476 .41763 .52344 .42824 .5191 .4263 .51788 Metetra
.407 .733 .991 r
.4263 .51788 .42824 .5191 .43879 .51868 .43684 .51793 Metetra
.918 .549 .308 r
.43684 .51793 .43879 .51868 .44863 .55188 .44668 .55117 Metetra
.76 .904 .94 r
.44668 .55117 .44863 .55188 .45952 .54533 .45758 .54472 Metetra
.76 .918 .942 r
.45758 .54472 .45952 .54533 .47042 .5396 .46851 .53818 Metetra
.635 .798 .961 r
.46851 .53818 .47042 .5396 .48131 .53706 .47941 .53518 Metetra
.884 .767 .728 r
.47941 .53518 .48131 .53706 .49241 .51732 .49053 .51542 Metetra
.888 .766 .721 r
.49053 .51542 .49241 .51732 .50346 .49673 .5016 .49482 Metetra
.871 .771 .749 r
.5016 .49482 .50346 .49673 .51442 .47949 .51258 .47793 Metetra
.832 .368 0 r
.51258 .47793 .51442 .47949 .52535 .49843 .5235 .49688 Metetra
.85 .395 .01 r
.5235 .49688 .52535 .49843 .53647 .51907 .53462 .51753 Metetra
.865 .42 .044 r
.53462 .51753 .53647 .51907 .54781 .54156 .54595 .54004 Metetra
.92 .788 .698 r
.54595 .54004 .54781 .54156 .55889 .51752 .55705 .51539 Metetra
.879 .457 .043 r
.55705 .51539 .55889 .51752 .57057 .54396 .56874 .54276 Metetra
.95 .614 .345 r
.56874 .54276 .57057 .54396 .58323 .61372 .58137 .61259 Metetra
.828 .354 0 r
.58137 .61259 .58323 .61372 .59544 .63416 .59356 .63219 Metetra
.923 .768 .671 r
.59356 .63219 .59544 .63416 .60666 .60433 .60481 .60234 Metetra
.926 .766 .663 r
.60481 .60234 .60666 .60433 .61772 .5733 .61589 .57127 Metetra
.93 .764 .656 r
.61589 .57127 .61772 .5733 .62859 .54102 .62679 .53897 Metetra
.932 .762 .648 r
.62679 .53897 .62859 .54102 .63927 .50749 .63749 .50541 Metetra
.477 .668 .947 r
.63749 .50541 .63927 .50749 .65105 .50739 .64931 .50592 Metetra
.929 .545 .204 r
.64931 .50592 .65105 .50739 .66474 .55146 .66298 .55003 Metetra
.934 .555 .219 r
.66298 .55003 .66474 .55146 .67902 .59997 .67725 .59858 Metetra
.904 .492 .128 r
.67725 .59858 .67902 .59997 .69314 .63646 .69134 .63449 Metetra
.645 .763 .934 r
.69134 .63449 .69314 .63646 .70551 .63301 .70372 .63103 Metetra
.645 .763 .934 r
.70372 .63103 .70551 .63301 .71794 .62954 .71616 .62755 Metetra
.645 .763 .934 r
.71616 .62755 .71794 .62954 .73043 .62606 .72866 .62406 Metetra
.645 .763 .934 r
.72866 .62406 .73043 .62606 .74297 .62256 .74121 .62055 Metetra
.645 .763 .934 r
.74121 .62055 .74297 .62256 .75556 .61905 .75382 .61703 Metetra
.645 .763 .934 r
.75382 .61703 .75556 .61905 .76821 .61552 .76648 .61349 Metetra
.645 .763 .934 r
.76648 .61349 .76821 .61552 .78092 .61197 .7792 .60994 Metetra
.645 .763 .934 r
.7792 .60994 .78092 .61197 .79368 .60841 .79197 .60637 Metetra
.645 .763 .934 r
.79197 .60637 .79368 .60841 .8065 .60484 .80481 .60278 Metetra
.645 .763 .934 r
.80481 .60278 .8065 .60484 .81938 .60124 .8177 .59918 Metetra
.645 .763 .934 r
.8177 .59918 .81938 .60124 .83231 .59764 .83064 .59557 Metetra
.645 .763 .934 r
.83064 .59557 .83231 .59764 .8453 .59401 .84365 .59193 Metetra
.645 .763 .934 r
.84365 .59193 .8453 .59401 .85835 .59037 .85671 .58828 Metetra
.645 .763 .934 r
.85671 .58828 .85835 .59037 .87146 .58671 .86983 .58462 Metetra
.645 .763 .934 r
.86983 .58462 .87146 .58671 .88463 .58304 .88301 .58093 Metetra
.645 .763 .934 r
.88301 .58093 .88463 .58304 .89785 .57935 .89625 .57723 Metetra
.645 .763 .934 r
.89625 .57723 .89785 .57935 .91114 .57564 .90955 .57352 Metetra
.645 .763 .934 r
.90955 .57352 .91114 .57564 .92449 .57192 .92291 .56978 Metetra
.645 .763 .934 r
.92291 .56978 .92449 .57192 .9379 .56818 .93634 .56603 Metetra
0 .527 .836 r
.31995 .55389 .32201 .55473 .33197 .55637 .32988 .55616 Metetra
.909 .878 .792 r
.32988 .55616 .33197 .55637 .34286 .54206 .34082 .54117 Metetra
.298 0 0 r
.34082 .54117 .34286 .54206 .35287 .54444 .35073 .54562 Metetra
.735 .983 .769 r
.35073 .54562 .35287 .54444 .36359 .53363 .36143 .53572 Metetra
.704 .928 .604 r
.36143 .53572 .36359 .53363 .3744 .52055 .37227 .5226 Metetra
.893 .97 .658 r
.37227 .5226 .3744 .52055 .38526 .5059 .38329 .50473 Metetra
.647 .823 .968 r
.38329 .50473 .38526 .5059 .39546 .5073 .39368 .50148 Metetra
.35 .354 .723 r
.39368 .50148 .39546 .5073 .40549 .51564 .4037 .50978 Metetra
.326 .338 .72 r
.4037 .50978 .40549 .51564 .4156 .52476 .4138 .51887 Metetra
.622 .524 .721 r
.4138 .51887 .4156 .52476 .4263 .51788 .42439 .51575 Metetra
.604 .702 .913 r
.42439 .51575 .4263 .51788 .43684 .51793 .43498 .51395 Metetra
.892 .524 .055 r
.43498 .51395 .43684 .51793 .44668 .55117 .4448 .54716 Metetra
.698 .62 .766 r
.4448 .54716 .44668 .55117 .45758 .54472 .45571 .54056 Metetra
.661 .597 .773 r
.45571 .54056 .45758 .54472 .46851 .53818 .4666 .53609 Metetra
.658 .73 .903 r
.4666 .53609 .46851 .53818 .47941 .53518 .47752 .53278 Metetra
.867 .74 .721 r
.47752 .53278 .47941 .53518 .49053 .51542 .48865 .51301 Metetra
.871 .74 .715 r
.48865 .51301 .49053 .51542 .5016 .49482 .49973 .49239 Metetra
.85 .74 .742 r
.49973 .49239 .5016 .49482 .51258 .47793 .51073 .47584 Metetra
.792 .332 0 r
.51073 .47584 .51258 .47793 .5235 .49688 .52164 .4948 Metetra
.818 .366 0 r
.52164 .4948 .5235 .49688 .53462 .51753 .53276 .51545 Metetra
.84 .396 0 r
.53276 .51545 .53462 .51753 .54595 .54004 .54409 .53796 Metetra
.904 .761 .693 r
.54409 .53796 .54595 .54004 .55705 .51539 .55521 .51289 Metetra
.867 .45 .008 r
.55521 .51289 .55705 .51539 .56874 .54276 .56689 .54082 Metetra
.956 .619 .325 r
.56689 .54082 .56874 .54276 .58137 .61259 .5795 .61069 Metetra
.795 .328 0 r
.5795 .61069 .58137 .61259 .59356 .63219 .5917 .6312 Metetra
.951 .811 .668 r
.5917 .6312 .59356 .63219 .60481 .60234 .60298 .6013 Metetra
.953 .806 .66 r
.60298 .6013 .60481 .60234 .61589 .57127 .61408 .5702 Metetra
.955 .802 .651 r
.61408 .5702 .61589 .57127 .62679 .53897 .62501 .53786 Metetra
.957 .798 .643 r
.62501 .53786 .62679 .53897 .63749 .50541 .63574 .50426 Metetra
.526 .808 .998 r
.63574 .50426 .63749 .50541 .64931 .50592 .64748 .50243 Metetra
.891 .516 .052 r
.64748 .50243 .64931 .50592 .66298 .55003 .66114 .54651 Metetra
.904 .533 .081 r
.66114 .54651 .66298 .55003 .67725 .59858 .67538 .59504 Metetra
.826 .44 0 r
.67538 .59504 .67725 .59858 .69134 .63449 .68953 .63251 Metetra
.645 .763 .934 r
.68953 .63251 .69134 .63449 .70372 .63103 .70193 .62904 Metetra
.645 .763 .934 r
.70193 .62904 .70372 .63103 .71616 .62755 .71438 .62556 Metetra
.645 .763 .934 r
.71438 .62556 .71616 .62755 .72866 .62406 .72689 .62206 Metetra
.645 .763 .934 r
.72689 .62206 .72866 .62406 .74121 .62055 .73945 .61854 Metetra
.645 .763 .934 r
.73945 .61854 .74121 .62055 .75382 .61703 .75207 .61501 Metetra
.645 .763 .934 r
.75207 .61501 .75382 .61703 .76648 .61349 .76475 .61146 Metetra
.645 .763 .934 r
.76475 .61146 .76648 .61349 .7792 .60994 .77748 .6079 Metetra
.645 .763 .934 r
.77748 .6079 .7792 .60994 .79197 .60637 .79026 .60432 Metetra
.645 .763 .934 r
.79026 .60432 .79197 .60637 .80481 .60278 .80311 .60073 Metetra
.645 .763 .934 r
.80311 .60073 .80481 .60278 .8177 .59918 .81601 .59712 Metetra
.645 .763 .934 r
.81601 .59712 .8177 .59918 .83064 .59557 .82897 .59349 Metetra
.645 .763 .934 r
.82897 .59349 .83064 .59557 .84365 .59193 .84199 .58985 Metetra
.645 .763 .934 r
.84199 .58985 .84365 .59193 .85671 .58828 .85506 .58619 Metetra
.645 .763 .934 r
.85506 .58619 .85671 .58828 .86983 .58462 .8682 .58251 Metetra
.645 .763 .934 r
.8682 .58251 .86983 .58462 .88301 .58093 .88139 .57882 Metetra
.645 .763 .934 r
.88139 .57882 .88301 .58093 .89625 .57723 .89465 .57511 Metetra
.645 .763 .934 r
.89465 .57511 .89625 .57723 .90955 .57352 .90796 .57139 Metetra
.645 .763 .934 r
.90796 .57139 .90955 .57352 .92291 .56978 .92133 .56764 Metetra
.645 .763 .934 r
.92133 .56764 .92291 .56978 .93634 .56603 .93477 .56388 Metetra
.459 .585 .892 r
.31799 .55122 .31995 .55389 .32988 .55616 .32796 .5528 Metetra
.798 .676 .73 r
.32796 .5528 .32988 .55616 .34082 .54117 .3389 .53821 Metetra
.434 .547 .872 r
.3389 .53821 .34082 .54117 .35073 .54562 .34891 .54061 Metetra
.728 .601 .715 r
.34891 .54061 .35073 .54562 .36143 .53572 .35965 .52976 Metetra
.729 .583 .692 r
.35965 .52976 .36143 .53572 .37227 .5226 .37049 .51666 Metetra
.739 .589 .688 r
.37049 .51666 .37227 .5226 .38329 .50473 .38137 .50231 Metetra
.459 .608 .911 r
.38137 .50231 .38329 .50473 .39368 .50148 .39158 .50363 Metetra
.688 .28 .267 r
.39158 .50363 .39368 .50148 .4037 .50978 .40161 .51196 Metetra
.7 .295 .276 r
.40161 .51196 .4037 .50978 .4138 .51887 .41172 .52108 Metetra
.41172 .52108 .4138 .51887 .42439 .51575 .42245 .5142 Metetra
.476 .721 .978 r
.42245 .5142 .42439 .51575 .43498 .51395 .43301 .51402 Metetra
.902 .54 .344 r
.43301 .51402 .43498 .51395 .4448 .54716 .44281 .54729 Metetra
.681 .971 .92 r
.44281 .54729 .4448 .54716 .45571 .54056 .45373 .54092 Metetra
.649 .969 .881 r
.45373 .54092 .45571 .54056 .4666 .53609 .46468 .53427 Metetra
.651 .756 .926 r
.46468 .53427 .4666 .53609 .47752 .53278 .47561 .53109 Metetra
.891 .779 .73 r
.47561 .53109 .47752 .53278 .48865 .51301 .48676 .5113 Metetra
.895 .777 .723 r
.48676 .5113 .48865 .51301 .49973 .49239 .49786 .49066 Metetra
.876 .784 .757 r
.49786 .49066 .49973 .49239 .51073 .47584 .50887 .47421 Metetra
.828 .364 0 r
.50887 .47421 .51073 .47584 .52164 .4948 .51979 .49317 Metetra
.847 .392 0 r
.51979 .49317 .52164 .4948 .53276 .51545 .5309 .51384 Metetra
.863 .418 .034 r
.5309 .51384 .53276 .51545 .54409 .53796 .54222 .53636 Metetra
.918 .784 .696 r
.54222 .53636 .54409 .53796 .55521 .51289 .55337 .51145 Metetra
.896 .475 .125 r
.55337 .51145 .55521 .51289 .56689 .54082 .56504 .53895 Metetra
.955 .618 .327 r
.56504 .53895 .56689 .54082 .5795 .61069 .57762 .60886 Metetra
.785 .312 0 r
.57762 .60886 .5795 .61069 .5917 .6312 .5898 .62851 Metetra
.903 .741 .67 r
.5898 .62851 .5917 .6312 .60298 .6013 .6011 .5986 Metetra
.907 .74 .663 r
.6011 .5986 .60298 .6013 .61408 .5702 .61223 .56748 Metetra
.911 .739 .656 r
.61223 .56748 .61408 .5702 .62501 .53786 .62318 .53513 Metetra
.915 .738 .649 r
.62318 .53513 .62501 .53786 .63574 .50426 .63393 .50151 Metetra
.529 .627 .893 r
.63393 .50151 .63574 .50426 .64748 .50243 .64575 .50173 Metetra
.927 .546 .247 r
.64575 .50173 .64748 .50243 .66114 .54651 .6594 .54587 Metetra
.931 .555 .259 r
.6594 .54587 .66114 .54651 .67538 .59504 .67364 .59447 Metetra
.907 .5 .192 r
.67364 .59447 .67538 .59504 .68953 .63251 .68772 .63053 Metetra
.645 .763 .934 r
.68772 .63053 .68953 .63251 .70193 .62904 .70013 .62705 Metetra
.645 .763 .934 r
.70013 .62705 .70193 .62904 .71438 .62556 .71259 .62356 Metetra
.645 .763 .934 r
.71259 .62356 .71438 .62556 .72689 .62206 .72511 .62005 Metetra
.645 .763 .934 r
.72511 .62005 .72689 .62206 .73945 .61854 .73769 .61653 Metetra
.645 .763 .934 r
.73769 .61653 .73945 .61854 .75207 .61501 .75032 .61299 Metetra
.645 .763 .934 r
.75032 .61299 .75207 .61501 .76475 .61146 .76301 .60943 Metetra
.645 .763 .934 r
.76301 .60943 .76475 .61146 .77748 .6079 .77575 .60586 Metetra
.645 .763 .934 r
.77575 .60586 .77748 .6079 .79026 .60432 .78855 .60227 Metetra
.645 .763 .934 r
.78855 .60227 .79026 .60432 .80311 .60073 .80141 .59867 Metetra
.645 .763 .934 r
.80141 .59867 .80311 .60073 .81601 .59712 .81432 .59505 Metetra
.645 .763 .934 r
.81432 .59505 .81601 .59712 .82897 .59349 .82729 .59141 Metetra
.645 .763 .934 r
.82729 .59141 .82897 .59349 .84199 .58985 .84032 .58776 Metetra
.645 .763 .934 r
.84032 .58776 .84199 .58985 .85506 .58619 .85341 .58409 Metetra
.645 .763 .934 r
.85341 .58409 .85506 .58619 .8682 .58251 .86656 .58041 Metetra
.645 .763 .934 r
.86656 .58041 .8682 .58251 .88139 .57882 .87977 .5767 Metetra
.645 .763 .934 r
.87977 .5767 .88139 .57882 .89465 .57511 .89303 .57298 Metetra
.645 .763 .934 r
.89303 .57298 .89465 .57511 .90796 .57139 .90636 .56925 Metetra
.645 .763 .934 r
.90636 .56925 .90796 .57139 .92133 .56764 .91975 .5655 Metetra
.645 .763 .934 r
.91975 .5655 .92133 .56764 .93477 .56388 .9332 .56173 Metetra
.002 .548 .833 r
.31591 .5505 .31799 .55122 .32796 .5528 .32587 .55238 Metetra
.9 .863 .795 r
.32587 .55238 .32796 .5528 .3389 .53821 .33682 .53778 Metetra
.454 0 0 r
.33682 .53778 .3389 .53821 .34891 .54061 .34673 .54239 Metetra
.584 .892 .611 r
.34673 .54239 .34891 .54061 .35965 .52976 .35746 .53225 Metetra
.623 .867 .513 r
.35746 .53225 .35965 .52976 .37049 .51666 .36834 .51877 Metetra
.879 .97 .652 r
.36834 .51877 .37049 .51666 .38137 .50231 .37938 .50121 Metetra
.671 .84 .964 r
.37938 .50121 .38137 .50231 .39158 .50363 .38982 .4974 Metetra
.368 .355 .713 r
.38982 .4974 .39158 .50363 .40161 .51196 .39983 .50569 Metetra
.345 .34 .71 r
.39983 .50569 .40161 .51196 .41172 .52108 .40993 .51478 Metetra
.62 .514 .712 r
.40993 .51478 .41172 .52108 .42245 .5142 .42054 .51157 Metetra
.591 .652 .879 r
.42054 .51157 .42245 .5142 .43301 .51402 .43113 .51029 Metetra
.905 .533 .084 r
.43113 .51029 .43301 .51402 .44281 .54729 .44092 .54353 Metetra
.699 .631 .778 r
.44092 .54353 .44281 .54729 .45373 .54092 .45184 .53725 Metetra
.693 .634 .785 r
.45184 .53725 .45373 .54092 .46468 .53427 .46278 .53141 Metetra
.639 .658 .852 r
.46278 .53141 .46468 .53427 .47561 .53109 .4737 .52861 Metetra
.864 .736 .72 r
.4737 .52861 .47561 .53109 .48676 .5113 .48488 .50881 Metetra
.869 .736 .714 r
.48488 .50881 .48676 .5113 .49786 .49066 .49599 .48815 Metetra
.844 .736 .745 r
.49599 .48815 .49786 .49066 .50887 .47421 .50702 .47212 Metetra
.793 .333 0 r
.50702 .47212 .50887 .47421 .51979 .49317 .51793 .49109 Metetra
.819 .367 0 r
.51793 .49109 .51979 .49317 .5309 .51384 .52903 .51176 Metetra
.841 .397 0 r
.52903 .51176 .5309 .51384 .54222 .53636 .54035 .53429 Metetra
.902 .762 .697 r
.54035 .53429 .54222 .53636 .55337 .51145 .55152 .50986 Metetra
.886 .458 .089 r
.55152 .50986 .55337 .51145 .56504 .53895 .56317 .53604 Metetra
.96 .623 .295 r
.56317 .53604 .56504 .53895 .57762 .60886 .57572 .60594 Metetra
.678 .25 0 r
.57572 .60594 .57762 .60886 .5898 .62851 .58792 .62697 Metetra
.936 .787 .671 r
.58792 .62697 .5898 .62851 .6011 .5986 .59924 .59703 Metetra
.939 .784 .662 r
.59924 .59703 .6011 .5986 .61223 .56748 .6104 .56588 Metetra
.941 .781 .654 r
.6104 .56588 .61223 .56748 .62318 .53513 .62137 .53349 Metetra
.944 .778 .646 r
.62137 .53349 .62318 .53513 .63393 .50151 .63215 .49985 Metetra
.536 .746 .972 r
.63215 .49985 .63393 .50151 .64575 .50173 .64394 .49868 Metetra
.907 .528 .091 r
.64394 .49868 .64575 .50173 .6594 .54587 .65757 .54281 Metetra
.917 .542 .116 r
.65757 .54281 .6594 .54587 .67364 .59447 .67179 .5914 Metetra
.855 .458 0 r
.67179 .5914 .67364 .59447 .68772 .63053 .6859 .62855 Metetra
.645 .763 .934 r
.6859 .62855 .68772 .63053 .70013 .62705 .69833 .62506 Metetra
.645 .763 .934 r
.69833 .62506 .70013 .62705 .71259 .62356 .7108 .62156 Metetra
.645 .763 .934 r
.7108 .62156 .71259 .62356 .72511 .62005 .72333 .61804 Metetra
.645 .763 .934 r
.72333 .61804 .72511 .62005 .73769 .61653 .73592 .61451 Metetra
.645 .763 .934 r
.73592 .61451 .73769 .61653 .75032 .61299 .74856 .61096 Metetra
.645 .763 .934 r
.74856 .61096 .75032 .61299 .76301 .60943 .76126 .60739 Metetra
.645 .763 .934 r
.76126 .60739 .76301 .60943 .77575 .60586 .77402 .60381 Metetra
.645 .763 .934 r
.77402 .60381 .77575 .60586 .78855 .60227 .78683 .60021 Metetra
.645 .763 .934 r
.78683 .60021 .78855 .60227 .80141 .59867 .7997 .5966 Metetra
.645 .763 .934 r
.7997 .5966 .80141 .59867 .81432 .59505 .81263 .59297 Metetra
.645 .763 .934 r
.81263 .59297 .81432 .59505 .82729 .59141 .82561 .58933 Metetra
.645 .763 .934 r
.82561 .58933 .82729 .59141 .84032 .58776 .83865 .58567 Metetra
.645 .763 .934 r
.83865 .58567 .84032 .58776 .85341 .58409 .85176 .58199 Metetra
.645 .763 .934 r
.85176 .58199 .85341 .58409 .86656 .58041 .86492 .57829 Metetra
.645 .763 .934 r
.86492 .57829 .86656 .58041 .87977 .5767 .87814 .57458 Metetra
.645 .763 .934 r
.87814 .57458 .87977 .5767 .89303 .57298 .89142 .57085 Metetra
.645 .763 .934 r
.89142 .57085 .89303 .57298 .90636 .56925 .90476 .56711 Metetra
.645 .763 .934 r
.90476 .56711 .90636 .56925 .91975 .5655 .91816 .56334 Metetra
.645 .763 .934 r
.91816 .56334 .91975 .5655 .9332 .56173 .93163 .55956 Metetra
.46 .567 .876 r
.31396 .54761 .31591 .5505 .32587 .55238 .32392 .5494 Metetra
.811 .695 .737 r
.32392 .5494 .32587 .55238 .33682 .53778 .3349 .53454 Metetra
.422 .52 .853 r
.3349 .53454 .33682 .53778 .34673 .54239 .3449 .53746 Metetra
.73 .604 .716 r
.3449 .53746 .34673 .54239 .35746 .53225 .35567 .52657 Metetra
.735 .591 .696 r
.35567 .52657 .35746 .53225 .36834 .51877 .36654 .51343 Metetra
.754 .608 .695 r
.36654 .51343 .36834 .51877 .37938 .50121 .37746 .49852 Metetra
.506 .607 .887 r
.37746 .49852 .37938 .50121 .38982 .4974 .38771 .49925 Metetra
.692 .271 .242 r
.38771 .49925 .38982 .4974 .39983 .50569 .39774 .50758 Metetra
.704 .288 .253 r
.39774 .50758 .39983 .50569 .40993 .51478 .40785 .51669 Metetra
.40785 .51669 .40993 .51478 .42054 .51157 .41858 .51043 Metetra
.454 .768 .997 r
.41858 .51043 .42054 .51157 .43113 .51029 .42916 .50977 Metetra
.914 .546 .319 r
.42916 .50977 .43113 .51029 .44092 .54353 .43894 .54305 Metetra
.728 .931 .957 r
.43894 .54305 .44092 .54353 .45184 .53725 .44987 .53713 Metetra
.752 .967 .932 r
.44987 .53713 .45184 .53725 .46278 .53141 .46085 .53004 Metetra
.621 .802 .969 r
.46085 .53004 .46278 .53141 .4737 .52861 .47178 .52722 Metetra
.903 .797 .734 r
.47178 .52722 .4737 .52861 .48488 .50881 .48297 .5074 Metetra
.906 .795 .726 r
.48297 .5074 .48488 .50881 .49599 .48815 .49411 .48673 Metetra
.888 .805 .762 r
.49411 .48673 .49599 .48815 .50702 .47212 .50516 .47013 Metetra
.802 .341 0 r
.50516 .47013 .50702 .47212 .51793 .49109 .51606 .48911 Metetra
.827 .373 0 r
.51606 .48911 .51793 .49109 .52903 .51176 .52716 .50978 Metetra
.847 .402 0 r
.52716 .50978 .52903 .51176 .54035 .53429 .53848 .53232 Metetra
.905 .767 .698 r
.53848 .53232 .54035 .53429 .55152 .50986 .54967 .50786 Metetra
.878 .452 .047 r
.54967 .50786 .55152 .50986 .56317 .53604 .56131 .53446 Metetra
.953 .616 .335 r
.56131 .53446 .56317 .53604 .57572 .60594 .57383 .60442 Metetra
.821 .351 0 r
.57383 .60442 .57572 .60594 .58792 .62697 .58603 .62489 Metetra
.921 .765 .671 r
.58603 .62489 .58792 .62697 .59924 .59703 .59737 .59493 Metetra
.924 .763 .663 r
.59737 .59493 .59924 .59703 .6104 .56588 .60855 .56375 Metetra
.927 .761 .656 r
.60855 .56375 .6104 .56588 .62137 .53349 .61955 .53134 Metetra
.93 .759 .648 r
.61955 .53134 .62137 .53349 .63215 .49985 .63036 .49767 Metetra
.528 .683 .937 r
.63036 .49767 .63215 .49985 .64394 .49868 .64217 .49728 Metetra
.929 .545 .209 r
.64217 .49728 .64394 .49868 .65757 .54281 .6558 .54146 Metetra
.933 .555 .224 r
.6558 .54146 .65757 .54281 .67179 .5914 .67001 .59009 Metetra
.906 .496 .14 r
.67001 .59009 .67179 .5914 .6859 .62855 .68408 .62656 Metetra
.645 .763 .934 r
.68408 .62656 .6859 .62855 .69833 .62506 .69652 .62306 Metetra
.645 .763 .934 r
.69652 .62306 .69833 .62506 .7108 .62156 .70901 .61955 Metetra
.645 .763 .934 r
.70901 .61955 .7108 .62156 .72333 .61804 .72155 .61602 Metetra
.645 .763 .934 r
.72155 .61602 .72333 .61804 .73592 .61451 .73415 .61248 Metetra
.645 .763 .934 r
.73415 .61248 .73592 .61451 .74856 .61096 .7468 .60892 Metetra
.645 .763 .934 r
.7468 .60892 .74856 .61096 .76126 .60739 .75951 .60535 Metetra
.645 .763 .934 r
.75951 .60535 .76126 .60739 .77402 .60381 .77228 .60176 Metetra
.645 .763 .934 r
.77228 .60176 .77402 .60381 .78683 .60021 .78511 .59815 Metetra
.645 .763 .934 r
.78511 .59815 .78683 .60021 .7997 .5966 .79799 .59453 Metetra
.645 .763 .934 r
.79799 .59453 .7997 .5966 .81263 .59297 .81093 .59089 Metetra
.645 .763 .934 r
.81093 .59089 .81263 .59297 .82561 .58933 .82393 .58724 Metetra
.645 .763 .934 r
.82393 .58724 .82561 .58933 .83865 .58567 .83698 .58357 Metetra
.645 .763 .934 r
.83698 .58357 .83865 .58567 .85176 .58199 .8501 .57988 Metetra
.645 .763 .934 r
.8501 .57988 .85176 .58199 .86492 .57829 .86327 .57617 Metetra
.645 .763 .934 r
.86327 .57617 .86492 .57829 .87814 .57458 .87651 .57245 Metetra
.645 .763 .934 r
.87651 .57245 .87814 .57458 .89142 .57085 .8898 .56871 Metetra
.645 .763 .934 r
.8898 .56871 .89142 .57085 .90476 .56711 .90316 .56496 Metetra
.645 .763 .934 r
.90316 .56496 .90476 .56711 .91816 .56334 .91657 .56119 Metetra
.645 .763 .934 r
.91657 .56119 .91816 .56334 .93163 .55956 .93005 .5574 Metetra
.024 .562 .847 r
.31186 .54686 .31396 .54761 .32392 .5494 .32184 .54865 Metetra
.888 .838 .791 r
.32184 .54865 .32392 .5494 .3349 .53454 .33281 .53413 Metetra
.476 0 0 r
.33281 .53413 .3349 .53454 .3449 .53746 .34271 .53893 Metetra
.695 .96 .711 r
.34271 .53893 .3449 .53746 .35567 .52657 .35348 .52857 Metetra
.757 .954 .64 r
.35348 .52857 .35567 .52657 .36654 .51343 .3644 .51495 Metetra
.929 .972 .716 r
.3644 .51495 .36654 .51343 .37746 .49852 .37547 .49745 Metetra
.677 .844 .963 r
.37547 .49745 .37746 .49852 .38771 .49925 .38592 .49349 Metetra
.343 .352 .725 r
.38592 .49349 .38771 .49925 .39774 .50758 .39594 .50178 Metetra
.317 .335 .722 r
.39594 .50178 .39774 .50758 .40785 .51669 .40604 .51086 Metetra
.623 .526 .723 r
.40604 .51086 .40785 .51669 .41858 .51043 .41666 .50764 Metetra
.588 .638 .868 r
.41666 .50764 .41858 .51043 .42916 .50977 .42727 .50646 Metetra
.92 .544 .129 r
.42727 .50646 .42916 .50977 .43894 .54305 .43703 .53973 Metetra
.701 .654 .8 r
.43703 .53973 .43894 .54305 .44987 .53713 .44796 .53386 Metetra
.718 .663 .795 r
.44796 .53386 .44987 .53713 .46085 .53004 .45894 .52701 Metetra
.625 .641 .846 r
.45894 .52701 .46085 .53004 .47178 .52722 .46987 .52467 Metetra
.862 .733 .719 r
.46987 .52467 .47178 .52722 .48297 .5074 .48108 .50483 Metetra
.867 .733 .713 r
.48108 .50483 .48297 .5074 .49411 .48673 .49224 .48414 Metetra
.841 .732 .744 r
.49224 .48414 .49411 .48673 .50516 .47013 .50329 .46818 Metetra
.806 .343 0 r
.50329 .46818 .50516 .47013 .51606 .48911 .51419 .48715 Metetra
.829 .375 0 r
.51419 .48715 .51606 .48911 .52716 .50978 .52529 .50783 Metetra
.849 .404 0 r
.52529 .50783 .52716 .50978 .53848 .53232 .5366 .53038 Metetra
.904 .77 .702 r
.5366 .53038 .53848 .53232 .54967 .50786 .54781 .50652 Metetra
.882 .448 .098 r
.54781 .50652 .54967 .50786 .56131 .53446 .55944 .5314 Metetra
.96 .623 .291 r
.55944 .5314 .56131 .53446 .57383 .60442 .57192 .60135 Metetra
.674 .255 0 r
.57192 .60135 .57383 .60442 .58603 .62489 .58413 .62299 Metetra
.926 .773 .671 r
.58413 .62299 .58603 .62489 .59737 .59493 .5955 .59301 Metetra
.929 .77 .663 r
.5955 .59301 .59737 .59493 .60855 .56375 .6067 .56181 Metetra
.932 .768 .655 r
.6067 .56181 .60855 .56375 .61955 .53134 .61773 .52937 Metetra
.935 .766 .648 r
.61773 .52937 .61955 .53134 .63036 .49767 .62856 .49567 Metetra
.55 .712 .947 r
.62856 .49567 .63036 .49767 .64217 .49728 .64036 .49464 Metetra
.918 .535 .125 r
.64036 .49464 .64217 .49728 .6558 .54146 .65397 .53882 Metetra
.925 .548 .147 r
.65397 .53882 .6558 .54146 .67001 .59009 .66816 .58746 Metetra
.877 .473 .025 r
.66816 .58746 .67001 .59009 .68408 .62656 .68226 .62456 Metetra
.645 .763 .934 r
.68226 .62456 .68408 .62656 .69652 .62306 .6947 .62106 Metetra
.645 .763 .934 r
.6947 .62106 .69652 .62306 .70901 .61955 .7072 .61754 Metetra
.645 .763 .934 r
.7072 .61754 .70901 .61955 .72155 .61602 .71976 .614 Metetra
.645 .763 .934 r
.71976 .614 .72155 .61602 .73415 .61248 .73237 .61045 Metetra
.645 .763 .934 r
.73237 .61045 .73415 .61248 .7468 .60892 .74504 .60688 Metetra
.645 .763 .934 r
.74504 .60688 .7468 .60892 .75951 .60535 .75776 .6033 Metetra
.645 .763 .934 r
.75776 .6033 .75951 .60535 .77228 .60176 .77054 .5997 Metetra
.645 .763 .934 r
.77054 .5997 .77228 .60176 .78511 .59815 .78338 .59608 Metetra
.645 .763 .934 r
.78338 .59608 .78511 .59815 .79799 .59453 .79627 .59245 Metetra
.645 .763 .934 r
.79627 .59245 .79799 .59453 .81093 .59089 .80923 .5888 Metetra
.645 .763 .934 r
.80923 .5888 .81093 .59089 .82393 .58724 .82224 .58514 Metetra
.645 .763 .934 r
.82224 .58514 .82393 .58724 .83698 .58357 .83531 .58146 Metetra
.645 .763 .934 r
.83531 .58146 .83698 .58357 .8501 .57988 .84843 .57776 Metetra
.645 .763 .934 r
.84843 .57776 .8501 .57988 .86327 .57617 .86162 .57405 Metetra
.645 .763 .934 r
.86162 .57405 .86327 .57617 .87651 .57245 .87487 .57032 Metetra
.645 .763 .934 r
.87487 .57032 .87651 .57245 .8898 .56871 .88818 .56657 Metetra
.645 .763 .934 r
.88818 .56657 .8898 .56871 .90316 .56496 .90155 .56281 Metetra
.645 .763 .934 r
.90155 .56281 .90316 .56496 .91657 .56119 .91498 .55902 Metetra
.645 .763 .934 r
.91498 .55902 .91657 .56119 .93005 .5574 .92847 .55522 Metetra
.4 .519 .862 r
.30992 .54374 .31186 .54686 .32184 .54865 .31981 .54683 Metetra
.86 .757 .748 r
.31981 .54683 .32184 .54865 .33281 .53413 .33092 .53023 Metetra
.369 .447 .811 r
.33092 .53023 .33281 .53413 .34271 .53893 .34082 .53502 Metetra
.756 .645 .738 r
.34082 .53502 .34271 .53893 .35348 .52857 .35163 .52385 Metetra
.754 .621 .712 r
.35163 .52385 .35348 .52857 .3644 .51495 .36253 .51069 Metetra
.787 .647 .707 r
.36253 .51069 .3644 .51495 .37547 .49745 .37356 .49443 Metetra
.551 .602 .857 r
.37356 .49443 .37547 .49745 .38592 .49349 .38385 .49436 Metetra
.704 .235 .134 r
.38385 .49436 .38592 .49349 .39594 .50178 .39388 .50267 Metetra
.72 .257 .152 r
.39388 .50267 .39594 .50178 .40604 .51086 .40399 .51178 Metetra
.40399 .51178 .40604 .51086 .41666 .50764 .41466 .50755 Metetra
.468 .882 .933 r
.41466 .50755 .41666 .50764 .42727 .50646 .42533 .5043 Metetra
.933 .554 .225 r
.42533 .5043 .42727 .50646 .43703 .53973 .43508 .53758 Metetra
.67 .728 .893 r
.43508 .53758 .43703 .53973 .44796 .53386 .44597 .53385 Metetra
.806 .974 .902 r
.44597 .53385 .44796 .53386 .45894 .52701 .45701 .52517 Metetra
.572 .73 .949 r
.45701 .52517 .45894 .52701 .46987 .52467 .46793 .52372 Metetra
.919 .825 .738 r
.46793 .52372 .46987 .52467 .48108 .50483 .47916 .50386 Metetra
.922 .821 .73 r
.47916 .50386 .48108 .50483 .49224 .48414 .49034 .48315 Metetra
.91 .834 .759 r
.49034 .48315 .49224 .48414 .50329 .46818 .50142 .4656 Metetra
.733 .289 0 r
.50142 .4656 .50329 .46818 .51419 .48715 .51232 .48457 Metetra
.77 .33 0 r
.51232 .48457 .51419 .48715 .52529 .50783 .52341 .50525 Metetra
.801 .366 0 r
.52341 .50525 .52529 .50783 .5366 .53038 .53471 .52779 Metetra
.879 .74 .704 r
.53471 .52779 .5366 .53038 .54781 .50652 .54595 .5051 Metetra
.871 .43 .064 r
.54595 .5051 .54781 .50652 .55944 .5314 .55756 .52874 Metetra
.959 .622 .304 r
.55756 .52874 .55944 .5314 .57192 .60135 .57001 .5987 Metetra
.786 .351 0 r
.57001 .5987 .57192 .60135 .58413 .62299 .58225 .6226 Metetra
.967 .838 .663 r
.58225 .6226 .58413 .62299 .5955 .59301 .59365 .59256 Metetra
.968 .832 .654 r
.59365 .59256 .5955 .59301 .6067 .56181 .60489 .56131 Metetra
.97 .826 .645 r
.60489 .56131 .6067 .56181 .61773 .52937 .61594 .52883 Metetra
.971 .821 .636 r
.61594 .52883 .61773 .52937 .62856 .49567 .6268 .49508 Metetra
.567 .894 .985 r
.6268 .49508 .62856 .49567 .64036 .49464 .63853 .49142 Metetra
.902 .525 .079 r
.63853 .49142 .64036 .49464 .65397 .53882 .65212 .53558 Metetra
.913 .54 .105 r
.65212 .53558 .65397 .53882 .66816 .58746 .66629 .5842 Metetra
.855 .463 0 r
.66629 .5842 .66816 .58746 .68226 .62456 .68043 .62256 Metetra
.645 .763 .934 r
.68043 .62256 .68226 .62456 .6947 .62106 .69289 .61905 Metetra
.645 .763 .934 r
.69289 .61905 .6947 .62106 .7072 .61754 .7054 .61552 Metetra
.645 .763 .934 r
.7054 .61552 .7072 .61754 .71976 .614 .71797 .61197 Metetra
.645 .763 .934 r
.71797 .61197 .71976 .614 .73237 .61045 .73059 .60841 Metetra
.645 .763 .934 r
.73059 .60841 .73237 .61045 .74504 .60688 .74327 .60484 Metetra
.645 .763 .934 r
.74327 .60484 .74504 .60688 .75776 .6033 .756 .60124 Metetra
.645 .763 .934 r
.756 .60124 .75776 .6033 .77054 .5997 .7688 .59764 Metetra
.645 .763 .934 r
.7688 .59764 .77054 .5997 .78338 .59608 .78165 .59401 Metetra
.645 .763 .934 r
.78165 .59401 .78338 .59608 .79627 .59245 .79455 .59037 Metetra
.645 .763 .934 r
.79455 .59037 .79627 .59245 .80923 .5888 .80752 .58671 Metetra
.645 .763 .934 r
.80752 .58671 .80923 .5888 .82224 .58514 .82054 .58304 Metetra
.645 .763 .934 r
.82054 .58304 .82224 .58514 .83531 .58146 .83362 .57935 Metetra
.645 .763 .934 r
.83362 .57935 .83531 .58146 .84843 .57776 .84677 .57564 Metetra
.645 .763 .934 r
.84677 .57564 .84843 .57776 .86162 .57405 .85997 .57192 Metetra
.645 .763 .934 r
.85997 .57192 .86162 .57405 .87487 .57032 .87323 .56818 Metetra
.645 .763 .934 r
.87323 .56818 .87487 .57032 .88818 .56657 .88655 .56442 Metetra
.645 .763 .934 r
.88655 .56442 .88818 .56657 .90155 .56281 .89993 .56065 Metetra
.645 .763 .934 r
.89993 .56065 .90155 .56281 .91498 .55902 .91338 .55685 Metetra
.645 .763 .934 r
.91338 .55685 .91498 .55902 .92847 .55522 .92688 .55305 Metetra
0 .518 .833 r
.30782 .54287 .30992 .54374 .31981 .54683 .31777 .54525 Metetra
.863 .774 .762 r
.31777 .54525 .31981 .54683 .33092 .53023 .32883 .52972 Metetra
.491 0 0 r
.32883 .52972 .33092 .53023 .34082 .53502 .33871 .53493 Metetra
.867 .934 .865 r
.33871 .53493 .34082 .53502 .35163 .52385 .34951 .52433 Metetra
.904 .96 .817 r
.34951 .52433 .35163 .52385 .36253 .51069 .36044 .51114 Metetra
.943 .913 .758 r
.36044 .51114 .36253 .51069 .37356 .49443 .37155 .49336 Metetra
.64 .838 .976 r
.37155 .49336 .37356 .49443 .38385 .49436 .38199 .49009 Metetra
.218 .334 .769 r
.38199 .49009 .38385 .49436 .39388 .50267 .39201 .49838 Metetra
.176 .307 .76 r
.39201 .49838 .39388 .50267 .40399 .51178 .40211 .50747 Metetra
.632 .575 .773 r
.40211 .50747 .40399 .51178 .41466 .50755 .41274 .50449 Metetra
.626 .636 .84 r
.41274 .50449 .41466 .50755 .42533 .5043 .4234 .50213 Metetra
.933 .554 .224 r
.4234 .50213 .42533 .5043 .43508 .53758 .43313 .53541 Metetra
.704 .736 .876 r
.43313 .53541 .43508 .53758 .44597 .53385 .44406 .53049 Metetra
.727 .663 .786 r
.44406 .53049 .44597 .53385 .45701 .52517 .45508 .52298 Metetra
.607 .704 .913 r
.45508 .52298 .45701 .52517 .46793 .52372 .46601 .52101 Metetra
.858 .726 .717 r
.46601 .52101 .46793 .52372 .47916 .50386 .47726 .50114 Metetra
.862 .726 .711 r
.47726 .50114 .47916 .50386 .49034 .48315 .48846 .48042 Metetra
.839 .725 .738 r
.48846 .48042 .49034 .48315 .50142 .4656 .49955 .46399 Metetra
.83 .366 0 r
.49955 .46399 .50142 .4656 .51232 .48457 .51044 .48297 Metetra
.849 .394 .005 r
.51044 .48297 .51232 .48457 .52341 .50525 .52152 .50366 Metetra
.864 .419 .04 r
.52152 .50366 .52341 .50525 .53471 .52779 .53282 .52621 Metetra
.915 .79 .708 r
.53282 .52621 .53471 .52779 .54595 .5051 .54408 .50283 Metetra
.841 .405 0 r
.54408 .50283 .54595 .5051 .55756 .52874 .55569 .52701 Metetra
.954 .617 .331 r
.55569 .52701 .55756 .52874 .57001 .5987 .56811 .59702 Metetra
.843 .389 0 r
.56811 .59702 .57001 .5987 .58225 .6226 .58033 .61989 Metetra
.904 .741 .67 r
.58033 .61989 .58225 .6226 .59365 .59256 .59175 .58984 Metetra
.908 .741 .663 r
.59175 .58984 .59365 .59256 .60489 .56131 .60301 .55858 Metetra
.912 .74 .656 r
.60301 .55858 .60489 .56131 .61594 .52883 .61409 .52608 Metetra
.915 .739 .649 r
.61409 .52608 .61594 .52883 .6268 .49508 .62497 .49232 Metetra
.625 .672 .875 r
.62497 .49232 .6268 .49508 .63853 .49142 .63675 .48978 Metetra
.929 .544 .195 r
.63675 .48978 .63853 .49142 .65212 .53558 .65033 .53398 Metetra
.933 .555 .21 r
.65033 .53398 .65212 .53558 .66629 .5842 .66449 .58264 Metetra
.908 .502 .132 r
.66449 .58264 .66629 .5842 .68043 .62256 .6786 .62055 Metetra
.645 .763 .934 r
.6786 .62055 .68043 .62256 .69289 .61905 .69107 .61703 Metetra
.645 .763 .934 r
.69107 .61703 .69289 .61905 .7054 .61552 .70359 .61349 Metetra
.645 .763 .934 r
.70359 .61349 .7054 .61552 .71797 .61197 .71617 .60994 Metetra
.645 .763 .934 r
.71617 .60994 .71797 .61197 .73059 .60841 .7288 .60637 Metetra
.645 .763 .934 r
.7288 .60637 .73059 .60841 .74327 .60484 .74149 .60278 Metetra
.645 .763 .934 r
.74149 .60278 .74327 .60484 .756 .60124 .75424 .59918 Metetra
.645 .763 .934 r
.75424 .59918 .756 .60124 .7688 .59764 .76705 .59557 Metetra
.645 .763 .934 r
.76705 .59557 .7688 .59764 .78165 .59401 .77991 .59193 Metetra
.645 .763 .934 r
.77991 .59193 .78165 .59401 .79455 .59037 .79283 .58828 Metetra
.645 .763 .934 r
.79283 .58828 .79455 .59037 .80752 .58671 .80581 .58462 Metetra
.645 .763 .934 r
.80581 .58462 .80752 .58671 .82054 .58304 .81884 .58093 Metetra
.645 .763 .934 r
.81884 .58093 .82054 .58304 .83362 .57935 .83194 .57723 Metetra
.645 .763 .934 r
.83194 .57723 .83362 .57935 .84677 .57564 .84509 .57352 Metetra
.645 .763 .934 r
.84509 .57352 .84677 .57564 .85997 .57192 .85831 .56978 Metetra
.645 .763 .934 r
.85831 .56978 .85997 .57192 .87323 .56818 .87158 .56603 Metetra
.645 .763 .934 r
.87158 .56603 .87323 .56818 .88655 .56442 .88492 .56227 Metetra
.645 .763 .934 r
.88492 .56227 .88655 .56442 .89993 .56065 .89831 .55848 Metetra
.645 .763 .934 r
.89831 .55848 .89993 .56065 .91338 .55685 .91177 .55468 Metetra
.645 .763 .934 r
.91177 .55468 .91338 .55685 .92688 .55305 .92529 .55086 Metetra
.305 .479 .867 r
.30586 .53989 .30782 .54287 .31777 .54525 .31569 .54414 Metetra
.892 .796 .748 r
.31569 .54414 .31777 .54525 .32883 .52972 .32692 .526 Metetra
.273 .402 .812 r
.32692 .526 .32883 .52972 .33871 .53493 .33675 .5321 Metetra
.785 .699 .77 r
.33675 .5321 .33871 .53493 .34951 .52433 .34758 .52108 Metetra
.792 .682 .743 r
.34758 .52108 .34951 .52433 .36044 .51114 .35852 .50789 Metetra
.822 .689 .717 r
.35852 .50789 .36044 .51114 .37155 .49336 .36963 .49036 Metetra
.579 .617 .854 r
.36963 .49036 .37155 .49336 .38199 .49009 .37997 .4895 Metetra
.662 .108 0 r
.37997 .4895 .38199 .49009 .39201 .49838 .38999 .4978 Metetra
.692 .15 0 r
.38999 .4978 .39201 .49838 .40211 .50747 .4001 .5069 Metetra
.502 .859 .99 r
.4001 .5069 .40211 .50747 .41274 .50449 .41072 .50453 Metetra
.648 .957 .935 r
.41072 .50453 .41274 .50449 .4234 .50213 .42149 .49897 Metetra
.924 .547 .145 r
.42149 .49897 .4234 .50213 .43313 .53541 .4312 .53224 Metetra
.633 .636 .835 r
.4312 .53224 .43313 .53541 .44406 .53049 .44208 .52955 Metetra
.808 .877 .896 r
.44208 .52955 .44406 .53049 .45508 .52298 .45313 .52128 Metetra
.545 .737 .965 r
.45313 .52128 .45508 .52298 .46601 .52101 .46406 .52015 Metetra
.921 .831 .739 r
.46406 .52015 .46601 .52101 .47726 .50114 .47533 .50025 Metetra
.925 .827 .73 r
.47533 .50025 .47726 .50114 .48846 .48042 .48655 .4795 Metetra
.916 .836 .751 r
.48655 .4795 .48846 .48042 .49955 .46399 .49767 .4611 Metetra
.685 .258 0 r
.49767 .4611 .49955 .46399 .51044 .48297 .50856 .48007 Metetra
.729 .302 0 r
.50856 .48007 .51044 .48297 .52152 .50366 .51964 .50075 Metetra
.767 .343 0 r
.51964 .50075 .52152 .50366 .53282 .52621 .53093 .5233 Metetra
.868 .726 .703 r
.53093 .5233 .53282 .52621 .54408 .50283 .54221 .501 Metetra
.856 .412 .005 r
.54221 .501 .54408 .50283 .55569 .52701 .55381 .52438 Metetra
.959 .622 .305 r
.55381 .52438 .55569 .52701 .56811 .59702 .5662 .5944 Metetra
.82 .39 0 r
.5662 .5944 .56811 .59702 .58033 .61989 .57846 .62011 Metetra
.979 .864 .653 r
.57846 .62011 .58033 .61989 .59175 .58984 .58991 .59 Metetra
.981 .857 .644 r
.58991 .59 .59175 .58984 .60301 .55858 .6012 .55868 Metetra
.982 .85 .635 r
.6012 .55868 .60301 .55858 .61409 .52608 .61231 .52612 Metetra
.983 .843 .627 r
.61231 .52612 .61409 .52608 .62497 .49232 .62322 .49229 Metetra
.659 .967 .916 r
.62322 .49229 .62497 .49232 .63675 .48978 .63488 .48572 Metetra
.867 .501 .006 r
.63488 .48572 .63675 .48978 .65033 .53398 .64844 .52987 Metetra
.884 .52 .039 r
.64844 .52987 .65033 .53398 .66449 .58264 .66257 .57849 Metetra
.809 .44 0 r
.66257 .57849 .66449 .58264 .6786 .62055 .67676 .61854 Metetra
.645 .763 .934 r
.67676 .61854 .6786 .62055 .69107 .61703 .68924 .61501 Metetra
.645 .763 .934 r
.68924 .61501 .69107 .61703 .70359 .61349 .70177 .61146 Metetra
.645 .763 .934 r
.70177 .61146 .70359 .61349 .71617 .60994 .71437 .6079 Metetra
.645 .763 .934 r
.71437 .6079 .71617 .60994 .7288 .60637 .72701 .60432 Metetra
.645 .763 .934 r
.72701 .60432 .7288 .60637 .74149 .60278 .73972 .60073 Metetra
.645 .763 .934 r
.73972 .60073 .74149 .60278 .75424 .59918 .75248 .59712 Metetra
.645 .763 .934 r
.75248 .59712 .75424 .59918 .76705 .59557 .76529 .59349 Metetra
.645 .763 .934 r
.76529 .59349 .76705 .59557 .77991 .59193 .77817 .58985 Metetra
.645 .763 .934 r
.77817 .58985 .77991 .59193 .79283 .58828 .7911 .58619 Metetra
.645 .763 .934 r
.7911 .58619 .79283 .58828 .80581 .58462 .80409 .58251 Metetra
.645 .763 .934 r
.80409 .58251 .80581 .58462 .81884 .58093 .81714 .57882 Metetra
.645 .763 .934 r
.81714 .57882 .81884 .58093 .83194 .57723 .83025 .57511 Metetra
.645 .763 .934 r
.83025 .57511 .83194 .57723 .84509 .57352 .84342 .57139 Metetra
.645 .763 .934 r
.84342 .57139 .84509 .57352 .85831 .56978 .85665 .56764 Metetra
.645 .763 .934 r
.85665 .56764 .85831 .56978 .87158 .56603 .86993 .56388 Metetra
.645 .763 .934 r
.86993 .56388 .87158 .56603 .88492 .56227 .88328 .56011 Metetra
.645 .763 .934 r
.88328 .56011 .88492 .56227 .89831 .55848 .89669 .55631 Metetra
.645 .763 .934 r
.89669 .55631 .89831 .55848 .91177 .55468 .91016 .5525 Metetra
.645 .763 .934 r
.91016 .5525 .91177 .55468 .92529 .55086 .9237 .54867 Metetra
0 .484 .81 r
.30376 .53898 .30586 .53989 .31569 .54414 .31368 .54172 Metetra
.837 .725 .74 r
.31368 .54172 .31569 .54414 .32692 .526 .32482 .52553 Metetra
.5 0 0 r
.32482 .52553 .32692 .526 .33675 .5321 .3347 .53075 Metetra
.832 .809 .829 r
.3347 .53075 .33675 .5321 .34758 .52108 .34552 .52023 Metetra
.877 .843 .807 r
.34552 .52023 .34758 .52108 .35852 .50789 .35647 .50702 Metetra
.903 .82 .756 r
.35647 .50702 .35852 .50789 .36963 .49036 .36761 .48937 Metetra
.608 .841 .988 r
.36761 .48937 .36963 .49036 .37997 .4895 .37805 .48653 Metetra
0 .272 .777 r
.37805 .48653 .37997 .4895 .38999 .4978 .38807 .49482 Metetra
0 .227 .747 r
.38807 .49482 .38999 .4978 .4001 .5069 .39817 .50391 Metetra
.64 .647 .841 r
.39817 .50391 .4001 .5069 .41072 .50453 .40881 .50106 Metetra
.642 .62 .812 r
.40881 .50106 .41072 .50453 .42149 .49897 .41951 .49794 Metetra
.922 .55 .294 r
.41951 .49794 .42149 .49897 .4312 .53224 .42921 .53124 Metetra
.703 .867 .959 r
.42921 .53124 .4312 .53224 .44208 .52955 .44016 .52637 Metetra
.721 .671 .8 r
.44016 .52637 .44208 .52955 .45313 .52128 .45118 .51952 Metetra
.61 .754 .947 r
.45118 .51952 .45313 .52128 .46406 .52015 .46214 .51722 Metetra
.851 .716 .714 r
.46214 .51722 .46406 .52015 .47533 .50025 .47343 .49731 Metetra
.856 .717 .708 r
.47343 .49731 .47533 .50025 .48655 .4795 .48466 .47655 Metetra
.834 .714 .732 r
.48466 .47655 .48655 .4795 .49767 .4611 .49578 .45988 Metetra
.846 .384 .032 r
.49578 .45988 .49767 .4611 .50856 .48007 .50667 .47887 Metetra
.86 .408 .064 r
.50667 .47887 .50856 .48007 .51964 .50075 .51775 .49957 Metetra
.873 .43 .093 r
.51775 .49957 .51964 .50075 .53093 .5233 .52903 .52213 Metetra
.93 .811 .706 r
.52903 .52213 .53093 .5233 .54221 .501 .54033 .49829 Metetra
.822 .398 0 r
.54033 .49829 .54221 .501 .55381 .52438 .55193 .52349 Metetra
.947 .612 .352 r
.55193 .52349 .55381 .52438 .5662 .5944 .5643 .59359 Metetra
.864 .416 .101 r
.5643 .59359 .5662 .5944 .57846 .62011 .57651 .61649 Metetra
.88 .71 .666 r
.57651 .61649 .57846 .62011 .58991 .59 .58798 .58638 Metetra
.885 .71 .66 r
.58798 .58638 .58991 .59 .6012 .55868 .59929 .55506 Metetra
.889 .711 .654 r
.59929 .55506 .6012 .55868 .61231 .52612 .61042 .52249 Metetra
.894 .711 .648 r
.61042 .52249 .61231 .52612 .62322 .49229 .62136 .48867 Metetra
.644 .625 .816 r
.62136 .48867 .62322 .49229 .63488 .48572 .63313 .48518 Metetra
.925 .545 .255 r
.63313 .48518 .63488 .48572 .64844 .52987 .64668 .52939 Metetra
.929 .554 .266 r
.64668 .52939 .64844 .52987 .66257 .57849 .6608 .57809 Metetra
.911 .511 .216 r
.6608 .57809 .66257 .57849 .67676 .61854 .67492 .61653 Metetra
.645 .763 .934 r
.67492 .61653 .67676 .61854 .68924 .61501 .68741 .61299 Metetra
.645 .763 .934 r
.68741 .61299 .68924 .61501 .70177 .61146 .69996 .60943 Metetra
.645 .763 .934 r
.69996 .60943 .70177 .61146 .71437 .6079 .71256 .60586 Metetra
.645 .763 .934 r
.71256 .60586 .71437 .6079 .72701 .60432 .72522 .60227 Metetra
.645 .763 .934 r
.72522 .60227 .72701 .60432 .73972 .60073 .73793 .59867 Metetra
.645 .763 .934 r
.73793 .59867 .73972 .60073 .75248 .59712 .75071 .59505 Metetra
.645 .763 .934 r
.75071 .59505 .75248 .59712 .76529 .59349 .76353 .59141 Metetra
.645 .763 .934 r
.76353 .59141 .76529 .59349 .77817 .58985 .77642 .58776 Metetra
.645 .763 .934 r
.77642 .58776 .77817 .58985 .7911 .58619 .78937 .58409 Metetra
.645 .763 .934 r
.78937 .58409 .7911 .58619 .80409 .58251 .80237 .58041 Metetra
.645 .763 .934 r
.80237 .58041 .80409 .58251 .81714 .57882 .81543 .5767 Metetra
.645 .763 .934 r
.81543 .5767 .81714 .57882 .83025 .57511 .82855 .57298 Metetra
.645 .763 .934 r
.82855 .57298 .83025 .57511 .84342 .57139 .84174 .56925 Metetra
.645 .763 .934 r
.84174 .56925 .84342 .57139 .85665 .56764 .85498 .5655 Metetra
.645 .763 .934 r
.85498 .5655 .85665 .56764 .86993 .56388 .86828 .56173 Metetra
.645 .763 .934 r
.86828 .56173 .86993 .56388 .88328 .56011 .88164 .55794 Metetra
.645 .763 .934 r
.88164 .55794 .88328 .56011 .89669 .55631 .89507 .55414 Metetra
.645 .763 .934 r
.89507 .55414 .89669 .55631 .91016 .5525 .90855 .55031 Metetra
.645 .763 .934 r
.90855 .55031 .91016 .5525 .9237 .54867 .9221 .54647 Metetra
.278 .484 .88 r
.30177 .53622 .30376 .53898 .31368 .54172 .31161 .5404 Metetra
.884 .785 .747 r
.31161 .5404 .31368 .54172 .32482 .52553 .32286 .52247 Metetra
.219 .422 .848 r
.32286 .52247 .32482 .52553 .3347 .53075 .33273 .528 Metetra
.78 .702 .778 r
.33273 .528 .3347 .53075 .34552 .52023 .34354 .51768 Metetra
.815 .72 .76 r
.34354 .51768 .34552 .52023 .35647 .50702 .35451 .50446 Metetra
.845 .722 .727 r
.35451 .50446 .35647 .50702 .36761 .48937 .36568 .48653 Metetra
.593 .635 .862 r
.36568 .48653 .36761 .48937 .37805 .48653 .37605 .48522 Metetra
.545 0 0 r
.37605 .48522 .37805 .48653 .38807 .49482 .38607 .49352 Metetra
.595 .045 0 r
.38607 .49352 .38807 .49482 .39817 .50391 .39618 .50262 Metetra
.584 .798 .981 r
.39618 .50262 .39817 .50391 .40881 .50106 .4068 .50043 Metetra
.716 .91 .962 r
.4068 .50043 .40881 .50106 .41951 .49794 .41759 .49504 Metetra
.929 .55 .169 r
.41759 .49504 .41951 .49794 .42921 .53124 .42727 .52833 Metetra
.679 .672 .836 r
.42727 .52833 .42921 .53124 .44016 .52637 .43821 .5239 Metetra
.7 .711 .857 r
.43821 .5239 .44016 .52637 .45118 .51952 .4492 .51889 Metetra
.528 .865 .993 r
.4492 .51889 .45118 .51952 .46214 .51722 .46018 .51622 Metetra
.917 .822 .738 r
.46018 .51622 .46214 .51722 .47343 .49731 .47149 .49628 Metetra
.92 .819 .729 r
.47149 .49628 .47343 .49731 .48466 .47655 .48274 .4755 Metetra
.912 .827 .749 r
.48274 .4755 .48466 .47655 .49578 .45988 .4939 .45701 Metetra
.69 .261 0 r
.4939 .45701 .49578 .45988 .50667 .47887 .50478 .47599 Metetra
.733 .305 0 r
.50478 .47599 .50667 .47887 .51775 .49957 .51585 .49668 Metetra
.77 .345 0 r
.51585 .49668 .51775 .49957 .52903 .52213 .52713 .51923 Metetra
.877 .727 .692 r
.52713 .51923 .52903 .52213 .54033 .49829 .53844 .49491 Metetra
.798 .398 0 r
.53844 .49491 .54033 .49829 .55193 .52349 .55005 .52236 Metetra
.949 .613 .347 r
.55005 .52236 .55193 .52349 .5643 .59359 .56239 .59254 Metetra
.866 .418 .082 r
.56239 .59254 .5643 .59359 .57651 .61649 .57461 .61601 Metetra
.965 .835 .664 r
.57461 .61601 .57651 .61649 .58798 .58638 .58611 .58586 Metetra
.967 .829 .655 r
.58611 .58586 .58798 .58638 .59929 .55506 .59745 .55449 Metetra
.968 .823 .646 r
.59745 .55449 .59929 .55506 .61042 .52249 .60861 .52187 Metetra
.97 .818 .638 r
.60861 .52187 .61042 .52249 .62136 .48867 .61958 .488 Metetra
.728 .931 .957 r
.61958 .488 .62136 .48867 .63313 .48518 .63127 .48164 Metetra
.892 .518 .055 r
.63127 .48164 .63313 .48518 .64668 .52939 .6448 .52583 Metetra
.905 .534 .084 r
.6448 .52583 .64668 .52939 .6608 .57809 .6589 .5745 Metetra
.85 .466 0 r
.6589 .5745 .6608 .57809 .67492 .61653 .67307 .61451 Metetra
.645 .763 .934 r
.67307 .61451 .67492 .61653 .68741 .61299 .68557 .61096 Metetra
.645 .763 .934 r
.68557 .61096 .68741 .61299 .69996 .60943 .69813 .60739 Metetra
.645 .763 .934 r
.69813 .60739 .69996 .60943 .71256 .60586 .71075 .60381 Metetra
.645 .763 .934 r
.71075 .60381 .71256 .60586 .72522 .60227 .72342 .60021 Metetra
.645 .763 .934 r
.72342 .60021 .72522 .60227 .73793 .59867 .73615 .5966 Metetra
.645 .763 .934 r
.73615 .5966 .73793 .59867 .75071 .59505 .74893 .59297 Metetra
.645 .763 .934 r
.74893 .59297 .75071 .59505 .76353 .59141 .76177 .58933 Metetra
.645 .763 .934 r
.76177 .58933 .76353 .59141 .77642 .58776 .77467 .58567 Metetra
.645 .763 .934 r
.77467 .58567 .77642 .58776 .78937 .58409 .78763 .58199 Metetra
.645 .763 .934 r
.78763 .58199 .78937 .58409 .80237 .58041 .80065 .57829 Metetra
.645 .763 .934 r
.80065 .57829 .80237 .58041 .81543 .5767 .81372 .57458 Metetra
.645 .763 .934 r
.81372 .57458 .81543 .5767 .82855 .57298 .82686 .57085 Metetra
.645 .763 .934 r
.82686 .57085 .82855 .57298 .84174 .56925 .84005 .56711 Metetra
.645 .763 .934 r
.84005 .56711 .84174 .56925 .85498 .5655 .85331 .56334 Metetra
.645 .763 .934 r
.85331 .56334 .85498 .5655 .86828 .56173 .86662 .55956 Metetra
.645 .763 .934 r
.86662 .55956 .86828 .56173 .88164 .55794 .88 .55577 Metetra
.645 .763 .934 r
.88 .55577 .88164 .55794 .89507 .55414 .89343 .55195 Metetra
.645 .763 .934 r
.89343 .55195 .89507 .55414 .90855 .55031 .90693 .54812 Metetra
.645 .763 .934 r
.90693 .54812 .90855 .55031 .9221 .54647 .9205 .54427 Metetra
0 .514 .828 r
.29965 .53534 .30177 .53622 .31161 .5404 .30961 .53775 Metetra
.827 .713 .739 r
.30961 .53775 .31161 .5404 .32286 .52247 .32075 .52199 Metetra
.452 0 0 r
.32075 .52199 .32286 .52247 .33273 .528 .33067 .5267 Metetra
.831 .815 .835 r
.33067 .5267 .33273 .528 .34354 .51768 .34149 .51642 Metetra
.862 .809 .796 r
.34149 .51642 .34354 .51768 .35451 .50446 .35247 .50318 Metetra
.888 .794 .751 r
.35247 .50318 .35451 .50446 .36568 .48653 .36364 .48561 Metetra
.608 .851 .99 r
.36364 .48561 .36568 .48653 .37605 .48522 .3741 .48264 Metetra
0 .231 .747 r
.3741 .48264 .37605 .48522 .38607 .49352 .38412 .49093 Metetra
0 .178 .706 r
.38412 .49093 .38607 .49352 .39618 .50262 .39422 .50002 Metetra
.652 .681 .865 r
.39422 .50002 .39618 .50262 .4068 .50043 .40489 .49685 Metetra
.626 .607 .811 r
.40489 .49685 .4068 .50043 .41759 .49504 .41558 .49434 Metetra
.916 .547 .31 r
.41558 .49434 .41759 .49504 .42727 .52833 .42526 .52767 Metetra
.731 .911 .956 r
.42526 .52767 .42727 .52833 .43821 .5239 .43625 .52182 Metetra
.724 .752 .875 r
.43625 .52182 .43821 .5239 .4492 .51889 .44726 .51617 Metetra
.644 .674 .864 r
.44726 .51617 .4492 .51889 .46018 .51622 .45826 .51315 Metetra
.847 .711 .712 r
.45826 .51315 .46018 .51622 .47149 .49628 .46958 .4932 Metetra
.852 .711 .707 r
.46958 .4932 .47149 .49628 .48274 .4755 .48085 .47241 Metetra
.828 .708 .732 r
.48085 .47241 .48274 .4755 .4939 .45701 .492 .45596 Metetra
.85 .39 .058 r
.492 .45596 .4939 .45701 .50478 .47599 .50288 .47496 Metetra
.863 .413 .088 r
.50288 .47496 .50478 .47599 .51585 .49668 .51395 .49567 Metetra
.874 .434 .114 r
.51395 .49567 .51585 .49668 .52713 .51923 .52523 .51825 Metetra
.938 .818 .7 r
.52523 .51825 .52713 .51923 .53844 .49491 .53656 .49345 Metetra
.892 .467 .115 r
.53656 .49345 .53844 .49491 .55005 .52236 .54816 .52034 Metetra
.956 .619 .324 r
.54816 .52034 .55005 .52236 .56239 .59254 .56047 .59056 Metetra
.808 .348 0 r
.56047 .59056 .56239 .59254 .57461 .61601 .57266 .61213 Metetra
.874 .702 .665 r
.57266 .61213 .57461 .61601 .58611 .58586 .58418 .58198 Metetra
.879 .702 .659 r
.58418 .58198 .58611 .58586 .59745 .55449 .59554 .55061 Metetra
.883 .703 .653 r
.59554 .55061 .59745 .55449 .60861 .52187 .60672 .518 Metetra
.888 .704 .648 r
.60672 .518 .60861 .52187 .61958 .488 .61771 .48413 Metetra
.625 .604 .809 r
.61771 .48413 .61958 .488 .63127 .48164 .62951 .48141 Metetra
.923 .544 .27 r
.62951 .48141 .63127 .48164 .6448 .52583 .64304 .52568 Metetra
.926 .552 .279 r
.64304 .52568 .6448 .52583 .6589 .5745 .65714 .57444 Metetra
.907 .509 .233 r
.65714 .57444 .6589 .5745 .67307 .61451 .67122 .61248 Metetra
.645 .763 .934 r
.67122 .61248 .67307 .61451 .68557 .61096 .68373 .60892 Metetra
.645 .763 .934 r
.68373 .60892 .68557 .61096 .69813 .60739 .6963 .60535 Metetra
.645 .763 .934 r
.6963 .60535 .69813 .60739 .71075 .60381 .70893 .60176 Metetra
.645 .763 .934 r
.70893 .60176 .71075 .60381 .72342 .60021 .72161 .59815 Metetra
.645 .763 .934 r
.72161 .59815 .72342 .60021 .73615 .5966 .73435 .59453 Metetra
.645 .763 .934 r
.73435 .59453 .73615 .5966 .74893 .59297 .74715 .59089 Metetra
.645 .763 .934 r
.74715 .59089 .74893 .59297 .76177 .58933 .76 .58724 Metetra
.645 .763 .934 r
.76 .58724 .76177 .58933 .77467 .58567 .77292 .58357 Metetra
.645 .763 .934 r
.77292 .58357 .77467 .58567 .78763 .58199 .78589 .57988 Metetra
.645 .763 .934 r
.78589 .57988 .78763 .58199 .80065 .57829 .79892 .57617 Metetra
.645 .763 .934 r
.79892 .57617 .80065 .57829 .81372 .57458 .81201 .57245 Metetra
.645 .763 .934 r
.81201 .57245 .81372 .57458 .82686 .57085 .82515 .56871 Metetra
.645 .763 .934 r
.82515 .56871 .82686 .57085 .84005 .56711 .83836 .56496 Metetra
.645 .763 .934 r
.83836 .56496 .84005 .56711 .85331 .56334 .85163 .56119 Metetra
.645 .763 .934 r
.85163 .56119 .85331 .56334 .86662 .55956 .86496 .5574 Metetra
.645 .763 .934 r
.86496 .5574 .86662 .55956 .88 .55577 .87835 .55359 Metetra
.645 .763 .934 r
.87835 .55359 .88 .55577 .89343 .55195 .8918 .54977 Metetra
.645 .763 .934 r
.8918 .54977 .89343 .55195 .90693 .54812 .90531 .54592 Metetra
.645 .763 .934 r
.90531 .54592 .90693 .54812 .9205 .54427 .91889 .54206 Metetra
.364 .545 .899 r
.29765 .53271 .29965 .53534 .30961 .53775 .30758 .53554 Metetra
.843 .738 .747 r
.30758 .53554 .30961 .53775 .32075 .52199 .31874 .51969 Metetra
.187 .482 .897 r
.31874 .51969 .32075 .52199 .33067 .5267 .32868 .52394 Metetra
.78 .703 .779 r
.32868 .52394 .33067 .5267 .34149 .51642 .33952 .51362 Metetra
.807 .706 .754 r
.33952 .51362 .34149 .51642 .35247 .50318 .35051 .50037 Metetra
.835 .71 .726 r
.35051 .50037 .35247 .50318 .36364 .48561 .36169 .48294 Metetra
.593 .649 .875 r
.36169 .48294 .36364 .48561 .3741 .48264 .37208 .48158 Metetra
.595 .033 0 r
.37208 .48158 .3741 .48264 .38412 .49093 .3821 .48987 Metetra
.638 .084 0 r
.3821 .48987 .38412 .49093 .39422 .50002 .39221 .49897 Metetra
.659 .849 .973 r
.39221 .49897 .39422 .50002 .40489 .49685 .40291 .49518 Metetra
.623 .765 .947 r
.40291 .49518 .40489 .49685 .41558 .49434 .41361 .49259 Metetra
.931 .554 .254 r
.41361 .49259 .41558 .49434 .42526 .52767 .42327 .52594 Metetra
.739 .788 .892 r
.42327 .52594 .42526 .52767 .43625 .52182 .43428 .51996 Metetra
.71 .769 .899 r
.43428 .51996 .43625 .52182 .44726 .51617 .44529 .51495 Metetra
.621 .824 .979 r
.44529 .51495 .44726 .51617 .45826 .51315 .45629 .51192 Metetra
.909 .808 .736 r
.45629 .51192 .45826 .51315 .46958 .4932 .46763 .49195 Metetra
.913 .805 .728 r
.46763 .49195 .46958 .4932 .48085 .47241 .47893 .47113 Metetra
.901 .815 .754 r
.47893 .47113 .48085 .47241 .492 .45596 .49011 .45333 Metetra
.731 .288 0 r
.49011 .45333 .492 .45596 .50288 .47496 .50098 .47232 Metetra
.768 .329 0 r
.50098 .47232 .50288 .47496 .51395 .49567 .51204 .49303 Metetra
.799 .365 0 r
.51204 .49303 .51395 .49567 .52523 .51825 .52332 .5156 Metetra
.886 .738 .692 r
.52332 .5156 .52523 .51825 .53656 .49345 .53467 .49079 Metetra
.861 .445 0 r
.53467 .49079 .53656 .49345 .54816 .52034 .54626 .51865 Metetra
.954 .617 .333 r
.54626 .51865 .54816 .52034 .56047 .59056 .55854 .58892 Metetra
.826 .362 0 r
.55854 .58892 .56047 .59056 .57266 .61213 .57073 .61021 Metetra
.927 .773 .671 r
.57073 .61021 .57266 .61213 .58418 .58198 .58227 .58003 Metetra
.93 .771 .663 r
.58227 .58003 .58418 .58198 .59554 .55061 .59366 .54863 Metetra
.932 .768 .655 r
.59366 .54863 .59554 .55061 .60672 .518 .60486 .516 Metetra
.935 .766 .648 r
.60486 .516 .60672 .518 .61771 .48413 .61588 .4821 Metetra
.626 .744 .932 r
.61588 .4821 .61771 .48413 .62951 .48141 .6277 .47929 Metetra
.926 .542 .165 r
.6277 .47929 .62951 .48141 .64304 .52568 .64121 .52358 Metetra
.931 .553 .183 r
.64121 .52358 .64304 .52568 .65714 .57444 .65529 .57235 Metetra
.9 .495 .091 r
.65529 .57235 .65714 .57444 .67122 .61248 .66936 .61045 Metetra
.645 .763 .934 r
.66936 .61045 .67122 .61248 .68373 .60892 .68189 .60688 Metetra
.645 .763 .934 r
.68189 .60688 .68373 .60892 .6963 .60535 .69447 .6033 Metetra
.645 .763 .934 r
.69447 .6033 .6963 .60535 .70893 .60176 .70711 .5997 Metetra
.645 .763 .934 r
.70711 .5997 .70893 .60176 .72161 .59815 .7198 .59608 Metetra
.645 .763 .934 r
.7198 .59608 .72161 .59815 .73435 .59453 .73256 .59245 Metetra
.645 .763 .934 r
.73256 .59245 .73435 .59453 .74715 .59089 .74537 .5888 Metetra
.645 .763 .934 r
.74537 .5888 .74715 .59089 .76 .58724 .75823 .58514 Metetra
.645 .763 .934 r
.75823 .58514 .76 .58724 .77292 .58357 .77116 .58146 Metetra
.645 .763 .934 r
.77116 .58146 .77292 .58357 .78589 .57988 .78414 .57776 Metetra
.645 .763 .934 r
.78414 .57776 .78589 .57988 .79892 .57617 .79718 .57405 Metetra
.645 .763 .934 r
.79718 .57405 .79892 .57617 .81201 .57245 .81028 .57032 Metetra
.645 .763 .934 r
.81028 .57032 .81201 .57245 .82515 .56871 .82345 .56657 Metetra
.645 .763 .934 r
.82345 .56657 .82515 .56871 .83836 .56496 .83667 .56281 Metetra
.645 .763 .934 r
.83667 .56281 .83836 .56496 .85163 .56119 .84995 .55902 Metetra
.645 .763 .934 r
.84995 .55902 .85163 .56119 .86496 .5574 .86329 .55522 Metetra
.645 .763 .934 r
.86329 .55522 .86496 .5574 .87835 .55359 .87669 .55141 Metetra
.645 .763 .934 r
.87669 .55141 .87835 .55359 .8918 .54977 .89016 .54757 Metetra
.645 .763 .934 r
.89016 .54757 .8918 .54977 .90531 .54592 .90369 .54372 Metetra
.645 .763 .934 r
.90369 .54372 .90531 .54592 .91889 .54206 .91728 .53985 Metetra
.049 .561 .877 r
.29553 .53175 .29765 .53271 .30758 .53554 .30551 .53385 Metetra
.858 .769 .763 r
.30551 .53385 .30758 .53554 .31874 .51969 .31665 .51854 Metetra
0 .321 .707 r
.31665 .51854 .31874 .51969 .32868 .52394 .32658 .52315 Metetra
.847 .866 .855 r
.32658 .52315 .32868 .52394 .33952 .51362 .33743 .5129 Metetra
.882 .855 .811 r
.33743 .5129 .33952 .51362 .35051 .50037 .34844 .49963 Metetra
.908 .829 .757 r
.34844 .49963 .35051 .50037 .36169 .48294 .35965 .48189 Metetra
.646 .843 .976 r
.35965 .48189 .36169 .48294 .37208 .48158 .37015 .47844 Metetra
.009 .282 .781 r
.37015 .47844 .37208 .48158 .3821 .48987 .38017 .48672 Metetra
0 .239 .755 r
.38017 .48672 .3821 .48987 .39221 .49897 .39027 .4958 Metetra
.648 .641 .829 r
.39027 .4958 .39221 .49897 .40291 .49518 .40096 .49257 Metetra
.612 .666 .878 r
.40096 .49257 .40291 .49518 .41361 .49259 .41164 .49058 Metetra
.932 .554 .237 r
.41164 .49058 .41361 .49259 .42327 .52594 .42129 .52395 Metetra
.737 .761 .872 r
.42129 .52395 .42327 .52594 .43428 .51996 .43231 .51777 Metetra
.721 .742 .868 r
.43231 .51777 .43428 .51996 .44529 .51495 .44334 .51211 Metetra
.644 .666 .856 r
.44334 .51211 .44529 .51495 .45629 .51192 .45435 .50903 Metetra
.853 .72 .715 r
.45435 .50903 .45629 .51192 .46763 .49195 .46571 .48906 Metetra
.858 .72 .709 r
.46571 .48906 .46763 .49195 .47893 .47113 .47702 .46823 Metetra
.833 .717 .737 r
.47702 .46823 .47893 .47113 .49011 .45333 .48821 .452 Metetra
.843 .38 .017 r
.48821 .452 .49011 .45333 .50098 .47232 .49907 .47101 Metetra
.858 .405 .05 r
.49907 .47101 .50098 .47232 .51204 .49303 .51013 .49173 Metetra
.871 .428 .081 r
.51013 .49173 .51204 .49303 .52332 .5156 .5214 .51433 Metetra
.929 .803 .699 r
.5214 .51433 .52332 .5156 .53467 .49079 .53278 .48943 Metetra
.892 .468 .126 r
.53278 .48943 .53467 .49079 .54626 .51865 .54436 .51626 Metetra
.958 .621 .314 r
.54436 .51626 .54626 .51865 .55854 .58892 .55661 .58655 Metetra
.767 .313 0 r
.55661 .58655 .55854 .58892 .57073 .61021 .56879 .60779 Metetra
.913 .753 .67 r
.56879 .60779 .57073 .61021 .58227 .58003 .58036 .57759 Metetra
.916 .752 .663 r
.58036 .57759 .58227 .58003 .59366 .54863 .59176 .54617 Metetra
.92 .751 .656 r
.59176 .54617 .59366 .54863 .60486 .516 .60299 .51352 Metetra
.923 .749 .649 r
.60299 .51352 .60486 .516 .61588 .4821 .61403 .4796 Metetra
.605 .689 .902 r
.61403 .4796 .61588 .4821 .6277 .47929 .62588 .47755 Metetra
.928 .544 .19 r
.62588 .47755 .6277 .47929 .64121 .52358 .63938 .52187 Metetra
.933 .554 .206 r
.63938 .52187 .64121 .52358 .65529 .57235 .65345 .57068 Metetra
.906 .499 .122 r
.65345 .57068 .65529 .57235 .66936 .61045 .6675 .60841 Metetra
.645 .763 .934 r
.6675 .60841 .66936 .61045 .68189 .60688 .68004 .60484 Metetra
.645 .763 .934 r
.68004 .60484 .68189 .60688 .69447 .6033 .69263 .60124 Metetra
.645 .763 .934 r
.69263 .60124 .69447 .6033 .70711 .5997 .70528 .59764 Metetra
.645 .763 .934 r
.70528 .59764 .70711 .5997 .7198 .59608 .71799 .59401 Metetra
.645 .763 .934 r
.71799 .59401 .7198 .59608 .73256 .59245 .73075 .59037 Metetra
.645 .763 .934 r
.73075 .59037 .73256 .59245 .74537 .5888 .74358 .58671 Metetra
.645 .763 .934 r
.74358 .58671 .74537 .5888 .75823 .58514 .75646 .58304 Metetra
.645 .763 .934 r
.75646 .58304 .75823 .58514 .77116 .58146 .76939 .57935 Metetra
.645 .763 .934 r
.76939 .57935 .77116 .58146 .78414 .57776 .78239 .57564 Metetra
.645 .763 .934 r
.78239 .57564 .78414 .57776 .79718 .57405 .79545 .57192 Metetra
.645 .763 .934 r
.79545 .57192 .79718 .57405 .81028 .57032 .80856 .56818 Metetra
.645 .763 .934 r
.80856 .56818 .81028 .57032 .82345 .56657 .82173 .56442 Metetra
.645 .763 .934 r
.82173 .56442 .82345 .56657 .83667 .56281 .83497 .56065 Metetra
.645 .763 .934 r
.83497 .56065 .83667 .56281 .84995 .55902 .84826 .55685 Metetra
.645 .763 .934 r
.84826 .55685 .84995 .55902 .86329 .55522 .86162 .55305 Metetra
.645 .763 .934 r
.86162 .55305 .86329 .55522 .87669 .55141 .87504 .54922 Metetra
.645 .763 .934 r
.87504 .54922 .87669 .55141 .89016 .54757 .88852 .54537 Metetra
.645 .763 .934 r
.88852 .54537 .89016 .54757 .90369 .54372 .90206 .54151 Metetra
.645 .763 .934 r
.90206 .54151 .90369 .54372 .91728 .53985 .91566 .53763 Metetra
.455 .605 .91 r
.29351 .52924 .29553 .53175 .30551 .53385 .30355 .53054 Metetra
.794 .68 .738 r
.30355 .53054 .30551 .53385 .31665 .51854 .3146 .51679 Metetra
.165 .538 .925 r
.3146 .51679 .31665 .51854 .32658 .52315 .32461 .51998 Metetra
.773 .681 .762 r
.32461 .51998 .32658 .52315 .33743 .5129 .33551 .5091 Metetra
.778 .658 .731 r
.33551 .5091 .33743 .5129 .34844 .49963 .34653 .49583 Metetra
.801 .666 .715 r
.34653 .49583 .34844 .49963 .35965 .48189 .35768 .47944 Metetra
.578 .664 .897 r
.35768 .47944 .35965 .48189 .37015 .47844 .36807 .47834 Metetra
.692 .163 0 r
.36807 .47834 .37015 .47844 .38017 .48672 .3781 .48664 Metetra
.715 .196 0 r
.3781 .48664 .38017 .48672 .39027 .4958 .3882 .49574 Metetra
.684 .959 .946 r
.3882 .49574 .39027 .4958 .40096 .49257 .399 .48994 Metetra
.512 .622 .898 r
.399 .48994 .40096 .49257 .41164 .49058 .40961 .49036 Metetra
.907 .542 .331 r
.40961 .49036 .41164 .49058 .42129 .52395 .41924 .52378 Metetra
.724 .96 .944 r
.41924 .52378 .42129 .52395 .43231 .51777 .43029 .5173 Metetra
.783 .935 .93 r
.43029 .5173 .43231 .51777 .44334 .51211 .44138 .50985 Metetra
.622 .707 .906 r
.44138 .50985 .44334 .51211 .45435 .50903 .45239 .50744 Metetra
.897 .787 .732 r
.45239 .50744 .45435 .50903 .46571 .48906 .46377 .48745 Metetra
.9 .785 .725 r
.46377 .48745 .46571 .48906 .47702 .46823 .47509 .4666 Metetra
.882 .794 .759 r
.47509 .4666 .47702 .46823 .48821 .452 .4863 .44984 Metetra
.791 .332 0 r
.4863 .44984 .48821 .452 .49907 .47101 .49717 .46885 Metetra
.818 .366 0 r
.49717 .46885 .49907 .47101 .51013 .49173 .50822 .48958 Metetra
.84 .396 0 r
.50822 .48958 .51013 .49173 .5214 .51433 .51948 .51218 Metetra
.899 .762 .701 r
.51948 .51218 .5214 .51433 .53278 .48943 .53088 .48815 Metetra
.885 .454 .112 r
.53088 .48815 .53278 .48943 .54436 .51626 .54245 .51358 Metetra
.959 .622 .305 r
.54245 .51358 .54436 .51626 .55661 .58655 .55466 .58387 Metetra
.709 .264 0 r
.55466 .58387 .55661 .58655 .56879 .60779 .56683 .60431 Metetra
.885 .715 .667 r
.56683 .60431 .56879 .60779 .58036 .57759 .57842 .5741 Metetra
.889 .716 .661 r
.57842 .5741 .58036 .57759 .59176 .54617 .58985 .54268 Metetra
.893 .716 .654 r
.58985 .54268 .59176 .54617 .60299 .51352 .6011 .51002 Metetra
.898 .716 .648 r
.6011 .51002 .60299 .51352 .61403 .4796 .61216 .4761 Metetra
.516 .57 .849 r
.61216 .4761 .61403 .4796 .62588 .47755 .6241 .47709 Metetra
.925 .544 .259 r
.6241 .47709 .62588 .47755 .63938 .52187 .6376 .52148 Metetra
.928 .553 .27 r
.6376 .52148 .63938 .52187 .65345 .57068 .65166 .57038 Metetra
.904 .498 .208 r
.65166 .57038 .65345 .57068 .6675 .60841 .66563 .60637 Metetra
.645 .763 .934 r
.66563 .60637 .6675 .60841 .68004 .60484 .67818 .60278 Metetra
.645 .763 .934 r
.67818 .60278 .68004 .60484 .69263 .60124 .69079 .59918 Metetra
.645 .763 .934 r
.69079 .59918 .69263 .60124 .70528 .59764 .70345 .59557 Metetra
.645 .763 .934 r
.70345 .59557 .70528 .59764 .71799 .59401 .71617 .59193 Metetra
.645 .763 .934 r
.71617 .59193 .71799 .59401 .73075 .59037 .72895 .58828 Metetra
.645 .763 .934 r
.72895 .58828 .73075 .59037 .74358 .58671 .74178 .58462 Metetra
.645 .763 .934 r
.74178 .58462 .74358 .58671 .75646 .58304 .75468 .58093 Metetra
.645 .763 .934 r
.75468 .58093 .75646 .58304 .76939 .57935 .76763 .57723 Metetra
.645 .763 .934 r
.76763 .57723 .76939 .57935 .78239 .57564 .78063 .57352 Metetra
.645 .763 .934 r
.78063 .57352 .78239 .57564 .79545 .57192 .7937 .56978 Metetra
.645 .763 .934 r
.7937 .56978 .79545 .57192 .80856 .56818 .80683 .56603 Metetra
.645 .763 .934 r
.80683 .56603 .80856 .56818 .82173 .56442 .82002 .56227 Metetra
.645 .763 .934 r
.82002 .56227 .82173 .56442 .83497 .56065 .83327 .55848 Metetra
.645 .763 .934 r
.83327 .55848 .83497 .56065 .84826 .55685 .84657 .55468 Metetra
.645 .763 .934 r
.84657 .55468 .84826 .55685 .86162 .55305 .85994 .55086 Metetra
.645 .763 .934 r
.85994 .55086 .86162 .55305 .87504 .54922 .87338 .54702 Metetra
.645 .763 .934 r
.87338 .54702 .87504 .54922 .88852 .54537 .88687 .54317 Metetra
.645 .763 .934 r
.88687 .54317 .88852 .54537 .90206 .54151 .90042 .5393 Metetra
.645 .763 .934 r
.90042 .5393 .90206 .54151 .91566 .53763 .91404 .53541 Metetra
.124 .582 .921 r
.29139 .52802 .29351 .52924 .30355 .53054 .30138 .53025 Metetra
.909 .869 .787 r
.30138 .53025 .30355 .53054 .3146 .51679 .31256 .5147 Metetra
.052 .426 .869 r
.31256 .5147 .3146 .51679 .32461 .51998 .32248 .51961 Metetra
.858 .909 .867 r
.32248 .51961 .32461 .51998 .33551 .5091 .33335 .5093 Metetra
.907 .935 .818 r
.33335 .5093 .33551 .5091 .34653 .49583 .3444 .4958 Metetra
.931 .879 .762 r
.3444 .4958 .34653 .49583 .35768 .47944 .35565 .47802 Metetra
.672 .803 .945 r
.35565 .47802 .35768 .47944 .36807 .47834 .36617 .47428 Metetra
.177 .324 .775 r
.36617 .47428 .36807 .47834 .3781 .48664 .3762 .48256 Metetra
.131 .294 .763 r
.3762 .48256 .3781 .48664 .3882 .49574 .3863 .49164 Metetra
.631 .585 .785 r
.3863 .49164 .3882 .49574 .399 .48994 .39699 .48872 Metetra
.583 .811 .986 r
.39699 .48872 .399 .48994 .40961 .49036 .4077 .4864 Metetra
.901 .532 .074 r
.4077 .4864 .40961 .49036 .41924 .52378 .41731 .51978 Metetra
.687 .62 .775 r
.41731 .51978 .41924 .52378 .43029 .5173 .42835 .51391 Metetra
.701 .654 .8 r
.42835 .51391 .43029 .5173 .44138 .50985 .43941 .50792 Metetra
.636 .745 .927 r
.43941 .50792 .44138 .50985 .45239 .50744 .45043 .50503 Metetra
.869 .743 .722 r
.45043 .50503 .45239 .50744 .46377 .48745 .46183 .48502 Metetra
.873 .743 .715 r
.46183 .48502 .46377 .48745 .47509 .4666 .47317 .46416 Metetra
.849 .744 .747 r
.47317 .46416 .47509 .4666 .4863 .44984 .48439 .4479 Metetra
.811 .347 0 r
.48439 .4479 .4863 .44984 .49717 .46885 .49525 .46692 Metetra
.833 .379 0 r
.49525 .46692 .49717 .46885 .50822 .48958 .5063 .48765 Metetra
.852 .407 0 r
.5063 .48765 .50822 .48958 .51948 .51218 .51755 .51026 Metetra
.908 .772 .698 r
.51755 .51026 .51948 .51218 .53088 .48815 .52898 .4856 Metetra
.851 .427 0 r
.52898 .4856 .53088 .48815 .54245 .51358 .54054 .51189 Metetra
.954 .617 .333 r
.54054 .51189 .54245 .51358 .55466 .58387 .55272 .58224 Metetra
.833 .371 0 r
.55272 .58224 .55466 .58387 .56683 .60431 .5649 .604 Metetra
.969 .843 .662 r
.5649 .604 .56683 .60431 .57842 .5741 .57652 .57374 Metetra
.971 .836 .653 r
.57652 .57374 .57842 .5741 .58985 .54268 .58798 .54227 Metetra
.972 .83 .644 r
.58798 .54227 .58985 .54268 .6011 .51002 .59927 .50956 Metetra
.973 .825 .636 r
.59927 .50956 .6011 .51002 .61216 .4761 .61036 .47559 Metetra
.445 .85 .97 r
.61036 .47559 .61216 .4761 .6241 .47709 .62222 .47312 Metetra
.876 .508 .022 r
.62222 .47312 .6241 .47709 .6376 .52148 .63568 .51747 Metetra
.891 .526 .053 r
.63568 .51747 .6376 .52148 .65166 .57038 .64972 .56632 Metetra
.8 .426 0 r
.64972 .56632 .65166 .57038 .66563 .60637 .66376 .60432 Metetra
.645 .763 .934 r
.66376 .60432 .66563 .60637 .67818 .60278 .67632 .60073 Metetra
.645 .763 .934 r
.67632 .60073 .67818 .60278 .69079 .59918 .68894 .59712 Metetra
.645 .763 .934 r
.68894 .59712 .69079 .59918 .70345 .59557 .70162 .59349 Metetra
.645 .763 .934 r
.70162 .59349 .70345 .59557 .71617 .59193 .71435 .58985 Metetra
.645 .763 .934 r
.71435 .58985 .71617 .59193 .72895 .58828 .72714 .58619 Metetra
.645 .763 .934 r
.72714 .58619 .72895 .58828 .74178 .58462 .73998 .58251 Metetra
.645 .763 .934 r
.73998 .58251 .74178 .58462 .75468 .58093 .75289 .57882 Metetra
.645 .763 .934 r
.75289 .57882 .75468 .58093 .76763 .57723 .76585 .57511 Metetra
.645 .763 .934 r
.76585 .57511 .76763 .57723 .78063 .57352 .77887 .57139 Metetra
.645 .763 .934 r
.77887 .57139 .78063 .57352 .7937 .56978 .79196 .56764 Metetra
.645 .763 .934 r
.79196 .56764 .7937 .56978 .80683 .56603 .8051 .56388 Metetra
.645 .763 .934 r
.8051 .56388 .80683 .56603 .82002 .56227 .8183 .56011 Metetra
.645 .763 .934 r
.8183 .56011 .82002 .56227 .83327 .55848 .83156 .55631 Metetra
.645 .763 .934 r
.83156 .55631 .83327 .55848 .84657 .55468 .84488 .5525 Metetra
.645 .763 .934 r
.84488 .5525 .84657 .55468 .85994 .55086 .85826 .54867 Metetra
.645 .763 .934 r
.85826 .54867 .85994 .55086 .87338 .54702 .87171 .54482 Metetra
.645 .763 .934 r
.87171 .54482 .87338 .54702 .88687 .54317 .88522 .54096 Metetra
.645 .763 .934 r
.88522 .54096 .88687 .54317 .90042 .5393 .89879 .53708 Metetra
.645 .763 .934 r
.89879 .53708 .90042 .5393 .91404 .53541 .91242 .53318 Metetra
.482 .614 .905 r
.28937 .52547 .29139 .52802 .30138 .53025 .29944 .52634 Metetra
.775 .653 .728 r
.29944 .52634 .30138 .53025 .31256 .5147 .31049 .51304 Metetra
.183 .562 .934 r
.31049 .51304 .31256 .5147 .32248 .51961 .32054 .51585 Metetra
.76 .654 .744 r
.32054 .51585 .32248 .51961 .33335 .5093 .33147 .5047 Metetra
.759 .628 .715 r
.33147 .5047 .33335 .5093 .3444 .4958 .34252 .4914 Metetra
.782 .643 .708 r
.34252 .4914 .3444 .4958 .35565 .47802 .35367 .4756 Metetra
.555 .658 .905 r
.35367 .4756 .35565 .47802 .36617 .47428 .36405 .47495 Metetra
.702 .218 .096 r
.36405 .47495 .36617 .47428 .3762 .48256 .37408 .48326 Metetra
.718 .243 .117 r
.37408 .48326 .3762 .48256 .3863 .49164 .38419 .49236 Metetra
.571 .936 .811 r
.38419 .49236 .3863 .49164 .39699 .48872 .39504 .48575 Metetra
.488 .583 .876 r
.39504 .48575 .39699 .48872 .4077 .4864 .40563 .48695 Metetra
.892 .533 .358 r
.40563 .48695 .4077 .4864 .41731 .51978 .41523 .52041 Metetra
.564 .935 .822 r
.41523 .52041 .41731 .51978 .42835 .51391 .4263 .51395 Metetra
.79 .979 .906 r
.4263 .51395 .42835 .51391 .43941 .50792 .43744 .50553 Metetra
.615 .693 .899 r
.43744 .50553 .43941 .50792 .45043 .50503 .44846 .50333 Metetra
.893 .781 .731 r
.44846 .50333 .45043 .50503 .46183 .48502 .45987 .4833 Metetra
.897 .779 .723 r
.45987 .4833 .46183 .48502 .47317 .46416 .47124 .46242 Metetra
.876 .788 .76 r
.47124 .46242 .47317 .46416 .48439 .4479 .48248 .44595 Metetra
.81 .347 0 r
.48248 .44595 .48439 .4479 .49525 .46692 .49333 .46497 Metetra
.833 .379 0 r
.49333 .46497 .49525 .46692 .5063 .48765 .50437 .48571 Metetra
.852 .407 0 r
.50437 .48571 .5063 .48765 .51755 .51026 .51562 .50833 Metetra
.905 .773 .704 r
.51562 .50833 .51755 .51026 .52898 .4856 .52707 .48455 Metetra
.882 .449 .126 r
.52707 .48455 .52898 .4856 .54054 .51189 .53863 .50916 Metetra
.959 .622 .304 r
.53863 .50916 .54054 .51189 .55272 .58224 .55077 .57952 Metetra
.701 .257 0 r
.55077 .57952 .55272 .58224 .5649 .604 .56293 .59984 Metetra
.868 .694 .664 r
.56293 .59984 .5649 .604 .57652 .57374 .57457 .56959 Metetra
.873 .695 .658 r
.57457 .56959 .57652 .57374 .58798 .54227 .58605 .53812 Metetra
.878 .696 .652 r
.58605 .53812 .58798 .54227 .59927 .50956 .59735 .50542 Metetra
.883 .697 .647 r
.59735 .50542 .59927 .50956 .61036 .47559 .60846 .47145 Metetra
.499 .525 .815 r
.60846 .47145 .61036 .47559 .62222 .47312 .62045 .47343 Metetra
.916 .54 .292 r
.62045 .47343 .62222 .47312 .63568 .51747 .63392 .51787 Metetra
.92 .549 .3 r
.63392 .51787 .63568 .51747 .64972 .56632 .64795 .56683 Metetra
.894 .494 .251 r
.64795 .56683 .64972 .56632 .66376 .60432 .66189 .60227 Metetra
.645 .763 .934 r
.66189 .60227 .66376 .60432 .67632 .60073 .67446 .59867 Metetra
.645 .763 .934 r
.67446 .59867 .67632 .60073 .68894 .59712 .68709 .59505 Metetra
.645 .763 .934 r
.68709 .59505 .68894 .59712 .70162 .59349 .69978 .59141 Metetra
.645 .763 .934 r
.69978 .59141 .70162 .59349 .71435 .58985 .71252 .58776 Metetra
.645 .763 .934 r
.71252 .58776 .71435 .58985 .72714 .58619 .72532 .58409 Metetra
.645 .763 .934 r
.72532 .58409 .72714 .58619 .73998 .58251 .73818 .58041 Metetra
.645 .763 .934 r
.73818 .58041 .73998 .58251 .75289 .57882 .7511 .5767 Metetra
.645 .763 .934 r
.7511 .5767 .75289 .57882 .76585 .57511 .76407 .57298 Metetra
.645 .763 .934 r
.76407 .57298 .76585 .57511 .77887 .57139 .77711 .56925 Metetra
.645 .763 .934 r
.77711 .56925 .77887 .57139 .79196 .56764 .7902 .5655 Metetra
.645 .763 .934 r
.7902 .5655 .79196 .56764 .8051 .56388 .80336 .56173 Metetra
.645 .763 .934 r
.80336 .56173 .8051 .56388 .8183 .56011 .81657 .55794 Metetra
.645 .763 .934 r
.81657 .55794 .8183 .56011 .83156 .55631 .82985 .55414 Metetra
.645 .763 .934 r
.82985 .55414 .83156 .55631 .84488 .5525 .84318 .55031 Metetra
.645 .763 .934 r
.84318 .55031 .84488 .5525 .85826 .54867 .85658 .54647 Metetra
.645 .763 .934 r
.85658 .54647 .85826 .54867 .87171 .54482 .87004 .54262 Metetra
.645 .763 .934 r
.87004 .54262 .87171 .54482 .88522 .54096 .88356 .53874 Metetra
.645 .763 .934 r
.88356 .53874 .88522 .54096 .89879 .53708 .89714 .53485 Metetra
.645 .763 .934 r
.89714 .53485 .89879 .53708 .91242 .53318 .91079 .53094 Metetra
.253 .611 .955 r
.28727 .52388 .28937 .52547 .29944 .52634 .29727 .52593 Metetra
.901 .865 .795 r
.29727 .52593 .29944 .52634 .31049 .51304 .30843 .51111 Metetra
.017 .423 .862 r
.30843 .51111 .31049 .51304 .32054 .51585 .31836 .51588 Metetra
.867 .946 .865 r
.31836 .51588 .32054 .51585 .33147 .5047 .32929 .50515 Metetra
.905 .957 .818 r
.32929 .50515 .33147 .5047 .34252 .4914 .34036 .49183 Metetra
.942 .909 .758 r
.34036 .49183 .34252 .4914 .35367 .4756 .35165 .47375 Metetra
.651 .75 .922 r
.35165 .47375 .35367 .4756 .36405 .47495 .36216 .47063 Metetra
.209 .329 .768 r
.36216 .47063 .36405 .47495 .37408 .48326 .37218 .47891 Metetra
.166 .302 .758 r
.37218 .47891 .37408 .48326 .38419 .49236 .38229 .48799 Metetra
.641 .58 .771 r
.38229 .48799 .38419 .49236 .39504 .48575 .39302 .48438 Metetra
.534 .775 .986 r
.39302 .48438 .39504 .48575 .40563 .48695 .40371 .48298 Metetra
.901 .532 .075 r
.40371 .48298 .40563 .48695 .41523 .52041 .41329 .5164 Metetra
.68 .617 .778 r
.41329 .5164 .41523 .52041 .4263 .51395 .42434 .51091 Metetra
.736 .686 .802 r
.42434 .51091 .4263 .51395 .43744 .50553 .43547 .5033 Metetra
.6 .704 .916 r
.43547 .5033 .43744 .50553 .44846 .50333 .44648 .5014 Metetra
.885 .769 .728 r
.44648 .5014 .44846 .50333 .45987 .4833 .45792 .48135 Metetra
.889 .768 .721 r
.45792 .48135 .45987 .4833 .47124 .46242 .4693 .46045 Metetra
.871 .773 .751 r
.4693 .46045 .47124 .46242 .48248 .44595 .48056 .44348 Metetra
.758 .307 0 r
.48056 .44348 .48248 .44595 .49333 .46497 .49141 .4625 Metetra
.791 .345 0 r
.49141 .4625 .49333 .46497 .50437 .48571 .50245 .48324 Metetra
.818 .379 0 r
.50245 .48324 .50437 .48571 .51562 .50833 .51369 .50586 Metetra
.887 .748 .702 r
.51369 .50586 .51562 .50833 .52707 .48455 .52516 .48246 Metetra
.853 .414 0 r
.52516 .48246 .52707 .48455 .53863 .50916 .5367 .50663 Metetra
.958 .621 .31 r
.5367 .50663 .53863 .50916 .55077 .57952 .54882 .57699 Metetra
.776 .33 0 r
.54882 .57699 .55077 .57952 .56293 .59984 .56099 .59936 Metetra
.965 .835 .665 r
.56099 .59936 .56293 .59984 .57457 .56959 .57266 .56906 Metetra
.967 .83 .656 r
.57266 .56906 .57457 .56959 .58605 .53812 .58417 .53755 Metetra
.968 .824 .647 r
.58417 .53755 .58605 .53812 .59735 .50542 .5955 .5048 Metetra
.97 .819 .638 r
.5955 .5048 .59735 .50542 .60846 .47145 .60665 .47078 Metetra
.374 .798 .972 r
.60665 .47078 .60846 .47145 .62045 .47343 .61856 .46947 Metetra
.878 .509 .026 r
.61856 .46947 .62045 .47343 .63392 .51787 .632 .51388 Metetra
.893 .527 .057 r
.632 .51388 .63392 .51787 .64795 .56683 .64601 .5628 Metetra
.797 .421 0 r
.64601 .5628 .64795 .56683 .66189 .60227 .66 .60021 Metetra
.645 .763 .934 r
.66 .60021 .66189 .60227 .67446 .59867 .67259 .5966 Metetra
.645 .763 .934 r
.67259 .5966 .67446 .59867 .68709 .59505 .68523 .59297 Metetra
.645 .763 .934 r
.68523 .59297 .68709 .59505 .69978 .59141 .69793 .58933 Metetra
.645 .763 .934 r
.69793 .58933 .69978 .59141 .71252 .58776 .71069 .58567 Metetra
.645 .763 .934 r
.71069 .58567 .71252 .58776 .72532 .58409 .7235 .58199 Metetra
.645 .763 .934 r
.7235 .58199 .72532 .58409 .73818 .58041 .73637 .57829 Metetra
.645 .763 .934 r
.73637 .57829 .73818 .58041 .7511 .5767 .7493 .57458 Metetra
.645 .763 .934 r
.7493 .57458 .7511 .5767 .76407 .57298 .76229 .57085 Metetra
.645 .763 .934 r
.76229 .57085 .76407 .57298 .77711 .56925 .77534 .56711 Metetra
.645 .763 .934 r
.77534 .56711 .77711 .56925 .7902 .5655 .78845 .56334 Metetra
.645 .763 .934 r
.78845 .56334 .7902 .5655 .80336 .56173 .80161 .55956 Metetra
.645 .763 .934 r
.80161 .55956 .80336 .56173 .81657 .55794 .81484 .55577 Metetra
.645 .763 .934 r
.81484 .55577 .81657 .55794 .82985 .55414 .82813 .55195 Metetra
.645 .763 .934 r
.82813 .55195 .82985 .55414 .84318 .55031 .84148 .54812 Metetra
.645 .763 .934 r
.84148 .54812 .84318 .55031 .85658 .54647 .85489 .54427 Metetra
.645 .763 .934 r
.85489 .54427 .85658 .54647 .87004 .54262 .86836 .5404 Metetra
.645 .763 .934 r
.86836 .5404 .87004 .54262 .88356 .53874 .8819 .53652 Metetra
.645 .763 .934 r
.8819 .53652 .88356 .53874 .89714 .53485 .8955 .53262 Metetra
.645 .763 .934 r
.8955 .53262 .89714 .53485 .91079 .53094 .90916 .52869 Metetra
.489 .625 .911 r
.28523 .52141 .28727 .52388 .29727 .52593 .29532 .52206 Metetra
.77 .653 .733 r
.29532 .52206 .29727 .52593 .30843 .51111 .30635 .50949 Metetra
.222 .59 .947 r
.30635 .50949 .30843 .51111 .31836 .51588 .31643 .51187 Metetra
.754 .643 .738 r
.31643 .51187 .31836 .51588 .32929 .50515 .32739 .50065 Metetra
.761 .632 .717 r
.32739 .50065 .32929 .50515 .34036 .49183 .33847 .48733 Metetra
.781 .64 .706 r
.33847 .48733 .34036 .49183 .35165 .47375 .34966 .4714 Metetra
.53 .656 .916 r
.34966 .4714 .35165 .47375 .36216 .47063 .36003 .47118 Metetra
.701 .21 .076 r
.36003 .47118 .36216 .47063 .37218 .47891 .37005 .47948 Metetra
.719 .236 .098 r
.37005 .47948 .37218 .47891 .38229 .48799 .38017 .48858 Metetra
.655 .971 .852 r
.38017 .48858 .38229 .48799 .39302 .48438 .39106 .48137 Metetra
.442 .558 .877 r
.39106 .48137 .39302 .48438 .40371 .48298 .40162 .48349 Metetra
.893 .534 .357 r
.40162 .48349 .40371 .48298 .41329 .5164 .4112 .51698 Metetra
.615 .957 .843 r
.4112 .51698 .41329 .5164 .42434 .51091 .4223 .51009 Metetra
.812 .893 .901 r
.4223 .51009 .42434 .51091 .43547 .5033 .43347 .50165 Metetra
.587 .764 .963 r
.43347 .50165 .43547 .5033 .44648 .5014 .4445 .49961 Metetra
.89 .776 .73 r
.4445 .49961 .44648 .5014 .45792 .48135 .45595 .47954 Metetra
.894 .775 .723 r
.45595 .47954 .45792 .48135 .4693 .46045 .46736 .45862 Metetra
.876 .781 .753 r
.46736 .45862 .4693 .46045 .48056 .44348 .47864 .44159 Metetra
.815 .351 0 r
.47864 .44159 .48056 .44348 .49141 .4625 .48948 .46061 Metetra
.837 .382 0 r
.48948 .46061 .49141 .4625 .50245 .48324 .50052 .48136 Metetra
.855 .409 .004 r
.50052 .48136 .50245 .48324 .51369 .50586 .51175 .50398 Metetra
.907 .777 .706 r
.51175 .50398 .51369 .50586 .52516 .48246 .52324 .48039 Metetra
.858 .421 .002 r
.52324 .48039 .52516 .48246 .5367 .50663 .53478 .50496 Metetra
.953 .616 .334 r
.53478 .50496 .5367 .50663 .54882 .57699 .54686 .57538 Metetra
.807 .332 0 r
.54686 .57538 .54882 .57699 .56099 .59936 .55901 .59519 Metetra
.868 .694 .663 r
.55901 .59519 .56099 .59936 .57266 .56906 .5707 .5649 Metetra
.873 .695 .658 r
.5707 .5649 .57266 .56906 .58417 .53755 .58222 .53339 Metetra
.878 .696 .652 r
.58222 .53339 .58417 .53755 .5955 .5048 .59358 .50064 Metetra
.883 .697 .647 r
.59358 .50064 .5955 .5048 .60665 .47078 .60474 .46664 Metetra
.46 .504 .817 r
.60474 .46664 .60665 .47078 .61856 .46947 .61678 .46977 Metetra
.916 .54 .291 r
.61678 .46977 .61856 .46947 .632 .51388 .63022 .51427 Metetra
.92 .549 .299 r
.63022 .51427 .632 .51388 .64601 .5628 .64422 .56329 Metetra
.892 .49 .246 r
.64422 .56329 .64601 .5628 .66 .60021 .65812 .59815 Metetra
.645 .763 .934 r
.65812 .59815 .66 .60021 .67259 .5966 .67072 .59453 Metetra
.645 .763 .934 r
.67072 .59453 .67259 .5966 .68523 .59297 .68337 .59089 Metetra
.645 .763 .934 r
.68337 .59089 .68523 .59297 .69793 .58933 .69608 .58724 Metetra
.645 .763 .934 r
.69608 .58724 .69793 .58933 .71069 .58567 .70885 .58357 Metetra
.645 .763 .934 r
.70885 .58357 .71069 .58567 .7235 .58199 .72168 .57988 Metetra
.645 .763 .934 r
.72168 .57988 .7235 .58199 .73637 .57829 .73456 .57617 Metetra
.645 .763 .934 r
.73456 .57617 .73637 .57829 .7493 .57458 .7475 .57245 Metetra
.645 .763 .934 r
.7475 .57245 .7493 .57458 .76229 .57085 .76051 .56871 Metetra
.645 .763 .934 r
.76051 .56871 .76229 .57085 .77534 .56711 .77357 .56496 Metetra
.645 .763 .934 r
.77357 .56496 .77534 .56711 .78845 .56334 .78669 .56119 Metetra
.645 .763 .934 r
.78669 .56119 .78845 .56334 .80161 .55956 .79987 .5574 Metetra
.645 .763 .934 r
.79987 .5574 .80161 .55956 .81484 .55577 .81311 .55359 Metetra
.645 .763 .934 r
.81311 .55359 .81484 .55577 .82813 .55195 .82641 .54977 Metetra
.645 .763 .934 r
.82641 .54977 .82813 .55195 .84148 .54812 .83977 .54592 Metetra
.645 .763 .934 r
.83977 .54592 .84148 .54812 .85489 .54427 .8532 .54206 Metetra
.645 .763 .934 r
.8532 .54206 .85489 .54427 .86836 .5404 .86668 .53819 Metetra
.645 .763 .934 r
.86668 .53819 .86836 .5404 .8819 .53652 .88023 .53429 Metetra
.645 .763 .934 r
.88023 .53429 .8819 .53652 .8955 .53262 .89384 .53038 Metetra
.645 .763 .934 r
.89384 .53038 .8955 .53262 .90916 .52869 .90752 .52645 Metetra
.416 .645 .952 r
.28315 .51942 .28523 .52141 .29532 .52206 .29322 .5205 Metetra
.841 .786 .799 r
.29322 .5205 .29532 .52206 .30635 .50949 .30424 .50822 Metetra
.011 .501 .87 r
.30424 .50822 .30635 .50949 .31643 .51187 .31428 .51136 Metetra
.863 .891 .854 r
.31428 .51136 .31643 .51187 .32739 .50065 .32524 .50046 Metetra
.898 .903 .82 r
.32524 .50046 .32739 .50065 .33847 .48733 .33633 .48712 Metetra
.926 .866 .761 r
.33633 .48712 .33847 .48733 .34966 .4714 .34765 .46919 Metetra
.597 .696 .912 r
.34765 .46919 .34966 .4714 .36003 .47118 .3581 .46747 Metetra
.116 .309 .781 r
.3581 .46747 .36003 .47118 .37005 .47948 .36812 .47575 Metetra
.062 .274 .765 r
.36812 .47575 .37005 .47948 .38017 .48858 .37823 .48483 Metetra
.691 .63 .783 r
.37823 .48483 .38017 .48858 .39106 .48137 .38907 .479 Metetra
.404 .599 .925 r
.38907 .479 .39106 .48137 .40162 .48349 .39965 .48086 Metetra
.933 .554 .197 r
.39965 .48086 .40162 .48349 .4112 .51698 .40921 .51435 Metetra
.739 .714 .827 r
.40921 .51435 .4112 .51698 .4223 .51009 .42033 .50726 Metetra
.741 .701 .813 r
.42033 .50726 .4223 .51009 .43347 .50165 .43148 .4997 Metetra
.582 .727 .943 r
.43148 .4997 .43347 .50165 .4445 .49961 .4425 .49802 Metetra
.897 .789 .732 r
.4425 .49802 .4445 .49961 .45595 .47954 .45398 .47793 Metetra
.901 .786 .725 r
.45398 .47793 .45595 .47954 .46736 .45862 .46541 .45699 Metetra
.89 .793 .747 r
.46541 .45699 .46736 .45862 .47864 .44159 .47672 .43886 Metetra
.724 .284 0 r
.47672 .43886 .47864 .44159 .48948 .46061 .48756 .45788 Metetra
.762 .325 0 r
.48756 .45788 .48948 .46061 .50052 .48136 .49858 .47862 Metetra
.794 .362 0 r
.49858 .47862 .50052 .48136 .51175 .50398 .50981 .50124 Metetra
.878 .736 .702 r
.50981 .50124 .51175 .50398 .52324 .48039 .52132 .47811 Metetra
.846 .41 0 r
.52132 .47811 .52324 .48039 .53478 .50496 .53285 .5025 Metetra
.958 .621 .312 r
.53285 .5025 .53478 .50496 .54686 .57538 .5449 .57294 Metetra
.738 .281 0 r
.5449 .57294 .54686 .57538 .55901 .59519 .55705 .59315 Metetra
.924 .769 .671 r
.55705 .59315 .55901 .59519 .5707 .5649 .56876 .56283 Metetra
.927 .767 .663 r
.56876 .56283 .5707 .5649 .58222 .53339 .58031 .5313 Metetra
.93 .765 .656 r
.58031 .5313 .58222 .53339 .59358 .50064 .59169 .49852 Metetra
.933 .763 .648 r
.59169 .49852 .59358 .50064 .60474 .46664 .60289 .46449 Metetra
.318 .587 .94 r
.60289 .46449 .60474 .46664 .61678 .46977 .61492 .46731 Metetra
.922 .539 .145 r
.61492 .46731 .61678 .46977 .63022 .51427 .62834 .51182 Metetra
.929 .551 .165 r
.62834 .51182 .63022 .51427 .64422 .56329 .64233 .56086 Metetra
.877 .465 .028 r
.64233 .56086 .64422 .56329 .65812 .59815 .65623 .59608 Metetra
.645 .763 .934 r
.65623 .59608 .65812 .59815 .67072 .59453 .66884 .59245 Metetra
.645 .763 .934 r
.66884 .59245 .67072 .59453 .68337 .59089 .68151 .5888 Metetra
.645 .763 .934 r
.68151 .5888 .68337 .59089 .69608 .58724 .69423 .58514 Metetra
.645 .763 .934 r
.69423 .58514 .69608 .58724 .70885 .58357 .70701 .58146 Metetra
.645 .763 .934 r
.70701 .58146 .70885 .58357 .72168 .57988 .71985 .57776 Metetra
.645 .763 .934 r
.71985 .57776 .72168 .57988 .73456 .57617 .73275 .57405 Metetra
.645 .763 .934 r
.73275 .57405 .73456 .57617 .7475 .57245 .7457 .57032 Metetra
.645 .763 .934 r
.7457 .57032 .7475 .57245 .76051 .56871 .75871 .56657 Metetra
.645 .763 .934 r
.75871 .56657 .76051 .56871 .77357 .56496 .77179 .56281 Metetra
.645 .763 .934 r
.77179 .56281 .77357 .56496 .78669 .56119 .78492 .55902 Metetra
.645 .763 .934 r
.78492 .55902 .78669 .56119 .79987 .5574 .79811 .55522 Metetra
.645 .763 .934 r
.79811 .55522 .79987 .5574 .81311 .55359 .81137 .55141 Metetra
.645 .763 .934 r
.81137 .55141 .81311 .55359 .82641 .54977 .82468 .54757 Metetra
.645 .763 .934 r
.82468 .54757 .82641 .54977 .83977 .54592 .83806 .54372 Metetra
.645 .763 .934 r
.83806 .54372 .83977 .54592 .8532 .54206 .8515 .53985 Metetra
.645 .763 .934 r
.8515 .53985 .8532 .54206 .86668 .53819 .865 .53596 Metetra
.645 .763 .934 r
.865 .53596 .86668 .53819 .88023 .53429 .87856 .53206 Metetra
.645 .763 .934 r
.87856 .53206 .88023 .53429 .89384 .53038 .89219 .52813 Metetra
.645 .763 .934 r
.89219 .52813 .89384 .53038 .90752 .52645 .90588 .52419 Metetra
.496 .671 .942 r
.28107 .51734 .28315 .51942 .29322 .5205 .29121 .51742 Metetra
.777 .687 .765 r
.29121 .51742 .29322 .5205 .30424 .50822 .30216 .50649 Metetra
.337 .641 .964 r
.30216 .50649 .30424 .50822 .31428 .51136 .3123 .508 Metetra
.77 .674 .757 r
.3123 .508 .31428 .51136 .32524 .50046 .32327 .49698 Metetra
.788 .674 .739 r
.32327 .49698 .32524 .50046 .33633 .48712 .33438 .48363 Metetra
.81 .681 .721 r
.33438 .48363 .33633 .48712 .34765 .46919 .34563 .46717 Metetra
.507 .683 .946 r
.34563 .46717 .34765 .46919 .3581 .46747 .356 .467 Metetra
.671 .121 0 r
.356 .467 .3581 .46747 .36812 .47575 .36603 .4753 Metetra
.699 .16 0 r
.36603 .4753 .36812 .47575 .37823 .48483 .37614 .48439 Metetra
.805 .93 .916 r
.37614 .48439 .37823 .48483 .38907 .479 .38709 .47636 Metetra
.275 .502 .893 r
.38709 .47636 .38907 .479 .39965 .48086 .39759 .4804 Metetra
.912 .544 .321 r
.39759 .4804 .39965 .48086 .40921 .51435 .40713 .51394 Metetra
.809 .937 .914 r
.40713 .51394 .40921 .51435 .42033 .50726 .41831 .50556 Metetra
.77 .799 .876 r
.41831 .50556 .42033 .50726 .43148 .4997 .42947 .49821 Metetra
.591 .784 .972 r
.42947 .49821 .43148 .4997 .4425 .49802 .44052 .49592 Metetra
.88 .76 .726 r
.44052 .49592 .4425 .49802 .45398 .47793 .45201 .47581 Metetra
.884 .759 .719 r
.45201 .47581 .45398 .47793 .46541 .45699 .46346 .45485 Metetra
.869 .762 .742 r
.46346 .45485 .46541 .45699 .47672 .43886 .47479 .4371 Metetra
.824 .359 0 r
.47479 .4371 .47672 .43886 .48756 .45788 .48562 .45613 Metetra
.844 .389 0 r
.48562 .45613 .48756 .45788 .49858 .47862 .49664 .47688 Metetra
.86 .415 .025 r
.49664 .47688 .49858 .47862 .50981 .50124 .50786 .49951 Metetra
.913 .784 .705 r
.50786 .49951 .50981 .50124 .52132 .47811 .51939 .47558 Metetra
.847 .42 0 r
.51939 .47558 .52132 .47811 .53285 .5025 .53092 .50127 Metetra
.95 .613 .345 r
.53092 .50127 .53285 .5025 .5449 .57294 .54294 .57178 Metetra
.804 .316 0 r
.54294 .57178 .5449 .57294 .55705 .59315 .55507 .5898 Metetra
.889 .721 .667 r
.55507 .5898 .55705 .59315 .56876 .56283 .5668 .55948 Metetra
.894 .721 .661 r
.5668 .55948 .56876 .56283 .58031 .5313 .57838 .52794 Metetra
.898 .722 .655 r
.57838 .52794 .58031 .5313 .59169 .49852 .58978 .49516 Metetra
.902 .722 .648 r
.58978 .49516 .59169 .49852 .60289 .46449 .60099 .46112 Metetra
.302 .461 .853 r
.60099 .46112 .60289 .46449 .61492 .46731 .6131 .46669 Metetra
.926 .544 .251 r
.6131 .46669 .61492 .46731 .62834 .51182 .62652 .51127 Metetra
.929 .553 .262 r
.62652 .51127 .62834 .51182 .64233 .56086 .6405 .56038 Metetra
.898 .482 .179 r
.6405 .56038 .64233 .56086 .65623 .59608 .65433 .59401 Metetra
.645 .763 .934 r
.65433 .59401 .65623 .59608 .66884 .59245 .66696 .59037 Metetra
.645 .763 .934 r
.66696 .59037 .66884 .59245 .68151 .5888 .67963 .58671 Metetra
.645 .763 .934 r
.67963 .58671 .68151 .5888 .69423 .58514 .69237 .58304 Metetra
.645 .763 .934 r
.69237 .58304 .69423 .58514 .70701 .58146 .70516 .57935 Metetra
.645 .763 .934 r
.70516 .57935 .70701 .58146 .71985 .57776 .71801 .57564 Metetra
.645 .763 .934 r
.71801 .57564 .71985 .57776 .73275 .57405 .73092 .57192 Metetra
.645 .763 .934 r
.73092 .57192 .73275 .57405 .7457 .57032 .74389 .56818 Metetra
.645 .763 .934 r
.74389 .56818 .7457 .57032 .75871 .56657 .75692 .56442 Metetra
.645 .763 .934 r
.75692 .56442 .75871 .56657 .77179 .56281 .77 .56065 Metetra
.645 .763 .934 r
.77 .56065 .77179 .56281 .78492 .55902 .78315 .55685 Metetra
.645 .763 .934 r
.78315 .55685 .78492 .55902 .79811 .55522 .79636 .55305 Metetra
.645 .763 .934 r
.79636 .55305 .79811 .55522 .81137 .55141 .80963 .54922 Metetra
.645 .763 .934 r
.80963 .54922 .81137 .55141 .82468 .54757 .82295 .54537 Metetra
.645 .763 .934 r
.82295 .54537 .82468 .54757 .83806 .54372 .83634 .54151 Metetra
.645 .763 .934 r
.83634 .54151 .83806 .54372 .8515 .53985 .8498 .53763 Metetra
.645 .763 .934 r
.8498 .53763 .8515 .53985 .865 .53596 .86331 .53373 Metetra
.645 .763 .934 r
.86331 .53373 .865 .53596 .87856 .53206 .87689 .52982 Metetra
.645 .763 .934 r
.87689 .52982 .87856 .53206 .89219 .52813 .89053 .52588 Metetra
.645 .763 .934 r
.89053 .52588 .89219 .52813 .90588 .52419 .90423 .52193 Metetra
.511 .673 .937 r
.27899 .51522 .28107 .51734 .29121 .51742 .28915 .5151 Metetra
.787 .732 .802 r
.28915 .5151 .29121 .51742 .30216 .50649 .30002 .50539 Metetra
.224 .659 .955 r
.30002 .50539 .30216 .50649 .3123 .508 .31019 .50658 Metetra
.831 .805 .826 r
.31019 .50658 .3123 .508 .32327 .49698 .32116 .49586 Metetra
.868 .823 .801 r
.32116 .49586 .32327 .49698 .33438 .48363 .33228 .4825 Metetra
.893 .806 .755 r
.33228 .4825 .33438 .48363 .34563 .46717 .34362 .4649 Metetra
.551 .673 .919 r
.34362 .4649 .34563 .46717 .356 .467 .35402 .46419 Metetra
0 .247 .761 r
.35402 .46419 .356 .467 .36603 .4753 .36405 .47247 Metetra
0 .197 .725 r
.36405 .47247 .36603 .4753 .37614 .48439 .37416 .48156 Metetra
.749 .699 .804 r
.37416 .48156 .37614 .48439 .38709 .47636 .38511 .47353 Metetra
.209 .445 .868 r
.38511 .47353 .38709 .47636 .39759 .4804 .39557 .47875 Metetra
.929 .553 .262 r
.39557 .47875 .39759 .4804 .40713 .51394 .4051 .51231 Metetra
.81 .804 .846 r
.4051 .51231 .40713 .51394 .41831 .50556 .41632 .50278 Metetra
.716 .698 .831 r
.41632 .50278 .41831 .50556 .42947 .49821 .42745 .49669 Metetra
.597 .785 .97 r
.42745 .49669 .42947 .49821 .44052 .49592 .43851 .4943 Metetra
.897 .787 .732 r
.43851 .4943 .44052 .49592 .45201 .47581 .45003 .47417 Metetra
.902 .784 .72 r
.45003 .47417 .45201 .47581 .46346 .45485 .46151 .45262 Metetra
.868 .757 .738 r
.46151 .45262 .46346 .45485 .47479 .4371 .47286 .43452 Metetra
.746 .299 0 r
.47286 .43452 .47479 .4371 .48562 .45613 .48369 .45354 Metetra
.781 .338 0 r
.48369 .45354 .48562 .45613 .49664 .47688 .4947 .47429 Metetra
.81 .374 0 r
.4947 .47429 .49664 .47688 .50786 .49951 .50592 .49692 Metetra
.886 .743 .698 r
.50592 .49692 .50786 .49951 .51939 .47558 .51747 .47284 Metetra
.845 .425 0 r
.51747 .47284 .51939 .47558 .53092 .50127 .52898 .49945 Metetra
.954 .617 .33 r
.52898 .49945 .53092 .50127 .54294 .57178 .54097 .57001 Metetra
.733 .239 0 r
.54097 .57001 .54294 .57178 .55507 .5898 .55309 .58687 Metetra
.9 .736 .669 r
.55309 .58687 .55507 .5898 .5668 .55948 .56484 .55654 Metetra
.904 .736 .662 r
.56484 .55654 .5668 .55948 .57838 .52794 .57644 .52498 Metetra
.908 .735 .655 r
.57644 .52498 .57838 .52794 .58978 .49516 .58787 .49219 Metetra
.912 .734 .649 r
.58787 .49219 .58978 .49516 .60099 .46112 .59911 .45815 Metetra
.157 .404 .848 r
.59911 .45815 .60099 .46112 .6131 .46669 .61126 .4652 Metetra
.929 .545 .207 r
.61126 .4652 .6131 .46669 .62652 .51127 .62466 .50982 Metetra
.933 .555 .221 r
.62466 .50982 .62652 .51127 .6405 .56038 .63863 .55898 Metetra
.892 .468 .1 r
.63863 .55898 .6405 .56038 .65433 .59401 .65243 .59193 Metetra
.645 .763 .934 r
.65243 .59193 .65433 .59401 .66696 .59037 .66507 .58828 Metetra
.645 .763 .934 r
.66507 .58828 .66696 .59037 .67963 .58671 .67776 .58462 Metetra
.645 .763 .934 r
.67776 .58462 .67963 .58671 .69237 .58304 .69051 .58093 Metetra
.645 .763 .934 r
.69051 .58093 .69237 .58304 .70516 .57935 .70331 .57723 Metetra
.645 .763 .934 r
.70331 .57723 .70516 .57935 .71801 .57564 .71618 .57352 Metetra
.645 .763 .934 r
.71618 .57352 .71801 .57564 .73092 .57192 .7291 .56978 Metetra
.645 .763 .934 r
.7291 .56978 .73092 .57192 .74389 .56818 .74208 .56603 Metetra
.645 .763 .934 r
.74208 .56603 .74389 .56818 .75692 .56442 .75512 .56227 Metetra
.645 .763 .934 r
.75512 .56227 .75692 .56442 .77 .56065 .76822 .55848 Metetra
.645 .763 .934 r
.76822 .55848 .77 .56065 .78315 .55685 .78138 .55468 Metetra
.645 .763 .934 r
.78138 .55468 .78315 .55685 .79636 .55305 .7946 .55086 Metetra
.645 .763 .934 r
.7946 .55086 .79636 .55305 .80963 .54922 .80788 .54702 Metetra
.645 .763 .934 r
.80788 .54702 .80963 .54922 .82295 .54537 .82122 .54317 Metetra
.645 .763 .934 r
.82122 .54317 .82295 .54537 .83634 .54151 .83462 .5393 Metetra
.645 .763 .934 r
.83462 .5393 .83634 .54151 .8498 .53763 .84809 .53541 Metetra
.645 .763 .934 r
.84809 .53541 .8498 .53763 .86331 .53373 .86162 .5315 Metetra
.645 .763 .934 r
.86162 .5315 .86331 .53373 .87689 .52982 .87521 .52757 Metetra
.645 .763 .934 r
.87521 .52757 .87689 .52982 .89053 .52588 .88886 .52363 Metetra
.645 .763 .934 r
.88886 .52363 .89053 .52588 .90423 .52193 .90258 .51966 Metetra
.505 .699 .957 r
.27688 .51335 .27899 .51522 .28915 .5151 .28706 .51305 Metetra
.797 .753 .812 r
.28706 .51305 .28915 .5151 .30002 .50539 .29795 .50324 Metetra
.438 .639 .941 r
.29795 .50324 .30002 .50539 .31019 .50658 .30814 .50423 Metetra
.801 .734 .79 r
.30814 .50423 .31019 .50658 .32116 .49586 .31913 .49332 Metetra
.817 .724 .762 r
.31913 .49332 .32116 .49586 .33228 .4825 .33027 .47994 Metetra
.841 .725 .736 r
.33027 .47994 .33228 .4825 .34362 .4649 .34158 .46303 Metetra
.5 .698 .957 r
.34158 .46303 .34362 .4649 .35402 .46419 .35197 .46278 Metetra
.526 0 0 r
.35197 .46278 .35402 .46419 .36405 .47247 .362 .47107 Metetra
.578 .031 0 r
.362 .47107 .36405 .47247 .37416 .48156 .3721 .48016 Metetra
.802 .822 .867 r
.3721 .48016 .37416 .48156 .38511 .47353 .38309 .47163 Metetra
0 .393 .84 r
.38309 .47163 .38511 .47353 .39557 .47875 .39354 .47697 Metetra
.931 .554 .255 r
.39354 .47697 .39557 .47875 .4051 .51231 .40306 .51054 Metetra
.802 .793 .843 r
.40306 .51054 .4051 .51231 .41632 .50278 .41429 .50124 Metetra
.76 .815 .896 r
.41429 .50124 .41632 .50278 .42745 .49669 .42545 .49446 Metetra
.617 .711 .913 r
.42545 .49446 .42745 .49669 .43851 .4943 .43652 .4921 Metetra
.877 .756 .725 r
.43652 .4921 .43851 .4943 .45003 .47417 .44806 .47195 Metetra
.883 .754 .715 r
.44806 .47195 .45003 .47417 .46151 .45262 .45955 .45051 Metetra
.871 .764 .742 r
.45955 .45051 .46151 .45262 .47286 .43452 .47091 .4327 Metetra
.821 .356 0 r
.47091 .4327 .47286 .43452 .48369 .45354 .48174 .45173 Metetra
.841 .386 0 r
.48174 .45173 .48369 .45354 .4947 .47429 .49275 .47248 Metetra
.858 .413 .017 r
.49275 .47248 .4947 .47429 .50592 .49692 .50396 .49512 Metetra
.911 .781 .704 r
.50396 .49512 .50592 .49692 .51747 .47284 .51553 .47108 Metetra
.883 .453 .075 r
.51553 .47108 .51747 .47284 .52898 .49945 .52704 .49727 Metetra
.956 .619 .321 r
.52704 .49727 .52898 .49945 .54097 .57001 .539 .56787 Metetra
.688 .207 0 r
.539 .56787 .54097 .57001 .55309 .58687 .55111 .58483 Metetra
.924 .77 .671 r
.55111 .58483 .55309 .58687 .56484 .55654 .56289 .55446 Metetra
.927 .768 .663 r
.56289 .55446 .56484 .55654 .57644 .52498 .57452 .52289 Metetra
.93 .766 .656 r
.57452 .52289 .57644 .52498 .58787 .49219 .58597 .49007 Metetra
.933 .764 .648 r
.58597 .49007 .58787 .49219 .59911 .45815 .59724 .456 Metetra
0 .354 .824 r
.59724 .456 .59911 .45815 .61126 .4652 .60939 .4632 Metetra
.927 .543 .176 r
.60939 .4632 .61126 .4652 .62466 .50982 .62278 .50784 Metetra
.932 .554 .194 r
.62278 .50784 .62466 .50982 .63863 .55898 .63673 .55703 Metetra
.879 .456 .046 r
.63673 .55703 .63863 .55898 .65243 .59193 .65053 .58985 Metetra
.645 .763 .934 r
.65053 .58985 .65243 .59193 .66507 .58828 .66318 .58619 Metetra
.645 .763 .934 r
.66318 .58619 .66507 .58828 .67776 .58462 .67588 .58251 Metetra
.645 .763 .934 r
.67588 .58251 .67776 .58462 .69051 .58093 .68864 .57882 Metetra
.645 .763 .934 r
.68864 .57882 .69051 .58093 .70331 .57723 .70146 .57511 Metetra
.645 .763 .934 r
.70146 .57511 .70331 .57723 .71618 .57352 .71433 .57139 Metetra
.645 .763 .934 r
.71433 .57139 .71618 .57352 .7291 .56978 .72727 .56764 Metetra
.645 .763 .934 r
.72727 .56764 .7291 .56978 .74208 .56603 .74026 .56388 Metetra
.645 .763 .934 r
.74026 .56388 .74208 .56603 .75512 .56227 .75331 .56011 Metetra
.645 .763 .934 r
.75331 .56011 .75512 .56227 .76822 .55848 .76642 .55631 Metetra
.645 .763 .934 r
.76642 .55631 .76822 .55848 .78138 .55468 .7796 .5525 Metetra
.645 .763 .934 r
.7796 .5525 .78138 .55468 .7946 .55086 .79283 .54867 Metetra
.645 .763 .934 r
.79283 .54867 .7946 .55086 .80788 .54702 .80612 .54482 Metetra
.645 .763 .934 r
.80612 .54482 .80788 .54702 .82122 .54317 .81948 .54096 Metetra
.645 .763 .934 r
.81948 .54096 .82122 .54317 .83462 .5393 .8329 .53708 Metetra
.645 .763 .934 r
.8329 .53708 .83462 .5393 .84809 .53541 .84638 .53318 Metetra
.645 .763 .934 r
.84638 .53318 .84809 .53541 .86162 .5315 .85992 .52926 Metetra
.645 .763 .934 r
.85992 .52926 .86162 .5315 .87521 .52757 .87353 .52532 Metetra
.645 .763 .934 r
.87353 .52532 .87521 .52757 .88886 .52363 .8872 .52136 Metetra
.645 .763 .934 r
.8872 .52136 .88886 .52363 .90258 .51966 .90093 .51739 Metetra
.53 .686 .938 r
.27479 .51128 .27688 .51335 .28706 .51305 .28499 .51078 Metetra
.784 .736 .809 r
.28499 .51078 .28706 .51305 .29795 .50324 .29585 .50148 Metetra
.41 .673 .969 r
.29585 .50148 .29795 .50324 .30814 .50423 .30606 .50223 Metetra
.814 .759 .801 r
.30606 .50223 .30814 .50423 .31913 .49332 .31708 .49117 Metetra
.831 .749 .773 r
.31708 .49117 .31913 .49332 .33027 .47994 .32822 .47779 Metetra
.854 .746 .743 r
.32822 .47779 .33027 .47994 .34158 .46303 .33955 .4609 Metetra
.499 .668 .939 r
.33955 .4609 .34158 .46303 .35197 .46278 .34992 .46097 Metetra
0 .099 .58 r
.34992 .46097 .35197 .46278 .362 .47107 .35995 .46926 Metetra
.479 0 0 r
.35995 .46926 .362 .47107 .3721 .48016 .37006 .47835 Metetra
.796 .783 .84 r
.37006 .47835 .3721 .48016 .38309 .47163 .38109 .46934 Metetra
.008 .376 .841 r
.38109 .46934 .38309 .47163 .39354 .47697 .39151 .47534 Metetra
.929 .553 .264 r
.39151 .47534 .39354 .47697 .40306 .51054 .40101 .50894 Metetra
.809 .808 .85 r
.40101 .50894 .40306 .51054 .41429 .50124 .41226 .49955 Metetra
.768 .8 .879 r
.41226 .49955 .41429 .50124 .42545 .49446 .42345 .49228 Metetra
.604 .713 .922 r
.42345 .49228 .42545 .49446 .43652 .4921 .43452 .49021 Metetra
.888 .773 .729 r
.43452 .49021 .43652 .4921 .44806 .47195 .44607 .47005 Metetra
.895 .77 .715 r
.44607 .47005 .44806 .47195 .45955 .45051 .4576 .44811 Metetra
.859 .748 .739 r
.4576 .44811 .45955 .45051 .47091 .4327 .46897 .4305 Metetra
.792 .332 0 r
.46897 .4305 .47091 .4327 .48174 .45173 .47979 .44953 Metetra
.818 .366 0 r
.47979 .44953 .48174 .45173 .49275 .47248 .49079 .47029 Metetra
.84 .397 0 r
.49079 .47029 .49275 .47248 .50396 .49512 .502 .49294 Metetra
.898 .763 .704 r
.502 .49294 .50396 .49512 .51553 .47108 .51359 .46926 Metetra
.877 .444 .057 r
.51359 .46926 .51553 .47108 .52704 .49727 .52509 .49487 Metetra
.958 .62 .315 r
.52509 .49487 .52704 .49727 .539 .56787 .53701 .56549 Metetra
.646 .177 0 r
.53701 .56549 .539 .56787 .55111 .58483 .54913 .58235 Metetra
.913 .753 .67 r
.54913 .58235 .55111 .58483 .56289 .55446 .56093 .55196 Metetra
.916 .752 .663 r
.56093 .55196 .56289 .55446 .57452 .52289 .57258 .52037 Metetra
.919 .75 .656 r
.57258 .52037 .57452 .52289 .58597 .49007 .58406 .48753 Metetra
.923 .749 .649 r
.58406 .48753 .58597 .49007 .59724 .456 .59535 .45344 Metetra
0 .336 .818 r
.59535 .45344 .59724 .456 .60939 .4632 .60753 .46148 Metetra
.929 .544 .194 r
.60753 .46148 .60939 .4632 .62278 .50784 .62091 .50615 Metetra
.933 .555 .21 r
.62091 .50615 .62278 .50784 .63673 .55703 .63485 .55538 Metetra
.885 .459 .071 r
.63485 .55538 .63673 .55703 .65053 .58985 .64862 .58776 Metetra
.645 .763 .934 r
.64862 .58776 .65053 .58985 .66318 .58619 .66128 .58409 Metetra
.645 .763 .934 r
.66128 .58409 .66318 .58619 .67588 .58251 .67399 .58041 Metetra
.645 .763 .934 r
.67399 .58041 .67588 .58251 .68864 .57882 .68676 .5767 Metetra
.645 .763 .934 r
.68676 .5767 .68864 .57882 .70146 .57511 .69959 .57298 Metetra
.645 .763 .934 r
.69959 .57298 .70146 .57511 .71433 .57139 .71248 .56925 Metetra
.645 .763 .934 r
.71248 .56925 .71433 .57139 .72727 .56764 .72543 .5655 Metetra
.645 .763 .934 r
.72543 .5655 .72727 .56764 .74026 .56388 .73844 .56173 Metetra
.645 .763 .934 r
.73844 .56173 .74026 .56388 .75331 .56011 .7515 .55794 Metetra
.645 .763 .934 r
.7515 .55794 .75331 .56011 .76642 .55631 .76463 .55414 Metetra
.645 .763 .934 r
.76463 .55414 .76642 .55631 .7796 .5525 .77781 .55031 Metetra
.645 .763 .934 r
.77781 .55031 .7796 .5525 .79283 .54867 .79106 .54647 Metetra
.645 .763 .934 r
.79106 .54647 .79283 .54867 .80612 .54482 .80437 .54262 Metetra
.645 .763 .934 r
.80437 .54262 .80612 .54482 .81948 .54096 .81774 .53874 Metetra
.645 .763 .934 r
.81774 .53874 .81948 .54096 .8329 .53708 .83117 .53485 Metetra
.645 .763 .934 r
.83117 .53485 .8329 .53708 .84638 .53318 .84466 .53094 Metetra
.645 .763 .934 r
.84466 .53094 .84638 .53318 .85992 .52926 .85822 .52701 Metetra
.645 .763 .934 r
.85822 .52701 .85992 .52926 .87353 .52532 .87184 .52306 Metetra
.645 .763 .934 r
.87184 .52306 .87353 .52532 .8872 .52136 .88552 .51909 Metetra
.645 .763 .934 r
.88552 .51909 .8872 .52136 .90093 .51739 .89927 .51511 Metetra
.462 .714 .978 r
.27265 .50967 .27479 .51128 .28499 .51078 .28283 .50958 Metetra
.832 .825 .842 r
.28283 .50958 .28499 .51078 .29585 .50148 .29377 .49937 Metetra
.374 .614 .944 r
.29377 .49937 .29585 .50148 .30606 .50223 .30392 .50109 Metetra
.845 .831 .833 r
.30392 .50109 .30606 .50223 .31708 .49117 .31495 .49003 Metetra
.868 .821 .801 r
.31495 .49003 .31708 .49117 .32822 .47779 .32611 .47662 Metetra
.892 .805 .756 r
.32611 .47662 .32822 .47779 .33955 .4609 .33749 .45917 Metetra
.538 .731 .964 r
.33749 .45917 .33955 .4609 .34992 .46097 .34793 .45815 Metetra
0 .244 .759 r
.34793 .45815 .34992 .46097 .35995 .46926 .35796 .46643 Metetra
0 .194 .722 r
.35796 .46643 .35995 .46926 .37006 .47835 .36807 .47552 Metetra
.745 .699 .808 r
.36807 .47552 .37006 .47835 .38109 .46934 .37904 .46774 Metetra
0 .413 .836 r
.37904 .46774 .38109 .46934 .39151 .47534 .38952 .47244 Metetra
.931 .553 .179 r
.38952 .47244 .39151 .47534 .40101 .50894 .39901 .50603 Metetra
.754 .701 .802 r
.39901 .50603 .40101 .50894 .41226 .49955 .41023 .49751 Metetra
.768 .768 .852 r
.41023 .49751 .41226 .49955 .42345 .49228 .42145 .48971 Metetra
.598 .674 .894 r
.42145 .48971 .42345 .49228 .43452 .49021 .43252 .48794 Metetra
.875 .753 .724 r
.43252 .48794 .43452 .49021 .44607 .47005 .44409 .46776 Metetra
.88 .752 .717 r
.44409 .46776 .44607 .47005 .4576 .44811 .45562 .44667 Metetra
.897 .806 .751 r
.45562 .44667 .4576 .44811 .46897 .4305 .46702 .42853 Metetra
.811 .347 0 r
.46702 .42853 .46897 .4305 .47979 .44953 .47784 .44756 Metetra
.833 .379 0 r
.47784 .44756 .47979 .44953 .49079 .47029 .48883 .46833 Metetra
.852 .407 0 r
.48883 .46833 .49079 .47029 .502 .49294 .50003 .49098 Metetra
.904 .774 .708 r
.50003 .49098 .502 .49294 .51359 .46926 .51164 .46768 Metetra
.875 .437 .067 r
.51164 .46768 .51359 .46926 .52509 .49487 .52314 .49225 Metetra
.959 .621 .309 r
.52314 .49225 .52509 .49487 .53701 .56549 .53503 .56287 Metetra
.659 .204 0 r
.53503 .56287 .53701 .56549 .54913 .58235 .54715 .58112 Metetra
.947 .804 .67 r
.54715 .58112 .54913 .58235 .56093 .55196 .55898 .5507 Metetra
.949 .8 .661 r
.55898 .5507 .56093 .55196 .57258 .52037 .57066 .51906 Metetra
.951 .796 .653 r
.57066 .51906 .57258 .52037 .58406 .48753 .58217 .48619 Metetra
.953 .792 .645 r
.58217 .48619 .58406 .48753 .59535 .45344 .59349 .45205 Metetra
0 .315 .742 r
.59349 .45205 .59535 .45344 .60753 .46148 .60564 .45846 Metetra
.913 .533 .108 r
.60564 .45846 .60753 .46148 .62091 .50615 .61899 .50312 Metetra
.921 .546 .132 r
.61899 .50312 .62091 .50615 .63485 .55538 .63291 .55234 Metetra
.833 .424 0 r
.63291 .55234 .63485 .55538 .64862 .58776 .64671 .58567 Metetra
.645 .763 .934 r
.64671 .58567 .64862 .58776 .66128 .58409 .65938 .58199 Metetra
.645 .763 .934 r
.65938 .58199 .66128 .58409 .67399 .58041 .6721 .57829 Metetra
.645 .763 .934 r
.6721 .57829 .67399 .58041 .68676 .5767 .68489 .57458 Metetra
.645 .763 .934 r
.68489 .57458 .68676 .5767 .69959 .57298 .69773 .57085 Metetra
.645 .763 .934 r
.69773 .57085 .69959 .57298 .71248 .56925 .71063 .56711 Metetra
.645 .763 .934 r
.71063 .56711 .71248 .56925 .72543 .5655 .72359 .56334 Metetra
.645 .763 .934 r
.72359 .56334 .72543 .5655 .73844 .56173 .73661 .55956 Metetra
.645 .763 .934 r
.73661 .55956 .73844 .56173 .7515 .55794 .74969 .55577 Metetra
.645 .763 .934 r
.74969 .55577 .7515 .55794 .76463 .55414 .76283 .55195 Metetra
.645 .763 .934 r
.76283 .55195 .76463 .55414 .77781 .55031 .77602 .54812 Metetra
.645 .763 .934 r
.77602 .54812 .77781 .55031 .79106 .54647 .78928 .54427 Metetra
.645 .763 .934 r
.78928 .54427 .79106 .54647 .80437 .54262 .80261 .5404 Metetra
.645 .763 .934 r
.80261 .5404 .80437 .54262 .81774 .53874 .81599 .53652 Metetra
.645 .763 .934 r
.81599 .53652 .81774 .53874 .83117 .53485 .82943 .53262 Metetra
.645 .763 .934 r
.82943 .53262 .83117 .53485 .84466 .53094 .84294 .52869 Metetra
.645 .763 .934 r
.84294 .52869 .84466 .53094 .85822 .52701 .85651 .52476 Metetra
.645 .763 .934 r
.85651 .52476 .85822 .52701 .87184 .52306 .87015 .5208 Metetra
.645 .763 .934 r
.87015 .5208 .87184 .52306 .88552 .51909 .88384 .51682 Metetra
.645 .763 .934 r
.88384 .51682 .88552 .51909 .89927 .51511 .89761 .51282 Metetra
.505 .664 .933 r
.27056 .50747 .27265 .50967 .28283 .50958 .28073 .50749 Metetra
.81 .751 .797 r
.28073 .50749 .28283 .50958 .29377 .49937 .29174 .49642 Metetra
.474 .579 .88 r
.29174 .49642 .29377 .49937 .30392 .50109 .30192 .49773 Metetra
.775 .676 .755 r
.30192 .49773 .30392 .50109 .31495 .49003 .31299 .48623 Metetra
.78 .661 .732 r
.31299 .48623 .31495 .49003 .32611 .47662 .32416 .47282 Metetra
.798 .667 .72 r
.32416 .47282 .32611 .47662 .33749 .45917 .33545 .45706 Metetra
.44 .645 .944 r
.33545 .45706 .33749 .45917 .34793 .45815 .34579 .45796 Metetra
.685 .149 0 r
.34579 .45796 .34793 .45815 .35796 .46643 .35582 .46625 Metetra
.709 .184 0 r
.35582 .46625 .35796 .46643 .36807 .47552 .36594 .47535 Metetra
.821 .955 .903 r
.36594 .47535 .36807 .47552 .37904 .46774 .37698 .46651 Metetra
0 .407 .792 r
.37698 .46651 .37904 .46774 .38952 .47244 .38749 .47068 Metetra
.93 .554 .257 r
.38749 .47068 .38952 .47244 .39901 .50603 .39695 .50429 Metetra
.777 .796 .868 r
.39695 .50429 .39901 .50603 .41023 .49751 .40817 .49651 Metetra
.817 .874 .888 r
.40817 .49651 .41023 .49751 .42145 .48971 .41943 .48766 Metetra
.587 .721 .936 r
.41943 .48766 .42145 .48971 .43252 .48794 .43051 .48588 Metetra
.882 .764 .727 r
.43051 .48588 .43252 .48794 .44409 .46776 .4421 .46568 Metetra
.886 .762 .72 r
.4421 .46568 .44409 .46776 .45562 .44667 .45365 .44463 Metetra
.874 .77 .744 r
.45365 .44463 .45562 .44667 .46702 .42853 .46506 .42672 Metetra
.823 .358 0 r
.46506 .42672 .46702 .42853 .47784 .44756 .47587 .44577 Metetra
.843 .387 0 r
.47587 .44577 .47784 .44756 .48883 .46833 .48686 .46654 Metetra
.859 .414 .022 r
.48686 .46654 .48883 .46833 .50003 .49098 .49806 .48921 Metetra
.91 .784 .71 r
.49806 .48921 .50003 .49098 .51164 .46768 .50969 .46588 Metetra
.867 .428 .036 r
.50969 .46588 .51164 .46768 .52314 .49225 .52119 .49024 Metetra
.955 .618 .326 r
.52119 .49024 .52314 .49225 .53503 .56287 .53304 .56091 Metetra
.758 .279 0 r
.53304 .56091 .53503 .56287 .54715 .58112 .54516 .57959 Metetra
.939 .791 .671 r
.54516 .57959 .54715 .58112 .55898 .5507 .55702 .54913 Metetra
.941 .788 .663 r
.55702 .54913 .55898 .5507 .57066 .51906 .56873 .51746 Metetra
.944 .785 .654 r
.56873 .51746 .57066 .51906 .58217 .48619 .58026 .48455 Metetra
.946 .782 .646 r
.58026 .48455 .58217 .48619 .59349 .45205 .59161 .45038 Metetra
0 .403 .836 r
.59161 .45038 .59349 .45205 .60564 .45846 .60375 .45612 Metetra
.925 .541 .156 r
.60375 .45612 .60564 .45846 .61899 .50312 .61709 .5008 Metetra
.93 .552 .175 r
.61709 .5008 .61899 .50312 .63291 .55234 .63099 .55003 Metetra
.872 .453 .02 r
.63099 .55003 .63291 .55234 .64671 .58567 .64479 .58357 Metetra
.645 .763 .934 r
.64479 .58357 .64671 .58567 .65938 .58199 .65747 .57988 Metetra
.645 .763 .934 r
.65747 .57988 .65938 .58199 .6721 .57829 .67021 .57617 Metetra
.645 .763 .934 r
.67021 .57617 .6721 .57829 .68489 .57458 .683 .57245 Metetra
.645 .763 .934 r
.683 .57245 .68489 .57458 .69773 .57085 .69586 .56871 Metetra
.645 .763 .934 r
.69586 .56871 .69773 .57085 .71063 .56711 .70877 .56496 Metetra
.645 .763 .934 r
.70877 .56496 .71063 .56711 .72359 .56334 .72174 .56119 Metetra
.645 .763 .934 r
.72174 .56119 .72359 .56334 .73661 .55956 .73478 .5574 Metetra
.645 .763 .934 r
.73478 .5574 .73661 .55956 .74969 .55577 .74787 .55359 Metetra
.645 .763 .934 r
.74787 .55359 .74969 .55577 .76283 .55195 .76102 .54977 Metetra
.645 .763 .934 r
.76102 .54977 .76283 .55195 .77602 .54812 .77423 .54592 Metetra
.645 .763 .934 r
.77423 .54592 .77602 .54812 .78928 .54427 .7875 .54206 Metetra
.645 .763 .934 r
.7875 .54206 .78928 .54427 .80261 .5404 .80084 .53819 Metetra
.645 .763 .934 r
.80084 .53819 .80261 .5404 .81599 .53652 .81424 .53429 Metetra
.645 .763 .934 r
.81424 .53429 .81599 .53652 .82943 .53262 .82769 .53038 Metetra
.645 .763 .934 r
.82769 .53038 .82943 .53262 .84294 .52869 .84122 .52645 Metetra
.645 .763 .934 r
.84122 .52645 .84294 .52869 .85651 .52476 .8548 .5225 Metetra
.645 .763 .934 r
.8548 .5225 .85651 .52476 .87015 .5208 .86845 .51853 Metetra
.645 .763 .934 r
.86845 .51853 .87015 .5208 .88384 .51682 .88216 .51454 Metetra
.645 .763 .934 r
.88216 .51454 .88384 .51682 .89761 .51282 .89594 .51053 Metetra
.284 .682 .972 r
.26838 .50626 .27056 .50747 .28073 .50749 .2785 .50716 Metetra
.884 .894 .833 r
.2785 .50716 .28073 .50749 .29174 .49642 .28962 .49475 Metetra
.119 .526 .914 r
.28962 .49475 .29174 .49642 .30192 .49773 .29967 .49799 Metetra
.864 .967 .863 r
.29967 .49799 .30192 .49773 .31299 .48623 .31072 .48715 Metetra
.891 .986 .8 r
.31072 .48715 .31299 .48623 .32416 .47282 .32192 .47372 Metetra
.946 .939 .751 r
.32192 .47372 .32416 .47282 .33545 .45706 .33337 .45557 Metetra
.609 .785 .965 r
.33337 .45557 .33545 .45706 .34579 .45796 .3439 .45308 Metetra
.253 .333 .752 r
.3439 .45308 .34579 .45796 .35582 .46625 .35393 .46135 Metetra
.216 .309 .745 r
.35393 .46135 .35582 .46625 .36594 .47535 .36403 .47042 Metetra
.666 .576 .745 r
.36403 .47042 .36594 .47535 .37698 .46651 .37493 .46486 Metetra
.297 .633 .964 r
.37493 .46486 .37698 .46651 .38749 .47068 .38554 .4666 Metetra
.901 .534 .076 r
.38554 .4666 .38749 .47068 .39695 .50429 .39499 .50018 Metetra
.706 .627 .766 r
.39499 .50018 .39695 .50429 .40817 .49651 .40619 .49284 Metetra
.716 .65 .782 r
.40619 .49284 .40817 .49651 .41943 .48766 .41741 .4855 Metetra
.6 .715 .925 r
.41741 .4855 .41943 .48766 .43051 .48588 .4285 .48349 Metetra
.872 .747 .723 r
.4285 .48349 .43051 .48588 .4421 .46568 .44011 .46328 Metetra
.876 .747 .716 r
.44011 .46328 .4421 .46568 .45365 .44463 .45168 .44222 Metetra
.86 .748 .739 r
.45168 .44222 .45365 .44463 .46506 .42672 .46311 .42454 Metetra
.795 .335 0 r
.46311 .42454 .46506 .42672 .47587 .44577 .47391 .44359 Metetra
.821 .368 0 r
.47391 .44359 .47587 .44577 .48686 .46654 .4849 .46437 Metetra
.842 .398 0 r
.4849 .46437 .48686 .46654 .49806 .48921 .49608 .48704 Metetra
.898 .764 .705 r
.49608 .48704 .49806 .48921 .50969 .46588 .50774 .4634 Metetra
.841 .408 0 r
.50774 .4634 .50969 .46588 .52119 .49024 .51923 .48817 Metetra
.956 .619 .324 r
.51923 .48817 .52119 .49024 .53304 .56091 .53104 .55887 Metetra
.782 .312 0 r
.53104 .55887 .53304 .56091 .54516 .57959 .54317 .57894 Metetra
.961 .829 .667 r
.54317 .57894 .54516 .57959 .55702 .54913 .55506 .54843 Metetra
.963 .823 .658 r
.55506 .54843 .55702 .54913 .56873 .51746 .5668 .51672 Metetra
.965 .818 .649 r
.5668 .51672 .56873 .51746 .58026 .48455 .57837 .48376 Metetra
.966 .813 .64 r
.57837 .48376 .58026 .48455 .59161 .45038 .58975 .44954 Metetra
0 .53 .838 r
.58975 .44954 .59161 .45038 .60375 .45612 .60183 .45221 Metetra
.885 .515 .04 r
.60183 .45221 .60375 .45612 .61709 .5008 .61515 .49685 Metetra
.899 .532 .07 r
.61515 .49685 .61709 .5008 .63099 .55003 .62902 .54606 Metetra
.784 .404 0 r
.62902 .54606 .63099 .55003 .64479 .58357 .64286 .58146 Metetra
.645 .763 .934 r
.64286 .58146 .64479 .58357 .65747 .57988 .65556 .57776 Metetra
.645 .763 .934 r
.65556 .57776 .65747 .57988 .67021 .57617 .66831 .57405 Metetra
.645 .763 .934 r
.66831 .57405 .67021 .57617 .683 .57245 .68112 .57032 Metetra
.645 .763 .934 r
.68112 .57032 .683 .57245 .69586 .56871 .69398 .56657 Metetra
.645 .763 .934 r
.69398 .56657 .69586 .56871 .70877 .56496 .70691 .56281 Metetra
.645 .763 .934 r
.70691 .56281 .70877 .56496 .72174 .56119 .71989 .55902 Metetra
.645 .763 .934 r
.71989 .55902 .72174 .56119 .73478 .5574 .73294 .55522 Metetra
.645 .763 .934 r
.73294 .55522 .73478 .5574 .74787 .55359 .74604 .55141 Metetra
.645 .763 .934 r
.74604 .55141 .74787 .55359 .76102 .54977 .75921 .54757 Metetra
.645 .763 .934 r
.75921 .54757 .76102 .54977 .77423 .54592 .77243 .54372 Metetra
.645 .763 .934 r
.77243 .54372 .77423 .54592 .7875 .54206 .78572 .53985 Metetra
.645 .763 .934 r
.78572 .53985 .7875 .54206 .80084 .53819 .79907 .53596 Metetra
.645 .763 .934 r
.79907 .53596 .80084 .53819 .81424 .53429 .81248 .53206 Metetra
.645 .763 .934 r
.81248 .53206 .81424 .53429 .82769 .53038 .82595 .52813 Metetra
.645 .763 .934 r
.82595 .52813 .82769 .53038 .84122 .52645 .83949 .52419 Metetra
.645 .763 .934 r
.83949 .52419 .84122 .52645 .8548 .5225 .85308 .52023 Metetra
.645 .763 .934 r
.85308 .52023 .8548 .5225 .86845 .51853 .86675 .51625 Metetra
.645 .763 .934 r
.86675 .51625 .86845 .51853 .88216 .51454 .88047 .51225 Metetra
.645 .763 .934 r
.88047 .51225 .88216 .51454 .89594 .51053 .89427 .50824 Metetra
.483 .626 .915 r
.2663 .50378 .26838 .50626 .2785 .50716 .27644 .50443 Metetra
.807 .712 .76 r
.27644 .50443 .2785 .50716 .28962 .49475 .28762 .4914 Metetra
.465 .545 .854 r
.28762 .4914 .28962 .49475 .29967 .49799 .29776 .49324 Metetra
.74 .617 .722 r
.29776 .49324 .29967 .49799 .31072 .48715 .30885 .48173 Metetra
.743 .603 .702 r
.30885 .48173 .31072 .48715 .32192 .47372 .32005 .4683 Metetra
.755 .609 .697 r
.32005 .4683 .32192 .47372 .33337 .45557 .33133 .4533 Metetra
.434 .625 .933 r
.33133 .4533 .33337 .45557 .3439 .45308 .34166 .45448 Metetra
.692 .242 .179 r
.34166 .45448 .3439 .45308 .35393 .46135 .3517 .46277 Metetra
.706 .262 .194 r
.3517 .46277 .35393 .46135 .36403 .47042 .36181 .47187 Metetra
.488 .861 .638 r
.36181 .47187 .36403 .47042 .37493 .46486 .37284 .46371 Metetra
.138 .603 .924 r
.37284 .46371 .37493 .46486 .38554 .4666 .38346 .46568 Metetra
.919 .548 .3 r
.38346 .46568 .38554 .4666 .39499 .50018 .39289 .49929 Metetra
.767 .89 .932 r
.39289 .49929 .39499 .50018 .40619 .49284 .40409 .49244 Metetra
.815 .94 .909 r
.40409 .49244 .40619 .49284 .41741 .4855 .41537 .48374 Metetra
.601 .759 .955 r
.41537 .48374 .41741 .4855 .4285 .48349 .42648 .48144 Metetra
.883 .765 .727 r
.42648 .48144 .4285 .48349 .44011 .46328 .43811 .46122 Metetra
.887 .764 .72 r
.43811 .46122 .44011 .46328 .45168 .44222 .4497 .44013 Metetra
.869 .768 .749 r
.4497 .44013 .45168 .44222 .46311 .42454 .46113 .42293 Metetra
.833 .368 0 r
.46113 .42293 .46311 .42454 .47391 .44359 .47193 .44199 Metetra
.851 .395 .015 r
.47193 .44199 .47391 .44359 .4849 .46437 .48292 .46278 Metetra
.866 .42 .049 r
.48292 .46278 .4849 .46437 .49608 .48704 .4941 .48547 Metetra
.919 .793 .707 r
.4941 .48547 .49608 .48704 .50774 .4634 .50578 .46144 Metetra
.869 .434 .034 r
.50578 .46144 .50774 .4634 .51923 .48817 .51726 .4866 Metetra
.952 .615 .337 r
.51726 .4866 .51923 .48817 .53104 .55887 .52904 .55736 Metetra
.811 .334 0 r
.52904 .55736 .53104 .55887 .54317 .57894 .54117 .57702 Metetra
.929 .776 .671 r
.54117 .57702 .54317 .57894 .55506 .54843 .55309 .54649 Metetra
.932 .774 .663 r
.55309 .54649 .55506 .54843 .5668 .51672 .56485 .51475 Metetra
.934 .771 .655 r
.56485 .51475 .5668 .51672 .57837 .48376 .57645 .48176 Metetra
.937 .769 .648 r
.57645 .48176 .57837 .48376 .58975 .44954 .58786 .44751 Metetra
.278 .582 .943 r
.58786 .44751 .58975 .44954 .60183 .45221 .59995 .45047 Metetra
.929 .544 .193 r
.59995 .45047 .60183 .45221 .61515 .49685 .61325 .49514 Metetra
.933 .554 .209 r
.61325 .49514 .61515 .49685 .62902 .54606 .62711 .54438 Metetra
.896 .479 .098 r
.62711 .54438 .62902 .54606 .64286 .58146 .64093 .57935 Metetra
.645 .763 .934 r
.64093 .57935 .64286 .58146 .65556 .57776 .65364 .57564 Metetra
.645 .763 .934 r
.65364 .57564 .65556 .57776 .66831 .57405 .6664 .57192 Metetra
.645 .763 .934 r
.6664 .57192 .66831 .57405 .68112 .57032 .67922 .56818 Metetra
.645 .763 .934 r
.67922 .56818 .68112 .57032 .69398 .56657 .6921 .56442 Metetra
.645 .763 .934 r
.6921 .56442 .69398 .56657 .70691 .56281 .70504 .56065 Metetra
.645 .763 .934 r
.70504 .56065 .70691 .56281 .71989 .55902 .71804 .55685 Metetra
.645 .763 .934 r
.71804 .55685 .71989 .55902 .73294 .55522 .7311 .55305 Metetra
.645 .763 .934 r
.7311 .55305 .73294 .55522 .74604 .55141 .74421 .54922 Metetra
.645 .763 .934 r
.74421 .54922 .74604 .55141 .75921 .54757 .75739 .54537 Metetra
.645 .763 .934 r
.75739 .54537 .75921 .54757 .77243 .54372 .77063 .54151 Metetra
.645 .763 .934 r
.77063 .54151 .77243 .54372 .78572 .53985 .78393 .53763 Metetra
.645 .763 .934 r
.78393 .53763 .78572 .53985 .79907 .53596 .79729 .53373 Metetra
.645 .763 .934 r
.79729 .53373 .79907 .53596 .81248 .53206 .81072 .52982 Metetra
.645 .763 .934 r
.81072 .52982 .81248 .53206 .82595 .52813 .8242 .52588 Metetra
.645 .763 .934 r
.8242 .52588 .82595 .52813 .83949 .52419 .83775 .52193 Metetra
.645 .763 .934 r
.83775 .52193 .83949 .52419 .85308 .52023 .85136 .51796 Metetra
.645 .763 .934 r
.85136 .51796 .85308 .52023 .86675 .51625 .86504 .51397 Metetra
.645 .763 .934 r
.86504 .51397 .86675 .51625 .88047 .51225 .87878 .50996 Metetra
.645 .763 .934 r
.87878 .50996 .88047 .51225 .89427 .50824 .89259 .50593 Metetra
.159 .623 .931 r
.2641 .50268 .2663 .50378 .27644 .50443 .27418 .50425 Metetra
.902 .893 .811 r
.27418 .50425 .27644 .50443 .28762 .4914 .28545 .49016 Metetra
0 .401 .784 r
.28545 .49016 .28762 .4914 .29776 .49324 .29546 .49415 Metetra
.811 1 .827 r
.29546 .49415 .29776 .49324 .30885 .48173 .3065 .48362 Metetra
.783 .973 .685 r
.3065 .48362 .30885 .48173 .32005 .4683 .31773 .47015 Metetra
.92 .974 .698 r
.31773 .47015 .32005 .4683 .33133 .4533 .32923 .45186 Metetra
.645 .8 .957 r
.32923 .45186 .33133 .4533 .34166 .45448 .33982 .44862 Metetra
.322 .34 .724 r
.33982 .44862 .34166 .45448 .3517 .46277 .34985 .45688 Metetra
.294 .322 .72 r
.34985 .45688 .3517 .46277 .36181 .47187 .35995 .46595 Metetra
.633 .533 .723 r
.35995 .46595 .36181 .47187 .37284 .46371 .3708 .46174 Metetra
.51 .697 .954 r
.3708 .46174 .37284 .46371 .38346 .46568 .38152 .46134 Metetra
.89 .527 .052 r
.38152 .46134 .38346 .46568 .39289 .49929 .39093 .49491 Metetra
.695 .612 .76 r
.39093 .49491 .39289 .49929 .40409 .49244 .40214 .48797 Metetra
.681 .603 .761 r
.40214 .48797 .40409 .49244 .41537 .48374 .41334 .48183 Metetra
.625 .751 .937 r
.41334 .48183 .41537 .48374 .42648 .48144 .42446 .47908 Metetra
.873 .749 .723 r
.42446 .47908 .42648 .48144 .43811 .46122 .43611 .45884 Metetra
.877 .748 .717 r
.43611 .45884 .43811 .46122 .4497 .44013 .44772 .43774 Metetra
.858 .75 .744 r
.44772 .43774 .4497 .44013 .46113 .42293 .45917 .42058 Metetra
.778 .322 0 r
.45917 .42058 .46113 .42293 .47193 .44199 .46997 .43963 Metetra
.807 .358 0 r
.46997 .43963 .47193 .44199 .48292 .46278 .48094 .46042 Metetra
.831 .39 0 r
.48094 .46042 .48292 .46278 .4941 .48547 .49211 .48311 Metetra
.896 .755 .698 r
.49211 .48311 .4941 .48547 .50578 .46144 .50382 .45848 Metetra
.828 .411 0 r
.50382 .45848 .50578 .46144 .51726 .4866 .51529 .48478 Metetra
.954 .617 .331 r
.51529 .48478 .51726 .4866 .52904 .55736 .52704 .5556 Metetra
.812 .342 0 r
.52704 .5556 .52904 .55736 .54117 .57702 .53916 .57624 Metetra
.958 .823 .668 r
.53916 .57624 .54117 .57702 .55309 .54649 .55111 .54566 Metetra
.96 .818 .659 r
.55111 .54566 .55309 .54649 .56485 .51475 .56291 .51387 Metetra
.962 .813 .65 r
.56291 .51387 .56485 .51475 .57645 .48176 .57454 .48083 Metetra
.963 .808 .641 r
.57454 .48083 .57645 .48176 .58786 .44751 .58598 .44654 Metetra
.316 .736 .975 r
.58598 .44654 .58786 .44751 .59995 .45047 .59802 .44651 Metetra
.883 .514 .037 r
.59802 .44651 .59995 .45047 .61325 .49514 .6113 .49115 Metetra
.897 .531 .067 r
.6113 .49115 .61325 .49514 .62711 .54438 .62513 .54035 Metetra
.799 .421 0 r
.62513 .54035 .62711 .54438 .64093 .57935 .639 .57723 Metetra
.645 .763 .934 r
.639 .57723 .64093 .57935 .65364 .57564 .65172 .57352 Metetra
.645 .763 .934 r
.65172 .57352 .65364 .57564 .6664 .57192 .66449 .56978 Metetra
.645 .763 .934 r
.66449 .56978 .6664 .57192 .67922 .56818 .67733 .56603 Metetra
.645 .763 .934 r
.67733 .56603 .67922 .56818 .6921 .56442 .69022 .56227 Metetra
.645 .763 .934 r
.69022 .56227 .6921 .56442 .70504 .56065 .70317 .55848 Metetra
.645 .763 .934 r
.70317 .55848 .70504 .56065 .71804 .55685 .71618 .55468 Metetra
.645 .763 .934 r
.71618 .55468 .71804 .55685 .7311 .55305 .72925 .55086 Metetra
.645 .763 .934 r
.72925 .55086 .7311 .55305 .74421 .54922 .74238 .54702 Metetra
.645 .763 .934 r
.74238 .54702 .74421 .54922 .75739 .54537 .75557 .54317 Metetra
.645 .763 .934 r
.75557 .54317 .75739 .54537 .77063 .54151 .76882 .5393 Metetra
.645 .763 .934 r
.76882 .5393 .77063 .54151 .78393 .53763 .78214 .53541 Metetra
.645 .763 .934 r
.78214 .53541 .78393 .53763 .79729 .53373 .79551 .5315 Metetra
.645 .763 .934 r
.79551 .5315 .79729 .53373 .81072 .52982 .80895 .52757 Metetra
.645 .763 .934 r
.80895 .52757 .81072 .52982 .8242 .52588 .82245 .52363 Metetra
.645 .763 .934 r
.82245 .52363 .8242 .52588 .83775 .52193 .83601 .51966 Metetra
.645 .763 .934 r
.83601 .51966 .83775 .52193 .85136 .51796 .84964 .51568 Metetra
.645 .763 .934 r
.84964 .51568 .85136 .51796 .86504 .51397 .86333 .51168 Metetra
.645 .763 .934 r
.86333 .51168 .86504 .51397 .87878 .50996 .87709 .50766 Metetra
.645 .763 .934 r
.87709 .50766 .87878 .50996 .89259 .50593 .89091 .50362 Metetra
.493 .611 .898 r
.26203 .49998 .2641 .50268 .27418 .50425 .27217 .50063 Metetra
.781 .668 .738 r
.27217 .50063 .27418 .50425 .28545 .49016 .28338 .48757 Metetra
.411 .582 .91 r
.28338 .48757 .28545 .49016 .29546 .49415 .29353 .48945 Metetra
.74 .619 .724 r
.29353 .48945 .29546 .49415 .3065 .48362 .30464 .47808 Metetra
.741 .6 .7 r
.30464 .47808 .3065 .48362 .31773 .47015 .31587 .46462 Metetra
.755 .607 .694 r
.31587 .46462 .31773 .47015 .32923 .45186 .32719 .44936 Metetra
.477 .623 .914 r
.32719 .44936 .32923 .45186 .33982 .44862 .33756 .45011 Metetra
.69 .243 .187 r
.33756 .45011 .33982 .44862 .34985 .45688 .3476 .4584 Metetra
.704 .263 .201 r
.3476 .4584 .34985 .45688 .35995 .46595 .35771 .46749 Metetra
.432 .822 .596 r
.35771 .46749 .35995 .46595 .3708 .46174 .36875 .45959 Metetra
.366 .61 .944 r
.36875 .45959 .3708 .46174 .38152 .46134 .37938 .46146 Metetra
.9 .537 .342 r
.37938 .46146 .38152 .46134 .39093 .49491 .38878 .49509 Metetra
.709 .978 .913 r
.38878 .49509 .39093 .49491 .40214 .48797 .40001 .48796 Metetra
.777 .976 .915 r
.40001 .48796 .40214 .48797 .41334 .48183 .4113 .47984 Metetra
.619 .74 .933 r
.4113 .47984 .41334 .48183 .42446 .47908 .42242 .47726 Metetra
.891 .778 .73 r
.42242 .47726 .42446 .47908 .43611 .45884 .4341 .457 Metetra
.895 .776 .723 r
.4341 .457 .43611 .45884 .44772 .43774 .44572 .43588 Metetra
.877 .783 .754 r
.44572 .43588 .44772 .43774 .45917 .42058 .45719 .41874 Metetra
.822 .357 0 r
.45719 .41874 .45917 .42058 .46997 .43963 .46798 .4378 Metetra
.842 .386 0 r
.46798 .4378 .46997 .43963 .48094 .46042 .47895 .4586 Metetra
.859 .413 .019 r
.47895 .4586 .48094 .46042 .49211 .48311 .49012 .4813 Metetra
.912 .781 .703 r
.49012 .4813 .49211 .48311 .50382 .45848 .50185 .4569 Metetra
.883 .451 .088 r
.50185 .4569 .50382 .45848 .51529 .48478 .51331 .48268 Metetra
.956 .619 .324 r
.51331 .48268 .51529 .48478 .52704 .5556 .52503 .55353 Metetra
.766 .293 0 r
.52503 .55353 .52704 .5556 .53916 .57624 .53714 .57293 Metetra
.892 .725 .668 r
.53714 .57293 .53916 .57624 .55111 .54566 .54912 .54235 Metetra
.896 .725 .661 r
.54912 .54235 .55111 .54566 .56291 .51387 .56094 .51055 Metetra
.901 .725 .655 r
.56094 .51055 .56291 .51387 .57454 .48083 .57259 .47751 Metetra
.905 .725 .648 r
.57259 .47751 .57454 .48083 .58598 .44654 .58405 .4432 Metetra
.425 .539 .869 r
.58405 .4432 .58598 .44654 .59802 .44651 .59616 .44604 Metetra
.924 .543 .258 r
.59616 .44604 .59802 .44651 .6113 .49115 .60943 .49075 Metetra
.928 .552 .268 r
.60943 .49075 .6113 .49115 .62513 .54035 .62325 .54003 Metetra
.9 .489 .198 r
.62325 .54003 .62513 .54035 .639 .57723 .63706 .57511 Metetra
.645 .763 .934 r
.63706 .57511 .639 .57723 .65172 .57352 .64979 .57139 Metetra
.645 .763 .934 r
.64979 .57139 .65172 .57352 .66449 .56978 .66258 .56764 Metetra
.645 .763 .934 r
.66258 .56764 .66449 .56978 .67733 .56603 .67542 .56388 Metetra
.645 .763 .934 r
.67542 .56388 .67733 .56603 .69022 .56227 .68833 .56011 Metetra
.645 .763 .934 r
.68833 .56011 .69022 .56227 .70317 .55848 .70129 .55631 Metetra
.645 .763 .934 r
.70129 .55631 .70317 .55848 .71618 .55468 .71431 .5525 Metetra
.645 .763 .934 r
.71431 .5525 .71618 .55468 .72925 .55086 .7274 .54867 Metetra
.645 .763 .934 r
.7274 .54867 .72925 .55086 .74238 .54702 .74054 .54482 Metetra
.645 .763 .934 r
.74054 .54482 .74238 .54702 .75557 .54317 .75374 .54096 Metetra
.645 .763 .934 r
.75374 .54096 .75557 .54317 .76882 .5393 .76701 .53708 Metetra
.645 .763 .934 r
.76701 .53708 .76882 .5393 .78214 .53541 .78034 .53318 Metetra
.645 .763 .934 r
.78034 .53318 .78214 .53541 .79551 .5315 .79373 .52926 Metetra
.645 .763 .934 r
.79373 .52926 .79551 .5315 .80895 .52757 .80718 .52532 Metetra
.645 .763 .934 r
.80718 .52532 .80895 .52757 .82245 .52363 .82069 .52136 Metetra
.645 .763 .934 r
.82069 .52136 .82245 .52363 .83601 .51966 .83427 .51739 Metetra
.645 .763 .934 r
.83427 .51739 .83601 .51966 .84964 .51568 .84791 .5134 Metetra
.645 .763 .934 r
.84791 .5134 .84964 .51568 .86333 .51168 .86162 .50939 Metetra
.645 .763 .934 r
.86162 .50939 .86333 .51168 .87709 .50766 .87539 .50535 Metetra
.645 .763 .934 r
.87539 .50535 .87709 .50766 .89091 .50362 .88922 .50131 Metetra
.153 .627 .926 r
.25982 .49895 .26203 .49998 .27217 .50063 .26991 .5004 Metetra
.901 .888 .809 r
.26991 .5004 .27217 .50063 .28338 .48757 .28122 .48623 Metetra
0 .404 .797 r
.28122 .48623 .28338 .48757 .29353 .48945 .29122 .49033 Metetra
.818 .999 .831 r
.29122 .49033 .29353 .48945 .30464 .47808 .3023 .4797 Metetra
.828 .99 .732 r
.3023 .4797 .30464 .47808 .31587 .46462 .31356 .46621 Metetra
.933 .97 .72 r
.31356 .46621 .31587 .46462 .32719 .44936 .32508 .44801 Metetra
.654 .814 .96 r
.32508 .44801 .32719 .44936 .33756 .45011 .33571 .44451 Metetra
.304 .337 .731 r
.33571 .44451 .33756 .45011 .3476 .4584 .34573 .45277 Metetra
.274 .318 .726 r
.34573 .45277 .3476 .4584 .35771 .46749 .35583 .46183 Metetra
.635 .54 .73 r
.35583 .46183 .35771 .46749 .36875 .45959 .36669 .45765 Metetra
.508 .701 .957 r
.36669 .45765 .36875 .45959 .37938 .46146 .37743 .45723 Metetra
.896 .531 .065 r
.37743 .45723 .37938 .46146 .38878 .49509 .38681 .49082 Metetra
.694 .616 .765 r
.38681 .49082 .38878 .49509 .40001 .48796 .39803 .48407 Metetra
.7 .635 .78 r
.39803 .48407 .40001 .48796 .4113 .47984 .40927 .47741 Metetra
.627 .701 .899 r
.40927 .47741 .4113 .47984 .42242 .47726 .4204 .47475 Metetra
.868 .742 .721 r
.4204 .47475 .42242 .47726 .4341 .457 .43209 .45447 Metetra
.873 .742 .715 r
.43209 .45447 .4341 .457 .44572 .43588 .44374 .43334 Metetra
.85 .743 .744 r
.44374 .43334 .44572 .43588 .45719 .41874 .45522 .41654 Metetra
.795 .335 0 r
.45522 .41654 .45719 .41874 .46798 .4378 .466 .43561 Metetra
.821 .369 0 r
.466 .43561 .46798 .4378 .47895 .4586 .47697 .45641 Metetra
.842 .399 0 r
.47697 .45641 .47895 .4586 .49012 .4813 .48813 .47911 Metetra
.901 .763 .7 r
.48813 .47911 .49012 .4813 .50185 .4569 .49988 .45459 Metetra
.861 .431 .003 r
.49988 .45459 .50185 .4569 .51331 .48268 .51133 .48033 Metetra
.957 .62 .317 r
.51133 .48033 .51331 .48268 .52503 .55353 .52301 .5512 Metetra
.773 .313 0 r
.52301 .5512 .52503 .55353 .53714 .57293 .53513 .57212 Metetra
.958 .822 .668 r
.53513 .57212 .53714 .57293 .54912 .54235 .54714 .54149 Metetra
.96 .817 .659 r
.54714 .54149 .54912 .54235 .56094 .51055 .55899 .50965 Metetra
.961 .813 .65 r
.55899 .50965 .56094 .51055 .57259 .47751 .57067 .47656 Metetra
.963 .808 .642 r
.57067 .47656 .57259 .47751 .58405 .4432 .58217 .44221 Metetra
.323 .738 .977 r
.58217 .44221 .58405 .4432 .59616 .44604 .59422 .44215 Metetra
.887 .516 .045 r
.59422 .44215 .59616 .44604 .60943 .49075 .60747 .48682 Metetra
.901 .533 .074 r
.60747 .48682 .60943 .49075 .62325 .54003 .62126 .53607 Metetra
.807 .426 0 r
.62126 .53607 .62325 .54003 .63706 .57511 .63511 .57298 Metetra
.645 .763 .934 r
.63511 .57298 .63706 .57511 .64979 .57139 .64786 .56925 Metetra
.645 .763 .934 r
.64786 .56925 .64979 .57139 .66258 .56764 .66066 .5655 Metetra
.645 .763 .934 r
.66066 .5655 .66258 .56764 .67542 .56388 .67352 .56173 Metetra
.645 .763 .934 r
.67352 .56173 .67542 .56388 .68833 .56011 .68643 .55794 Metetra
.645 .763 .934 r
.68643 .55794 .68833 .56011 .70129 .55631 .69941 .55414 Metetra
.645 .763 .934 r
.69941 .55414 .70129 .55631 .71431 .5525 .71244 .55031 Metetra
.645 .763 .934 r
.71244 .55031 .71431 .5525 .7274 .54867 .72554 .54647 Metetra
.645 .763 .934 r
.72554 .54647 .7274 .54867 .74054 .54482 .7387 .54262 Metetra
.645 .763 .934 r
.7387 .54262 .74054 .54482 .75374 .54096 .75191 .53874 Metetra
.645 .763 .934 r
.75191 .53874 .75374 .54096 .76701 .53708 .76519 .53485 Metetra
.645 .763 .934 r
.76519 .53485 .76701 .53708 .78034 .53318 .77853 .53094 Metetra
.645 .763 .934 r
.77853 .53094 .78034 .53318 .79373 .52926 .79194 .52701 Metetra
.645 .763 .934 r
.79194 .52701 .79373 .52926 .80718 .52532 .8054 .52306 Metetra
.645 .763 .934 r
.8054 .52306 .80718 .52532 .82069 .52136 .81893 .51909 Metetra
.645 .763 .934 r
.81893 .51909 .82069 .52136 .83427 .51739 .83252 .51511 Metetra
.645 .763 .934 r
.83252 .51511 .83427 .51739 .84791 .5134 .84618 .51111 Metetra
.645 .763 .934 r
.84618 .51111 .84791 .5134 .86162 .50939 .8599 .50708 Metetra
.645 .763 .934 r
.8599 .50708 .86162 .50939 .87539 .50535 .87368 .50304 Metetra
.645 .763 .934 r
.87368 .50304 .87539 .50535 .88922 .50131 .88753 .49898 Metetra
.5 .6 .885 r
.25775 .49607 .25982 .49895 .26991 .5004 .2679 .49673 Metetra
.777 .665 .74 r
.2679 .49673 .26991 .5004 .28122 .48623 .27911 .48405 Metetra
.35 .598 .94 r
.27911 .48405 .28122 .48623 .29122 .49033 .28926 .48607 Metetra
.749 .636 .735 r
.28926 .48607 .29122 .49033 .3023 .4797 .30038 .4749 Metetra
.757 .624 .713 r
.30038 .4749 .3023 .4797 .31356 .46621 .31164 .46141 Metetra
.777 .633 .703 r
.31164 .46141 .31356 .46621 .32508 .44801 .32305 .44525 Metetra
.528 .623 .89 r
.32305 .44525 .32508 .44801 .33571 .44451 .33348 .44525 Metetra
.696 .212 .094 r
.33348 .44525 .33571 .44451 .34573 .45277 .34351 .45353 Metetra
.713 .236 .115 r
.34351 .45353 .34573 .45277 .35583 .46183 .35361 .46261 Metetra
.627 .959 .818 r
.35361 .46261 .35583 .46183 .36669 .45765 .36465 .45514 Metetra
.389 .584 .919 r
.36465 .45514 .36669 .45765 .37743 .45723 .37528 .45725 Metetra
.902 .538 .338 r
.37528 .45725 .37743 .45723 .38681 .49082 .38465 .49091 Metetra
.745 .979 .917 r
.38465 .49091 .38681 .49082 .39803 .48407 .39592 .48333 Metetra
.783 .908 .927 r
.39592 .48333 .39803 .48407 .40927 .47741 .4072 .47588 Metetra
.605 .789 .969 r
.4072 .47588 .40927 .47741 .4204 .47475 .41835 .47327 Metetra
.902 .797 .734 r
.41835 .47327 .4204 .47475 .43209 .45447 .43006 .45297 Metetra
.906 .795 .726 r
.43006 .45297 .43209 .45447 .44374 .43334 .44172 .43181 Metetra
.891 .804 .756 r
.44172 .43181 .44374 .43334 .45522 .41654 .45324 .41425 Metetra
.787 .329 0 r
.45324 .41425 .45522 .41654 .466 .43561 .46402 .43332 Metetra
.814 .363 0 r
.46402 .43332 .466 .43561 .47697 .45641 .47498 .45412 Metetra
.837 .394 0 r
.47498 .45412 .47697 .45641 .48813 .47911 .48613 .47683 Metetra
.898 .759 .7 r
.48613 .47683 .48813 .47911 .49988 .45459 .4979 .45236 Metetra
.869 .44 .023 r
.4979 .45236 .49988 .45459 .51133 .48033 .50934 .47849 Metetra
.954 .617 .331 r
.50934 .47849 .51133 .48033 .52301 .5512 .52099 .54942 Metetra
.785 .305 0 r
.52099 .54942 .52301 .5512 .53513 .57212 .5331 .56853 Metetra
.885 .716 .666 r
.5331 .56853 .53513 .57212 .54714 .54149 .54513 .5379 Metetra
.89 .716 .66 r
.54513 .5379 .54714 .54149 .55899 .50965 .557 .50605 Metetra
.894 .716 .654 r
.557 .50605 .55899 .50965 .57067 .47656 .56871 .47296 Metetra
.898 .717 .648 r
.56871 .47296 .57067 .47656 .58217 .44221 .58023 .43861 Metetra
.425 .522 .853 r
.58023 .43861 .58217 .44221 .59422 .44215 .59235 .44174 Metetra
.923 .542 .261 r
.59235 .44174 .59422 .44215 .60747 .48682 .60559 .48649 Metetra
.927 .551 .271 r
.60559 .48649 .60747 .48682 .62126 .53607 .61938 .53583 Metetra
.899 .489 .202 r
.61938 .53583 .62126 .53607 .63511 .57298 .63317 .57085 Metetra
.645 .763 .934 r
.63317 .57085 .63511 .57298 .64786 .56925 .64592 .56711 Metetra
.645 .763 .934 r
.64592 .56711 .64786 .56925 .66066 .5655 .65873 .56334 Metetra
.645 .763 .934 r
.65873 .56334 .66066 .5655 .67352 .56173 .6716 .55956 Metetra
.645 .763 .934 r
.6716 .55956 .67352 .56173 .68643 .55794 .68453 .55577 Metetra
.645 .763 .934 r
.68453 .55577 .68643 .55794 .69941 .55414 .69752 .55195 Metetra
.645 .763 .934 r
.69752 .55195 .69941 .55414 .71244 .55031 .71057 .54812 Metetra
.645 .763 .934 r
.71057 .54812 .71244 .55031 .72554 .54647 .72368 .54427 Metetra
.645 .763 .934 r
.72368 .54427 .72554 .54647 .7387 .54262 .73685 .5404 Metetra
.645 .763 .934 r
.73685 .5404 .7387 .54262 .75191 .53874 .75008 .53652 Metetra
.645 .763 .934 r
.75008 .53652 .75191 .53874 .76519 .53485 .76337 .53262 Metetra
.645 .763 .934 r
.76337 .53262 .76519 .53485 .77853 .53094 .77672 .52869 Metetra
.645 .763 .934 r
.77672 .52869 .77853 .53094 .79194 .52701 .79014 .52476 Metetra
.645 .763 .934 r
.79014 .52476 .79194 .52701 .8054 .52306 .80362 .5208 Metetra
.645 .763 .934 r
.80362 .5208 .8054 .52306 .81893 .51909 .81716 .51682 Metetra
.645 .763 .934 r
.81716 .51682 .81893 .51909 .83252 .51511 .83077 .51282 Metetra
.645 .763 .934 r
.83077 .51282 .83252 .51511 .84618 .51111 .84444 .50881 Metetra
.645 .763 .934 r
.84444 .50881 .84618 .51111 .8599 .50708 .85817 .50478 Metetra
.645 .763 .934 r
.85817 .50478 .8599 .50708 .87368 .50304 .87197 .50073 Metetra
.645 .763 .934 r
.87197 .50073 .87368 .50304 .88753 .49898 .88584 .49665 Metetra
.159 .643 .923 r
.25551 .49515 .25775 .49607 .2679 .49673 .26563 .49629 Metetra
.892 .874 .813 r
.26563 .49629 .2679 .49673 .27911 .48405 .27694 .48254 Metetra
0 .434 .839 r
.27694 .48254 .27911 .48405 .28926 .48607 .28695 .48659 Metetra
.851 .986 .856 r
.28695 .48659 .28926 .48607 .30038 .4749 .29806 .47583 Metetra
.894 .984 .799 r
.29806 .47583 .30038 .4749 .31164 .46141 .30936 .46219 Metetra
.945 .933 .756 r
.30936 .46219 .31164 .46141 .32305 .44525 .32092 .44408 Metetra
.66 .838 .969 r
.32092 .44408 .32305 .44525 .33348 .44525 .33157 .44031 Metetra
.25 .33 .751 r
.33157 .44031 .33348 .44525 .34351 .45353 .34159 .44856 Metetra
.213 .306 .743 r
.34159 .44856 .34351 .45353 .35361 .46261 .35169 .45762 Metetra
.646 .565 .75 r
.35169 .45762 .35361 .46261 .36465 .45514 .36258 .45323 Metetra
.467 .688 .963 r
.36258 .45323 .36465 .45514 .37528 .45725 .3733 .45336 Metetra
.911 .541 .1 r
.3733 .45336 .37528 .45725 .38465 .49091 .38265 .48699 Metetra
.701 .634 .778 r
.38265 .48699 .38465 .49091 .39592 .48333 .39389 .48024 Metetra
.731 .687 .808 r
.39389 .48024 .39592 .48333 .4072 .47588 .40518 .47288 Metetra
.619 .653 .861 r
.40518 .47288 .4072 .47588 .41835 .47327 .41632 .47047 Metetra
.86 .729 .717 r
.41632 .47047 .41835 .47327 .43006 .45297 .42805 .45016 Metetra
.864 .729 .712 r
.42805 .45016 .43006 .45297 .44172 .43181 .43974 .42899 Metetra
.84 .728 .74 r
.43974 .42899 .44172 .43181 .45324 .41425 .45125 .41241 Metetra
.822 .357 0 r
.45125 .41241 .45324 .41425 .46402 .43332 .46202 .43148 Metetra
.842 .387 0 r
.46202 .43148 .46402 .43332 .47498 .45412 .47297 .4523 Metetra
.859 .413 .02 r
.47297 .4523 .47498 .45412 .48613 .47683 .48412 .47501 Metetra
.912 .782 .705 r
.48412 .47501 .48613 .47683 .4979 .45236 .49592 .45079 Metetra
.877 .44 .075 r
.49592 .45079 .4979 .45236 .50934 .47849 .50736 .47567 Metetra
.959 .622 .305 r
.50736 .47567 .50934 .47849 .52099 .54942 .51897 .5466 Metetra
.72 .278 0 r
.51897 .5466 .52099 .54942 .5331 .56853 .53108 .56758 Metetra
.954 .817 .669 r
.53108 .56758 .5331 .56853 .54513 .5379 .54313 .5369 Metetra
.956 .812 .66 r
.54313 .5369 .54513 .5379 .557 .50605 .55504 .50501 Metetra
.958 .807 .651 r
.55504 .50501 .557 .50605 .56871 .47296 .56677 .47188 Metetra
.96 .803 .643 r
.56677 .47188 .56871 .47296 .58023 .43861 .57833 .43748 Metetra
.286 .702 .972 r
.57833 .43748 .58023 .43861 .59235 .44174 .59041 .43812 Metetra
.898 .523 .067 r
.59041 .43812 .59235 .44174 .60559 .48649 .60363 .48284 Metetra
.909 .539 .095 r
.60363 .48284 .60559 .48649 .61938 .53583 .61739 .53215 Metetra
.825 .436 0 r
.61739 .53215 .61938 .53583 .63317 .57085 .63121 .56871 Metetra
.645 .763 .934 r
.63121 .56871 .63317 .57085 .64592 .56711 .64398 .56496 Metetra
.645 .763 .934 r
.64398 .56496 .64592 .56711 .65873 .56334 .6568 .56119 Metetra
.645 .763 .934 r
.6568 .56119 .65873 .56334 .6716 .55956 .66968 .5574 Metetra
.645 .763 .934 r
.66968 .5574 .6716 .55956 .68453 .55577 .68263 .55359 Metetra
.645 .763 .934 r
.68263 .55359 .68453 .55577 .69752 .55195 .69563 .54977 Metetra
.645 .763 .934 r
.69563 .54977 .69752 .55195 .71057 .54812 .70869 .54592 Metetra
.645 .763 .934 r
.70869 .54592 .71057 .54812 .72368 .54427 .72181 .54206 Metetra
.645 .763 .934 r
.72181 .54206 .72368 .54427 .73685 .5404 .73499 .53819 Metetra
.645 .763 .934 r
.73499 .53819 .73685 .5404 .75008 .53652 .74824 .53429 Metetra
.645 .763 .934 r
.74824 .53429 .75008 .53652 .76337 .53262 .76154 .53038 Metetra
.645 .763 .934 r
.76154 .53038 .76337 .53262 .77672 .52869 .77491 .52645 Metetra
.645 .763 .934 r
.77491 .52645 .77672 .52869 .79014 .52476 .78834 .5225 Metetra
.645 .763 .934 r
.78834 .5225 .79014 .52476 .80362 .5208 .80183 .51853 Metetra
.645 .763 .934 r
.80183 .51853 .80362 .5208 .81716 .51682 .81539 .51454 Metetra
.645 .763 .934 r
.81539 .51454 .81716 .51682 .83077 .51282 .82901 .51053 Metetra
.645 .763 .934 r
.82901 .51053 .83077 .51282 .84444 .50881 .84269 .50651 Metetra
.645 .763 .934 r
.84269 .50651 .84444 .50881 .85817 .50478 .85644 .50246 Metetra
.645 .763 .934 r
.85644 .50246 .85817 .50478 .87197 .50073 .87026 .4984 Metetra
.645 .763 .934 r
.87026 .4984 .87197 .50073 .88584 .49665 .88414 .49432 Metetra
.454 .561 .874 r
.25345 .49205 .25551 .49515 .26563 .49629 .26353 .49375 Metetra
.823 .725 .757 r
.26353 .49375 .26563 .49629 .27694 .48254 .27489 .47953 Metetra
.346 .512 .879 r
.27489 .47953 .27694 .48254 .28695 .48659 .28494 .48288 Metetra
.763 .66 .749 r
.28494 .48288 .28695 .48659 .29806 .47583 .2961 .47163 Metetra
.771 .647 .725 r
.2961 .47163 .29806 .47583 .30936 .46219 .30739 .45811 Metetra
.8 .661 .71 r
.30739 .45811 .30936 .46219 .32092 .44408 .3189 .44103 Metetra
.559 .615 .865 r
.3189 .44103 .32092 .44408 .33157 .44031 .32937 .44044 Metetra
.691 .171 0 r
.32937 .44044 .33157 .44031 .34159 .44856 .33939 .4487 Metetra
.712 .202 .015 r
.33939 .4487 .34159 .44856 .35169 .45762 .3495 .45778 Metetra
.643 .96 .923 r
.3495 .45778 .35169 .45762 .36258 .45323 .36048 .45191 Metetra
.406 .734 .991 r
.36048 .45191 .36258 .45323 .3733 .45336 .37121 .45183 Metetra
.927 .552 .27 r
.37121 .45183 .3733 .45336 .38265 .48699 .38055 .48548 Metetra
.743 .82 .912 r
.38055 .48548 .38265 .48699 .39389 .48024 .39178 .47932 Metetra
.797 .888 .91 r
.39178 .47932 .39389 .48024 .40518 .47288 .4031 .47132 Metetra
.569 .776 .976 r
.4031 .47132 .40518 .47288 .41632 .47047 .41424 .46935 Metetra
.915 .819 .738 r
.41424 .46935 .41632 .47047 .42805 .45016 .426 .44902 Metetra
.918 .816 .73 r
.426 .44902 .42805 .45016 .43974 .42899 .4377 .42782 Metetra
.907 .826 .756 r
.4377 .42782 .43974 .42899 .45125 .41241 .44927 .40966 Metetra
.735 .292 0 r
.44927 .40966 .45125 .41241 .46202 .43148 .46004 .42872 Metetra
.771 .333 0 r
.46004 .42872 .46202 .43148 .47297 .4523 .47098 .44953 Metetra
.802 .369 0 r
.47098 .44953 .47297 .4523 .48412 .47501 .48212 .47224 Metetra
.881 .739 .701 r
.48212 .47224 .48412 .47501 .49592 .45079 .49393 .44859 Metetra
.858 .422 0 r
.49393 .44859 .49592 .45079 .50736 .47567 .50536 .47343 Metetra
.957 .619 .321 r
.50536 .47343 .50736 .47567 .51897 .5466 .51694 .54439 Metetra
.793 .333 0 r
.51694 .54439 .51897 .5466 .53108 .56758 .52904 .56574 Metetra
.931 .78 .671 r
.52904 .56574 .53108 .56758 .54313 .5369 .54113 .53503 Metetra
.934 .778 .663 r
.54113 .53503 .54313 .5369 .55504 .50501 .55306 .50311 Metetra
.937 .775 .655 r
.55306 .50311 .55504 .50501 .56677 .47188 .56482 .46994 Metetra
.94 .772 .647 r
.56482 .46994 .56677 .47188 .57833 .43748 .57641 .43551 Metetra
.447 .685 .967 r
.57641 .43551 .57833 .43748 .59041 .43812 .58849 .43589 Metetra
.926 .542 .165 r
.58849 .43589 .59041 .43812 .60363 .48284 .6017 .48063 Metetra
.931 .553 .184 r
.6017 .48063 .60363 .48284 .61739 .53215 .61544 .52996 Metetra
.893 .482 .072 r
.61544 .52996 .61739 .53215 .63121 .56871 .62925 .56657 Metetra
.645 .763 .934 r
.62925 .56657 .63121 .56871 .64398 .56496 .64203 .56281 Metetra
.645 .763 .934 r
.64203 .56281 .64398 .56496 .6568 .56119 .65487 .55902 Metetra
.645 .763 .934 r
.65487 .55902 .6568 .56119 .66968 .5574 .66776 .55522 Metetra
.645 .763 .934 r
.66776 .55522 .66968 .5574 .68263 .55359 .68072 .55141 Metetra
.645 .763 .934 r
.68072 .55141 .68263 .55359 .69563 .54977 .69373 .54757 Metetra
.645 .763 .934 r
.69373 .54757 .69563 .54977 .70869 .54592 .70681 .54372 Metetra
.645 .763 .934 r
.70681 .54372 .70869 .54592 .72181 .54206 .71994 .53985 Metetra
.645 .763 .934 r
.71994 .53985 .72181 .54206 .73499 .53819 .73314 .53596 Metetra
.645 .763 .934 r
.73314 .53596 .73499 .53819 .74824 .53429 .74639 .53206 Metetra
.645 .763 .934 r
.74639 .53206 .74824 .53429 .76154 .53038 .75971 .52813 Metetra
.645 .763 .934 r
.75971 .52813 .76154 .53038 .77491 .52645 .77309 .52419 Metetra
.645 .763 .934 r
.77309 .52419 .77491 .52645 .78834 .5225 .78654 .52023 Metetra
.645 .763 .934 r
.78654 .52023 .78834 .5225 .80183 .51853 .80004 .51625 Metetra
.645 .763 .934 r
.80004 .51625 .80183 .51853 .81539 .51454 .81361 .51225 Metetra
.645 .763 .934 r
.81361 .51225 .81539 .51454 .82901 .51053 .82725 .50824 Metetra
.645 .763 .934 r
.82725 .50824 .82901 .51053 .84269 .50651 .84095 .5042 Metetra
.645 .763 .934 r
.84095 .5042 .84269 .50651 .85644 .50246 .85471 .50014 Metetra
.645 .763 .934 r
.85471 .50014 .85644 .50246 .87026 .4984 .86854 .49607 Metetra
.645 .763 .934 r
.86854 .49607 .87026 .4984 .88414 .49432 .88243 .49198 Metetra
.113 .604 .908 r
.25121 .49104 .25345 .49205 .26353 .49375 .2613 .49269 Metetra
.877 .821 .789 r
.2613 .49269 .26353 .49375 .27489 .47953 .27271 .47804 Metetra
0 .385 .798 r
.27271 .47804 .27489 .47953 .28494 .48288 .28268 .48254 Metetra
.865 .911 .861 r
.28268 .48254 .28494 .48288 .2961 .47163 .29383 .4716 Metetra
.901 .918 .822 r
.29383 .4716 .2961 .47163 .30739 .45811 .30516 .45806 Metetra
.93 .878 .762 r
.30516 .45806 .30739 .45811 .3189 .44103 .31675 .43985 Metetra
.642 .834 .974 r
.31675 .43985 .3189 .44103 .32937 .44044 .3274 .43642 Metetra
.137 .309 .775 r
.3274 .43642 .32937 .44044 .33939 .4487 .33742 .44467 Metetra
.086 .276 .76 r
.33742 .44467 .33939 .4487 .3495 .45778 .34752 .45373 Metetra
.65 .603 .788 r
.34752 .45373 .3495 .45778 .36048 .45191 .35841 .44972 Metetra
.551 .693 .933 r
.35841 .44972 .36048 .45191 .37121 .45183 .36919 .44875 Metetra
.93 .553 .17 r
.36919 .44875 .37121 .45183 .38055 .48548 .37851 .48238 Metetra
.705 .678 .822 r
.37851 .48238 .38055 .48548 .39178 .47932 .38974 .47645 Metetra
.745 .705 .814 r
.38974 .47645 .39178 .47932 .4031 .47132 .40107 .46859 Metetra
.608 .669 .883 r
.40107 .46859 .4031 .47132 .41424 .46935 .41222 .46647 Metetra
.858 .726 .716 r
.41222 .46647 .41424 .46935 .426 .44902 .42399 .44612 Metetra
.862 .726 .711 r
.42399 .44612 .426 .44902 .4377 .42782 .43571 .42492 Metetra
.839 .724 .737 r
.43571 .42492 .4377 .42782 .44927 .40966 .44726 .40801 Metetra
.833 .367 0 r
.44726 .40801 .44927 .40966 .46004 .42872 .45803 .42709 Metetra
.85 .395 .013 r
.45803 .42709 .46004 .42872 .47098 .44953 .46897 .44791 Metetra
.865 .419 .048 r
.46897 .44791 .47098 .44953 .48212 .47224 .4801 .47064 Metetra
.917 .794 .709 r
.4801 .47064 .48212 .47224 .49393 .44859 .49194 .44678 Metetra
.867 .426 .037 r
.49194 .44678 .49393 .44859 .50536 .47343 .50337 .47107 Metetra
.957 .62 .318 r
.50337 .47107 .50536 .47343 .51694 .54439 .51491 .54205 Metetra
.796 .342 0 r
.51491 .54205 .51694 .54439 .52904 .56574 .527 .56414 Metetra
.938 .79 .671 r
.527 .56414 .52904 .56574 .54113 .53503 .53912 .5334 Metetra
.94 .787 .663 r
.53912 .5334 .54113 .53503 .55306 .50311 .55108 .50144 Metetra
.943 .784 .654 r
.55108 .50144 .55306 .50311 .56482 .46994 .56287 .46824 Metetra
.945 .781 .646 r
.56287 .46824 .56482 .46994 .57641 .43551 .57449 .43378 Metetra
.495 .736 .98 r
.57449 .43378 .57641 .43551 .58849 .43589 .58656 .43302 Metetra
.918 .536 .124 r
.58656 .43302 .58849 .43589 .6017 .48063 .59974 .47776 Metetra
.925 .549 .146 r
.59974 .47776 .6017 .48063 .61544 .52996 .61347 .52709 Metetra
.875 .472 .02 r
.61347 .52709 .61544 .52996 .62925 .56657 .62729 .56442 Metetra
.645 .763 .934 r
.62729 .56442 .62925 .56657 .64203 .56281 .64008 .56065 Metetra
.645 .763 .934 r
.64008 .56065 .64203 .56281 .65487 .55902 .65293 .55685 Metetra
.645 .763 .934 r
.65293 .55685 .65487 .55902 .66776 .55522 .66583 .55305 Metetra
.645 .763 .934 r
.66583 .55305 .66776 .55522 .68072 .55141 .6788 .54922 Metetra
.645 .763 .934 r
.6788 .54922 .68072 .55141 .69373 .54757 .69183 .54537 Metetra
.645 .763 .934 r
.69183 .54537 .69373 .54757 .70681 .54372 .70492 .54151 Metetra
.645 .763 .934 r
.70492 .54151 .70681 .54372 .71994 .53985 .71806 .53763 Metetra
.645 .763 .934 r
.71806 .53763 .71994 .53985 .73314 .53596 .73127 .53373 Metetra
.645 .763 .934 r
.73127 .53373 .73314 .53596 .74639 .53206 .74454 .52982 Metetra
.645 .763 .934 r
.74454 .52982 .74639 .53206 .75971 .52813 .75788 .52588 Metetra
.645 .763 .934 r
.75788 .52588 .75971 .52813 .77309 .52419 .77127 .52193 Metetra
.645 .763 .934 r
.77127 .52193 .77309 .52419 .78654 .52023 .78473 .51796 Metetra
.645 .763 .934 r
.78473 .51796 .78654 .52023 .80004 .51625 .79825 .51397 Metetra
.645 .763 .934 r
.79825 .51397 .80004 .51625 .81361 .51225 .81183 .50996 Metetra
.645 .763 .934 r
.81183 .50996 .81361 .51225 .82725 .50824 .82548 .50593 Metetra
.645 .763 .934 r
.82548 .50593 .82725 .50824 .84095 .5042 .83919 .50188 Metetra
.645 .763 .934 r
.83919 .50188 .84095 .5042 .85471 .50014 .85297 .49782 Metetra
.645 .763 .934 r
.85297 .49782 .85471 .50014 .86854 .49607 .86681 .49373 Metetra
.645 .763 .934 r
.86681 .49373 .86854 .49607 .88243 .49198 .88072 .48963 Metetra
.328 .498 .874 r
.24914 .48797 .25121 .49104 .2613 .49269 .25907 .49159 Metetra
.89 .805 .759 r
.25907 .49159 .2613 .49269 .27271 .47804 .27071 .47411 Metetra
.295 .414 .813 r
.27071 .47411 .27271 .47804 .28268 .48254 .28061 .47959 Metetra
.786 .702 .771 r
.28061 .47959 .28268 .48254 .29383 .4716 .2918 .46829 Metetra
.795 .687 .745 r
.2918 .46829 .29383 .4716 .30516 .45806 .30313 .45473 Metetra
.825 .693 .718 r
.30313 .45473 .30516 .45806 .31675 .43985 .31472 .43675 Metetra
.578 .62 .858 r
.31472 .43675 .31675 .43985 .3274 .43642 .32523 .43566 Metetra
.639 .078 0 r
.32523 .43566 .3274 .43642 .33742 .44467 .33526 .44392 Metetra
.673 .123 0 r
.33526 .44392 .33742 .44467 .34752 .45373 .34536 .45298 Metetra
.585 .874 .994 r
.34536 .45298 .34752 .45373 .35841 .44972 .35622 .44977 Metetra
.543 .921 .928 r
.35622 .44977 .35841 .44972 .36919 .44875 .36719 .44531 Metetra
.924 .549 .143 r
.36719 .44531 .36919 .44875 .37851 .48238 .37648 .47893 Metetra
.649 .636 .823 r
.37648 .47893 .37851 .48238 .38974 .47645 .38762 .47526 Metetra
.802 .858 .891 r
.38762 .47526 .38974 .47645 .40107 .46859 .39899 .46684 Metetra
.545 .746 .969 r
.39899 .46684 .40107 .46859 .41222 .46647 .41012 .46547 Metetra
.919 .826 .739 r
.41012 .46547 .41222 .46647 .42399 .44612 .42191 .44509 Metetra
.922 .823 .73 r
.42191 .44509 .42399 .44612 .43571 .42492 .43366 .42386 Metetra
.914 .832 .751 r
.43366 .42386 .43571 .42492 .44726 .40801 .44528 .40501 Metetra
.699 .27 0 r
.44528 .40501 .44726 .40801 .45803 .42709 .45604 .42407 Metetra
.741 .313 0 r
.45604 .42407 .45803 .42709 .46897 .44791 .46697 .44489 Metetra
.777 .352 0 r
.46697 .44489 .46897 .44791 .4801 .47064 .47809 .4676 Metetra
.87 .728 .702 r
.47809 .4676 .4801 .47064 .49194 .44678 .48994 .4447 Metetra
.852 .409 0 r
.48994 .4447 .49194 .44678 .50337 .47107 .50136 .46843 Metetra
.958 .621 .31 r
.50136 .46843 .50337 .47107 .51491 .54205 .51287 .53942 Metetra
.82 .384 0 r
.51287 .53942 .51491 .54205 .527 .56414 .52496 .5644 Metetra
.979 .867 .655 r
.52496 .5644 .527 .56414 .53912 .5334 .53711 .5336 Metetra
.981 .86 .646 r
.53711 .5336 .53912 .5334 .55108 .50144 .54911 .50158 Metetra
.982 .853 .637 r
.54911 .50158 .55108 .50144 .56287 .46824 .56094 .46831 Metetra
.983 .846 .628 r
.56094 .46831 .56287 .46824 .57449 .43378 .57258 .43378 Metetra
.534 .921 .906 r
.57258 .43378 .57449 .43378 .58656 .43302 .5846 .42863 Metetra
.867 .505 .009 r
.5846 .42863 .58656 .43302 .59974 .47776 .59775 .47332 Metetra
.884 .524 .041 r
.59775 .47332 .59974 .47776 .61347 .52709 .61145 .5226 Metetra
.8 .434 0 r
.61145 .5226 .61347 .52709 .62729 .56442 .62532 .56227 Metetra
.645 .763 .934 r
.62532 .56227 .62729 .56442 .64008 .56065 .63812 .55848 Metetra
.645 .763 .934 r
.63812 .55848 .64008 .56065 .65293 .55685 .65098 .55468 Metetra
.645 .763 .934 r
.65098 .55468 .65293 .55685 .66583 .55305 .6639 .55086 Metetra
.645 .763 .934 r
.6639 .55086 .66583 .55305 .6788 .54922 .67688 .54702 Metetra
.645 .763 .934 r
.67688 .54702 .6788 .54922 .69183 .54537 .68992 .54317 Metetra
.645 .763 .934 r
.68992 .54317 .69183 .54537 .70492 .54151 .70302 .5393 Metetra
.645 .763 .934 r
.70302 .5393 .70492 .54151 .71806 .53763 .71618 .53541 Metetra
.645 .763 .934 r
.71618 .53541 .71806 .53763 .73127 .53373 .7294 .5315 Metetra
.645 .763 .934 r
.7294 .5315 .73127 .53373 .74454 .52982 .74269 .52757 Metetra
.645 .763 .934 r
.74269 .52757 .74454 .52982 .75788 .52588 .75603 .52363 Metetra
.645 .763 .934 r
.75603 .52363 .75788 .52588 .77127 .52193 .76944 .51966 Metetra
.645 .763 .934 r
.76944 .51966 .77127 .52193 .78473 .51796 .78291 .51568 Metetra
.645 .763 .934 r
.78291 .51568 .78473 .51796 .79825 .51397 .79645 .51168 Metetra
.645 .763 .934 r
.79645 .51168 .79825 .51397 .81183 .50996 .81005 .50766 Metetra
.645 .763 .934 r
.81005 .50766 .81183 .50996 .82548 .50593 .82371 .50362 Metetra
.645 .763 .934 r
.82371 .50362 .82548 .50593 .83919 .50188 .83743 .49956 Metetra
.645 .763 .934 r
.83743 .49956 .83919 .50188 .85297 .49782 .85123 .49549 Metetra
.645 .763 .934 r
.85123 .49549 .85297 .49782 .86681 .49373 .86508 .49139 Metetra
.645 .763 .934 r
.86508 .49139 .86681 .49373 .88072 .48963 .87901 .48727 Metetra
0 .516 .84 r
.24689 .48697 .24914 .48797 .25907 .49159 .25692 .48944 Metetra
.849 .747 .75 r
.25692 .48944 .25907 .49159 .27071 .47411 .26848 .47315 Metetra
.382 0 0 r
.26848 .47315 .27071 .47411 .28061 .47959 .27841 .4783 Metetra
.838 .821 .832 r
.27841 .4783 .28061 .47959 .2918 .46829 .28959 .46735 Metetra
.876 .841 .807 r
.28959 .46735 .2918 .46829 .30313 .45473 .30094 .45377 Metetra
.902 .818 .756 r
.30094 .45377 .30313 .45473 .31472 .43675 .31256 .43566 Metetra
.618 .84 .985 r
.31256 .43566 .31472 .43675 .32523 .43566 .32321 .43254 Metetra
0 .261 .77 r
.32321 .43254 .32523 .43566 .33526 .44392 .33323 .44078 Metetra
0 .215 .739 r
.33323 .44078 .33526 .44392 .34536 .45298 .34333 .44984 Metetra
.642 .648 .841 r
.34333 .44984 .34536 .45298 .35622 .44977 .35419 .44664 Metetra
.636 .648 .845 r
.35419 .44664 .35622 .44977 .36719 .44531 .36509 .44367 Metetra
.928 .552 .265 r
.36509 .44367 .36719 .44531 .37648 .47893 .37437 .47731 Metetra
.707 .805 .926 r
.37437 .47731 .37648 .47893 .38762 .47526 .38557 .4723 Metetra
.74 .699 .812 r
.38557 .4723 .38762 .47526 .39899 .46684 .39692 .46459 Metetra
.606 .712 .92 r
.39692 .46459 .39899 .46684 .41012 .46547 .40809 .46237 Metetra
.852 .717 .714 r
.40809 .46237 .41012 .46547 .42191 .44509 .4199 .44199 Metetra
.856 .717 .708 r
.4199 .44199 .42191 .44509 .43366 .42386 .43167 .42075 Metetra
.834 .715 .732 r
.43167 .42075 .43366 .42386 .44528 .40501 .44326 .40368 Metetra
.843 .379 .024 r
.44326 .40368 .44528 .40501 .45604 .42407 .45401 .42276 Metetra
.858 .404 .057 r
.45401 .42276 .45604 .42407 .46697 .44489 .46494 .44359 Metetra
.871 .427 .086 r
.46494 .44359 .46697 .44489 .47809 .4676 .47606 .46633 Metetra
.928 .811 .71 r
.47606 .46633 .47809 .4676 .48994 .4447 .48794 .44232 Metetra
.847 .412 0 r
.48794 .44232 .48994 .4447 .50136 .46843 .49935 .46693 Metetra
.951 .615 .339 r
.49935 .46693 .50136 .46843 .51287 .53942 .51082 .538 Metetra
.856 .402 .036 r
.51082 .538 .51287 .53942 .52496 .5644 .52291 .56129 Metetra
.898 .733 .668 r
.52291 .56129 .52496 .5644 .53711 .5336 .53508 .53047 Metetra
.902 .733 .662 r
.53508 .53047 .53711 .5336 .54911 .50158 .5471 .49844 Metetra
.906 .732 .655 r
.5471 .49844 .54911 .50158 .56094 .46831 .55896 .46516 Metetra
.91 .732 .648 r
.55896 .46516 .56094 .46831 .57258 .43378 .57063 .43062 Metetra
.637 .661 .857 r
.57063 .43062 .57258 .43378 .5846 .42863 .58268 .42735 Metetra
.928 .544 .219 r
.58268 .42735 .5846 .42863 .59775 .47332 .59583 .47208 Metetra
.932 .554 .232 r
.59583 .47208 .59775 .47332 .61145 .5226 .60951 .52142 Metetra
.911 .505 .167 r
.60951 .52142 .61145 .5226 .62532 .56227 .62334 .56011 Metetra
.645 .763 .934 r
.62334 .56011 .62532 .56227 .63812 .55848 .63616 .55631 Metetra
.645 .763 .934 r
.63616 .55631 .63812 .55848 .65098 .55468 .64903 .5525 Metetra
.645 .763 .934 r
.64903 .5525 .65098 .55468 .6639 .55086 .66196 .54867 Metetra
.645 .763 .934 r
.66196 .54867 .6639 .55086 .67688 .54702 .67496 .54482 Metetra
.645 .763 .934 r
.67496 .54482 .67688 .54702 .68992 .54317 .68801 .54096 Metetra
.645 .763 .934 r
.68801 .54096 .68992 .54317 .70302 .5393 .70112 .53708 Metetra
.645 .763 .934 r
.70112 .53708 .70302 .5393 .71618 .53541 .7143 .53318 Metetra
.645 .763 .934 r
.7143 .53318 .71618 .53541 .7294 .5315 .72753 .52926 Metetra
.645 .763 .934 r
.72753 .52926 .7294 .5315 .74269 .52757 .74083 .52532 Metetra
.645 .763 .934 r
.74083 .52532 .74269 .52757 .75603 .52363 .75419 .52136 Metetra
.645 .763 .934 r
.75419 .52136 .75603 .52363 .76944 .51966 .76761 .51739 Metetra
.645 .763 .934 r
.76761 .51739 .76944 .51966 .78291 .51568 .78109 .5134 Metetra
.645 .763 .934 r
.78109 .5134 .78291 .51568 .79645 .51168 .79464 .50939 Metetra
.645 .763 .934 r
.79464 .50939 .79645 .51168 .81005 .50766 .80825 .50535 Metetra
.645 .763 .934 r
.80825 .50535 .81005 .50766 .82371 .50362 .82193 .50131 Metetra
.645 .763 .934 r
.82193 .50131 .82371 .50362 .83743 .49956 .83567 .49724 Metetra
.645 .763 .934 r
.83567 .49724 .83743 .49956 .85123 .49549 .84948 .49315 Metetra
.645 .763 .934 r
.84948 .49315 .85123 .49549 .86508 .49139 .86335 .48904 Metetra
.645 .763 .934 r
.86335 .48904 .86508 .49139 .87901 .48727 .87729 .48491 Metetra
.23 .456 .871 r
.24479 .48405 .24689 .48697 .25692 .48944 .25465 .48861 Metetra
.906 .815 .747 r
.25465 .48861 .25692 .48944 .26848 .47315 .26648 .46929 Metetra
.233 .381 .808 r
.26648 .46929 .26848 .47315 .27841 .4783 .27631 .47557 Metetra
.79 .714 .781 r
.27631 .47557 .27841 .4783 .28959 .46735 .28751 .46455 Metetra
.812 .714 .758 r
.28751 .46455 .28959 .46735 .30094 .45377 .29887 .45097 Metetra
.842 .717 .725 r
.29887 .45097 .30094 .45377 .31256 .43566 .31052 .43267 Metetra
.589 .634 .864 r
.31052 .43267 .31256 .43566 .32321 .43254 .32106 .43124 Metetra
.557 0 0 r
.32106 .43124 .32321 .43254 .33323 .44078 .33109 .43949 Metetra
.605 .051 0 r
.33109 .43949 .33323 .44078 .34333 .44984 .34119 .44855 Metetra
.543 .796 .992 r
.34119 .44855 .34333 .44984 .35419 .44664 .35199 .44671 Metetra
.714 .973 .927 r
.35199 .44671 .35419 .44664 .36509 .44367 .36309 .43989 Metetra
.916 .544 .114 r
.36309 .43989 .36509 .44367 .37437 .47731 .37235 .4735 Metetra
.633 .61 .809 r
.37235 .4735 .37437 .47731 .38557 .4723 .38348 .47036 Metetra
.757 .781 .873 r
.38348 .47036 .38557 .4723 .39692 .46459 .39481 .46324 Metetra
.55 .797 .99 r
.39481 .46324 .39692 .46459 .40809 .46237 .40598 .46126 Metetra
.915 .821 .738 r
.40598 .46126 .40809 .46237 .4199 .44199 .41782 .44085 Metetra
.919 .817 .73 r
.41782 .44085 .4199 .44199 .43167 .42075 .42961 .41958 Metetra
.91 .825 .75 r
.42961 .41958 .43167 .42075 .44326 .40368 .44127 .40067 Metetra
.702 .272 0 r
.44127 .40067 .44326 .40368 .45401 .42276 .45201 .41975 Metetra
.744 .315 0 r
.45201 .41975 .45401 .42276 .46494 .44359 .46293 .44057 Metetra
.78 .354 0 r
.46293 .44057 .46494 .44359 .47606 .46633 .47404 .46329 Metetra
.874 .728 .698 r
.47404 .46329 .47606 .46633 .48794 .44232 .48594 .4396 Metetra
.835 .408 0 r
.48594 .4396 .48794 .44232 .49935 .46693 .49734 .46488 Metetra
.955 .618 .326 r
.49734 .46488 .49935 .46693 .51082 .538 .50877 .53599 Metetra
.861 .421 .015 r
.50877 .53599 .51082 .538 .52291 .56129 .52085 .56176 Metetra
.982 .875 .651 r
.52085 .56176 .52291 .56129 .53508 .53047 .53306 .53088 Metetra
.984 .868 .642 r
.53306 .53088 .53508 .53047 .5471 .49844 .54512 .49878 Metetra
.985 .86 .633 r
.54512 .49878 .5471 .49844 .55896 .46516 .55701 .46543 Metetra
.986 .853 .624 r
.55701 .46543 .55896 .46516 .57063 .43062 .56872 .43082 Metetra
.697 .982 .878 r
.56872 .43082 .57063 .43062 .58268 .42735 .58071 .42268 Metetra
.853 .496 0 r
.58071 .42268 .58268 .42735 .59583 .47208 .59383 .46735 Metetra
.873 .517 .021 r
.59383 .46735 .59583 .47208 .60951 .52142 .60748 .51662 Metetra
.796 .439 0 r
.60748 .51662 .60951 .52142 .62334 .56011 .62136 .55794 Metetra
.645 .763 .934 r
.62136 .55794 .62334 .56011 .63616 .55631 .63419 .55414 Metetra
.645 .763 .934 r
.63419 .55414 .63616 .55631 .64903 .5525 .64708 .55031 Metetra
.645 .763 .934 r
.64708 .55031 .64903 .5525 .66196 .54867 .66002 .54647 Metetra
.645 .763 .934 r
.66002 .54647 .66196 .54867 .67496 .54482 .67303 .54262 Metetra
.645 .763 .934 r
.67303 .54262 .67496 .54482 .68801 .54096 .68609 .53874 Metetra
.645 .763 .934 r
.68609 .53874 .68801 .54096 .70112 .53708 .69922 .53485 Metetra
.645 .763 .934 r
.69922 .53485 .70112 .53708 .7143 .53318 .7124 .53094 Metetra
.645 .763 .934 r
.7124 .53094 .7143 .53318 .72753 .52926 .72565 .52701 Metetra
.645 .763 .934 r
.72565 .52701 .72753 .52926 .74083 .52532 .73896 .52306 Metetra
.645 .763 .934 r
.73896 .52306 .74083 .52532 .75419 .52136 .75234 .51909 Metetra
.645 .763 .934 r
.75234 .51909 .75419 .52136 .76761 .51739 .76577 .51511 Metetra
.645 .763 .934 r
.76577 .51511 .76761 .51739 .78109 .5134 .77927 .51111 Metetra
.645 .763 .934 r
.77927 .51111 .78109 .5134 .79464 .50939 .79283 .50708 Metetra
.645 .763 .934 r
.79283 .50708 .79464 .50939 .80825 .50535 .80646 .50304 Metetra
.645 .763 .934 r
.80646 .50304 .80825 .50535 .82193 .50131 .82015 .49898 Metetra
.645 .763 .934 r
.82015 .49898 .82193 .50131 .83567 .49724 .83391 .4949 Metetra
.645 .763 .934 r
.83391 .4949 .83567 .49724 .84948 .49315 .84773 .4908 Metetra
.645 .763 .934 r
.84773 .4908 .84948 .49315 .86335 .48904 .86161 .48668 Metetra
.645 .763 .934 r
.86161 .48668 .86335 .48904 .87729 .48491 .87557 .48255 Metetra
0 .486 .804 r
.24252 .48312 .24479 .48405 .25465 .48861 .25255 .48574 Metetra
.83 .711 .733 r
.25255 .48574 .25465 .48861 .26648 .46929 .26419 .46896 Metetra
.522 0 0 r
.26419 .46896 .26648 .46929 .27631 .47557 .27411 .47422 Metetra
.834 .818 .833 r
.27411 .47422 .27631 .47557 .28751 .46455 .2853 .46344 Metetra
.87 .827 .803 r
.2853 .46344 .28751 .46455 .29887 .45097 .29668 .44984 Metetra
.896 .808 .753 r
.29668 .44984 .29887 .45097 .31052 .43267 .30834 .43168 Metetra
.628 .855 .985 r
.30834 .43168 .31052 .43267 .32106 .43124 .31902 .42826 Metetra
0 .247 .761 r
.31902 .42826 .32106 .43124 .33109 .43949 .32904 .43651 Metetra
0 .198 .726 r
.32904 .43651 .33109 .43949 .34119 .44855 .33914 .44556 Metetra
.632 .656 .855 r
.33914 .44556 .34119 .44855 .35199 .44671 .34999 .44273 Metetra
.641 .603 .796 r
.34999 .44273 .35199 .44671 .36309 .43989 .36094 .43917 Metetra
.915 .544 .309 r
.36094 .43917 .36309 .43989 .37235 .4735 .37018 .47283 Metetra
.687 .911 .972 r
.37018 .47283 .37235 .4735 .38348 .47036 .38141 .46767 Metetra
.734 .716 .834 r
.38141 .46767 .38348 .47036 .39481 .46324 .39275 .46072 Metetra
.626 .696 .895 r
.39275 .46072 .39481 .46324 .40598 .46126 .40395 .45803 Metetra
.848 .711 .712 r
.40395 .45803 .40598 .46126 .41782 .44085 .4158 .43761 Metetra
.853 .712 .706 r
.4158 .43761 .41782 .44085 .42961 .41958 .42761 .41634 Metetra
.829 .708 .732 r
.42761 .41634 .42961 .41958 .44127 .40067 .43923 .39949 Metetra
.846 .384 .044 r
.43923 .39949 .44127 .40067 .45201 .41975 .44997 .41858 Metetra
.86 .407 .075 r
.44997 .41858 .45201 .41975 .46293 .44057 .46089 .43942 Metetra
.872 .429 .103 r
.46089 .43942 .46293 .44057 .47404 .46329 .47199 .46216 Metetra
.934 .817 .706 r
.47199 .46216 .47404 .46329 .48594 .4396 .48393 .43752 Metetra
.871 .438 .034 r
.48393 .43752 .48594 .4396 .49734 .46488 .49531 .46317 Metetra
.953 .616 .334 r
.49531 .46317 .49734 .46488 .50877 .53599 .50671 .53433 Metetra
.848 .393 .004 r
.50671 .53433 .50877 .53599 .52085 .56176 .51879 .55745 Metetra
.87 .695 .663 r
.51879 .55745 .52085 .56176 .53306 .53088 .53102 .52658 Metetra
.875 .696 .657 r
.53102 .52658 .53306 .53088 .54512 .49878 .5431 .49448 Metetra
.88 .697 .652 r
.5431 .49448 .54512 .49878 .55701 .46543 .55501 .46115 Metetra
.884 .698 .646 r
.55501 .46115 .55701 .46543 .56872 .43082 .56674 .42655 Metetra
.643 .603 .794 r
.56674 .42655 .56872 .43082 .58071 .42268 .57881 .42253 Metetra
.92 .54 .27 r
.57881 .42253 .58071 .42268 .59383 .46735 .59192 .46729 Metetra
.924 .549 .28 r
.59192 .46729 .59383 .46735 .60748 .51662 .60556 .51665 Metetra
.905 .507 .237 r
.60556 .51665 .60748 .51662 .62136 .55794 .61938 .55577 Metetra
.645 .763 .934 r
.61938 .55577 .62136 .55794 .63419 .55414 .63222 .55195 Metetra
.645 .763 .934 r
.63222 .55195 .63419 .55414 .64708 .55031 .64512 .54812 Metetra
.645 .763 .934 r
.64512 .54812 .64708 .55031 .66002 .54647 .65807 .54427 Metetra
.645 .763 .934 r
.65807 .54427 .66002 .54647 .67303 .54262 .67109 .5404 Metetra
.645 .763 .934 r
.67109 .5404 .67303 .54262 .68609 .53874 .68417 .53652 Metetra
.645 .763 .934 r
.68417 .53652 .68609 .53874 .69922 .53485 .69731 .53262 Metetra
.645 .763 .934 r
.69731 .53262 .69922 .53485 .7124 .53094 .71051 .52869 Metetra
.645 .763 .934 r
.71051 .52869 .7124 .53094 .72565 .52701 .72377 .52476 Metetra
.645 .763 .934 r
.72377 .52476 .72565 .52701 .73896 .52306 .73709 .5208 Metetra
.645 .763 .934 r
.73709 .5208 .73896 .52306 .75234 .51909 .75048 .51682 Metetra
.645 .763 .934 r
.75048 .51682 .75234 .51909 .76577 .51511 .76393 .51282 Metetra
.645 .763 .934 r
.76393 .51282 .76577 .51511 .77927 .51111 .77744 .50881 Metetra
.645 .763 .934 r
.77744 .50881 .77927 .51111 .79283 .50708 .79102 .50478 Metetra
.645 .763 .934 r
.79102 .50478 .79283 .50708 .80646 .50304 .80466 .50073 Metetra
.645 .763 .934 r
.80466 .50073 .80646 .50304 .82015 .49898 .81836 .49665 Metetra
.645 .763 .934 r
.81836 .49665 .82015 .49898 .83391 .4949 .83213 .49256 Metetra
.645 .763 .934 r
.83213 .49256 .83391 .4949 .84773 .4908 .84597 .48845 Metetra
.645 .763 .934 r
.84597 .48845 .84773 .4908 .86161 .48668 .85987 .48432 Metetra
.645 .763 .934 r
.85987 .48432 .86161 .48668 .87557 .48255 .87384 .48017 Metetra
.274 .491 .886 r
.24041 .48029 .24252 .48312 .25255 .48574 .25033 .48415 Metetra
.879 .774 .743 r
.25033 .48415 .25255 .48574 .26419 .46896 .26214 .46552 Metetra
.235 .414 .836 r
.26214 .46552 .26419 .46896 .27411 .47422 .27204 .47098 Metetra
.773 .685 .766 r
.27204 .47098 .27411 .47422 .2853 .46344 .28325 .46005 Metetra
.794 .685 .744 r
.28325 .46005 .2853 .46344 .29668 .44984 .29464 .44644 Metetra
.822 .691 .72 r
.29464 .44644 .29668 .44984 .30834 .43168 .30628 .42883 Metetra
.581 .643 .876 r
.30628 .42883 .30834 .43168 .31902 .42826 .31683 .42753 Metetra
.642 .081 0 r
.31683 .42753 .31902 .42826 .32904 .43651 .32685 .43578 Metetra
.675 .125 0 r
.32685 .43578 .32904 .43651 .33914 .44556 .33695 .44484 Metetra
.539 .863 .995 r
.33695 .44484 .33914 .44556 .34999 .44273 .34781 .44211 Metetra
.718 .917 .962 r
.34781 .44211 .34999 .44273 .36094 .43917 .35888 .4364 Metetra
.933 .554 .195 r
.35888 .4364 .36094 .43917 .37018 .47283 .36811 .47004 Metetra
.669 .689 .86 r
.36811 .47004 .37018 .47283 .38141 .46767 .3793 .46592 Metetra
.748 .799 .894 r
.3793 .46592 .38141 .46767 .39275 .46072 .39063 .45939 Metetra
.593 .814 .984 r
.39063 .45939 .39275 .46072 .40395 .45803 .40184 .45669 Metetra
.908 .807 .736 r
.40184 .45669 .40395 .45803 .4158 .43761 .41372 .43625 Metetra
.912 .804 .728 r
.41372 .43625 .4158 .43761 .42761 .41634 .42555 .41495 Metetra
.899 .814 .754 r
.42555 .41495 .42761 .41634 .43923 .39949 .43722 .39677 Metetra
.745 .299 0 r
.43722 .39677 .43923 .39949 .44997 .41858 .44796 .41585 Metetra
.78 .339 0 r
.44796 .41585 .44997 .41858 .46089 .43942 .45887 .43669 Metetra
.809 .374 0 r
.45887 .43669 .46089 .43942 .47199 .46216 .46996 .45943 Metetra
.886 .741 .696 r
.46996 .45943 .47199 .46216 .48393 .43752 .48192 .43478 Metetra
.851 .429 0 r
.48192 .43478 .48393 .43752 .49531 .46317 .49328 .46137 Metetra
.954 .616 .333 r
.49328 .46137 .49531 .46317 .50671 .53433 .50465 .53259 Metetra
.856 .407 .017 r
.50465 .53259 .50671 .53433 .51879 .55745 .51672 .55683 Metetra
.963 .831 .667 r
.51672 .55683 .51879 .55745 .53102 .52658 .52898 .52591 Metetra
.964 .826 .658 r
.52898 .52591 .53102 .52658 .5431 .49448 .54109 .49377 Metetra
.966 .821 .649 r
.54109 .49377 .5431 .49448 .55501 .46115 .55304 .46038 Metetra
.967 .816 .64 r
.55304 .46038 .55501 .46115 .56674 .42655 .56481 .42573 Metetra
.738 .923 .953 r
.56481 .42573 .56674 .42655 .57881 .42253 .57684 .41898 Metetra
.902 .527 .078 r
.57684 .41898 .57881 .42253 .59192 .46729 .58993 .46372 Metetra
.913 .541 .105 r
.58993 .46372 .59192 .46729 .60556 .51665 .60355 .51307 Metetra
.865 .479 0 r
.60355 .51307 .60556 .51665 .61938 .55577 .61739 .55359 Metetra
.645 .763 .934 r
.61739 .55359 .61938 .55577 .63222 .55195 .63024 .54977 Metetra
.645 .763 .934 r
.63024 .54977 .63222 .55195 .64512 .54812 .64315 .54592 Metetra
.645 .763 .934 r
.64315 .54592 .64512 .54812 .65807 .54427 .65612 .54206 Metetra
.645 .763 .934 r
.65612 .54206 .65807 .54427 .67109 .5404 .66915 .53819 Metetra
.645 .763 .934 r
.66915 .53819 .67109 .5404 .68417 .53652 .68224 .53429 Metetra
.645 .763 .934 r
.68224 .53429 .68417 .53652 .69731 .53262 .69539 .53038 Metetra
.645 .763 .934 r
.69539 .53038 .69731 .53262 .71051 .52869 .70861 .52645 Metetra
.645 .763 .934 r
.70861 .52645 .71051 .52869 .72377 .52476 .72188 .5225 Metetra
.645 .763 .934 r
.72188 .5225 .72377 .52476 .73709 .5208 .73522 .51853 Metetra
.645 .763 .934 r
.73522 .51853 .73709 .5208 .75048 .51682 .74862 .51454 Metetra
.645 .763 .934 r
.74862 .51454 .75048 .51682 .76393 .51282 .76208 .51053 Metetra
.645 .763 .934 r
.76208 .51053 .76393 .51282 .77744 .50881 .77561 .50651 Metetra
.645 .763 .934 r
.77561 .50651 .77744 .50881 .79102 .50478 .7892 .50246 Metetra
.645 .763 .934 r
.7892 .50246 .79102 .50478 .80466 .50073 .80285 .4984 Metetra
.645 .763 .934 r
.80285 .4984 .80466 .50073 .81836 .49665 .81657 .49432 Metetra
.645 .763 .934 r
.81657 .49432 .81836 .49665 .83213 .49256 .83036 .49022 Metetra
.645 .763 .934 r
.83036 .49022 .83213 .49256 .84597 .48845 .84421 .48609 Metetra
.645 .763 .934 r
.84421 .48609 .84597 .48845 .85987 .48432 .85812 .48195 Metetra
.645 .763 .934 r
.85812 .48195 .85987 .48432 .87384 .48017 .87211 .47779 Metetra
0 .523 .847 r
.23814 .47926 .24041 .48029 .25033 .48415 .24818 .48169 Metetra
.841 .731 .743 r
.24818 .48169 .25033 .48415 .26214 .46552 .25984 .46514 Metetra
.508 0 0 r
.25984 .46514 .26214 .46552 .27204 .47098 .26977 .47032 Metetra
.855 .883 .858 r
.26977 .47032 .27204 .47098 .28325 .46005 .28098 .45959 Metetra
.892 .881 .816 r
.28098 .45959 .28325 .46005 .29464 .44644 .2924 .44587 Metetra
.915 .844 .76 r
.2924 .44587 .29464 .44644 .30628 .42883 .3041 .42768 Metetra
.656 .842 .972 r
.3041 .42768 .30628 .42883 .31683 .42753 .31481 .42389 Metetra
.061 .29 .778 r
.31481 .42389 .31683 .42753 .32685 .43578 .32484 .43213 Metetra
.002 .251 .757 r
.32484 .43213 .32685 .43578 .33695 .44484 .33493 .44117 Metetra
.627 .612 .816 r
.33493 .44117 .33695 .44484 .34781 .44211 .3458 .43835 Metetra
.637 .612 .809 r
.3458 .43835 .34781 .44211 .35888 .4364 .35675 .43507 Metetra
.924 .55 .281 r
.35675 .43507 .35888 .4364 .36811 .47004 .36596 .46874 Metetra
.72 .844 .941 r
.36596 .46874 .36811 .47004 .3793 .46592 .37722 .46331 Metetra
.733 .722 .841 r
.37722 .46331 .3793 .46592 .39063 .45939 .38857 .45651 Metetra
.63 .669 .869 r
.38857 .45651 .39063 .45939 .40184 .45669 .39979 .45368 Metetra
.855 .721 .715 r
.39979 .45368 .40184 .45669 .41372 .43625 .41169 .43323 Metetra
.859 .722 .709 r
.41169 .43323 .41372 .43625 .42555 .41495 .42354 .41191 Metetra
.834 .719 .737 r
.42354 .41191 .42555 .41495 .43722 .39677 .43518 .39525 Metetra
.838 .373 0 r
.43518 .39525 .43722 .39677 .44796 .41585 .44591 .41435 Metetra
.854 .399 .033 r
.44591 .41435 .44796 .41585 .45887 .43669 .45681 .4352 Metetra
.868 .423 .065 r
.45681 .4352 .45887 .43669 .46996 .45943 .46791 .45796 Metetra
.925 .8 .704 r
.46791 .45796 .46996 .45943 .48192 .43478 .47989 .43312 Metetra
.882 .45 .084 r
.47989 .43312 .48192 .43478 .49328 .46137 .49126 .45894 Metetra
.957 .62 .317 r
.49126 .45894 .49328 .46137 .50465 .53259 .50258 .53017 Metetra
.805 .355 0 r
.50258 .53017 .50465 .53259 .51672 .55683 .51465 .553 Metetra
.882 .71 .665 r
.51465 .553 .51672 .55683 .52898 .52591 .52694 .52208 Metetra
.886 .711 .659 r
.52694 .52208 .52898 .52591 .54109 .49377 .53907 .48993 Metetra
.891 .711 .653 r
.53907 .48993 .54109 .49377 .55304 .46038 .55104 .45655 Metetra
.895 .712 .647 r
.55104 .45655 .55304 .46038 .56481 .42573 .56283 .42189 Metetra
.64 .624 .818 r
.56283 .42189 .56481 .42573 .57684 .41898 .57492 .41823 Metetra
.925 .543 .244 r
.57492 .41823 .57684 .41898 .58993 .46372 .588 .46303 Metetra
.929 .552 .256 r
.588 .46303 .58993 .46372 .60355 .51307 .6016 .51245 Metetra
.91 .507 .202 r
.6016 .51245 .60355 .51307 .61739 .55359 .61539 .55141 Metetra
.645 .763 .934 r
.61539 .55141 .61739 .55359 .63024 .54977 .62826 .54757 Metetra
.645 .763 .934 r
.62826 .54757 .63024 .54977 .64315 .54592 .64118 .54372 Metetra
.645 .763 .934 r
.64118 .54372 .64315 .54592 .65612 .54206 .65416 .53985 Metetra
.645 .763 .934 r
.65416 .53985 .65612 .54206 .66915 .53819 .66721 .53596 Metetra
.645 .763 .934 r
.66721 .53596 .66915 .53819 .68224 .53429 .68031 .53206 Metetra
.645 .763 .934 r
.68031 .53206 .68224 .53429 .69539 .53038 .69347 .52813 Metetra
.645 .763 .934 r
.69347 .52813 .69539 .53038 .70861 .52645 .7067 .52419 Metetra
.645 .763 .934 r
.7067 .52419 .70861 .52645 .72188 .5225 .71999 .52023 Metetra
.645 .763 .934 r
.71999 .52023 .72188 .5225 .73522 .51853 .73334 .51625 Metetra
.645 .763 .934 r
.73334 .51625 .73522 .51853 .74862 .51454 .74675 .51225 Metetra
.645 .763 .934 r
.74675 .51225 .74862 .51454 .76208 .51053 .76023 .50824 Metetra
.645 .763 .934 r
.76023 .50824 .76208 .51053 .77561 .50651 .77377 .5042 Metetra
.645 .763 .934 r
.77377 .5042 .77561 .50651 .7892 .50246 .78737 .50014 Metetra
.645 .763 .934 r
.78737 .50014 .7892 .50246 .80285 .4984 .80104 .49607 Metetra
.645 .763 .934 r
.80104 .49607 .80285 .4984 .81657 .49432 .81478 .49198 Metetra
.645 .763 .934 r
.81478 .49198 .81657 .49432 .83036 .49022 .82857 .48786 Metetra
.645 .763 .934 r
.82857 .48786 .83036 .49022 .84421 .48609 .84244 .48373 Metetra
.645 .763 .934 r
.84244 .48373 .84421 .48609 .85812 .48195 .85637 .47958 Metetra
.645 .763 .934 r
.85637 .47958 .85812 .48195 .87211 .47779 .87037 .47541 Metetra
.374 .562 .909 r
.236 .47659 .23814 .47926 .24818 .48169 .24606 .47891 Metetra
.832 .716 .737 r
.24606 .47891 .24818 .48169 .25984 .46514 .25773 .4623 Metetra
.245 .476 .882 r
.25773 .4623 .25984 .46514 .26977 .47032 .26773 .46651 Metetra
.762 .658 .748 r
.26773 .46651 .26977 .47032 .28098 .45959 .279 .45516 Metetra
.767 .641 .722 r
.279 .45516 .28098 .45959 .2924 .44587 .29042 .44154 Metetra
.79 .652 .71 r
.29042 .44154 .2924 .44587 .3041 .42768 .30201 .42511 Metetra
.56 .658 .902 r
.30201 .42511 .3041 .42768 .31481 .42389 .31254 .42417 Metetra
.69 .177 .009 r
.31254 .42417 .31481 .42389 .32484 .43213 .32257 .43242 Metetra
.71 .207 .037 r
.32257 .43242 .32484 .43213 .33493 .44117 .33267 .44148 Metetra
.51 .913 .881 r
.33267 .44148 .33493 .44117 .3458 .43835 .34367 .43668 Metetra
.618 .777 .957 r
.34367 .43668 .3458 .43835 .35675 .43507 .3546 .43391 Metetra
.922 .548 .29 r
.3546 .43391 .35675 .43507 .36596 .46874 .36379 .46763 Metetra
.698 .863 .96 r
.36379 .46763 .36596 .46874 .37722 .46331 .37504 .46265 Metetra
.801 .918 .917 r
.37504 .46265 .37722 .46331 .38857 .45651 .38647 .45444 Metetra
.613 .737 .934 r
.38647 .45444 .38857 .45651 .39979 .45368 .39769 .45192 Metetra
.895 .784 .732 r
.39769 .45192 .39979 .45368 .41169 .43323 .4096 .43145 Metetra
.898 .782 .724 r
.4096 .43145 .41169 .43323 .42354 .41191 .42148 .41011 Metetra
.879 .791 .759 r
.42148 .41011 .42354 .41191 .43518 .39525 .43315 .39307 Metetra
.801 .34 0 r
.43315 .39307 .43518 .39525 .44591 .41435 .44388 .41217 Metetra
.826 .373 0 r
.44388 .41217 .44591 .41435 .45681 .4352 .45477 .43302 Metetra
.846 .402 0 r
.45477 .43302 .45681 .4352 .46791 .45796 .46586 .45579 Metetra
.902 .767 .702 r
.46586 .45579 .46791 .45796 .47989 .43312 .47786 .43134 Metetra
.876 .44 .061 r
.47786 .43134 .47989 .43312 .49126 .45894 .48922 .4566 Metetra
.957 .62 .32 r
.48922 .4566 .49126 .45894 .50258 .53017 .50051 .52787 Metetra
.813 .36 0 r
.50051 .52787 .50258 .53017 .51465 .553 .51258 .55069 Metetra
.92 .764 .671 r
.51258 .55069 .51465 .553 .52694 .52208 .52489 .51974 Metetra
.923 .762 .663 r
.52489 .51974 .52694 .52208 .53907 .48993 .53705 .48758 Metetra
.927 .76 .656 r
.53705 .48758 .53907 .48993 .55104 .45655 .54905 .45416 Metetra
.93 .758 .648 r
.54905 .45416 .55104 .45655 .56283 .42189 .56086 .41949 Metetra
.627 .721 .915 r
.56086 .41949 .56283 .42189 .57492 .41823 .57297 .41648 Metetra
.928 .544 .195 r
.57297 .41648 .57492 .41823 .588 .46303 .58604 .46132 Metetra
.933 .554 .211 r
.58604 .46132 .588 .46303 .6016 .51245 .59963 .51077 Metetra
.907 .5 .132 r
.59963 .51077 .6016 .51245 .61539 .55141 .61339 .54922 Metetra
.645 .763 .934 r
.61339 .54922 .61539 .55141 .62826 .54757 .62627 .54537 Metetra
.645 .763 .934 r
.62627 .54537 .62826 .54757 .64118 .54372 .6392 .54151 Metetra
.645 .763 .934 r
.6392 .54151 .64118 .54372 .65416 .53985 .6522 .53763 Metetra
.645 .763 .934 r
.6522 .53763 .65416 .53985 .66721 .53596 .66525 .53373 Metetra
.645 .763 .934 r
.66525 .53373 .66721 .53596 .68031 .53206 .67837 .52982 Metetra
.645 .763 .934 r
.67837 .52982 .68031 .53206 .69347 .52813 .69155 .52588 Metetra
.645 .763 .934 r
.69155 .52588 .69347 .52813 .7067 .52419 .70479 .52193 Metetra
.645 .763 .934 r
.70479 .52193 .7067 .52419 .71999 .52023 .71809 .51796 Metetra
.645 .763 .934 r
.71809 .51796 .71999 .52023 .73334 .51625 .73145 .51397 Metetra
.645 .763 .934 r
.73145 .51397 .73334 .51625 .74675 .51225 .74488 .50996 Metetra
.645 .763 .934 r
.74488 .50996 .74675 .51225 .76023 .50824 .75837 .50593 Metetra
.645 .763 .934 r
.75837 .50593 .76023 .50824 .77377 .5042 .77193 .50188 Metetra
.645 .763 .934 r
.77193 .50188 .77377 .5042 .78737 .50014 .78554 .49782 Metetra
.645 .763 .934 r
.78554 .49782 .78737 .50014 .80104 .49607 .79923 .49373 Metetra
.645 .763 .934 r
.79923 .49373 .80104 .49607 .81478 .49198 .81297 .48963 Metetra
.645 .763 .934 r
.81297 .48963 .81478 .49198 .82857 .48786 .82679 .4855 Metetra
.645 .763 .934 r
.82679 .4855 .82857 .48786 .84244 .48373 .84067 .48136 Metetra
.645 .763 .934 r
.84067 .48136 .84244 .48373 .85637 .47958 .85461 .4772 Metetra
.645 .763 .934 r
.85461 .4772 .85637 .47958 .87037 .47541 .86863 .47301 Metetra
.049 .549 .882 r
.23373 .47545 .236 .47659 .24606 .47891 .24378 .47778 Metetra
.885 .81 .769 r
.24378 .47778 .24606 .47891 .25773 .4623 .25547 .46123 Metetra
.375 0 0 r
.25547 .46123 .25773 .4623 .26773 .46651 .26539 .46657 Metetra
.86 .953 .871 r
.26539 .46657 .26773 .46651 .279 .45516 .27663 .45587 Metetra
.908 .967 .806 r
.27663 .45587 .279 .45516 .29042 .44154 .28811 .44168 Metetra
.933 .894 .766 r
.28811 .44168 .29042 .44154 .30201 .42511 .29983 .42371 Metetra
.688 .82 .946 r
.29983 .42371 .30201 .42511 .31254 .42417 .3106 .41935 Metetra
.223 .322 .755 r
.3106 .41935 .31254 .42417 .32257 .43242 .32062 .42758 Metetra
.182 .296 .746 r
.32062 .42758 .32257 .43242 .33267 .44148 .33071 .43662 Metetra
.611 .553 .765 r
.33071 .43662 .33267 .44148 .34367 .43668 .34158 .43406 Metetra
.648 .693 .878 r
.34158 .43406 .34367 .43668 .3546 .43391 .35255 .43074 Metetra
.93 .553 .168 r
.35255 .43074 .3546 .43391 .36379 .46763 .36172 .46444 Metetra
.693 .671 .824 r
.36172 .46444 .36379 .46763 .37504 .46265 .373 .45895 Metetra
.706 .65 .791 r
.373 .45895 .37504 .46265 .38647 .45444 .38437 .45214 Metetra
.63 .72 .912 r
.38437 .45214 .38647 .45444 .39769 .45192 .39562 .44926 Metetra
.866 .738 .72 r
.39562 .44926 .39769 .45192 .4096 .43145 .40755 .42877 Metetra
.87 .738 .714 r
.40755 .42877 .4096 .43145 .42148 .41011 .41944 .40743 Metetra
.844 .738 .747 r
.41944 .40743 .42148 .41011 .43315 .39307 .43111 .39102 Metetra
.812 .348 0 r
.43111 .39102 .43315 .39307 .44388 .41217 .44183 .41013 Metetra
.834 .379 0 r
.44183 .41013 .44388 .41217 .45477 .43302 .45272 .43099 Metetra
.853 .407 0 r
.45272 .43099 .45477 .43302 .46586 .45579 .4638 .45376 Metetra
.908 .773 .7 r
.4638 .45376 .46586 .45579 .47786 .43134 .47583 .42883 Metetra
.854 .425 0 r
.47583 .42883 .47786 .43134 .48922 .4566 .48718 .45455 Metetra
.955 .618 .327 r
.48718 .45455 .48922 .4566 .50051 .52787 .49844 .52586 Metetra
.831 .375 0 r
.49844 .52586 .50051 .52787 .51258 .55069 .51049 .54874 Metetra
.93 .777 .671 r
.51049 .54874 .51258 .55069 .52489 .51974 .52283 .51776 Metetra
.932 .775 .663 r
.52283 .51776 .52489 .51974 .53705 .48758 .53502 .48556 Metetra
.935 .772 .655 r
.53502 .48556 .53705 .48758 .54905 .45416 .54705 .45212 Metetra
.938 .77 .647 r
.54705 .45212 .54905 .45416 .56086 .41949 .5589 .41741 Metetra
.649 .763 .932 r
.5589 .41741 .56086 .41949 .57297 .41648 .57101 .4137 Metetra
.92 .538 .133 r
.57101 .4137 .57297 .41648 .58604 .46132 .58405 .45853 Metetra
.927 .55 .155 r
.58405 .45853 .58604 .46132 .59963 .51077 .59762 .50799 Metetra
.889 .488 .053 r
.59762 .50799 .59963 .51077 .61339 .54922 .61138 .54702 Metetra
.645 .763 .934 r
.61138 .54702 .61339 .54922 .62627 .54537 .62427 .54317 Metetra
.645 .763 .934 r
.62427 .54317 .62627 .54537 .6392 .54151 .63722 .5393 Metetra
.645 .763 .934 r
.63722 .5393 .6392 .54151 .6522 .53763 .65023 .53541 Metetra
.645 .763 .934 r
.65023 .53541 .6522 .53763 .66525 .53373 .6633 .5315 Metetra
.645 .763 .934 r
.6633 .5315 .66525 .53373 .67837 .52982 .67643 .52757 Metetra
.645 .763 .934 r
.67643 .52757 .67837 .52982 .69155 .52588 .68962 .52363 Metetra
.645 .763 .934 r
.68962 .52363 .69155 .52588 .70479 .52193 .70287 .51966 Metetra
.645 .763 .934 r
.70287 .51966 .70479 .52193 .71809 .51796 .71619 .51568 Metetra
.645 .763 .934 r
.71619 .51568 .71809 .51796 .73145 .51397 .72956 .51168 Metetra
.645 .763 .934 r
.72956 .51168 .73145 .51397 .74488 .50996 .743 .50766 Metetra
.645 .763 .934 r
.743 .50766 .74488 .50996 .75837 .50593 .75651 .50362 Metetra
.645 .763 .934 r
.75651 .50362 .75837 .50593 .77193 .50188 .77008 .49956 Metetra
.645 .763 .934 r
.77008 .49956 .77193 .50188 .78554 .49782 .78371 .49549 Metetra
.645 .763 .934 r
.78371 .49549 .78554 .49782 .79923 .49373 .79741 .49139 Metetra
.645 .763 .934 r
.79741 .49139 .79923 .49373 .81297 .48963 .81117 .48727 Metetra
.645 .763 .934 r
.81117 .48727 .81297 .48963 .82679 .4855 .825 .48314 Metetra
.645 .763 .934 r
.825 .48314 .82679 .4855 .84067 .48136 .83889 .47898 Metetra
.645 .763 .934 r
.83889 .47898 .84067 .48136 .85461 .4772 .85285 .47481 Metetra
.645 .763 .934 r
.85285 .47481 .85461 .4772 .86863 .47301 .86688 .47061 Metetra
.449 .586 .897 r
.23159 .47261 .23373 .47545 .24378 .47778 .24174 .47398 Metetra
.795 .669 .725 r
.24174 .47398 .24378 .47778 .25547 .46123 .25334 .45862 Metetra
.292 .526 .907 r
.25334 .45862 .25547 .46123 .26539 .46657 .26342 .46185 Metetra
.743 .622 .725 r
.26342 .46185 .26539 .46657 .27663 .45587 .27473 .45019 Metetra
.741 .599 .699 r
.27473 .45019 .27663 .45587 .28811 .44168 .28618 .43654 Metetra
.765 .623 .702 r
.28618 .43654 .28811 .44168 .29983 .42371 .29774 .42108 Metetra
.527 .64 .904 r
.29774 .42108 .29983 .42371 .3106 .41935 .30824 .42085 Metetra
.685 .233 .174 r
.30824 .42085 .3106 .41935 .32062 .42758 .31826 .42911 Metetra
.699 .253 .189 r
.31826 .42911 .32062 .42758 .33071 .43662 .32836 .43817 Metetra
.32836 .43817 .33071 .43662 .34158 .43406 .33947 .43176 Metetra
.544 .683 .93 r
.33947 .43176 .34158 .43406 .35255 .43074 .35031 .43091 Metetra
.898 .534 .341 r
.35031 .43091 .35255 .43074 .36172 .46444 .35947 .46468 Metetra
.577 .941 .901 r
.35947 .46468 .36172 .46444 .373 .45895 .37077 .45915 Metetra
.8 .986 .891 r
.37077 .45915 .373 .45895 .38437 .45214 .38227 .44988 Metetra
.612 .717 .92 r
.38227 .44988 .38437 .45214 .39562 .44926 .39351 .44745 Metetra
.893 .782 .731 r
.39351 .44745 .39562 .44926 .40755 .42877 .40546 .42694 Metetra
.897 .78 .724 r
.40546 .42694 .40755 .42877 .41944 .40743 .41737 .40557 Metetra
.874 .789 .763 r
.41737 .40557 .41944 .40743 .43111 .39102 .42907 .38905 Metetra
.817 .353 0 r
.42907 .38905 .43111 .39102 .44183 .41013 .43978 .40816 Metetra
.838 .383 0 r
.43978 .40816 .44183 .41013 .45272 .43099 .45067 .42903 Metetra
.856 .41 .009 r
.45067 .42903 .45272 .43099 .4638 .45376 .46174 .45182 Metetra
.909 .778 .705 r
.46174 .45182 .4638 .45376 .47583 .42883 .47378 .42745 Metetra
.877 .439 .094 r
.47378 .42745 .47583 .42883 .48718 .45455 .48514 .45206 Metetra
.958 .62 .316 r
.48514 .45206 .48718 .45455 .49844 .52586 .49636 .52338 Metetra
.783 .33 0 r
.49636 .52338 .49844 .52586 .51049 .54874 .50841 .54521 Metetra
.89 .721 .667 r
.50841 .54521 .51049 .54874 .52283 .51776 .52077 .51423 Metetra
.894 .721 .66 r
.52077 .51423 .52283 .51776 .53502 .48556 .53299 .48203 Metetra
.898 .721 .654 r
.53299 .48203 .53502 .48556 .54705 .45212 .54504 .44858 Metetra
.902 .721 .647 r
.54504 .44858 .54705 .45212 .5589 .41741 .55691 .41387 Metetra
.555 .601 .854 r
.55691 .41387 .5589 .41741 .57101 .4137 .56907 .41328 Metetra
.923 .541 .259 r
.56907 .41328 .57101 .4137 .58405 .45853 .5821 .45819 Metetra
.926 .55 .269 r
.5821 .45819 .58405 .45853 .59762 .50799 .59566 .50774 Metetra
.903 .497 .211 r
.59566 .50774 .59762 .50799 .61138 .54702 .60937 .54482 Metetra
.645 .763 .934 r
.60937 .54482 .61138 .54702 .62427 .54317 .62227 .54096 Metetra
.645 .763 .934 r
.62227 .54096 .62427 .54317 .63722 .5393 .63523 .53708 Metetra
.645 .763 .934 r
.63523 .53708 .63722 .5393 .65023 .53541 .64826 .53318 Metetra
.645 .763 .934 r
.64826 .53318 .65023 .53541 .6633 .5315 .66134 .52926 Metetra
.645 .763 .934 r
.66134 .52926 .6633 .5315 .67643 .52757 .67448 .52532 Metetra
.645 .763 .934 r
.67448 .52532 .67643 .52757 .68962 .52363 .68768 .52136 Metetra
.645 .763 .934 r
.68768 .52136 .68962 .52363 .70287 .51966 .70095 .51739 Metetra
.645 .763 .934 r
.70095 .51739 .70287 .51966 .71619 .51568 .71428 .5134 Metetra
.645 .763 .934 r
.71428 .5134 .71619 .51568 .72956 .51168 .72767 .50939 Metetra
.645 .763 .934 r
.72767 .50939 .72956 .51168 .743 .50766 .74112 .50535 Metetra
.645 .763 .934 r
.74112 .50535 .743 .50766 .75651 .50362 .75464 .50131 Metetra
.645 .763 .934 r
.75464 .50131 .75651 .50362 .77008 .49956 .76822 .49724 Metetra
.645 .763 .934 r
.76822 .49724 .77008 .49956 .78371 .49549 .78187 .49315 Metetra
.645 .763 .934 r
.78187 .49315 .78371 .49549 .79741 .49139 .79558 .48904 Metetra
.645 .763 .934 r
.79558 .48904 .79741 .49139 .81117 .48727 .80936 .48491 Metetra
.645 .763 .934 r
.80936 .48491 .81117 .48727 .825 .48314 .8232 .48077 Metetra
.645 .763 .934 r
.8232 .48077 .825 .48314 .83889 .47898 .83711 .4766 Metetra
.645 .763 .934 r
.83711 .4766 .83889 .47898 .85285 .47481 .85109 .47241 Metetra
.645 .763 .934 r
.85109 .47241 .85285 .47481 .86688 .47061 .86513 .46821 Metetra
.148 .575 .93 r
.22934 .47111 .23159 .47261 .24174 .47398 .2394 .47349 Metetra
.905 .855 .782 r
.2394 .47349 .24174 .47398 .25334 .45862 .2511 .45716 Metetra
0 .281 .7 r
.2511 .45716 .25334 .45862 .26342 .46185 .26102 .46251 Metetra
.846 .991 .849 r
.26102 .46251 .26342 .46185 .27473 .45019 .2723 .45151 Metetra
.87 .995 .775 r
.2723 .45151 .27473 .45019 .28618 .43654 .28378 .43776 Metetra
.944 .953 .743 r
.28378 .43776 .28618 .43654 .29774 .42108 .29558 .41925 Metetra
.67 .769 .925 r
.29558 .41925 .29774 .42108 .30824 .42085 .30633 .41542 Metetra
.273 .327 .737 r
.30633 .41542 .30824 .42085 .31826 .42911 .31635 .42365 Metetra
.239 .306 .731 r
.31635 .42365 .31826 .42911 .32836 .43817 .32644 .43268 Metetra
.612 .535 .743 r
.32644 .43268 .32836 .43817 .33947 .43176 .33734 .42977 Metetra
.636 .748 .929 r
.33734 .42977 .33947 .43176 .35031 .43091 .34831 .42673 Metetra
.906 .539 .086 r
.34831 .42673 .35031 .43091 .35947 .46468 .35744 .46046 Metetra
.666 .609 .782 r
.35744 .46046 .35947 .46468 .37077 .45915 .36873 .4554 Metetra
.722 .654 .782 r
.36873 .4554 .37077 .45915 .38227 .44988 .38017 .44751 Metetra
.603 .705 .915 r
.38017 .44751 .38227 .44988 .39351 .44745 .3914 .44531 Metetra
.883 .765 .727 r
.3914 .44531 .39351 .44745 .40546 .42694 .40338 .42478 Metetra
.887 .763 .72 r
.40338 .42478 .40546 .42694 .41737 .40557 .41531 .40339 Metetra
.866 .768 .753 r
.41531 .40339 .41737 .40557 .42907 .38905 .42704 .38638 Metetra
.756 .307 0 r
.42704 .38638 .42907 .38905 .43978 .40816 .43775 .40549 Metetra
.789 .345 0 r
.43775 .40549 .43978 .40816 .45067 .42903 .44862 .42636 Metetra
.817 .379 0 r
.44862 .42636 .45067 .42903 .46174 .45182 .45968 .44914 Metetra
.886 .746 .701 r
.45968 .44914 .46174 .45182 .47378 .42745 .47175 .42507 Metetra
.845 .408 0 r
.47175 .42507 .47378 .42745 .48514 .45206 .4831 .44939 Metetra
.958 .621 .312 r
.4831 .44939 .48514 .45206 .49636 .52338 .49427 .52073 Metetra
.799 .356 0 r
.49427 .52073 .49636 .52338 .50841 .54521 .50631 .54424 Metetra
.955 .817 .669 r
.50631 .54424 .50841 .54521 .52077 .51423 .51871 .51322 Metetra
.957 .813 .66 r
.51871 .51322 .52077 .51423 .53299 .48203 .53095 .48097 Metetra
.958 .808 .652 r
.53095 .48097 .53299 .48203 .54504 .44858 .54304 .44747 Metetra
.96 .804 .643 r
.54304 .44747 .54504 .44858 .55691 .41387 .55494 .41272 Metetra
.592 .851 .993 r
.55494 .41272 .55691 .41387 .56907 .41328 .56708 .40936 Metetra
.892 .521 .055 r
.56708 .40936 .56907 .41328 .5821 .45819 .58009 .45424 Metetra
.905 .537 .083 r
.58009 .45424 .5821 .45819 .59566 .50774 .59362 .50375 Metetra
.833 .452 0 r
.59362 .50375 .59566 .50774 .60937 .54482 .60736 .54262 Metetra
.645 .763 .934 r
.60736 .54262 .60937 .54482 .62227 .54096 .62027 .53874 Metetra
.645 .763 .934 r
.62027 .53874 .62227 .54096 .63523 .53708 .63324 .53485 Metetra
.645 .763 .934 r
.63324 .53485 .63523 .53708 .64826 .53318 .64628 .53094 Metetra
.645 .763 .934 r
.64628 .53094 .64826 .53318 .66134 .52926 .65937 .52701 Metetra
.645 .763 .934 r
.65937 .52701 .66134 .52926 .67448 .52532 .67253 .52306 Metetra
.645 .763 .934 r
.67253 .52306 .67448 .52532 .68768 .52136 .68574 .51909 Metetra
.645 .763 .934 r
.68574 .51909 .68768 .52136 .70095 .51739 .69902 .51511 Metetra
.645 .763 .934 r
.69902 .51511 .70095 .51739 .71428 .5134 .71236 .51111 Metetra
.645 .763 .934 r
.71236 .51111 .71428 .5134 .72767 .50939 .72577 .50708 Metetra
.645 .763 .934 r
.72577 .50708 .72767 .50939 .74112 .50535 .73924 .50304 Metetra
.645 .763 .934 r
.73924 .50304 .74112 .50535 .75464 .50131 .75277 .49898 Metetra
.645 .763 .934 r
.75277 .49898 .75464 .50131 .76822 .49724 .76636 .4949 Metetra
.645 .763 .934 r
.76636 .4949 .76822 .49724 .78187 .49315 .78002 .4908 Metetra
.645 .763 .934 r
.78002 .4908 .78187 .49315 .79558 .48904 .79375 .48668 Metetra
.645 .763 .934 r
.79375 .48668 .79558 .48904 .80936 .48491 .80754 .48255 Metetra
.645 .763 .934 r
.80754 .48255 .80936 .48491 .8232 .48077 .8214 .47839 Metetra
.645 .763 .934 r
.8214 .47839 .8232 .48077 .83711 .4766 .83532 .47421 Metetra
.645 .763 .934 r
.83532 .47421 .83711 .4766 .85109 .47241 .84931 .47001 Metetra
.645 .763 .934 r
.84931 .47001 .85109 .47241 .86513 .46821 .86337 .46579 Metetra
.448 .591 .902 r
.22719 .46833 .22934 .47111 .2394 .47349 .23735 .46963 Metetra
.79 .666 .727 r
.23735 .46963 .2394 .47349 .2511 .45716 .24893 .45478 Metetra
.268 .54 .92 r
.24893 .45478 .2511 .45716 .26102 .46251 .25904 .45784 Metetra
.745 .625 .726 r
.25904 .45784 .26102 .46251 .2723 .45151 .27038 .44611 Metetra
.747 .608 .704 r
.27038 .44611 .2723 .45151 .28378 .43776 .28186 .43244 Metetra
.764 .618 .698 r
.28186 .43244 .28378 .43776 .29558 .41925 .29347 .41664 Metetra
.515 .638 .909 r
.29347 .41664 .29558 .41925 .30633 .41542 .30397 .41662 Metetra
.687 .221 .14 r
.30397 .41662 .30633 .41542 .31635 .42365 .314 .42486 Metetra
.703 .243 .157 r
.314 .42486 .31635 .42365 .32644 .43268 .32409 .43393 Metetra
.419 .837 .665 r
.32409 .43393 .32644 .43268 .33734 .42977 .33524 .42723 Metetra
.523 .652 .916 r
.33524 .42723 .33734 .42977 .34831 .42673 .34606 .42696 Metetra
.897 .533 .343 r
.34606 .42696 .34831 .42673 .35744 .46046 .35518 .46075 Metetra
.582 .943 .894 r
.35518 .46075 .35744 .46046 .36873 .4554 .36651 .45502 Metetra
.827 .941 .9 r
.36651 .45502 .36873 .4554 .38017 .44751 .37804 .44563 Metetra
.589 .751 .955 r
.37804 .44563 .38017 .44751 .3914 .44531 .38928 .44347 Metetra
.892 .781 .731 r
.38928 .44347 .3914 .44531 .40338 .42478 .40128 .42292 Metetra
.896 .779 .724 r
.40128 .42292 .40338 .42478 .41531 .40339 .41324 .40151 Metetra
.877 .786 .758 r
.41324 .40151 .41531 .40339 .42704 .38638 .42499 .38438 Metetra
.815 .351 0 r
.42499 .38438 .42704 .38638 .43775 .40549 .43569 .4035 Metetra
.837 .382 0 r
.43569 .4035 .43775 .40549 .44862 .42636 .44655 .42437 Metetra
.855 .409 .006 r
.44655 .42437 .44862 .42636 .45968 .44914 .45761 .44716 Metetra
.907 .778 .707 r
.45761 .44716 .45968 .44914 .47175 .42507 .4697 .42312 Metetra
.863 .422 .024 r
.4697 .42312 .47175 .42507 .4831 .44939 .48104 .44741 Metetra
.955 .617 .329 r
.48104 .44741 .4831 .44939 .49427 .52073 .49218 .5188 Metetra
.82 .356 0 r
.49218 .5188 .49427 .52073 .50631 .54424 .50422 .54049 Metetra
.884 .714 .666 r
.50422 .54049 .50631 .54424 .51871 .51322 .51664 .50946 Metetra
.889 .714 .659 r
.51664 .50946 .51871 .51322 .53095 .48097 .52891 .47721 Metetra
.893 .715 .653 r
.52891 .47721 .53095 .48097 .54304 .44747 .54102 .44371 Metetra
.897 .715 .647 r
.54102 .44371 .54304 .44747 .55494 .41272 .55295 .40895 Metetra
.533 .577 .845 r
.55295 .40895 .55494 .41272 .56708 .40936 .56513 .40909 Metetra
.921 .54 .265 r
.56513 .40909 .56708 .40936 .58009 .45424 .57813 .45405 Metetra
.925 .549 .275 r
.57813 .45405 .58009 .45424 .59362 .50375 .59165 .50366 Metetra
.9 .495 .217 r
.59165 .50366 .59362 .50375 .60736 .54262 .60533 .5404 Metetra
.645 .763 .934 r
.60533 .5404 .60736 .54262 .62027 .53874 .61826 .53652 Metetra
.645 .763 .934 r
.61826 .53652 .62027 .53874 .63324 .53485 .63125 .53262 Metetra
.645 .763 .934 r
.63125 .53262 .63324 .53485 .64628 .53094 .64429 .52869 Metetra
.645 .763 .934 r
.64429 .52869 .64628 .53094 .65937 .52701 .6574 .52476 Metetra
.645 .763 .934 r
.6574 .52476 .65937 .52701 .67253 .52306 .67057 .5208 Metetra
.645 .763 .934 r
.67057 .5208 .67253 .52306 .68574 .51909 .6838 .51682 Metetra
.645 .763 .934 r
.6838 .51682 .68574 .51909 .69902 .51511 .69709 .51282 Metetra
.645 .763 .934 r
.69709 .51282 .69902 .51511 .71236 .51111 .71045 .50881 Metetra
.645 .763 .934 r
.71045 .50881 .71236 .51111 .72577 .50708 .72386 .50478 Metetra
.645 .763 .934 r
.72386 .50478 .72577 .50708 .73924 .50304 .73735 .50073 Metetra
.645 .763 .934 r
.73735 .50073 .73924 .50304 .75277 .49898 .75089 .49665 Metetra
.645 .763 .934 r
.75089 .49665 .75277 .49898 .76636 .4949 .7645 .49256 Metetra
.645 .763 .934 r
.7645 .49256 .76636 .4949 .78002 .4908 .77818 .48845 Metetra
.645 .763 .934 r
.77818 .48845 .78002 .4908 .79375 .48668 .79192 .48432 Metetra
.645 .763 .934 r
.79192 .48432 .79375 .48668 .80754 .48255 .80572 .48017 Metetra
.645 .763 .934 r
.80572 .48017 .80754 .48255 .8214 .47839 .81959 .476 Metetra
.645 .763 .934 r
.81959 .476 .8214 .47839 .83532 .47421 .83353 .47181 Metetra
.645 .763 .934 r
.83353 .47181 .83532 .47421 .84931 .47001 .84754 .4676 Metetra
.645 .763 .934 r
.84754 .4676 .84931 .47001 .86337 .46579 .86161 .46337 Metetra
.313 .596 .946 r
.22498 .46623 .22719 .46833 .23735 .46963 .23507 .4683 Metetra
.87 .803 .781 r
.23507 .4683 .23735 .46963 .24893 .45478 .24669 .45323 Metetra
0 .412 .821 r
.24669 .45323 .24893 .45478 .25904 .45784 .25671 .45746 Metetra
.867 .906 .857 r
.25671 .45746 .25904 .45784 .27038 .44611 .26804 .44614 Metetra
.902 .923 .823 r
.26804 .44614 .27038 .44611 .28186 .43244 .27954 .43244 Metetra
.931 .884 .765 r
.27954 .43244 .28186 .43244 .29347 .41664 .29134 .41428 Metetra
.594 .694 .912 r
.29134 .41428 .29347 .41664 .30397 .41662 .30197 .41243 Metetra
.139 .305 .771 r
.30197 .41243 .30397 .41662 .314 .42486 .31199 .42066 Metetra
.089 .272 .756 r
.31199 .42066 .314 .42486 .32409 .43393 .32208 .42971 Metetra
.66 .603 .781 r
.32208 .42971 .32409 .43393 .33524 .42723 .33311 .42501 Metetra
.561 .7 .933 r
.33311 .42501 .33524 .42723 .34606 .42696 .34399 .42372 Metetra
.93 .553 .167 r
.34399 .42372 .34606 .42696 .35518 .46075 .35309 .4575 Metetra
.695 .671 .822 r
.35309 .4575 .35518 .46075 .36651 .45502 .36443 .45185 Metetra
.743 .691 .802 r
.36443 .45185 .36651 .45502 .37804 .44563 .37592 .44359 Metetra
.576 .729 .947 r
.37592 .44359 .37804 .44563 .38928 .44347 .38715 .4418 Metetra
.898 .79 .733 r
.38715 .4418 .38928 .44347 .40128 .42292 .39917 .42123 Metetra
.902 .788 .725 r
.39917 .42123 .40128 .42292 .41324 .40151 .41115 .3998 Metetra
.889 .795 .749 r
.41115 .3998 .41324 .40151 .42499 .38438 .42296 .38142 Metetra
.719 .283 0 r
.42296 .38142 .42499 .38438 .43569 .4035 .43365 .40052 Metetra
.758 .325 0 r
.43365 .40052 .43569 .4035 .44655 .42437 .44451 .42138 Metetra
.791 .362 0 r
.44451 .42138 .44655 .42437 .45761 .44716 .45555 .44416 Metetra
.875 .733 .701 r
.45555 .44416 .45761 .44716 .4697 .42312 .46765 .42061 Metetra
.837 .401 0 r
.46765 .42061 .4697 .42312 .48104 .44741 .47899 .4448 Metetra
.958 .621 .313 r
.47899 .4448 .48104 .44741 .49218 .5188 .49009 .5162 Metetra
.789 .34 0 r
.49009 .5162 .49218 .5188 .50422 .54049 .50212 .53878 Metetra
.936 .788 .671 r
.50212 .53878 .50422 .54049 .51664 .50946 .51457 .50772 Metetra
.939 .785 .663 r
.51457 .50772 .51664 .50946 .52891 .47721 .52687 .47543 Metetra
.942 .782 .655 r
.52687 .47543 .52891 .47721 .54102 .44371 .539 .4419 Metetra
.944 .779 .647 r
.539 .4419 .54102 .44371 .55295 .40895 .55096 .40711 Metetra
.517 .739 .975 r
.55096 .40711 .55295 .40895 .56513 .40909 .56314 .40597 Metetra
.915 .535 .114 r
.56314 .40597 .56513 .40909 .57813 .45405 .57612 .45092 Metetra
.923 .548 .137 r
.57612 .45092 .57813 .45405 .59165 .50366 .58962 .50052 Metetra
.87 .47 .008 r
.58962 .50052 .59165 .50366 .60533 .5404 .60331 .53819 Metetra
.645 .763 .934 r
.60331 .53819 .60533 .5404 .61826 .53652 .61624 .53429 Metetra
.645 .763 .934 r
.61624 .53429 .61826 .53652 .63125 .53262 .62924 .53038 Metetra
.645 .763 .934 r
.62924 .53038 .63125 .53262 .64429 .52869 .6423 .52645 Metetra
.645 .763 .934 r
.6423 .52645 .64429 .52869 .6574 .52476 .65542 .5225 Metetra
.645 .763 .934 r
.65542 .5225 .6574 .52476 .67057 .5208 .6686 .51853 Metetra
.645 .763 .934 r
.6686 .51853 .67057 .5208 .6838 .51682 .68185 .51454 Metetra
.645 .763 .934 r
.68185 .51454 .6838 .51682 .69709 .51282 .69515 .51053 Metetra
.645 .763 .934 r
.69515 .51053 .69709 .51282 .71045 .50881 .70852 .50651 Metetra
.645 .763 .934 r
.70852 .50651 .71045 .50881 .72386 .50478 .72195 .50246 Metetra
.645 .763 .934 r
.72195 .50246 .72386 .50478 .73735 .50073 .73545 .4984 Metetra
.645 .763 .934 r
.73545 .4984 .73735 .50073 .75089 .49665 .74901 .49432 Metetra
.645 .763 .934 r
.74901 .49432 .75089 .49665 .7645 .49256 .76263 .49022 Metetra
.645 .763 .934 r
.76263 .49022 .7645 .49256 .77818 .48845 .77632 .48609 Metetra
.645 .763 .934 r
.77632 .48609 .77818 .48845 .79192 .48432 .79007 .48195 Metetra
.645 .763 .934 r
.79007 .48195 .79192 .48432 .80572 .48017 .8039 .47779 Metetra
.645 .763 .934 r
.8039 .47779 .80572 .48017 .81959 .476 .81778 .47361 Metetra
.645 .763 .934 r
.81778 .47361 .81959 .476 .83353 .47181 .83174 .46941 Metetra
.645 .763 .934 r
.83174 .46941 .83353 .47181 .84754 .4676 .84576 .46519 Metetra
.645 .763 .934 r
.84576 .46519 .84754 .4676 .86161 .46337 .85985 .46095 Metetra
.44 .645 .945 r
.22277 .46401 .22498 .46623 .23507 .4683 .23298 .46475 Metetra
.783 .676 .745 r
.23298 .46475 .23507 .4683 .24669 .45323 .24443 .45188 Metetra
.108 .568 .914 r
.24443 .45188 .24669 .45323 .25671 .45746 .2546 .45424 Metetra
.78 .691 .765 r
.2546 .45424 .25671 .45746 .26804 .44614 .26595 .4428 Metetra
.797 .689 .746 r
.26595 .4428 .26804 .44614 .27954 .43244 .27746 .42909 Metetra
.82 .694 .725 r
.27746 .42909 .27954 .43244 .29134 .41428 .28919 .4121 Metetra
.52 .684 .941 r
.28919 .4121 .29134 .41428 .30197 .41243 .29973 .41159 Metetra
.628 .065 0 r
.29973 .41159 .30197 .41243 .31199 .42066 .30976 .41982 Metetra
.664 .111 0 r
.30976 .41982 .31199 .42066 .32208 .42971 .31985 .42888 Metetra
.777 .896 .928 r
.31985 .42888 .32208 .42971 .33311 .42501 .33104 .42168 Metetra
.449 .551 .867 r
.33104 .42168 .33311 .42501 .34399 .42372 .34175 .42354 Metetra
.905 .538 .329 r
.34175 .42354 .34399 .42372 .35309 .4575 .35084 .45738 Metetra
.748 .966 .933 r
.35084 .45738 .35309 .4575 .36443 .45185 .36227 .45003 Metetra
.78 .798 .867 r
.36227 .45003 .36443 .45185 .37592 .44359 .37377 .44184 Metetra
.585 .765 .965 r
.37377 .44184 .37592 .44359 .38715 .4418 .38503 .43963 Metetra
.882 .764 .727 r
.38503 .43963 .38715 .4418 .39917 .42123 .39707 .41904 Metetra
.886 .763 .72 r
.39707 .41904 .39917 .42123 .41115 .3998 .40907 .39759 Metetra
.872 .766 .743 r
.40907 .39759 .41115 .3998 .42296 .38142 .42089 .37942 Metetra
.816 .351 0 r
.42089 .37942 .42296 .38142 .43365 .40052 .43158 .39853 Metetra
.837 .382 0 r
.43158 .39853 .43365 .40052 .44451 .42138 .44243 .4194 Metetra
.855 .409 .007 r
.44243 .4194 .44451 .42138 .45555 .44416 .45347 .44219 Metetra
.908 .778 .707 r
.45347 .44219 .45555 .44416 .46765 .42061 .4656 .41808 Metetra
.848 .416 0 r
.4656 .41808 .46765 .42061 .47899 .4448 .47691 .44319 Metetra
.952 .615 .337 r
.47691 .44319 .47899 .4448 .49009 .5162 .48798 .51465 Metetra
.815 .338 0 r
.48798 .51465 .49009 .5162 .50212 .53878 .50003 .53461 Metetra
.875 .701 .663 r
.50003 .53461 .50212 .53878 .51457 .50772 .51249 .50355 Metetra
.88 .702 .658 r
.51249 .50355 .51457 .50772 .52687 .47543 .52481 .47127 Metetra
.884 .703 .652 r
.52481 .47127 .52687 .47543 .539 .4419 .53697 .43774 Metetra
.889 .704 .646 r
.53697 .43774 .539 .4419 .55096 .40711 .54896 .40296 Metetra
.448 .508 .828 r
.54896 .40296 .55096 .40711 .56314 .40597 .56118 .40579 Metetra
.92 .539 .268 r
.56118 .40579 .56314 .40597 .57612 .45092 .57415 .45083 Metetra
.924 .548 .278 r
.57415 .45083 .57612 .45092 .58962 .50052 .58764 .50052 Metetra
.896 .487 .215 r
.58764 .50052 .58962 .50052 .60331 .53819 .60127 .53596 Metetra
.645 .763 .934 r
.60127 .53596 .60331 .53819 .61624 .53429 .61422 .53206 Metetra
.645 .763 .934 r
.61422 .53206 .61624 .53429 .62924 .53038 .62724 .52813 Metetra
.645 .763 .934 r
.62724 .52813 .62924 .53038 .6423 .52645 .64031 .52419 Metetra
.645 .763 .934 r
.64031 .52419 .6423 .52645 .65542 .5225 .65344 .52023 Metetra
.645 .763 .934 r
.65344 .52023 .65542 .5225 .6686 .51853 .66663 .51625 Metetra
.645 .763 .934 r
.66663 .51625 .6686 .51853 .68185 .51454 .67989 .51225 Metetra
.645 .763 .934 r
.67989 .51225 .68185 .51454 .69515 .51053 .69321 .50824 Metetra
.645 .763 .934 r
.69321 .50824 .69515 .51053 .70852 .50651 .70659 .5042 Metetra
.645 .763 .934 r
.70659 .5042 .70852 .50651 .72195 .50246 .72004 .50014 Metetra
.645 .763 .934 r
.72004 .50014 .72195 .50246 .73545 .4984 .73355 .49607 Metetra
.645 .763 .934 r
.73355 .49607 .73545 .4984 .74901 .49432 .74712 .49198 Metetra
.645 .763 .934 r
.74712 .49198 .74901 .49432 .76263 .49022 .76076 .48786 Metetra
.645 .763 .934 r
.76076 .48786 .76263 .49022 .77632 .48609 .77446 .48373 Metetra
.645 .763 .934 r
.77446 .48373 .77632 .48609 .79007 .48195 .78823 .47958 Metetra
.645 .763 .934 r
.78823 .47958 .79007 .48195 .8039 .47779 .80206 .47541 Metetra
.645 .763 .934 r
.80206 .47541 .8039 .47779 .81778 .47361 .81597 .47121 Metetra
.645 .763 .934 r
.81597 .47121 .81778 .47361 .83174 .46941 .82993 .467 Metetra
.645 .763 .934 r
.82993 .467 .83174 .46941 .84576 .46519 .84397 .46277 Metetra
.645 .763 .934 r
.84397 .46277 .84576 .46519 .85985 .46095 .85807 .45851 Metetra
.427 .63 .939 r
.22057 .46171 .22277 .46401 .23298 .46475 .23076 .46272 Metetra
.829 .761 .787 r
.23076 .46272 .23298 .46475 .24443 .45188 .24221 .44995 Metetra
.247 .582 .945 r
.24221 .44995 .24443 .45188 .2546 .45424 .25238 .45236 Metetra
.821 .776 .811 r
.25238 .45236 .2546 .45424 .26595 .4428 .26373 .44109 Metetra
.85 .786 .788 r
.26373 .44109 .26595 .4428 .27746 .42909 .27526 .42736 Metetra
.875 .776 .75 r
.27526 .42736 .27746 .42909 .28919 .4121 .28706 .40967 Metetra
.534 .665 .921 r
.28706 .40967 .28919 .4121 .29973 .41159 .29761 .4091 Metetra
0 .184 .7 r
.29761 .4091 .29973 .41159 .30976 .41982 .30763 .41734 Metetra
0 .126 .649 r
.30763 .41734 .30976 .41982 .31985 .42888 .31772 .42638 Metetra
.739 .73 .843 r
.31772 .42638 .31985 .42888 .33104 .42168 .32891 .41948 Metetra
.358 .611 .946 r
.32891 .41948 .33104 .42168 .34175 .42354 .33962 .42126 Metetra
.933 .555 .233 r
.33962 .42126 .34175 .42354 .35084 .45738 .34869 .45511 Metetra
.758 .757 .851 r
.34869 .45511 .35084 .45738 .36227 .45003 .36015 .44744 Metetra
.743 .73 .84 r
.36015 .44744 .36227 .45003 .37377 .44184 .37162 .44012 Metetra
.585 .77 .967 r
.37162 .44012 .37377 .44184 .38503 .43963 .38289 .43787 Metetra
.896 .786 .732 r
.38289 .43787 .38503 .43963 .39707 .41904 .39495 .41726 Metetra
.899 .784 .725 r
.39495 .41726 .39707 .41904 .40907 .39759 .40697 .39579 Metetra
.89 .789 .743 r
.40697 .39579 .40907 .39759 .42089 .37942 .41884 .37677 Metetra
.761 .311 0 r
.41884 .37677 .42089 .37942 .43158 .39853 .42952 .39588 Metetra
.793 .348 0 r
.42952 .39588 .43158 .39853 .44243 .4194 .44037 .41674 Metetra
.82 .382 0 r
.44037 .41674 .44243 .4194 .45347 .44219 .45139 .43953 Metetra
.888 .748 .701 r
.45139 .43953 .45347 .44219 .4656 .41808 .46355 .41536 Metetra
.846 .42 0 r
.46355 .41536 .4656 .41808 .47691 .44319 .47484 .44116 Metetra
.955 .618 .328 r
.47484 .44116 .47691 .44319 .48798 .51465 .48587 .51267 Metetra
.786 .311 0 r
.48587 .51267 .48798 .51465 .50003 .53461 .49791 .53242 Metetra
.924 .769 .671 r
.49791 .53242 .50003 .53461 .51249 .50355 .51041 .50133 Metetra
.927 .767 .663 r
.51041 .50133 .51249 .50355 .52481 .47127 .52276 .46902 Metetra
.93 .765 .656 r
.52276 .46902 .52481 .47127 .53697 .43774 .53495 .43547 Metetra
.933 .763 .648 r
.53495 .43547 .53697 .43774 .54896 .40296 .54696 .40066 Metetra
.31 .582 .939 r
.54696 .40066 .54896 .40296 .56118 .40579 .55919 .40341 Metetra
.925 .542 .161 r
.55919 .40341 .56118 .40579 .57415 .45083 .57214 .44846 Metetra
.931 .553 .18 r
.57214 .44846 .57415 .45083 .58764 .50052 .58561 .49817 Metetra
.885 .471 .051 r
.58561 .49817 .58764 .50052 .60127 .53596 .59924 .53373 Metetra
.645 .763 .934 r
.59924 .53373 .60127 .53596 .61422 .53206 .6122 .52982 Metetra
.645 .763 .934 r
.6122 .52982 .61422 .53206 .62724 .52813 .62522 .52588 Metetra
.645 .763 .934 r
.62522 .52588 .62724 .52813 .64031 .52419 .63831 .52193 Metetra
.645 .763 .934 r
.63831 .52193 .64031 .52419 .65344 .52023 .65145 .51796 Metetra
.645 .763 .934 r
.65145 .51796 .65344 .52023 .66663 .51625 .66466 .51397 Metetra
.645 .763 .934 r
.66466 .51397 .66663 .51625 .67989 .51225 .67793 .50996 Metetra
.645 .763 .934 r
.67793 .50996 .67989 .51225 .69321 .50824 .69126 .50593 Metetra
.645 .763 .934 r
.69126 .50593 .69321 .50824 .70659 .5042 .70466 .50188 Metetra
.645 .763 .934 r
.70466 .50188 .70659 .5042 .72004 .50014 .71812 .49782 Metetra
.645 .763 .934 r
.71812 .49782 .72004 .50014 .73355 .49607 .73164 .49373 Metetra
.645 .763 .934 r
.73164 .49373 .73355 .49607 .74712 .49198 .74523 .48963 Metetra
.645 .763 .934 r
.74523 .48963 .74712 .49198 .76076 .48786 .75888 .4855 Metetra
.645 .763 .934 r
.75888 .4855 .76076 .48786 .77446 .48373 .7726 .48136 Metetra
.645 .763 .934 r
.7726 .48136 .77446 .48373 .78823 .47958 .78638 .4772 Metetra
.645 .763 .934 r
.78638 .4772 .78823 .47958 .80206 .47541 .80023 .47301 Metetra
.645 .763 .934 r
.80023 .47301 .80206 .47541 .81597 .47121 .81414 .46881 Metetra
.645 .763 .934 r
.81414 .46881 .81597 .47121 .82993 .467 .82813 .46458 Metetra
.645 .763 .934 r
.82813 .46458 .82993 .467 .84397 .46277 .84218 .46034 Metetra
.645 .763 .934 r
.84218 .46034 .84397 .46277 .85807 .45851 .8563 .45607 Metetra
.453 .684 .964 r
.21832 .45977 .22057 .46171 .23076 .46272 .22859 .45995 Metetra
.791 .715 .779 r
.22859 .45995 .23076 .46272 .24221 .44995 .23992 .44866 Metetra
.183 .623 .943 r
.23992 .44866 .24221 .44995 .25238 .45236 .25017 .45031 Metetra
.815 .764 .805 r
.25017 .45031 .25238 .45236 .26373 .44109 .26153 .43906 Metetra
.839 .764 .78 r
.26153 .43906 .26373 .44109 .27526 .42736 .27307 .42532 Metetra
.864 .759 .745 r
.27307 .42532 .27526 .42736 .28706 .40967 .28489 .40767 Metetra
.521 .706 .955 r
.28489 .40767 .28706 .40967 .29761 .4091 .29545 .40693 Metetra
0 .14 .641 r
.29545 .40693 .29761 .4091 .30763 .41734 .30547 .41516 Metetra
0 .08 .584 r
.30547 .41516 .30763 .41734 .31772 .42638 .31556 .42421 Metetra
.764 .76 .848 r
.31556 .42421 .31772 .42638 .32891 .41948 .32682 .41639 Metetra
.321 .502 .88 r
.32682 .41639 .32891 .41948 .33962 .42126 .33742 .42005 Metetra
.922 .548 .288 r
.33742 .42005 .33962 .42126 .34869 .45511 .34648 .45394 Metetra
.806 .862 .89 r
.34648 .45394 .34869 .45511 .36015 .44744 .35801 .44522 Metetra
.752 .761 .861 r
.35801 .44522 .36015 .44744 .37162 .44012 .36948 .43796 Metetra
.605 .728 .932 r
.36948 .43796 .37162 .44012 .38289 .43787 .38076 .43559 Metetra
.879 .759 .725 r
.38076 .43559 .38289 .43787 .39495 .41726 .39284 .41496 Metetra
.883 .758 .719 r
.39284 .41496 .39495 .41726 .40697 .39579 .40489 .39347 Metetra
.871 .76 .737 r
.40489 .39347 .40697 .39579 .41884 .37677 .41677 .37467 Metetra
.81 .347 0 r
.41677 .37467 .41884 .37677 .42952 .39588 .42744 .39378 Metetra
.833 .378 0 r
.42744 .39378 .42952 .39588 .44037 .41674 .43828 .41465 Metetra
.852 .406 0 r
.43828 .41465 .44037 .41674 .45139 .43953 .4493 .43745 Metetra
.905 .774 .705 r
.4493 .43745 .45139 .43953 .46355 .41536 .46148 .41311 Metetra
.869 .437 .024 r
.46148 .41311 .46355 .41536 .47484 .44116 .47276 .43904 Metetra
.955 .618 .326 r
.47276 .43904 .47484 .44116 .48587 .51267 .48375 .51059 Metetra
.749 .268 0 r
.48375 .51059 .48587 .51267 .49791 .53242 .49581 .52897 Metetra
.893 .725 .667 r
.49581 .52897 .49791 .53242 .51041 .50133 .50833 .49788 Metetra
.897 .725 .661 r
.50833 .49788 .51041 .50133 .52276 .46902 .5207 .46556 Metetra
.901 .725 .654 r
.5207 .46556 .52276 .46902 .53495 .43547 .53291 .43201 Metetra
.905 .725 .648 r
.53291 .43201 .53495 .43547 .54696 .40066 .54495 .39719 Metetra
.298 .467 .859 r
.54495 .39719 .54696 .40066 .55919 .40341 .55721 .40232 Metetra
.927 .543 .23 r
.55721 .40232 .55919 .40341 .57214 .44846 .57015 .44742 Metetra
.931 .553 .242 r
.57015 .44742 .57214 .44846 .58561 .49817 .5836 .4972 Metetra
.897 .478 .147 r
.5836 .4972 .58561 .49817 .59924 .53373 .59719 .5315 Metetra
.645 .763 .934 r
.59719 .5315 .59924 .53373 .6122 .52982 .61017 .52757 Metetra
.645 .763 .934 r
.61017 .52757 .6122 .52982 .62522 .52588 .6232 .52363 Metetra
.645 .763 .934 r
.6232 .52363 .62522 .52588 .63831 .52193 .6363 .51966 Metetra
.645 .763 .934 r
.6363 .51966 .63831 .52193 .65145 .51796 .64946 .51568 Metetra
.645 .763 .934 r
.64946 .51568 .65145 .51796 .66466 .51397 .66268 .51168 Metetra
.645 .763 .934 r
.66268 .51168 .66466 .51397 .67793 .50996 .67596 .50766 Metetra
.645 .763 .934 r
.67596 .50766 .67793 .50996 .69126 .50593 .68931 .50362 Metetra
.645 .763 .934 r
.68931 .50362 .69126 .50593 .70466 .50188 .70272 .49956 Metetra
.645 .763 .934 r
.70272 .49956 .70466 .50188 .71812 .49782 .71619 .49549 Metetra
.645 .763 .934 r
.71619 .49549 .71812 .49782 .73164 .49373 .72973 .49139 Metetra
.645 .763 .934 r
.72973 .49139 .73164 .49373 .74523 .48963 .74333 .48727 Metetra
.645 .763 .934 r
.74333 .48727 .74523 .48963 .75888 .4855 .75699 .48314 Metetra
.645 .763 .934 r
.75699 .48314 .75888 .4855 .7726 .48136 .77073 .47898 Metetra
.645 .763 .934 r
.77073 .47898 .7726 .48136 .78638 .4772 .78452 .47481 Metetra
.645 .763 .934 r
.78452 .47481 .78638 .4772 .80023 .47301 .79839 .47061 Metetra
.645 .763 .934 r
.79839 .47061 .80023 .47301 .81414 .46881 .81232 .4664 Metetra
.645 .763 .934 r
.81232 .4664 .81414 .46881 .82813 .46458 .82632 .46216 Metetra
.645 .763 .934 r
.82632 .46216 .82813 .46458 .84218 .46034 .84038 .4579 Metetra
.645 .763 .934 r
.84038 .4579 .84218 .46034 .8563 .45607 .85452 .45363 Metetra
.471 .655 .94 r
.2161 .4575 .21832 .45977 .22859 .45995 .22636 .45783 Metetra
.817 .757 .796 r
.22636 .45783 .22859 .45995 .23992 .44866 .23775 .44609 Metetra
.412 .597 .921 r
.23775 .44609 .23992 .44866 .25017 .45031 .248 .44762 Metetra
.797 .722 .781 r
.248 .44762 .25017 .45031 .26153 .43906 .25939 .43611 Metetra
.809 .71 .756 r
.25939 .43611 .26153 .43906 .27307 .42532 .27095 .42235 Metetra
.832 .713 .733 r
.27095 .42235 .27307 .42532 .28489 .40767 .28273 .4054 Metetra
.475 .656 .94 r
.28273 .4054 .28489 .40767 .29545 .40693 .29323 .40566 Metetra
.567 .005 0 r
.29323 .40566 .29545 .40693 .30547 .41516 .30325 .4139 Metetra
.613 .058 0 r
.30325 .4139 .30547 .41516 .31556 .42421 .31334 .42295 Metetra
.798 .848 .888 r
.31334 .42295 .31556 .42421 .32682 .41639 .32464 .41466 Metetra
.106 .523 .91 r
.32464 .41466 .32682 .41639 .33742 .42005 .33527 .418 Metetra
.932 .554 .246 r
.33527 .418 .33742 .42005 .34648 .45394 .3443 .45189 Metetra
.774 .778 .856 r
.3443 .45189 .34648 .45394 .35801 .44522 .35582 .44368 Metetra
.782 .827 .887 r
.35582 .44368 .35801 .44522 .36948 .43796 .36734 .43573 Metetra
.598 .72 .93 r
.36734 .43573 .36948 .43796 .38076 .43559 .37862 .43353 Metetra
.886 .77 .728 r
.37862 .43353 .38076 .43559 .39284 .41496 .39073 .41288 Metetra
.89 .769 .721 r
.39073 .41288 .39284 .41496 .40489 .39347 .40279 .39137 Metetra
.879 .772 .74 r
.40279 .39137 .40489 .39347 .41677 .37467 .4147 .37247 Metetra
.804 .341 0 r
.4147 .37247 .41677 .37467 .42744 .39378 .42536 .39159 Metetra
.828 .374 0 r
.42536 .39159 .42744 .39378 .43828 .41465 .43619 .41246 Metetra
.848 .403 0 r
.43619 .41246 .43828 .41465 .4493 .43745 .4472 .43526 Metetra
.902 .769 .706 r
.4472 .43526 .4493 .43745 .46148 .41311 .45941 .41114 Metetra
.874 .439 .048 r
.45941 .41114 .46148 .41311 .47276 .43904 .47069 .43667 Metetra
.957 .62 .32 r
.47069 .43667 .47276 .43904 .48375 .51059 .48163 .50825 Metetra
.734 .261 0 r
.48163 .50825 .48375 .51059 .49581 .52897 .49368 .52707 Metetra
.932 .781 .671 r
.49368 .52707 .49581 .52897 .50833 .49788 .50623 .49595 Metetra
.935 .778 .663 r
.50623 .49595 .50833 .49788 .5207 .46556 .51863 .4636 Metetra
.937 .776 .655 r
.51863 .4636 .5207 .46556 .53291 .43201 .53088 .43001 Metetra
.94 .773 .647 r
.53088 .43001 .53291 .43201 .54495 .39719 .54295 .39516 Metetra
.097 .482 .897 r
.54295 .39516 .54495 .39719 .55721 .40232 .55521 .39988 Metetra
.925 .541 .159 r
.55521 .39988 .55721 .40232 .57015 .44742 .56813 .445 Metetra
.931 .553 .178 r
.56813 .445 .57015 .44742 .5836 .4972 .58156 .4948 Metetra
.877 .46 .033 r
.58156 .4948 .5836 .4972 .59719 .5315 .59514 .52926 Metetra
.645 .763 .934 r
.59514 .52926 .59719 .5315 .61017 .52757 .60813 .52532 Metetra
.645 .763 .934 r
.60813 .52532 .61017 .52757 .6232 .52363 .62118 .52136 Metetra
.645 .763 .934 r
.62118 .52136 .6232 .52363 .6363 .51966 .63429 .51739 Metetra
.645 .763 .934 r
.63429 .51739 .6363 .51966 .64946 .51568 .64746 .5134 Metetra
.645 .763 .934 r
.64746 .5134 .64946 .51568 .66268 .51168 .6607 .50939 Metetra
.645 .763 .934 r
.6607 .50939 .66268 .51168 .67596 .50766 .67399 .50535 Metetra
.645 .763 .934 r
.67399 .50535 .67596 .50766 .68931 .50362 .68735 .50131 Metetra
.645 .763 .934 r
.68735 .50131 .68931 .50362 .70272 .49956 .70077 .49724 Metetra
.645 .763 .934 r
.70077 .49724 .70272 .49956 .71619 .49549 .71426 .49315 Metetra
.645 .763 .934 r
.71426 .49315 .71619 .49549 .72973 .49139 .72781 .48904 Metetra
.645 .763 .934 r
.72781 .48904 .72973 .49139 .74333 .48727 .74142 .48491 Metetra
.645 .763 .934 r
.74142 .48491 .74333 .48727 .75699 .48314 .75511 .48077 Metetra
.645 .763 .934 r
.75511 .48077 .75699 .48314 .77073 .47898 .76885 .4766 Metetra
.645 .763 .934 r
.76885 .4766 .77073 .47898 .78452 .47481 .78266 .47241 Metetra
.645 .763 .934 r
.78266 .47241 .78452 .47481 .79839 .47061 .79654 .46821 Metetra
.645 .763 .934 r
.79654 .46821 .79839 .47061 .81232 .4664 .81049 .46398 Metetra
.645 .763 .934 r
.81049 .46398 .81232 .4664 .82632 .46216 .8245 .45973 Metetra
.645 .763 .934 r
.8245 .45973 .82632 .46216 .84038 .4579 .83858 .45546 Metetra
.645 .763 .934 r
.83858 .45546 .84038 .4579 .85452 .45363 .85273 .45117 Metetra
.432 .708 .981 r
.21382 .45584 .2161 .4575 .22636 .45783 .22411 .45588 Metetra
.816 .77 .81 r
.22411 .45588 .22636 .45783 .23775 .44609 .23545 .4448 Metetra
.145 .6 .928 r
.23545 .4448 .23775 .44609 .248 .44762 .24568 .44672 Metetra
.854 .859 .844 r
.24568 .44672 .248 .44762 .25939 .43611 .25707 .43537 Metetra
.884 .86 .813 r
.25707 .43537 .25939 .43611 .27095 .42235 .26865 .4216 Metetra
.908 .835 .762 r
.26865 .4216 .27095 .42235 .28273 .4054 .28053 .40357 Metetra
.549 .737 .963 r
.28053 .40357 .28273 .4054 .29323 .40566 .29116 .40219 Metetra
.004 .271 .773 r
.29116 .40219 .29323 .40566 .30325 .4139 .30118 .41042 Metetra
0 .228 .747 r
.30118 .41042 .30325 .4139 .31334 .42295 .31126 .41945 Metetra
.724 .665 .791 r
.31126 .41945 .31334 .42295 .32464 .41466 .32252 .41186 Metetra
.268 .5 .894 r
.32252 .41186 .32464 .41466 .33527 .418 .33312 .41572 Metetra
.933 .555 .233 r
.33312 .41572 .33527 .418 .3443 .45189 .34214 .44962 Metetra
.773 .759 .841 r
.34214 .44962 .3443 .45189 .35582 .44368 .35368 .44108 Metetra
.753 .733 .833 r
.35368 .44108 .35582 .44368 .36734 .43573 .36521 .43316 Metetra
.596 .687 .905 r
.36521 .43316 .36734 .43573 .37862 .43353 .37649 .43114 Metetra
.876 .754 .724 r
.37649 .43114 .37862 .43353 .39073 .41288 .38862 .41047 Metetra
.88 .753 .718 r
.38862 .41047 .39073 .41288 .40279 .39137 .4007 .38895 Metetra
.867 .755 .737 r
.4007 .38895 .40279 .39137 .4147 .37247 .41262 .37027 Metetra
.804 .341 0 r
.41262 .37027 .4147 .37247 .42536 .39159 .42328 .38939 Metetra
.827 .374 0 r
.42328 .38939 .42536 .39159 .43619 .41246 .4341 .41027 Metetra
.848 .403 0 r
.4341 .41027 .43619 .41246 .4472 .43526 .4451 .43307 Metetra
.901 .77 .707 r
.4451 .43307 .4472 .43526 .45941 .41114 .45732 .40917 Metetra
.868 .43 .036 r
.45732 .40917 .45941 .41114 .47069 .43667 .46861 .43404 Metetra
.958 .621 .314 r
.46861 .43404 .47069 .43667 .48163 .50825 .47952 .50563 Metetra
.701 .239 0 r
.47952 .50563 .48163 .50825 .49368 .52707 .49156 .52444 Metetra
.913 .754 .67 r
.49156 .52444 .49368 .52707 .50623 .49595 .50413 .49329 Metetra
.917 .752 .663 r
.50413 .49329 .50623 .49595 .51863 .4636 .51656 .46092 Metetra
.92 .751 .655 r
.51656 .46092 .51863 .4636 .53088 .43001 .52884 .42732 Metetra
.923 .75 .648 r
.52884 .42732 .53088 .43001 .54295 .39516 .54094 .39244 Metetra
.181 .462 .885 r
.54094 .39244 .54295 .39516 .55521 .39988 .55321 .39781 Metetra
.928 .543 .181 r
.55321 .39781 .55521 .39988 .56813 .445 .56611 .44296 Metetra
.933 .554 .198 r
.56611 .44296 .56813 .445 .58156 .4948 .57952 .49279 Metetra
.886 .466 .066 r
.57952 .49279 .58156 .4948 .59514 .52926 .59309 .52701 Metetra
.645 .763 .934 r
.59309 .52701 .59514 .52926 .60813 .52532 .60609 .52306 Metetra
.645 .763 .934 r
.60609 .52306 .60813 .52532 .62118 .52136 .61915 .51909 Metetra
.645 .763 .934 r
.61915 .51909 .62118 .52136 .63429 .51739 .63227 .51511 Metetra
.645 .763 .934 r
.63227 .51511 .63429 .51739 .64746 .5134 .64546 .51111 Metetra
.645 .763 .934 r
.64546 .51111 .64746 .5134 .6607 .50939 .65871 .50708 Metetra
.645 .763 .934 r
.65871 .50708 .6607 .50939 .67399 .50535 .67201 .50304 Metetra
.645 .763 .934 r
.67201 .50304 .67399 .50535 .68735 .50131 .68539 .49898 Metetra
.645 .763 .934 r
.68539 .49898 .68735 .50131 .70077 .49724 .69882 .4949 Metetra
.645 .763 .934 r
.69882 .4949 .70077 .49724 .71426 .49315 .71232 .4908 Metetra
.645 .763 .934 r
.71232 .4908 .71426 .49315 .72781 .48904 .72589 .48668 Metetra
.645 .763 .934 r
.72589 .48668 .72781 .48904 .74142 .48491 .73952 .48255 Metetra
.645 .763 .934 r
.73952 .48255 .74142 .48491 .75511 .48077 .75321 .47839 Metetra
.645 .763 .934 r
.75321 .47839 .75511 .48077 .76885 .4766 .76697 .47421 Metetra
.645 .763 .934 r
.76697 .47421 .76885 .4766 .78266 .47241 .7808 .47001 Metetra
.645 .763 .934 r
.7808 .47001 .78266 .47241 .79654 .46821 .79469 .46579 Metetra
.645 .763 .934 r
.79469 .46579 .79654 .46821 .81049 .46398 .80865 .46155 Metetra
.645 .763 .934 r
.80865 .46155 .81049 .46398 .8245 .45973 .82268 .45729 Metetra
.645 .763 .934 r
.82268 .45729 .8245 .45973 .83858 .45546 .83678 .45301 Metetra
.645 .763 .934 r
.83678 .45301 .83858 .45546 .85273 .45117 .85094 .44871 Metetra
.481 .654 .936 r
.2116 .45351 .21382 .45584 .22411 .45588 .22187 .45372 Metetra
.82 .755 .791 r
.22187 .45372 .22411 .45588 .23545 .4448 .23333 .44152 Metetra
.46 .559 .869 r
.23333 .44152 .23545 .4448 .24568 .44672 .24359 .443 Metetra
.77 .667 .75 r
.24359 .443 .24568 .44672 .25707 .43537 .25503 .43118 Metetra
.775 .653 .728 r
.25503 .43118 .25707 .43537 .26865 .4216 .26662 .4174 Metetra
.792 .659 .716 r
.26662 .4174 .26865 .4216 .28053 .40357 .27836 .40134 Metetra
.434 .644 .946 r
.27836 .40134 .28053 .40357 .29116 .40219 .28883 .40213 Metetra
.679 .146 0 r
.28883 .40213 .29116 .40219 .30118 .41042 .29886 .41037 Metetra
.703 .18 0 r
.29886 .41037 .30118 .41042 .31126 .41945 .30895 .41942 Metetra
.803 .969 .909 r
.30895 .41942 .31126 .41945 .32252 .41186 .3203 .4107 Metetra
0 .49 .838 r
.3203 .4107 .32252 .41186 .33312 .41572 .33095 .41377 Metetra
.931 .554 .253 r
.33095 .41377 .33312 .41572 .34214 .44962 .33995 .44769 Metetra
.767 .789 .871 r
.33995 .44769 .34214 .44962 .35368 .44108 .35146 .44005 Metetra
.815 .878 .892 r
.35146 .44005 .35368 .44108 .36521 .43316 .36306 .431 Metetra
.591 .726 .937 r
.36306 .431 .36521 .43316 .37649 .43114 .37435 .42889 Metetra
.881 .762 .726 r
.37435 .42889 .37649 .43114 .38862 .41047 .38649 .40821 Metetra
.885 .76 .719 r
.38649 .40821 .38862 .41047 .4007 .38895 .3986 .38667 Metetra
.87 .764 .742 r
.3986 .38667 .4007 .38895 .41262 .37027 .41052 .3684 Metetra
.825 .359 0 r
.41052 .3684 .41262 .37027 .42328 .38939 .42118 .38753 Metetra
.844 .388 0 r
.42118 .38753 .42328 .38939 .4341 .41027 .43199 .40842 Metetra
.86 .414 .027 r
.43199 .40842 .4341 .41027 .4451 .43307 .44299 .43124 Metetra
.912 .787 .709 r
.44299 .43124 .4451 .43307 .45732 .40917 .45524 .40721 Metetra
.868 .429 .036 r
.45524 .40721 .45732 .40917 .46861 .43404 .46651 .43198 Metetra
.955 .618 .328 r
.46651 .43198 .46861 .43404 .47952 .50563 .47738 .50361 Metetra
.777 .299 0 r
.47738 .50361 .47952 .50563 .49156 .52444 .48942 .52296 Metetra
.943 .798 .671 r
.48942 .52296 .49156 .52444 .50413 .49329 .50202 .49177 Metetra
.945 .794 .663 r
.50202 .49177 .50413 .49329 .51656 .46092 .51449 .45937 Metetra
.947 .791 .654 r
.51449 .45937 .51656 .46092 .52884 .42732 .52679 .42572 Metetra
.95 .787 .646 r
.52679 .42572 .52884 .42732 .54094 .39244 .53892 .39081 Metetra
.027 .48 .879 r
.53892 .39081 .54094 .39244 .55321 .39781 .55119 .39519 Metetra
.923 .54 .149 r
.55119 .39519 .55321 .39781 .56611 .44296 .56407 .44034 Metetra
.93 .552 .169 r
.56407 .44034 .56611 .44296 .57952 .49279 .57746 .49018 Metetra
.872 .457 .018 r
.57746 .49018 .57952 .49279 .59309 .52701 .59103 .52476 Metetra
.645 .763 .934 r
.59103 .52476 .59309 .52701 .60609 .52306 .60404 .5208 Metetra
.645 .763 .934 r
.60404 .5208 .60609 .52306 .61915 .51909 .61712 .51682 Metetra
.645 .763 .934 r
.61712 .51682 .61915 .51909 .63227 .51511 .63025 .51282 Metetra
.645 .763 .934 r
.63025 .51282 .63227 .51511 .64546 .51111 .64345 .50881 Metetra
.645 .763 .934 r
.64345 .50881 .64546 .51111 .65871 .50708 .65671 .50478 Metetra
.645 .763 .934 r
.65671 .50478 .65871 .50708 .67201 .50304 .67003 .50073 Metetra
.645 .763 .934 r
.67003 .50073 .67201 .50304 .68539 .49898 .68342 .49665 Metetra
.645 .763 .934 r
.68342 .49665 .68539 .49898 .69882 .4949 .69687 .49256 Metetra
.645 .763 .934 r
.69687 .49256 .69882 .4949 .71232 .4908 .71038 .48845 Metetra
.645 .763 .934 r
.71038 .48845 .71232 .4908 .72589 .48668 .72396 .48432 Metetra
.645 .763 .934 r
.72396 .48432 .72589 .48668 .73952 .48255 .7376 .48017 Metetra
.645 .763 .934 r
.7376 .48017 .73952 .48255 .75321 .47839 .75131 .476 Metetra
.645 .763 .934 r
.75131 .476 .75321 .47839 .76697 .47421 .76509 .47181 Metetra
.645 .763 .934 r
.76509 .47181 .76697 .47421 .7808 .47001 .77893 .4676 Metetra
.645 .763 .934 r
.77893 .4676 .7808 .47001 .79469 .46579 .79283 .46337 Metetra
.645 .763 .934 r
.79283 .46337 .79469 .46579 .80865 .46155 .80681 .45912 Metetra
.645 .763 .934 r
.80681 .45912 .80865 .46155 .82268 .45729 .82085 .45485 Metetra
.645 .763 .934 r
.82085 .45485 .82268 .45729 .83678 .45301 .83496 .45056 Metetra
.645 .763 .934 r
.83496 .45056 .83678 .45301 .85094 .44871 .84914 .44625 Metetra
.329 .701 .982 r
.20927 .45218 .2116 .45351 .22187 .45372 .21953 .45268 Metetra
.858 .839 .826 r
.21953 .45268 .22187 .45372 .23333 .44152 .231 .44046 Metetra
0 .47 .805 r
.231 .44046 .23333 .44152 .24359 .443 .24114 .44339 Metetra
.86 .975 .86 r
.24114 .44339 .24359 .443 .25503 .43118 .25255 .43224 Metetra
.887 .989 .797 r
.25255 .43224 .25503 .43118 .26662 .4174 .26417 .41843 Metetra
.946 .943 .75 r
.26417 .41843 .26662 .4174 .27836 .40134 .27614 .39972 Metetra
.621 .783 .96 r
.27614 .39972 .27836 .40134 .28883 .40213 .28689 .39686 Metetra
.247 .32 .742 r
.28689 .39686 .28883 .40213 .29886 .41037 .2969 .40507 Metetra
.21 .296 .734 r
.2969 .40507 .29886 .41037 .30895 .41942 .30698 .41409 Metetra
.664 .57 .739 r
.30698 .41409 .30895 .41942 .3203 .4107 .31816 .40805 Metetra
.37 .572 .917 r
.31816 .40805 .3203 .4107 .33095 .41377 .32886 .41029 Metetra
.927 .553 .153 r
.32886 .41029 .33095 .41377 .33995 .44769 .33784 .44418 Metetra
.729 .671 .793 r
.33784 .44418 .33995 .44769 .35146 .44005 .34937 .43623 Metetra
.717 .652 .784 r
.34937 .43623 .35146 .44005 .36306 .431 .36091 .42859 Metetra
.599 .704 .917 r
.36091 .42859 .36306 .431 .37435 .42889 .37221 .42641 Metetra
.873 .75 .723 r
.37221 .42641 .37435 .42889 .38649 .40821 .38438 .40571 Metetra
.878 .749 .717 r
.38438 .40571 .38649 .40821 .3986 .38667 .39651 .38416 Metetra
.862 .751 .739 r
.39651 .38416 .3986 .38667 .41052 .3684 .40844 .36601 Metetra
.789 .331 0 r
.40844 .36601 .41052 .3684 .42118 .38753 .41909 .38513 Metetra
.816 .365 0 r
.41909 .38513 .42118 .38753 .43199 .40842 .4299 .40602 Metetra
.838 .396 0 r
.4299 .40602 .43199 .40842 .44299 .43124 .44088 .42884 Metetra
.896 .761 .705 r
.44088 .42884 .44299 .43124 .45524 .40721 .45315 .40472 Metetra
.848 .414 0 r
.45315 .40472 .45524 .40721 .46651 .43198 .46442 .42955 Metetra
.957 .62 .319 r
.46442 .42955 .46651 .43198 .47738 .50361 .47525 .50121 Metetra
.754 .288 0 r
.47525 .50121 .47738 .50361 .48942 .52296 .48727 .52107 Metetra
.932 .782 .671 r
.48727 .52107 .48942 .52296 .50202 .49177 .49991 .48985 Metetra
.935 .779 .663 r
.49991 .48985 .50202 .49177 .51449 .45937 .5124 .45741 Metetra
.938 .777 .655 r
.5124 .45741 .51449 .45937 .52679 .42572 .52474 .42373 Metetra
.941 .774 .647 r
.52474 .42373 .52679 .42572 .53892 .39081 .5369 .38879 Metetra
.212 .559 .935 r
.5369 .38879 .53892 .39081 .55119 .39519 .54917 .39211 Metetra
.917 .537 .121 r
.54917 .39211 .55119 .39519 .56407 .44034 .56203 .43726 Metetra
.925 .549 .144 r
.56203 .43726 .56407 .44034 .57746 .49018 .5754 .48709 Metetra
.858 .452 0 r
.5754 .48709 .57746 .49018 .59103 .52476 .58896 .5225 Metetra
.645 .763 .934 r
.58896 .5225 .59103 .52476 .60404 .5208 .60199 .51853 Metetra
.645 .763 .934 r
.60199 .51853 .60404 .5208 .61712 .51682 .61508 .51454 Metetra
.645 .763 .934 r
.61508 .51454 .61712 .51682 .63025 .51282 .62822 .51053 Metetra
.645 .763 .934 r
.62822 .51053 .63025 .51282 .64345 .50881 .64144 .50651 Metetra
.645 .763 .934 r
.64144 .50651 .64345 .50881 .65671 .50478 .65471 .50246 Metetra
.645 .763 .934 r
.65471 .50246 .65671 .50478 .67003 .50073 .66804 .4984 Metetra
.645 .763 .934 r
.66804 .4984 .67003 .50073 .68342 .49665 .68144 .49432 Metetra
.645 .763 .934 r
.68144 .49432 .68342 .49665 .69687 .49256 .69491 .49022 Metetra
.645 .763 .934 r
.69491 .49022 .69687 .49256 .71038 .48845 .70843 .48609 Metetra
.645 .763 .934 r
.70843 .48609 .71038 .48845 .72396 .48432 .72203 .48195 Metetra
.645 .763 .934 r
.72203 .48195 .72396 .48432 .7376 .48017 .73568 .47779 Metetra
.645 .763 .934 r
.73568 .47779 .7376 .48017 .75131 .476 .74941 .47361 Metetra
.645 .763 .934 r
.74941 .47361 .75131 .476 .76509 .47181 .76319 .46941 Metetra
.645 .763 .934 r
.76319 .46941 .76509 .47181 .77893 .4676 .77705 .46519 Metetra
.645 .763 .934 r
.77705 .46519 .77893 .4676 .79283 .46337 .79097 .46095 Metetra
.645 .763 .934 r
.79097 .46095 .79283 .46337 .80681 .45912 .80496 .45668 Metetra
.645 .763 .934 r
.80496 .45668 .80681 .45912 .82085 .45485 .81902 .4524 Metetra
.645 .763 .934 r
.81902 .4524 .82085 .45485 .83496 .45056 .83315 .4481 Metetra
.645 .763 .934 r
.83315 .4481 .83496 .45056 .84914 .44625 .84734 .44377 Metetra
.479 .63 .919 r
.20706 .44961 .20927 .45218 .21953 .45268 .21732 .45006 Metetra
.815 .727 .768 r
.21732 .45006 .21953 .45268 .231 .44046 .2289 .43677 Metetra
.46 .531 .843 r
.2289 .43677 .231 .44046 .24114 .44339 .23914 .43858 Metetra
.744 .622 .724 r
.23914 .43858 .24114 .44339 .25255 .43224 .25062 .42669 Metetra
.745 .606 .703 r
.25062 .42669 .25255 .43224 .26417 .41843 .26224 .41289 Metetra
.758 .612 .697 r
.26224 .41289 .26417 .41843 .27614 .39972 .27397 .39735 Metetra
.445 .635 .936 r
.27397 .39735 .27614 .39972 .28689 .39686 .28445 .39812 Metetra
.683 .217 .139 r
.28445 .39812 .28689 .39686 .2969 .40507 .29447 .40636 Metetra
.699 .239 .156 r
.29447 .40636 .2969 .40507 .30698 .41409 .30456 .41541 Metetra
.564 .916 .717 r
.30456 .41541 .30698 .41409 .31816 .40805 .31591 .40705 Metetra
.07 .581 .884 r
.31591 .40705 .31816 .40805 .32886 .41029 .32664 .40894 Metetra
.924 .549 .282 r
.32664 .40894 .32886 .41029 .33784 .44418 .3356 .44287 Metetra
.765 .851 .916 r
.3356 .44287 .33784 .44418 .34937 .43623 .3471 .43582 Metetra
.822 .94 .904 r
.3471 .43582 .34937 .43623 .36091 .42859 .35874 .42656 Metetra
.599 .743 .945 r
.35874 .42656 .36091 .42859 .37221 .42641 .37006 .42419 Metetra
.882 .763 .727 r
.37006 .42419 .37221 .42641 .38438 .40571 .38224 .40348 Metetra
.886 .762 .72 r
.38224 .40348 .38438 .40571 .39651 .38416 .3944 .3819 Metetra
.867 .766 .749 r
.3944 .3819 .39651 .38416 .40844 .36601 .40633 .36429 Metetra
.832 .366 0 r
.40633 .36429 .40844 .36601 .41909 .38513 .41697 .38343 Metetra
.849 .393 .013 r
.41697 .38343 .41909 .38513 .4299 .40602 .42777 .40433 Metetra
.864 .418 .047 r
.42777 .40433 .4299 .40602 .44088 .42884 .43875 .42717 Metetra
.918 .794 .708 r
.43875 .42717 .44088 .42884 .45315 .40472 .45106 .40279 Metetra
.87 .431 .041 r
.45106 .40279 .45315 .40472 .46442 .42955 .46231 .4277 Metetra
.953 .616 .333 r
.46231 .4277 .46442 .42955 .47525 .50121 .4731 .49941 Metetra
.803 .326 0 r
.4731 .49941 .47525 .50121 .48727 .52107 .48512 .51939 Metetra
.938 .791 .671 r
.48512 .51939 .48727 .52107 .49991 .48985 .49779 .48814 Metetra
.941 .788 .663 r
.49779 .48814 .49991 .48985 .5124 .45741 .51032 .45567 Metetra
.943 .784 .655 r
.51032 .45567 .5124 .45741 .52474 .42373 .52268 .42195 Metetra
.946 .781 .647 r
.52268 .42195 .52474 .42373 .5369 .38879 .53488 .38697 Metetra
.206 .58 .942 r
.53488 .38697 .5369 .38879 .54917 .39211 .54715 .38986 Metetra
.927 .542 .171 r
.54715 .38986 .54917 .39211 .56203 .43726 .55999 .43503 Metetra
.932 .553 .189 r
.55999 .43503 .56203 .43726 .5754 .48709 .57334 .48489 Metetra
.888 .471 .063 r
.57334 .48489 .5754 .48709 .58896 .5225 .58689 .52023 Metetra
.645 .763 .934 r
.58689 .52023 .58896 .5225 .60199 .51853 .59993 .51625 Metetra
.645 .763 .934 r
.59993 .51625 .60199 .51853 .61508 .51454 .61303 .51225 Metetra
.645 .763 .934 r
.61303 .51225 .61508 .51454 .62822 .51053 .62619 .50824 Metetra
.645 .763 .934 r
.62619 .50824 .62822 .51053 .64144 .50651 .63942 .5042 Metetra
.645 .763 .934 r
.63942 .5042 .64144 .50651 .65471 .50246 .6527 .50014 Metetra
.645 .763 .934 r
.6527 .50014 .65471 .50246 .66804 .4984 .66605 .49607 Metetra
.645 .763 .934 r
.66605 .49607 .66804 .4984 .68144 .49432 .67946 .49198 Metetra
.645 .763 .934 r
.67946 .49198 .68144 .49432 .69491 .49022 .69294 .48786 Metetra
.645 .763 .934 r
.69294 .48786 .69491 .49022 .70843 .48609 .70648 .48373 Metetra
.645 .763 .934 r
.70648 .48373 .70843 .48609 .72203 .48195 .72009 .47958 Metetra
.645 .763 .934 r
.72009 .47958 .72203 .48195 .73568 .47779 .73376 .47541 Metetra
.645 .763 .934 r
.73376 .47541 .73568 .47779 .74941 .47361 .7475 .47121 Metetra
.645 .763 .934 r
.7475 .47121 .74941 .47361 .76319 .46941 .7613 .467 Metetra
.645 .763 .934 r
.7613 .467 .76319 .46941 .77705 .46519 .77517 .46277 Metetra
.645 .763 .934 r
.77517 .46277 .77705 .46519 .79097 .46095 .78911 .45851 Metetra
.645 .763 .934 r
.78911 .45851 .79097 .46095 .80496 .45668 .80311 .45424 Metetra
.645 .763 .934 r
.80311 .45424 .80496 .45668 .81902 .4524 .81718 .44994 Metetra
.645 .763 .934 r
.81718 .44994 .81902 .4524 .83315 .4481 .83133 .44563 Metetra
.645 .763 .934 r
.83133 .44563 .83315 .4481 .84734 .44377 .84554 .44129 Metetra
.298 .675 .974 r
.20473 .44819 .20706 .44961 .21732 .45006 .21496 .44909 Metetra
.87 .84 .814 r
.21496 .44909 .21732 .45006 .2289 .43677 .22655 .43584 Metetra
0 .396 .721 r
.22655 .43584 .2289 .43677 .23914 .43858 .23666 .43919 Metetra
.846 .989 .854 r
.23666 .43919 .23914 .43858 .25062 .42669 .24808 .42817 Metetra
.856 .996 .764 r
.24808 .42817 .25062 .42669 .26224 .41289 .25973 .41434 Metetra
.94 .961 .735 r
.25973 .41434 .26224 .41289 .27397 .39735 .27175 .39559 Metetra
.638 .774 .945 r
.27175 .39559 .27397 .39735 .28445 .39812 .28253 .39241 Metetra
.277 .322 .73 r
.28253 .39241 .28445 .39812 .29447 .40636 .29254 .40061 Metetra
.244 .301 .723 r
.29254 .40061 .29447 .40636 .30456 .41541 .30262 .40963 Metetra
.647 .549 .73 r
.30262 .40963 .30456 .41541 .31591 .40705 .31377 .40431 Metetra
.458 .609 .912 r
.31377 .40431 .31591 .40705 .32664 .40894 .32456 .40527 Metetra
.924 .551 .141 r
.32456 .40527 .32664 .40894 .3356 .44287 .3335 .43917 Metetra
.72 .659 .789 r
.3335 .43917 .3356 .44287 .3471 .43582 .34504 .4315 Metetra
.696 .623 .771 r
.34504 .4315 .3471 .43582 .35874 .42656 .35656 .42446 Metetra
.61 .74 .938 r
.35656 .42446 .35874 .42656 .37006 .42419 .3679 .42188 Metetra
.879 .759 .725 r
.3679 .42188 .37006 .42419 .38224 .40348 .38011 .40114 Metetra
.883 .758 .719 r
.38011 .40114 .38224 .40348 .3944 .3819 .39228 .37955 Metetra
.866 .761 .745 r
.39228 .37955 .3944 .3819 .40633 .36429 .40424 .36165 Metetra
.767 .315 0 r
.40424 .36165 .40633 .36429 .41697 .38343 .41488 .38078 Metetra
.798 .352 0 r
.41488 .38078 .41697 .38343 .42777 .40433 .42567 .40168 Metetra
.824 .385 0 r
.42567 .40168 .42777 .40433 .43875 .42717 .43664 .42452 Metetra
.89 .749 .699 r
.43664 .42452 .43875 .42717 .45106 .40279 .44897 .39984 Metetra
.833 .41 0 r
.44897 .39984 .45106 .40279 .46231 .4277 .46021 .42551 Metetra
.956 .618 .325 r
.46021 .42551 .46231 .4277 .4731 .49941 .47096 .49726 Metetra
.785 .314 0 r
.47096 .49726 .4731 .49941 .48512 .51939 .48296 .51751 Metetra
.933 .783 .671 r
.48296 .51751 .48512 .51939 .49779 .48814 .49566 .48622 Metetra
.936 .78 .663 r
.49566 .48622 .49779 .48814 .51032 .45567 .50822 .45372 Metetra
.938 .777 .655 r
.50822 .45372 .51032 .45567 .52268 .42195 .52062 .41997 Metetra
.941 .774 .647 r
.52062 .41997 .52268 .42195 .53488 .38697 .53285 .38495 Metetra
.337 .634 .962 r
.53285 .38495 .53488 .38697 .54715 .38986 .54512 .38666 Metetra
.915 .535 .114 r
.54512 .38666 .54715 .38986 .55999 .43503 .55794 .43182 Metetra
.923 .549 .137 r
.55794 .43182 .55999 .43503 .57334 .48489 .57126 .48167 Metetra
.859 .456 0 r
.57126 .48167 .57334 .48489 .58689 .52023 .58482 .51796 Metetra
.645 .763 .934 r
.58482 .51796 .58689 .52023 .59993 .51625 .59787 .51397 Metetra
.645 .763 .934 r
.59787 .51397 .59993 .51625 .61303 .51225 .61098 .50996 Metetra
.645 .763 .934 r
.61098 .50996 .61303 .51225 .62619 .50824 .62415 .50593 Metetra
.645 .763 .934 r
.62415 .50593 .62619 .50824 .63942 .5042 .63739 .50188 Metetra
.645 .763 .934 r
.63739 .50188 .63942 .5042 .6527 .50014 .65069 .49782 Metetra
.645 .763 .934 r
.65069 .49782 .6527 .50014 .66605 .49607 .66405 .49373 Metetra
.645 .763 .934 r
.66405 .49373 .66605 .49607 .67946 .49198 .67748 .48963 Metetra
.645 .763 .934 r
.67748 .48963 .67946 .49198 .69294 .48786 .69097 .4855 Metetra
.645 .763 .934 r
.69097 .4855 .69294 .48786 .70648 .48373 .70452 .48136 Metetra
.645 .763 .934 r
.70452 .48136 .70648 .48373 .72009 .47958 .71814 .4772 Metetra
.645 .763 .934 r
.71814 .4772 .72009 .47958 .73376 .47541 .73183 .47301 Metetra
.645 .763 .934 r
.73183 .47301 .73376 .47541 .7475 .47121 .74558 .46881 Metetra
.645 .763 .934 r
.74558 .46881 .7475 .47121 .7613 .467 .7594 .46458 Metetra
.645 .763 .934 r
.7594 .46458 .7613 .467 .77517 .46277 .77328 .46034 Metetra
.645 .763 .934 r
.77328 .46034 .77517 .46277 .78911 .45851 .78723 .45607 Metetra
.645 .763 .934 r
.78723 .45607 .78911 .45851 .80311 .45424 .80125 .45179 Metetra
.645 .763 .934 r
.80125 .45179 .80311 .45424 .81718 .44994 .81534 .44748 Metetra
.645 .763 .934 r
.81534 .44748 .81718 .44994 .83133 .44563 .8295 .44315 Metetra
.645 .763 .934 r
.8295 .44315 .83133 .44563 .84554 .44129 .84373 .4388 Metetra
.496 .629 .911 r
.20251 .44551 .20473 .44819 .21496 .44909 .21281 .44574 Metetra
.787 .687 .754 r
.21281 .44574 .21496 .44909 .22655 .43584 .22435 .43314 Metetra
.407 .585 .913 r
.22435 .43314 .22655 .43584 .23666 .43919 .23461 .43482 Metetra
.752 .639 .736 r
.23461 .43482 .23666 .43919 .24808 .42817 .2461 .42314 Metetra
.756 .623 .712 r
.2461 .42314 .24808 .42817 .25973 .41434 .25775 .40931 Metetra
.774 .631 .702 r
.25775 .40931 .25973 .41434 .27175 .39559 .26958 .39306 Metetra
.497 .644 .922 r
.26958 .39306 .27175 .39559 .28253 .39241 .28012 .39315 Metetra
.686 .193 .072 r
.28012 .39315 .28253 .39241 .29254 .40061 .29014 .40137 Metetra
.704 .219 .094 r
.29014 .40137 .29254 .40061 .30262 .40963 .30022 .41041 Metetra
.683 .979 .839 r
.30022 .41041 .30262 .40963 .31377 .40431 .31158 .40217 Metetra
.269 .574 .94 r
.31158 .40217 .31377 .40431 .32456 .40527 .32228 .40475 Metetra
.91 .541 .316 r
.32228 .40475 .32456 .40527 .3335 .43917 .3312 .4387 Metetra
.78 .939 .932 r
.3312 .4387 .3335 .43917 .34504 .4315 .34276 .43092 Metetra
.804 .928 .916 r
.34276 .43092 .34504 .4315 .35656 .42446 .35438 .42238 Metetra
.606 .741 .94 r
.35438 .42238 .35656 .42446 .3679 .42188 .36573 .41986 Metetra
.888 .774 .729 r
.36573 .41986 .3679 .42188 .38011 .40114 .37796 .3991 Metetra
.892 .772 .722 r
.37796 .3991 .38011 .40114 .39228 .37955 .39015 .37749 Metetra
.875 .778 .751 r
.39015 .37749 .39228 .37955 .40424 .36165 .40213 .35965 Metetra
.818 .353 0 r
.40213 .35965 .40424 .36165 .41488 .38078 .41276 .37879 Metetra
.839 .383 0 r
.41276 .37879 .41488 .38078 .42567 .40168 .42355 .39969 Metetra
.857 .41 .012 r
.42355 .39969 .42567 .40168 .43664 .42452 .43451 .42253 Metetra
.91 .78 .705 r
.43451 .42253 .43664 .42452 .44897 .39984 .44686 .39793 Metetra
.874 .439 .055 r
.44686 .39793 .44897 .39984 .46021 .42551 .45809 .42337 Metetra
.955 .618 .326 r
.45809 .42337 .46021 .42551 .47096 .49726 .4688 .49516 Metetra
.77 .293 0 r
.4688 .49516 .47096 .49726 .48296 .51751 .48082 .51443 Metetra
.903 .739 .669 r
.48082 .51443 .48296 .51751 .49566 .48622 .49354 .48313 Metetra
.907 .739 .662 r
.49354 .48313 .49566 .48622 .50822 .45372 .50613 .45062 Metetra
.911 .738 .655 r
.50613 .45062 .50822 .45372 .52062 .41997 .51855 .41685 Metetra
.915 .737 .648 r
.51855 .41685 .52062 .41997 .53285 .38495 .53081 .38183 Metetra
.332 .519 .889 r
.53081 .38183 .53285 .38495 .54512 .38666 .5431 .38559 Metetra
.927 .542 .23 r
.5431 .38559 .54512 .38666 .55794 .43182 .5559 .4308 Metetra
.931 .552 .243 r
.5559 .4308 .55794 .43182 .57126 .48167 .56921 .48072 Metetra
.899 .481 .153 r
.56921 .48072 .57126 .48167 .58482 .51796 .58273 .51568 Metetra
.645 .763 .934 r
.58273 .51568 .58482 .51796 .59787 .51397 .5958 .51168 Metetra
.645 .763 .934 r
.5958 .51168 .59787 .51397 .61098 .50996 .60892 .50766 Metetra
.645 .763 .934 r
.60892 .50766 .61098 .50996 .62415 .50593 .62211 .50362 Metetra
.645 .763 .934 r
.62211 .50362 .62415 .50593 .63739 .50188 .63536 .49956 Metetra
.645 .763 .934 r
.63536 .49956 .63739 .50188 .65069 .49782 .64867 .49549 Metetra
.645 .763 .934 r
.64867 .49549 .65069 .49782 .66405 .49373 .66205 .49139 Metetra
.645 .763 .934 r
.66205 .49139 .66405 .49373 .67748 .48963 .67549 .48727 Metetra
.645 .763 .934 r
.67549 .48727 .67748 .48963 .69097 .4855 .68899 .48314 Metetra
.645 .763 .934 r
.68899 .48314 .69097 .4855 .70452 .48136 .70256 .47898 Metetra
.645 .763 .934 r
.70256 .47898 .70452 .48136 .71814 .4772 .71619 .47481 Metetra
.645 .763 .934 r
.71619 .47481 .71814 .4772 .73183 .47301 .72989 .47061 Metetra
.645 .763 .934 r
.72989 .47061 .73183 .47301 .74558 .46881 .74366 .4664 Metetra
.645 .763 .934 r
.74366 .4664 .74558 .46881 .7594 .46458 .75749 .46216 Metetra
.645 .763 .934 r
.75749 .46216 .7594 .46458 .77328 .46034 .77139 .4579 Metetra
.645 .763 .934 r
.77139 .4579 .77328 .46034 .78723 .45607 .78536 .45363 Metetra
.645 .763 .934 r
.78536 .45363 .78723 .45607 .80125 .45179 .79939 .44933 Metetra
.645 .763 .934 r
.79939 .44933 .80125 .45179 .81534 .44748 .8135 .44501 Metetra
.645 .763 .934 r
.8135 .44501 .81534 .44748 .8295 .44315 .82767 .44067 Metetra
.645 .763 .934 r
.82767 .44067 .8295 .44315 .84373 .4388 .84191 .43631 Metetra
.289 .674 .973 r
.20017 .44411 .20251 .44551 .21281 .44574 .2104 .44504 Metetra
.881 .861 .816 r
.2104 .44504 .21281 .44574 .22435 .43314 .22206 .43148 Metetra
.034 .488 .882 r
.22206 .43148 .22435 .43314 .23461 .43482 .23216 .43496 Metetra
.864 .956 .866 r
.23216 .43496 .23461 .43482 .2461 .42314 .24362 .42383 Metetra
.9 .97 .815 r
.24362 .42383 .2461 .42314 .25775 .40931 .2553 .40997 Metetra
.943 .924 .76 r
.2553 .40997 .25775 .40931 .26958 .39306 .26733 .3914 Metetra
.636 .785 .953 r
.26733 .3914 .26958 .39306 .28012 .39315 .27813 .3882 Metetra
.212 .313 .751 r
.27813 .3882 .28012 .39315 .29014 .40137 .28814 .39639 Metetra
.17 .287 .742 r
.28814 .39639 .29014 .40137 .30022 .41041 .29822 .40541 Metetra
.657 .576 .753 r
.29822 .40541 .30022 .41041 .31158 .40217 .30938 .40014 Metetra
.417 .665 .963 r
.30938 .40014 .31158 .40217 .32228 .40475 .32021 .40079 Metetra
.919 .548 .12 r
.32021 .40079 .32228 .40475 .3312 .4387 .3291 .43472 Metetra
.709 .642 .781 r
.3291 .43472 .3312 .4387 .34276 .43092 .34065 .42733 Metetra
.719 .665 .796 r
.34065 .42733 .34276 .43092 .35438 .42238 .35222 .41989 Metetra
.613 .703 .909 r
.35222 .41989 .35438 .42238 .36573 .41986 .36357 .41735 Metetra
.873 .75 .723 r
.36357 .41735 .36573 .41986 .37796 .3991 .37582 .39658 Metetra
.878 .749 .717 r
.37582 .39658 .37796 .3991 .39015 .37749 .38804 .37495 Metetra
.858 .751 .744 r
.38804 .37495 .39015 .37749 .40213 .35965 .40003 .35728 Metetra
.794 .334 0 r
.40003 .35728 .40213 .35965 .41276 .37879 .41065 .37642 Metetra
.82 .368 0 r
.41065 .37642 .41276 .37879 .42355 .39969 .42143 .39733 Metetra
.842 .398 0 r
.42143 .39733 .42355 .39969 .43451 .42253 .43238 .42018 Metetra
.899 .763 .702 r
.43238 .42018 .43451 .42253 .44686 .39793 .44476 .39554 Metetra
.859 .426 0 r
.44476 .39554 .44686 .39793 .45809 .42337 .45598 .42086 Metetra
.957 .62 .318 r
.45598 .42086 .45809 .42337 .4688 .49516 .46665 .49268 Metetra
.765 .304 0 r
.46665 .49268 .4688 .49516 .48082 .51443 .47864 .51329 Metetra
.951 .812 .67 r
.47864 .51329 .48082 .51443 .49354 .48313 .4914 .48194 Metetra
.953 .808 .662 r
.4914 .48194 .49354 .48313 .50613 .45062 .50402 .44938 Metetra
.955 .804 .653 r
.50402 .44938 .50613 .45062 .51855 .41685 .51648 .41557 Metetra
.957 .799 .644 r
.51648 .41557 .51855 .41685 .53081 .38183 .52877 .3805 Metetra
.239 .66 .96 r
.52877 .3805 .53081 .38183 .5431 .38559 .54106 .38183 Metetra
.902 .528 .078 r
.54106 .38183 .5431 .38559 .5559 .4308 .55384 .42701 Metetra
.913 .543 .104 r
.55384 .42701 .5559 .4308 .56921 .48072 .56711 .4769 Metetra
.83 .439 0 r
.56711 .4769 .56921 .48072 .58273 .51568 .58065 .5134 Metetra
.645 .763 .934 r
.58065 .5134 .58273 .51568 .5958 .51168 .59372 .50939 Metetra
.645 .763 .934 r
.59372 .50939 .5958 .51168 .60892 .50766 .60686 .50535 Metetra
.645 .763 .934 r
.60686 .50535 .60892 .50766 .62211 .50362 .62006 .50131 Metetra
.645 .763 .934 r
.62006 .50131 .62211 .50362 .63536 .49956 .63332 .49724 Metetra
.645 .763 .934 r
.63332 .49724 .63536 .49956 .64867 .49549 .64665 .49315 Metetra
.645 .763 .934 r
.64665 .49315 .64867 .49549 .66205 .49139 .66004 .48904 Metetra
.645 .763 .934 r
.66004 .48904 .66205 .49139 .67549 .48727 .67349 .48491 Metetra
.645 .763 .934 r
.67349 .48491 .67549 .48727 .68899 .48314 .68701 .48077 Metetra
.645 .763 .934 r
.68701 .48077 .68899 .48314 .70256 .47898 .70059 .4766 Metetra
.645 .763 .934 r
.70059 .4766 .70256 .47898 .71619 .47481 .71424 .47241 Metetra
.645 .763 .934 r
.71424 .47241 .71619 .47481 .72989 .47061 .72795 .46821 Metetra
.645 .763 .934 r
.72795 .46821 .72989 .47061 .74366 .4664 .74173 .46398 Metetra
.645 .763 .934 r
.74173 .46398 .74366 .4664 .75749 .46216 .75558 .45973 Metetra
.645 .763 .934 r
.75558 .45973 .75749 .46216 .77139 .4579 .76949 .45546 Metetra
.645 .763 .934 r
.76949 .45546 .77139 .4579 .78536 .45363 .78348 .45117 Metetra
.645 .763 .934 r
.78348 .45117 .78536 .45363 .79939 .44933 .79753 .44686 Metetra
.645 .763 .934 r
.79753 .44686 .79939 .44933 .8135 .44501 .81164 .44253 Metetra
.645 .763 .934 r
.81164 .44253 .8135 .44501 .82767 .44067 .82583 .43818 Metetra
.645 .763 .934 r
.82583 .43818 .82767 .44067 .84191 .43631 .84009 .43381 Metetra
.513 .625 .899 r
.19796 .4413 .20017 .44411 .2104 .44504 .20828 .4413 Metetra
.767 .666 .751 r
.20828 .4413 .2104 .44504 .22206 .43148 .21976 .42972 Metetra
.288 .63 .963 r
.21976 .42972 .22206 .43148 .23216 .43496 .23004 .43132 Metetra
.769 .672 .756 r
.23004 .43132 .23216 .43496 .24362 .42383 .24153 .41983 Metetra
.781 .662 .732 r
.24153 .41983 .24362 .42383 .2553 .40997 .25322 .40596 Metetra
.806 .671 .714 r
.25322 .40596 .2553 .40997 .26733 .3914 .26517 .38863 Metetra
.546 .644 .898 r
.26517 .38863 .26733 .3914 .27813 .3882 .27579 .38789 Metetra
.667 .121 0 r
.27579 .38789 .27813 .3882 .28814 .39639 .2858 .3961 Metetra
.694 .158 0 r
.2858 .3961 .28814 .39639 .29822 .40541 .29588 .40513 Metetra
.79 .951 .924 r
.29588 .40513 .29822 .40541 .30938 .40014 .30725 .39705 Metetra
.317 .505 .884 r
.30725 .39705 .30938 .40014 .32021 .40079 .31789 .4006 Metetra
.904 .537 .327 r
.31789 .4006 .32021 .40079 .3291 .43472 .32677 .43458 Metetra
.792 .966 .916 r
.32677 .43458 .3291 .43472 .34065 .42733 .3384 .42602 Metetra
.785 .853 .902 r
.3384 .42602 .34065 .42733 .35222 .41989 .35001 .41811 Metetra
.591 .77 .965 r
.35001 .41811 .35222 .41989 .36357 .41735 .36137 .41567 Metetra
.9 .793 .734 r
.36137 .41567 .36357 .41735 .37582 .39658 .37364 .39488 Metetra
.903 .79 .726 r
.37364 .39488 .37582 .39658 .38804 .37495 .38588 .37322 Metetra
.89 .798 .751 r
.38588 .37322 .38804 .37495 .40003 .35728 .39792 .35478 Metetra
.782 .325 0 r
.39792 .35478 .40003 .35728 .41065 .37642 .40854 .37391 Metetra
.81 .361 0 r
.40854 .37391 .41065 .37642 .42143 .39733 .41931 .39482 Metetra
.834 .392 0 r
.41931 .39482 .42143 .39733 .43238 .42018 .43025 .41766 Metetra
.894 .756 .702 r
.43025 .41766 .43238 .42018 .44476 .39554 .44265 .39316 Metetra
.862 .43 .007 r
.44265 .39316 .44476 .39554 .45598 .42086 .45385 .41875 Metetra
.955 .618 .327 r
.45385 .41875 .45598 .42086 .46665 .49268 .46448 .4906 Metetra
.759 .277 0 r
.46448 .4906 .46665 .49268 .47864 .51329 .4765 .50922 Metetra
.88 .708 .664 r
.4765 .50922 .47864 .51329 .4914 .48194 .48928 .47788 Metetra
.885 .708 .658 r
.48928 .47788 .4914 .48194 .50402 .44938 .50192 .44532 Metetra
.889 .709 .652 r
.50192 .44532 .50402 .44938 .51648 .41557 .51441 .41151 Metetra
.893 .709 .646 r
.51441 .41151 .51648 .41557 .52877 .3805 .52672 .37645 Metetra
.343 .458 .833 r
.52672 .37645 .52877 .3805 .54106 .38183 .53903 .38143 Metetra
.922 .539 .259 r
.53903 .38143 .54106 .38183 .55384 .42701 .55179 .4267 Metetra
.926 .548 .269 r
.55179 .4267 .55384 .42701 .56711 .4769 .56506 .47668 Metetra
.894 .478 .193 r
.56506 .47668 .56711 .4769 .58065 .5134 .57855 .51111 Metetra
.645 .763 .934 r
.57855 .51111 .58065 .5134 .59372 .50939 .59164 .50708 Metetra
.645 .763 .934 r
.59164 .50708 .59372 .50939 .60686 .50535 .60479 .50304 Metetra
.645 .763 .934 r
.60479 .50304 .60686 .50535 .62006 .50131 .61801 .49898 Metetra
.645 .763 .934 r
.61801 .49898 .62006 .50131 .63332 .49724 .63128 .4949 Metetra
.645 .763 .934 r
.63128 .4949 .63332 .49724 .64665 .49315 .64462 .4908 Metetra
.645 .763 .934 r
.64462 .4908 .64665 .49315 .66004 .48904 .65802 .48668 Metetra
.645 .763 .934 r
.65802 .48668 .66004 .48904 .67349 .48491 .67149 .48255 Metetra
.645 .763 .934 r
.67149 .48255 .67349 .48491 .68701 .48077 .68502 .47839 Metetra
.645 .763 .934 r
.68502 .47839 .68701 .48077 .70059 .4766 .69862 .47421 Metetra
.645 .763 .934 r
.69862 .47421 .70059 .4766 .71424 .47241 .71228 .47001 Metetra
.645 .763 .934 r
.71228 .47001 .71424 .47241 .72795 .46821 .72601 .46579 Metetra
.645 .763 .934 r
.72601 .46579 .72795 .46821 .74173 .46398 .7398 .46155 Metetra
.645 .763 .934 r
.7398 .46155 .74173 .46398 .75558 .45973 .75366 .45729 Metetra
.645 .763 .934 r
.75366 .45729 .75558 .45973 .76949 .45546 .76759 .45301 Metetra
.645 .763 .934 r
.76759 .45301 .76949 .45546 .78348 .45117 .78159 .44871 Metetra
.645 .763 .934 r
.78159 .44871 .78348 .45117 .79753 .44686 .79565 .44439 Metetra
.645 .763 .934 r
.79565 .44439 .79753 .44686 .81164 .44253 .80979 .44005 Metetra
.645 .763 .934 r
.80979 .44005 .81164 .44253 .82583 .43818 .82399 .43568 Metetra
.645 .763 .934 r
.82399 .43568 .82583 .43818 .84009 .43381 .83826 .4313 Metetra
.251 .681 .962 r
.19558 .44014 .19796 .4413 .20828 .4413 .20584 .44089 Metetra
.889 .885 .822 r
.20584 .44089 .20828 .4413 .21976 .42972 .21752 .42731 Metetra
.203 .507 .91 r
.21752 .42731 .21976 .42972 .23004 .43132 .22762 .43087 Metetra
.863 .904 .86 r
.22762 .43087 .23004 .43132 .24153 .41983 .23911 .41964 Metetra
.898 .906 .822 r
.23911 .41964 .24153 .41983 .25322 .40596 .25082 .40575 Metetra
.925 .87 .764 r
.25082 .40575 .25322 .40596 .26517 .38863 .26289 .38729 Metetra
.64 .825 .972 r
.26289 .38729 .26517 .38863 .27579 .38789 .27373 .3838 Metetra
.102 .293 .771 r
.27373 .3838 .27579 .38789 .2858 .3961 .28374 .39199 Metetra
.048 .257 .753 r
.28374 .39199 .2858 .3961 .29588 .40513 .29381 .40099 Metetra
.67 .616 .786 r
.29381 .40099 .29588 .40513 .30725 .39705 .30499 .39573 Metetra
.299 .691 .976 r
.30499 .39573 .30725 .39705 .31789 .4006 .31582 .39642 Metetra
.913 .545 .104 r
.31582 .39642 .31789 .4006 .32677 .43458 .32468 .43036 Metetra
.701 .63 .774 r
.32468 .43036 .32677 .43458 .3384 .42602 .33624 .42315 Metetra
.747 .716 .823 r
.33624 .42315 .3384 .42602 .35001 .41811 .34786 .41514 Metetra
.611 .664 .877 r
.34786 .41514 .35001 .41811 .36137 .41567 .35922 .41269 Metetra
.86 .728 .717 r
.35922 .41269 .36137 .41567 .37364 .39488 .37152 .39188 Metetra
.864 .728 .711 r
.37152 .39188 .37364 .39488 .38588 .37322 .38378 .37022 Metetra
.841 .727 .738 r
.38378 .37022 .38588 .37322 .39792 .35478 .39578 .35298 Metetra
.829 .363 0 r
.39578 .35298 .39792 .35478 .40854 .37391 .40639 .37212 Metetra
.847 .391 .004 r
.40639 .37212 .40854 .37391 .41931 .39482 .41716 .39304 Metetra
.863 .416 .039 r
.41716 .39304 .41931 .39482 .43025 .41766 .42809 .4159 Metetra
.916 .791 .708 r
.42809 .4159 .43025 .41766 .44265 .39316 .44052 .39136 Metetra
.871 .432 .055 r
.44052 .39136 .44265 .39316 .45385 .41875 .45173 .41609 Metetra
.958 .621 .314 r
.45173 .41609 .45385 .41875 .46448 .4906 .46232 .48796 Metetra
.756 .3 0 r
.46232 .48796 .46448 .4906 .4765 .50922 .4743 .50881 Metetra
.967 .842 .666 r
.4743 .50881 .4765 .50922 .48928 .47788 .48712 .47741 Metetra
.969 .836 .657 r
.48712 .47741 .48928 .47788 .50192 .44532 .4998 .44479 Metetra
.97 .83 .648 r
.4998 .44479 .50192 .44532 .51441 .41151 .51232 .41093 Metetra
.972 .824 .639 r
.51232 .41093 .51441 .41151 .52672 .37645 .52467 .3758 Metetra
.045 .592 .838 r
.52467 .3758 .52672 .37645 .53903 .38143 .53697 .37718 Metetra
.887 .519 .045 r
.53697 .37718 .53903 .38143 .55179 .4267 .54971 .4224 Metetra
.9 .536 .074 r
.54971 .4224 .55179 .4267 .56506 .47668 .56295 .47233 Metetra
.795 .418 0 r
.56295 .47233 .56506 .47668 .57855 .51111 .57645 .50881 Metetra
.645 .763 .934 r
.57645 .50881 .57855 .51111 .59164 .50708 .58956 .50478 Metetra
.645 .763 .934 r
.58956 .50478 .59164 .50708 .60479 .50304 .60272 .50073 Metetra
.645 .763 .934 r
.60272 .50073 .60479 .50304 .61801 .49898 .61595 .49665 Metetra
.645 .763 .934 r
.61595 .49665 .61801 .49898 .63128 .4949 .62923 .49256 Metetra
.645 .763 .934 r
.62923 .49256 .63128 .4949 .64462 .4908 .64259 .48845 Metetra
.645 .763 .934 r
.64259 .48845 .64462 .4908 .65802 .48668 .656 .48432 Metetra
.645 .763 .934 r
.656 .48432 .65802 .48668 .67149 .48255 .66948 .48017 Metetra
.645 .763 .934 r
.66948 .48017 .67149 .48255 .68502 .47839 .68303 .476 Metetra
.645 .763 .934 r
.68303 .476 .68502 .47839 .69862 .47421 .69664 .47181 Metetra
.645 .763 .934 r
.69664 .47181 .69862 .47421 .71228 .47001 .71032 .4676 Metetra
.645 .763 .934 r
.71032 .4676 .71228 .47001 .72601 .46579 .72406 .46337 Metetra
.645 .763 .934 r
.72406 .46337 .72601 .46579 .7398 .46155 .73787 .45912 Metetra
.645 .763 .934 r
.73787 .45912 .7398 .46155 .75366 .45729 .75174 .45485 Metetra
.645 .763 .934 r
.75174 .45485 .75366 .45729 .76759 .45301 .76568 .45056 Metetra
.645 .763 .934 r
.76568 .45056 .76759 .45301 .78159 .44871 .7797 .44625 Metetra
.645 .763 .934 r
.7797 .44625 .78159 .44871 .79565 .44439 .79378 .44191 Metetra
.645 .763 .934 r
.79378 .44191 .79565 .44439 .80979 .44005 .80793 .43756 Metetra
.645 .763 .934 r
.80793 .43756 .80979 .44005 .82399 .43568 .82214 .43318 Metetra
.645 .763 .934 r
.82214 .43318 .82399 .43568 .83826 .4313 .83643 .42878 Metetra
.496 .595 .882 r
.19339 .43704 .19558 .44014 .20584 .44089 .20367 .43754 Metetra
.784 .688 .758 r
.20367 .43754 .20584 .44089 .21752 .42731 .21524 .42527 Metetra
.265 .587 .946 r
.21524 .42527 .21752 .42731 .22762 .43087 .22546 .42753 Metetra
.778 .688 .765 r
.22546 .42753 .22762 .43087 .23911 .41964 .23699 .416 Metetra
.791 .679 .741 r
.23699 .416 .23911 .41964 .25082 .40575 .24871 .4021 Metetra
.819 .686 .718 r
.24871 .4021 .25082 .40575 .26289 .38729 .26075 .38419 Metetra
.566 .626 .871 r
.26075 .38419 .26289 .38729 .27373 .3838 .2714 .38311 Metetra
.642 .081 0 r
.2714 .38311 .27373 .3838 .28374 .39199 .28141 .39131 Metetra
.674 .124 0 r
.28141 .39131 .28374 .39199 .29381 .40099 .29149 .40033 Metetra
.773 .916 .935 r
.29149 .40033 .29381 .40099 .30499 .39573 .30282 .39305 Metetra
.344 .559 .916 r
.30282 .39305 .30499 .39573 .31582 .39642 .31353 .39558 Metetra
.916 .543 .304 r
.31353 .39558 .31582 .39642 .32468 .43036 .32237 .42957 Metetra
.788 .908 .924 r
.32237 .42957 .32468 .43036 .33624 .42315 .33399 .42167 Metetra
.788 .837 .89 r
.33399 .42167 .33624 .42315 .34786 .41514 .34564 .41348 Metetra
.564 .775 .977 r
.34564 .41348 .34786 .41514 .35922 .41269 .35699 .4114 Metetra
.912 .815 .738 r
.35699 .4114 .35922 .41269 .37152 .39188 .36931 .39057 Metetra
.915 .811 .73 r
.36931 .39057 .37152 .39188 .38378 .37022 .38159 .36888 Metetra
.905 .821 .753 r
.38159 .36888 .38378 .37022 .39578 .35298 .39369 .35001 Metetra
.734 .294 0 r
.39369 .35001 .39578 .35298 .40639 .37212 .40429 .36915 Metetra
.771 .334 0 r
.40429 .36915 .40639 .37212 .41716 .39304 .41504 .39006 Metetra
.802 .37 0 r
.41504 .39006 .41716 .39304 .42809 .4159 .42597 .41291 Metetra
.879 .737 .701 r
.42597 .41291 .42809 .4159 .44052 .39136 .4384 .38886 Metetra
.85 .415 0 r
.4384 .38886 .44052 .39136 .45173 .41609 .4496 .41374 Metetra
.956 .619 .322 r
.4496 .41374 .45173 .41609 .46232 .48796 .46015 .48564 Metetra
.763 .292 0 r
.46015 .48564 .46232 .48796 .4743 .50881 .47214 .50538 Metetra
.895 .728 .667 r
.47214 .50538 .4743 .50881 .48712 .47741 .48498 .47397 Metetra
.899 .728 .661 r
.48498 .47397 .48712 .47741 .4998 .44479 .49768 .44134 Metetra
.903 .728 .654 r
.49768 .44134 .4998 .44479 .51232 .41093 .51023 .40747 Metetra
.907 .728 .647 r
.51023 .40747 .51232 .41093 .52467 .3758 .52261 .37234 Metetra
.36 .51 .872 r
.52261 .37234 .52467 .3758 .53697 .37718 .53493 .37604 Metetra
.927 .542 .228 r
.53493 .37604 .53697 .37718 .54971 .4224 .54765 .42132 Metetra
.931 .552 .241 r
.54765 .42132 .54971 .4224 .56295 .47233 .56087 .47132 Metetra
.899 .481 .151 r
.56087 .47132 .56295 .47233 .57645 .50881 .57435 .50651 Metetra
.645 .763 .934 r
.57435 .50651 .57645 .50881 .58956 .50478 .58746 .50246 Metetra
.645 .763 .934 r
.58746 .50246 .58956 .50478 .60272 .50073 .60064 .4984 Metetra
.645 .763 .934 r
.60064 .4984 .60272 .50073 .61595 .49665 .61388 .49432 Metetra
.645 .763 .934 r
.61388 .49432 .61595 .49665 .62923 .49256 .62718 .49022 Metetra
.645 .763 .934 r
.62718 .49022 .62923 .49256 .64259 .48845 .64055 .48609 Metetra
.645 .763 .934 r
.64055 .48609 .64259 .48845 .656 .48432 .65398 .48195 Metetra
.645 .763 .934 r
.65398 .48195 .656 .48432 .66948 .48017 .66747 .47779 Metetra
.645 .763 .934 r
.66747 .47779 .66948 .48017 .68303 .476 .68103 .47361 Metetra
.645 .763 .934 r
.68103 .47361 .68303 .476 .69664 .47181 .69465 .46941 Metetra
.645 .763 .934 r
.69465 .46941 .69664 .47181 .71032 .4676 .70834 .46519 Metetra
.645 .763 .934 r
.70834 .46519 .71032 .4676 .72406 .46337 .7221 .46095 Metetra
.645 .763 .934 r
.7221 .46095 .72406 .46337 .73787 .45912 .73592 .45668 Metetra
.645 .763 .934 r
.73592 .45668 .73787 .45912 .75174 .45485 .74981 .4524 Metetra
.645 .763 .934 r
.74981 .4524 .75174 .45485 .76568 .45056 .76377 .4481 Metetra
.645 .763 .934 r
.76377 .4481 .76568 .45056 .7797 .44625 .7778 .44377 Metetra
.645 .763 .934 r
.7778 .44377 .7797 .44625 .79378 .44191 .79189 .43942 Metetra
.645 .763 .934 r
.79189 .43942 .79378 .44191 .80793 .43756 .80606 .43506 Metetra
.645 .763 .934 r
.80606 .43506 .80793 .43756 .82214 .43318 .82029 .43067 Metetra
.645 .763 .934 r
.82029 .43067 .82214 .43318 .83643 .42878 .8346 .42626 Metetra
.205 .661 .945 r
.19098 .43594 .19339 .43704 .20367 .43754 .20123 .43691 Metetra
.885 .863 .813 r
.20123 .43691 .20367 .43754 .21524 .42527 .21298 .42291 Metetra
.162 .489 .903 r
.21298 .42291 .21524 .42527 .22546 .42753 .22306 .42674 Metetra
.856 .873 .852 r
.22306 .42674 .22546 .42753 .23699 .416 .23458 .41548 Metetra
.89 .88 .817 r
.23458 .41548 .23699 .416 .24871 .4021 .24633 .40156 Metetra
.917 .848 .761 r
.24633 .40156 .24871 .4021 .26075 .38419 .25844 .38295 Metetra
.641 .837 .976 r
.25844 .38295 .26075 .38419 .2714 .38311 .26931 .37932 Metetra
.047 .28 .773 r
.26931 .37932 .2714 .38311 .28141 .39131 .27931 .3875 Metetra
0 .24 .751 r
.27931 .3875 .28141 .39131 .29149 .40033 .28938 .3965 Metetra
.669 .63 .802 r
.28938 .3965 .29149 .40033 .30282 .39305 .30056 .39156 Metetra
.382 .715 .987 r
.30056 .39156 .30282 .39305 .31353 .39558 .31143 .39172 Metetra
.922 .55 .132 r
.31143 .39172 .31353 .39558 .32237 .42957 .32025 .42568 Metetra
.703 .646 .789 r
.32025 .42568 .32237 .42957 .33399 .42167 .33182 .41875 Metetra
.747 .714 .821 r
.33182 .41875 .33399 .42167 .34564 .41348 .34347 .41065 Metetra
.608 .675 .888 r
.34347 .41065 .34564 .41348 .35699 .4114 .35484 .40826 Metetra
.855 .722 .715 r
.35484 .40826 .35699 .4114 .36931 .39057 .36718 .38742 Metetra
.86 .722 .709 r
.36718 .38742 .36931 .39057 .38159 .36888 .37949 .36571 Metetra
.837 .72 .735 r
.37949 .36571 .38159 .36888 .39369 .35001 .39153 .3484 Metetra
.836 .369 0 r
.39153 .3484 .39369 .35001 .40429 .36915 .40213 .36754 Metetra
.852 .396 .028 r
.40213 .36754 .40429 .36915 .41504 .39006 .41287 .38847 Metetra
.866 .42 .06 r
.41287 .38847 .41504 .39006 .42597 .41291 .42379 .41134 Metetra
.922 .801 .71 r
.42379 .41134 .42597 .41291 .4384 .38886 .43626 .38686 Metetra
.865 .425 .03 r
.43626 .38686 .4384 .38886 .4496 .41374 .44746 .41142 Metetra
.956 .619 .323 r
.44746 .41142 .4496 .41374 .46015 .48564 .45797 .48335 Metetra
.796 .333 0 r
.45797 .48335 .46015 .48564 .47214 .50538 .46993 .50466 Metetra
.961 .83 .668 r
.46993 .50466 .47214 .50538 .48498 .47397 .48281 .4732 Metetra
.963 .825 .659 r
.48281 .4732 .48498 .47397 .49768 .44134 .49555 .44052 Metetra
.965 .82 .65 r
.49555 .44052 .49768 .44134 .51023 .40747 .50813 .4066 Metetra
.966 .814 .642 r
.50813 .4066 .51023 .40747 .52261 .37234 .52055 .37141 Metetra
.196 .677 .931 r
.52055 .37141 .52261 .37234 .53493 .37604 .53287 .37212 Metetra
.899 .526 .07 r
.53287 .37212 .53493 .37604 .54765 .42132 .54556 .41737 Metetra
.91 .542 .097 r
.54556 .41737 .54765 .42132 .56087 .47132 .55875 .46733 Metetra
.825 .438 0 r
.55875 .46733 .56087 .47132 .57435 .50651 .57224 .5042 Metetra
.645 .763 .934 r
.57224 .5042 .57435 .50651 .58746 .50246 .58537 .50014 Metetra
.645 .763 .934 r
.58537 .50014 .58746 .50246 .60064 .4984 .59856 .49607 Metetra
.645 .763 .934 r
.59856 .49607 .60064 .4984 .61388 .49432 .61181 .49198 Metetra
.645 .763 .934 r
.61181 .49198 .61388 .49432 .62718 .49022 .62512 .48786 Metetra
.645 .763 .934 r
.62512 .48786 .62718 .49022 .64055 .48609 .6385 .48373 Metetra
.645 .763 .934 r
.6385 .48373 .64055 .48609 .65398 .48195 .65195 .47958 Metetra
.645 .763 .934 r
.65195 .47958 .65398 .48195 .66747 .47779 .66545 .47541 Metetra
.645 .763 .934 r
.66545 .47541 .66747 .47779 .68103 .47361 .67903 .47121 Metetra
.645 .763 .934 r
.67903 .47121 .68103 .47361 .69465 .46941 .69266 .467 Metetra
.645 .763 .934 r
.69266 .467 .69465 .46941 .70834 .46519 .70637 .46277 Metetra
.645 .763 .934 r
.70637 .46277 .70834 .46519 .7221 .46095 .72014 .45851 Metetra
.645 .763 .934 r
.72014 .45851 .7221 .46095 .73592 .45668 .73398 .45424 Metetra
.645 .763 .934 r
.73398 .45424 .73592 .45668 .74981 .4524 .74788 .44994 Metetra
.645 .763 .934 r
.74788 .44994 .74981 .4524 .76377 .4481 .76185 .44563 Metetra
.645 .763 .934 r
.76185 .44563 .76377 .4481 .7778 .44377 .7759 .44129 Metetra
.645 .763 .934 r
.7759 .44129 .7778 .44377 .79189 .43942 .79001 .43693 Metetra
.645 .763 .934 r
.79001 .43693 .79189 .43942 .80606 .43506 .80418 .43255 Metetra
.645 .763 .934 r
.80418 .43255 .80606 .43506 .82029 .43067 .81843 .42815 Metetra
.645 .763 .934 r
.81843 .42815 .82029 .43067 .8346 .42626 .83275 .42373 Metetra
.391 .533 .878 r
.1888 .43272 .19098 .43594 .20123 .43691 .19889 .43515 Metetra
.86 .778 .769 r
.19889 .43515 .20123 .43691 .21298 .42291 .21083 .41944 Metetra
.287 .456 .854 r
.21083 .41944 .21298 .42291 .22306 .42674 .22086 .42374 Metetra
.788 .708 .775 r
.22086 .42374 .22306 .42674 .23458 .41548 .23242 .41217 Metetra
.801 .695 .749 r
.23242 .41217 .23458 .41548 .24633 .40156 .24418 .39824 Metetra
.832 .701 .72 r
.24418 .39824 .24633 .40156 .25844 .38295 .2563 .37967 Metetra
.578 .62 .858 r
.2563 .37967 .25844 .38295 .26931 .37932 .26699 .37829 Metetra
.604 .038 0 r
.26699 .37829 .26931 .37932 .27931 .3875 .277 .38648 Metetra
.644 .087 0 r
.277 .38648 .27931 .3875 .28938 .3965 .28707 .39549 Metetra
.681 .874 .971 r
.28707 .39549 .28938 .3965 .30056 .39156 .29824 .39075 Metetra
.467 .83 .994 r
.29824 .39075 .30056 .39156 .31143 .39172 .30927 .38879 Metetra
.933 .556 .198 r
.30927 .38879 .31143 .39172 .32025 .42568 .31807 .42274 Metetra
.695 .697 .848 r
.31807 .42274 .32025 .42568 .33182 .41875 .32955 .41728 Metetra
.792 .839 .887 r
.32955 .41728 .33182 .41875 .34347 .41065 .34124 .40886 Metetra
.547 .756 .974 r
.34124 .40886 .34347 .41065 .35484 .40826 .35258 .40717 Metetra
.918 .827 .74 r
.35258 .40717 .35484 .40826 .36718 .38742 .36495 .3863 Metetra
.921 .823 .731 r
.36495 .3863 .36718 .38742 .37949 .36571 .37728 .36457 Metetra
.914 .831 .751 r
.37728 .36457 .37949 .36571 .39153 .3484 .38944 .34517 Metetra
.701 .274 0 r
.38944 .34517 .39153 .3484 .40213 .36754 .40002 .3643 Metetra
.743 .317 0 r
.40002 .3643 .40213 .36754 .41287 .38847 .41076 .38522 Metetra
.779 .356 0 r
.41076 .38522 .41287 .38847 .42379 .41134 .42166 .40807 Metetra
.87 .726 .701 r
.42166 .40807 .42379 .41134 .43626 .38686 .43413 .3845 Metetra
.849 .409 0 r
.43413 .3845 .43626 .38686 .44746 .41142 .44533 .4087 Metetra
.958 .621 .314 r
.44533 .4087 .44746 .41142 .45797 .48335 .45579 .48065 Metetra
.798 .353 0 r
.45579 .48065 .45797 .48335 .46993 .50466 .46771 .50385 Metetra
.959 .826 .669 r
.46771 .50385 .46993 .50466 .48281 .4732 .48063 .47234 Metetra
.961 .821 .66 r
.48063 .47234 .48281 .4732 .49555 .44052 .4934 .43961 Metetra
.963 .816 .651 r
.4934 .43961 .49555 .44052 .50813 .4066 .50602 .40563 Metetra
.964 .811 .642 r
.50602 .40563 .50813 .4066 .52055 .37141 .51847 .37039 Metetra
.465 .82 .997 r
.51847 .37039 .52055 .37141 .53287 .37212 .5308 .36842 Metetra
.905 .53 .085 r
.5308 .36842 .53287 .37212 .54556 .41737 .54348 .41364 Metetra
.915 .545 .111 r
.54348 .41364 .54556 .41737 .55875 .46733 .55664 .46357 Metetra
.851 .461 0 r
.55664 .46357 .55875 .46733 .57224 .5042 .57012 .50188 Metetra
.645 .763 .934 r
.57012 .50188 .57224 .5042 .58537 .50014 .58326 .49782 Metetra
.645 .763 .934 r
.58326 .49782 .58537 .50014 .59856 .49607 .59647 .49373 Metetra
.645 .763 .934 r
.59647 .49373 .59856 .49607 .61181 .49198 .60973 .48963 Metetra
.645 .763 .934 r
.60973 .48963 .61181 .49198 .62512 .48786 .62306 .4855 Metetra
.645 .763 .934 r
.62306 .4855 .62512 .48786 .6385 .48373 .63645 .48136 Metetra
.645 .763 .934 r
.63645 .48136 .6385 .48373 .65195 .47958 .64991 .4772 Metetra
.645 .763 .934 r
.64991 .4772 .65195 .47958 .66545 .47541 .66343 .47301 Metetra
.645 .763 .934 r
.66343 .47301 .66545 .47541 .67903 .47121 .67702 .46881 Metetra
.645 .763 .934 r
.67702 .46881 .67903 .47121 .69266 .467 .69067 .46458 Metetra
.645 .763 .934 r
.69067 .46458 .69266 .467 .70637 .46277 .70439 .46034 Metetra
.645 .763 .934 r
.70439 .46034 .70637 .46277 .72014 .45851 .71817 .45607 Metetra
.645 .763 .934 r
.71817 .45607 .72014 .45851 .73398 .45424 .73202 .45179 Metetra
.645 .763 .934 r
.73202 .45179 .73398 .45424 .74788 .44994 .74594 .44748 Metetra
.645 .763 .934 r
.74594 .44748 .74788 .44994 .76185 .44563 .75993 .44315 Metetra
.645 .763 .934 r
.75993 .44315 .76185 .44563 .7759 .44129 .77399 .4388 Metetra
.645 .763 .934 r
.77399 .4388 .7759 .44129 .79001 .43693 .78811 .43443 Metetra
.645 .763 .934 r
.78811 .43443 .79001 .43693 .80418 .43255 .80231 .43004 Metetra
.645 .763 .934 r
.80231 .43004 .80418 .43255 .81843 .42815 .81657 .42562 Metetra
.645 .763 .934 r
.81657 .42562 .81843 .42815 .83275 .42373 .83091 .42119 Metetra
.057 .571 .878 r
.18638 .43167 .1888 .43272 .19889 .43515 .19653 .43356 Metetra
.867 .789 .772 r
.19653 .43356 .19889 .43515 .21083 .41944 .2085 .41769 Metetra
0 .383 .81 r
.2085 .41769 .21083 .41944 .22086 .42374 .2185 .42233 Metetra
.837 .82 .832 r
.2185 .42233 .22086 .42374 .23242 .41217 .23005 .41108 Metetra
.873 .835 .806 r
.23005 .41108 .23242 .41217 .24418 .39824 .24183 .39714 Metetra
.899 .814 .755 r
.24183 .39714 .24418 .39824 .2563 .37967 .25398 .37854 Metetra
.628 .847 .983 r
.25398 .37854 .2563 .37967 .26699 .37829 .26485 .37504 Metetra
0 .247 .761 r
.26485 .37504 .26699 .37829 .277 .38648 .27485 .38322 Metetra
0 .199 .728 r
.27485 .38322 .277 .38648 .28707 .39549 .28492 .39222 Metetra
.653 .656 .84 r
.28492 .39222 .28707 .39549 .29824 .39075 .29604 .38833 Metetra
.597 .702 .917 r
.29604 .38833 .29824 .39075 .30927 .38879 .30708 .38618 Metetra
.934 .556 .217 r
.30708 .38618 .30927 .38879 .31807 .42274 .31586 .42013 Metetra
.711 .726 .862 r
.31586 .42013 .31807 .42274 .32955 .41728 .32738 .41424 Metetra
.74 .705 .818 r
.32738 .41424 .32955 .41728 .34124 .40886 .33904 .40636 Metetra
.61 .705 .912 r
.33904 .40636 .34124 .40886 .35258 .40717 .35044 .40384 Metetra
.85 .714 .712 r
.35044 .40384 .35258 .40717 .36495 .3863 .36282 .38296 Metetra
.855 .715 .707 r
.36282 .38296 .36495 .3863 .37728 .36457 .37517 .36122 Metetra
.832 .712 .731 r
.37517 .36122 .37728 .36457 .38944 .34517 .38726 .34379 Metetra
.842 .376 .025 r
.38726 .34379 .38944 .34517 .40002 .3643 .39784 .36294 Metetra
.857 .401 .057 r
.39784 .36294 .40002 .3643 .41076 .38522 .40857 .38387 Metetra
.869 .424 .087 r
.40857 .38387 .41076 .38522 .42166 .40807 .41947 .40675 Metetra
.93 .814 .71 r
.41947 .40675 .42166 .40807 .43413 .3845 .432 .38208 Metetra
.855 .419 0 r
.432 .38208 .43413 .3845 .44533 .4087 .44317 .40701 Metetra
.952 .615 .337 r
.44317 .40701 .44533 .4087 .45579 .48065 .45359 .47902 Metetra
.845 .385 .005 r
.45359 .47902 .45579 .48065 .46771 .50385 .46551 .50171 Metetra
.928 .775 .671 r
.46551 .50171 .46771 .50385 .48063 .47234 .47846 .47018 Metetra
.931 .773 .663 r
.47846 .47018 .48063 .47234 .4934 .43961 .49126 .43742 Metetra
.934 .77 .655 r
.49126 .43742 .4934 .43961 .50602 .40563 .50392 .40341 Metetra
.937 .768 .648 r
.50392 .40341 .50602 .40563 .51847 .37039 .5164 .36814 Metetra
.581 .732 .946 r
.5164 .36814 .51847 .37039 .5308 .36842 .52874 .36593 Metetra
.925 .541 .16 r
.52874 .36593 .5308 .36842 .54348 .41364 .54139 .41116 Metetra
.931 .553 .179 r
.54139 .41116 .54348 .41364 .55664 .46357 .55453 .46111 Metetra
.896 .49 .08 r
.55453 .46111 .55664 .46357 .57012 .50188 .568 .49956 Metetra
.645 .763 .934 r
.568 .49956 .57012 .50188 .58326 .49782 .58115 .49549 Metetra
.645 .763 .934 r
.58115 .49549 .58326 .49782 .59647 .49373 .59437 .49139 Metetra
.645 .763 .934 r
.59437 .49139 .59647 .49373 .60973 .48963 .60765 .48727 Metetra
.645 .763 .934 r
.60765 .48727 .60973 .48963 .62306 .4855 .62099 .48314 Metetra
.645 .763 .934 r
.62099 .48314 .62306 .4855 .63645 .48136 .6344 .47898 Metetra
.645 .763 .934 r
.6344 .47898 .63645 .48136 .64991 .4772 .64787 .47481 Metetra
.645 .763 .934 r
.64787 .47481 .64991 .4772 .66343 .47301 .6614 .47061 Metetra
.645 .763 .934 r
.6614 .47061 .66343 .47301 .67702 .46881 .675 .4664 Metetra
.645 .763 .934 r
.675 .4664 .67702 .46881 .69067 .46458 .68867 .46216 Metetra
.645 .763 .934 r
.68867 .46216 .69067 .46458 .70439 .46034 .7024 .4579 Metetra
.645 .763 .934 r
.7024 .4579 .70439 .46034 .71817 .45607 .7162 .45363 Metetra
.645 .763 .934 r
.7162 .45363 .71817 .45607 .73202 .45179 .73007 .44933 Metetra
.645 .763 .934 r
.73007 .44933 .73202 .45179 .74594 .44748 .744 .44501 Metetra
.645 .763 .934 r
.744 .44501 .74594 .44748 .75993 .44315 .758 .44067 Metetra
.645 .763 .934 r
.758 .44067 .75993 .44315 .77399 .4388 .77207 .43631 Metetra
.645 .763 .934 r
.77207 .43631 .77399 .4388 .78811 .43443 .78621 .43192 Metetra
.645 .763 .934 r
.78621 .43192 .78811 .43443 .80231 .43004 .80042 .42752 Metetra
.645 .763 .934 r
.80042 .42752 .80231 .43004 .81657 .42562 .8147 .42309 Metetra
.645 .763 .934 r
.8147 .42309 .81657 .42562 .83091 .42119 .82905 .41864 Metetra
.279 .478 .875 r
.18417 .42851 .18638 .43167 .19653 .43356 .19413 .43237 Metetra
.892 .803 .754 r
.19413 .43237 .19653 .43356 .2085 .41769 .20638 .41378 Metetra
.242 .397 .818 r
.20638 .41378 .2085 .41769 .2185 .42233 .21629 .41936 Metetra
.787 .709 .778 r
.21629 .41936 .2185 .42233 .23005 .41108 .22786 .40796 Metetra
.807 .706 .753 r
.22786 .40796 .23005 .41108 .24183 .39714 .23965 .394 Metetra
.838 .71 .723 r
.23965 .394 .24183 .39714 .25398 .37854 .25182 .37532 Metetra
.582 .627 .862 r
.25182 .37532 .25398 .37854 .26485 .37504 .26253 .37381 Metetra
.574 .01 0 r
.26253 .37381 .26485 .37504 .27485 .38322 .27254 .38199 Metetra
.619 .062 0 r
.27254 .38199 .27485 .38322 .28492 .39222 .28261 .39099 Metetra
.589 .83 .99 r
.28261 .39099 .28492 .39222 .29604 .38833 .29367 .38812 Metetra
.664 .946 .958 r
.29367 .38812 .29604 .38833 .30708 .38618 .30496 .38252 Metetra
.927 .553 .148 r
.30496 .38252 .30708 .38618 .31586 .42013 .31372 .41645 Metetra
.651 .635 .821 r
.31372 .41645 .31586 .42013 .32738 .41424 .32513 .41236 Metetra
.764 .799 .881 r
.32513 .41236 .32738 .41424 .33904 .40636 .33678 .40482 Metetra
.557 .789 .986 r
.33678 .40482 .33904 .40636 .35044 .40384 .34817 .40268 Metetra
.916 .823 .739 r
.34817 .40268 .35044 .40384 .36282 .38296 .36058 .38177 Metetra
.92 .819 .731 r
.36058 .38177 .36282 .38296 .37517 .36122 .37296 .36 Metetra
.911 .827 .75 r
.37296 .36 .37517 .36122 .38726 .34379 .38515 .34058 Metetra
.706 .277 0 r
.38515 .34058 .38726 .34379 .39784 .36294 .39572 .35972 Metetra
.747 .32 0 r
.39572 .35972 .39784 .36294 .40857 .38387 .40644 .38064 Metetra
.783 .358 0 r
.40644 .38064 .40857 .38387 .41947 .40675 .41733 .4035 Metetra
.873 .727 .698 r
.41733 .4035 .41947 .40675 .432 .38208 .42986 .37932 Metetra
.844 .415 0 r
.42986 .37932 .432 .38208 .44317 .40701 .44101 .40467 Metetra
.956 .619 .323 r
.44101 .40467 .44317 .40701 .45359 .47902 .45139 .47672 Metetra
.847 .403 0 r
.45139 .47672 .45359 .47902 .46551 .50171 .46326 .50177 Metetra
.976 .861 .661 r
.46326 .50177 .46551 .50171 .47846 .47018 .47625 .47017 Metetra
.977 .854 .652 r
.47625 .47017 .47846 .47018 .49126 .43742 .4891 .43734 Metetra
.978 .847 .643 r
.4891 .43734 .49126 .43742 .50392 .40341 .50179 .40327 Metetra
.98 .84 .634 r
.50179 .40327 .50392 .40341 .5164 .36814 .51431 .36794 Metetra
.658 .959 .937 r
.51431 .36794 .5164 .36814 .52874 .36593 .52667 .36137 Metetra
.877 .514 .027 r
.52667 .36137 .52874 .36593 .54139 .41116 .53929 .40654 Metetra
.892 .532 .057 r
.53929 .40654 .54139 .41116 .55453 .46111 .55239 .45644 Metetra
.822 .454 0 r
.55239 .45644 .55453 .46111 .568 .49956 .56587 .49724 Metetra
.645 .763 .934 r
.56587 .49724 .568 .49956 .58115 .49549 .57904 .49315 Metetra
.645 .763 .934 r
.57904 .49315 .58115 .49549 .59437 .49139 .59227 .48904 Metetra
.645 .763 .934 r
.59227 .48904 .59437 .49139 .60765 .48727 .60556 .48491 Metetra
.645 .763 .934 r
.60556 .48491 .60765 .48727 .62099 .48314 .61891 .48077 Metetra
.645 .763 .934 r
.61891 .48077 .62099 .48314 .6344 .47898 .63233 .4766 Metetra
.645 .763 .934 r
.63233 .4766 .6344 .47898 .64787 .47481 .64582 .47241 Metetra
.645 .763 .934 r
.64582 .47241 .64787 .47481 .6614 .47061 .65937 .46821 Metetra
.645 .763 .934 r
.65937 .46821 .6614 .47061 .675 .4664 .67298 .46398 Metetra
.645 .763 .934 r
.67298 .46398 .675 .4664 .68867 .46216 .68666 .45973 Metetra
.645 .763 .934 r
.68666 .45973 .68867 .46216 .7024 .4579 .70041 .45546 Metetra
.645 .763 .934 r
.70041 .45546 .7024 .4579 .7162 .45363 .71422 .45117 Metetra
.645 .763 .934 r
.71422 .45117 .7162 .45363 .73007 .44933 .7281 .44686 Metetra
.645 .763 .934 r
.7281 .44686 .73007 .44933 .744 .44501 .74205 .44253 Metetra
.645 .763 .934 r
.74205 .44253 .744 .44501 .758 .44067 .75607 .43818 Metetra
.645 .763 .934 r
.75607 .43818 .758 .44067 .77207 .43631 .77015 .43381 Metetra
.645 .763 .934 r
.77015 .43381 .77207 .43631 .78621 .43192 .78431 .42941 Metetra
.645 .763 .934 r
.78431 .42941 .78621 .43192 .80042 .42752 .79853 .42499 Metetra
.645 .763 .934 r
.79853 .42499 .80042 .42752 .8147 .42309 .81283 .42055 Metetra
.645 .763 .934 r
.81283 .42055 .8147 .42309 .82905 .41864 .8272 .41609 Metetra
0 .516 .827 r
.18173 .42753 .18417 .42851 .19413 .43237 .19185 .42984 Metetra
.843 .735 .745 r
.19185 .42984 .19413 .43237 .20638 .41378 .20395 .41296 Metetra
.416 0 0 r
.20395 .41296 .20638 .41378 .21629 .41936 .21392 .41801 Metetra
.838 .826 .836 r
.21392 .41801 .21629 .41936 .22786 .40796 .22548 .40686 Metetra
.873 .834 .805 r
.22548 .40686 .22786 .40796 .23965 .394 .23729 .39288 Metetra
.899 .814 .755 r
.23729 .39288 .23965 .394 .25182 .37532 .24948 .37426 Metetra
.634 .857 .984 r
.24948 .37426 .25182 .37532 .26253 .37381 .26038 .37055 Metetra
0 .245 .76 r
.26038 .37055 .26253 .37381 .27254 .38199 .27038 .37872 Metetra
0 .197 .726 r
.27038 .37872 .27254 .38199 .28261 .39099 .28045 .38771 Metetra
.634 .649 .847 r
.28045 .38771 .28261 .39099 .29367 .38812 .29153 .3845 Metetra
.636 .629 .827 r
.29153 .3845 .29367 .38812 .30496 .38252 .30268 .38108 Metetra
.924 .549 .279 r
.30268 .38108 .30496 .38252 .31372 .41645 .31142 .41504 Metetra
.716 .842 .942 r
.31142 .41504 .31372 .41645 .32513 .41236 .32293 .4095 Metetra
.736 .716 .832 r
.32293 .4095 .32513 .41236 .33678 .40482 .33459 .40209 Metetra
.622 .69 .893 r
.33459 .40209 .33678 .40482 .34817 .40268 .34602 .39924 Metetra
.848 .711 .711 r
.34602 .39924 .34817 .40268 .36058 .38177 .35844 .37833 Metetra
.853 .711 .706 r
.35844 .37833 .36058 .38177 .37296 .36 .37084 .35655 Metetra
.828 .707 .731 r
.37084 .35655 .37296 .36 .38515 .34058 .38296 .33929 Metetra
.843 .378 .035 r
.38296 .33929 .38515 .34058 .39572 .35972 .39352 .35844 Metetra
.857 .403 .067 r
.39352 .35844 .39572 .35972 .40644 .38064 .40424 .37938 Metetra
.869 .425 .095 r
.40424 .37938 .40644 .38064 .41733 .4035 .41512 .40227 Metetra
.933 .817 .707 r
.41512 .40227 .41733 .4035 .42986 .37932 .42771 .37715 Metetra
.87 .436 .035 r
.42771 .37715 .42986 .37932 .44101 .40467 .43884 .40276 Metetra
.953 .616 .332 r
.43884 .40276 .44101 .40467 .45139 .47672 .44918 .47486 Metetra
.843 .386 0 r
.44918 .47486 .45139 .47672 .46326 .50177 .46108 .49803 Metetra
.889 .72 .666 r
.46108 .49803 .46326 .50177 .47625 .47017 .47409 .46642 Metetra
.893 .72 .659 r
.47409 .46642 .47625 .47017 .4891 .43734 .48696 .43359 Metetra
.898 .72 .653 r
.48696 .43359 .4891 .43734 .50179 .40327 .49968 .39952 Metetra
.902 .72 .647 r
.49968 .39952 .50179 .40327 .51431 .36794 .51223 .36418 Metetra
.638 .638 .834 r
.51223 .36418 .51431 .36794 .52667 .36137 .52459 .36037 Metetra
.926 .541 .234 r
.52459 .36037 .52667 .36137 .53929 .40654 .5372 .40561 Metetra
.93 .551 .246 r
.5372 .40561 .53929 .40654 .55239 .45644 .55029 .45558 Metetra
.909 .504 .188 r
.55029 .45558 .55239 .45644 .56587 .49724 .56374 .4949 Metetra
.645 .763 .934 r
.56374 .4949 .56587 .49724 .57904 .49315 .57692 .4908 Metetra
.645 .763 .934 r
.57692 .4908 .57904 .49315 .59227 .48904 .59016 .48668 Metetra
.645 .763 .934 r
.59016 .48668 .59227 .48904 .60556 .48491 .60347 .48255 Metetra
.645 .763 .934 r
.60347 .48255 .60556 .48491 .61891 .48077 .61683 .47839 Metetra
.645 .763 .934 r
.61683 .47839 .61891 .48077 .63233 .4766 .63027 .47421 Metetra
.645 .763 .934 r
.63027 .47421 .63233 .4766 .64582 .47241 .64376 .47001 Metetra
.645 .763 .934 r
.64376 .47001 .64582 .47241 .65937 .46821 .65733 .46579 Metetra
.645 .763 .934 r
.65733 .46579 .65937 .46821 .67298 .46398 .67095 .46155 Metetra
.645 .763 .934 r
.67095 .46155 .67298 .46398 .68666 .45973 .68465 .45729 Metetra
.645 .763 .934 r
.68465 .45729 .68666 .45973 .70041 .45546 .69841 .45301 Metetra
.645 .763 .934 r
.69841 .45301 .70041 .45546 .71422 .45117 .71224 .44871 Metetra
.645 .763 .934 r
.71224 .44871 .71422 .45117 .7281 .44686 .72613 .44439 Metetra
.645 .763 .934 r
.72613 .44439 .7281 .44686 .74205 .44253 .7401 .44005 Metetra
.645 .763 .934 r
.7401 .44005 .74205 .44253 .75607 .43818 .75413 .43568 Metetra
.645 .763 .934 r
.75413 .43568 .75607 .43818 .77015 .43381 .76823 .4313 Metetra
.645 .763 .934 r
.76823 .4313 .77015 .43381 .78431 .42941 .7824 .42689 Metetra
.645 .763 .934 r
.7824 .42689 .78431 .42941 .79853 .42499 .79664 .42246 Metetra
.645 .763 .934 r
.79664 .42246 .79853 .42499 .81283 .42055 .81095 .41801 Metetra
.645 .763 .934 r
.81095 .41801 .81283 .42055 .8272 .41609 .82533 .41353 Metetra
.277 .49 .884 r
.1795 .4245 .18173 .42753 .19185 .42984 .18948 .42814 Metetra
.878 .775 .744 r
.18948 .42814 .19185 .42984 .20395 .41296 .20181 .40921 Metetra
.24 .409 .83 r
.20181 .40921 .20395 .41296 .21392 .41801 .21174 .4145 Metetra
.772 .681 .762 r
.21174 .4145 .21392 .41801 .22548 .40686 .22334 .40311 Metetra
.79 .676 .739 r
.22334 .40311 .22548 .40686 .23729 .39288 .23516 .38913 Metetra
.817 .684 .717 r
.23516 .38913 .23729 .39288 .24948 .37426 .2473 .37123 Metetra
.572 .638 .878 r
.2473 .37123 .24948 .37426 .26038 .37055 .25801 .36991 Metetra
.643 .083 0 r
.25801 .36991 .26038 .37055 .27038 .37872 .26801 .37809 Metetra
.675 .126 0 r
.26801 .37809 .27038 .37872 .28045 .38771 .27808 .38709 Metetra
.545 .879 .99 r
.27808 .38709 .28045 .38771 .29153 .3845 .28918 .38389 Metetra
.706 .922 .966 r
.28918 .38389 .29153 .3845 .30268 .38108 .3005 .37815 Metetra
.934 .556 .199 r
.3005 .37815 .30268 .38108 .31142 .41504 .30922 .4121 Metetra
.665 .689 .862 r
.30922 .4121 .31142 .41504 .32293 .4095 .32065 .40782 Metetra
.762 .82 .897 r
.32065 .40782 .32293 .4095 .33459 .40209 .33232 .40054 Metetra
.592 .8 .979 r
.33232 .40054 .33459 .40209 .34602 .39924 .34375 .39779 Metetra
.908 .807 .737 r
.34375 .39779 .34602 .39924 .35844 .37833 .35621 .37685 Metetra
.911 .804 .729 r
.35621 .37685 .35844 .37833 .37084 .35655 .36863 .35505 Metetra
.899 .813 .755 r
.36863 .35505 .37084 .35655 .38296 .33929 .38083 .33643 Metetra
.752 .306 0 r
.38083 .33643 .38296 .33929 .39352 .35844 .39138 .35558 Metetra
.786 .345 0 r
.39138 .35558 .39352 .35844 .40424 .37938 .40209 .37651 Metetra
.814 .379 0 r
.40209 .37651 .40424 .37938 .41512 .40227 .41296 .39939 Metetra
.886 .743 .698 r
.41296 .39939 .41512 .40227 .42771 .37715 .42557 .3744 Metetra
.856 .43 0 r
.42557 .3744 .42771 .37715 .43884 .40276 .43667 .40069 Metetra
.954 .617 .329 r
.43667 .40069 .43884 .40276 .44918 .47486 .44696 .47284 Metetra
.852 .403 .001 r
.44696 .47284 .44918 .47486 .46108 .49803 .45883 .49739 Metetra
.963 .834 .668 r
.45883 .49739 .46108 .49803 .47409 .46642 .47188 .46573 Metetra
.965 .828 .659 r
.47188 .46573 .47409 .46642 .48696 .43359 .48479 .43285 Metetra
.966 .823 .65 r
.48479 .43285 .48696 .43359 .49968 .39952 .49754 .39872 Metetra
.968 .818 .641 r
.49754 .39872 .49968 .39952 .51223 .36418 .51013 .36332 Metetra
.726 .925 .958 r
.51013 .36332 .51223 .36418 .52459 .36037 .52251 .35658 Metetra
.904 .529 .082 r
.52251 .35658 .52459 .36037 .5372 .40561 .53509 .40179 Metetra
.914 .544 .108 r
.53509 .40179 .5372 .40561 .55029 .45558 .54815 .45173 Metetra
.866 .481 .001 r
.54815 .45173 .55029 .45558 .56374 .4949 .5616 .49256 Metetra
.645 .763 .934 r
.5616 .49256 .56374 .4949 .57692 .4908 .57479 .48845 Metetra
.645 .763 .934 r
.57479 .48845 .57692 .4908 .59016 .48668 .58805 .48432 Metetra
.645 .763 .934 r
.58805 .48432 .59016 .48668 .60347 .48255 .60137 .48017 Metetra
.645 .763 .934 r
.60137 .48017 .60347 .48255 .61683 .47839 .61475 .476 Metetra
.645 .763 .934 r
.61475 .476 .61683 .47839 .63027 .47421 .62819 .47181 Metetra
.645 .763 .934 r
.62819 .47181 .63027 .47421 .64376 .47001 .6417 .4676 Metetra
.645 .763 .934 r
.6417 .4676 .64376 .47001 .65733 .46579 .65528 .46337 Metetra
.645 .763 .934 r
.65528 .46337 .65733 .46579 .67095 .46155 .66892 .45912 Metetra
.645 .763 .934 r
.66892 .45912 .67095 .46155 .68465 .45729 .68263 .45485 Metetra
.645 .763 .934 r
.68263 .45485 .68465 .45729 .69841 .45301 .69641 .45056 Metetra
.645 .763 .934 r
.69641 .45056 .69841 .45301 .71224 .44871 .71025 .44625 Metetra
.645 .763 .934 r
.71025 .44625 .71224 .44871 .72613 .44439 .72416 .44191 Metetra
.645 .763 .934 r
.72416 .44191 .72613 .44439 .7401 .44005 .73814 .43756 Metetra
.645 .763 .934 r
.73814 .43756 .7401 .44005 .75413 .43568 .75218 .43318 Metetra
.645 .763 .934 r
.75218 .43318 .75413 .43568 .76823 .4313 .7663 .42878 Metetra
.645 .763 .934 r
.7663 .42878 .76823 .4313 .7824 .42689 .78048 .42436 Metetra
.645 .763 .934 r
.78048 .42436 .7824 .42689 .79664 .42246 .79474 .41992 Metetra
.645 .763 .934 r
.79474 .41992 .79664 .42246 .81095 .41801 .80907 .41545 Metetra
.645 .763 .934 r
.80907 .41545 .81095 .41801 .82533 .41353 .82347 .41097 Metetra
.016 .546 .853 r
.17705 .42348 .1795 .4245 .18948 .42814 .1872 .42555 Metetra
.84 .733 .745 r
.1872 .42555 .18948 .42814 .20181 .40921 .19932 .40887 Metetra
.495 0 0 r
.19932 .40887 .20181 .40921 .21174 .4145 .20928 .41388 Metetra
.857 .892 .86 r
.20928 .41388 .21174 .4145 .22334 .40311 .22087 .40276 Metetra
.897 .892 .817 r
.22087 .40276 .22334 .40311 .23516 .38913 .23274 .38853 Metetra
.914 .847 .763 r
.23274 .38853 .23516 .38913 .2473 .37123 .24495 .37007 Metetra
.664 .852 .972 r
.24495 .37007 .2473 .37123 .25801 .36991 .25591 .36589 Metetra
.074 .284 .77 r
.25591 .36589 .25801 .36991 .26801 .37809 .26591 .37405 Metetra
.017 .246 .751 r
.26591 .37405 .26801 .37809 .27808 .38709 .27597 .38303 Metetra
.626 .602 .806 r
.27597 .38303 .27808 .38709 .28918 .38389 .28707 .37983 Metetra
.624 .602 .807 r
.28707 .37983 .28918 .38389 .3005 .37815 .29821 .37669 Metetra
.924 .549 .278 r
.29821 .37669 .3005 .37815 .30922 .4121 .30691 .41067 Metetra
.723 .841 .937 r
.30691 .41067 .30922 .4121 .32065 .40782 .31845 .40489 Metetra
.734 .712 .83 r
.31845 .40489 .32065 .40782 .33232 .40054 .33013 .3975 Metetra
.626 .669 .872 r
.33013 .3975 .33232 .40054 .34375 .39779 .34159 .39452 Metetra
.853 .718 .713 r
.34159 .39452 .34375 .39779 .35621 .37685 .35406 .37356 Metetra
.857 .718 .708 r
.35406 .37356 .35621 .37685 .36863 .35505 .3665 .35175 Metetra
.831 .715 .737 r
.3665 .35175 .36863 .35505 .38083 .33643 .37863 .33484 Metetra
.837 .37 0 r
.37863 .33484 .38083 .33643 .39138 .35558 .38918 .35401 Metetra
.853 .397 .034 r
.38918 .35401 .39138 .35558 .40209 .37651 .39988 .37496 Metetra
.867 .421 .066 r
.39988 .37496 .40209 .37651 .41296 .39939 .41075 .39785 Metetra
.925 .802 .705 r
.41075 .39785 .41296 .39939 .42557 .3744 .42339 .37254 Metetra
.877 .442 .067 r
.42339 .37254 .42557 .3744 .43667 .40069 .4345 .39819 Metetra
.957 .62 .32 r
.4345 .39819 .43667 .40069 .44696 .47284 .44475 .47036 Metetra
.811 .359 0 r
.44475 .47036 .44696 .47284 .45883 .49739 .45665 .49328 Metetra
.881 .708 .664 r
.45665 .49328 .45883 .49739 .47188 .46573 .46972 .46162 Metetra
.885 .709 .658 r
.46972 .46162 .47188 .46573 .48479 .43285 .48265 .42874 Metetra
.89 .71 .652 r
.48265 .42874 .48479 .43285 .49754 .39872 .49543 .39461 Metetra
.894 .71 .646 r
.49543 .39461 .49754 .39872 .51013 .36332 .50804 .35922 Metetra
.626 .614 .819 r
.50804 .35922 .51013 .36332 .52251 .35658 .52043 .35576 Metetra
.924 .54 .241 r
.52043 .35576 .52251 .35658 .53509 .40179 .53299 .40104 Metetra
.928 .55 .253 r
.53299 .40104 .53509 .40179 .54815 .45173 .54604 .45106 Metetra
.908 .503 .197 r
.54604 .45106 .54815 .45173 .5616 .49256 .55946 .49022 Metetra
.645 .763 .934 r
.55946 .49022 .5616 .49256 .57479 .48845 .57266 .48609 Metetra
.645 .763 .934 r
.57266 .48609 .57479 .48845 .58805 .48432 .58593 .48195 Metetra
.645 .763 .934 r
.58593 .48195 .58805 .48432 .60137 .48017 .59926 .47779 Metetra
.645 .763 .934 r
.59926 .47779 .60137 .48017 .61475 .476 .61265 .47361 Metetra
.645 .763 .934 r
.61265 .47361 .61475 .476 .62819 .47181 .62611 .46941 Metetra
.645 .763 .934 r
.62611 .46941 .62819 .47181 .6417 .4676 .63964 .46519 Metetra
.645 .763 .934 r
.63964 .46519 .6417 .4676 .65528 .46337 .65323 .46095 Metetra
.645 .763 .934 r
.65323 .46095 .65528 .46337 .66892 .45912 .66688 .45668 Metetra
.645 .763 .934 r
.66688 .45668 .66892 .45912 .68263 .45485 .68061 .4524 Metetra
.645 .763 .934 r
.68061 .4524 .68263 .45485 .69641 .45056 .6944 .4481 Metetra
.645 .763 .934 r
.6944 .4481 .69641 .45056 .71025 .44625 .70825 .44377 Metetra
.645 .763 .934 r
.70825 .44377 .71025 .44625 .72416 .44191 .72218 .43942 Metetra
.645 .763 .934 r
.72218 .43942 .72416 .44191 .73814 .43756 .73617 .43506 Metetra
.645 .763 .934 r
.73617 .43506 .73814 .43756 .75218 .43318 .75023 .43067 Metetra
.645 .763 .934 r
.75023 .43067 .75218 .43318 .7663 .42878 .76436 .42626 Metetra
.645 .763 .934 r
.76436 .42626 .7663 .42878 .78048 .42436 .77856 .42182 Metetra
.645 .763 .934 r
.77856 .42182 .78048 .42436 .79474 .41992 .79284 .41737 Metetra
.645 .763 .934 r
.79284 .41737 .79474 .41992 .80907 .41545 .80718 .41289 Metetra
.645 .763 .934 r
.80718 .41289 .80907 .41545 .82347 .41097 .82159 .40839 Metetra
.361 .548 .902 r
.17479 .42057 .17705 .42348 .1872 .42555 .18491 .42295 Metetra
.845 .732 .739 r
.18491 .42295 .1872 .42555 .19932 .40887 .19714 .40532 Metetra
.292 .455 .851 r
.19714 .40532 .19932 .40887 .20928 .41388 .20718 .40956 Metetra
.755 .645 .739 r
.20718 .40956 .20928 .41388 .22087 .40276 .21884 .39778 Metetra
.76 .628 .714 r
.21884 .39778 .22087 .40276 .23274 .38853 .23069 .38378 Metetra
.783 .644 .708 r
.23069 .38378 .23274 .38853 .24495 .37007 .24274 .36728 Metetra
.546 .647 .901 r
.24274 .36728 .24495 .37007 .25591 .36589 .25342 .36644 Metetra
.68 .175 .035 r
.25342 .36644 .25591 .36589 .26591 .37405 .26342 .37462 Metetra
.7 .203 .06 r
.26342 .37462 .26591 .37405 .27597 .38303 .27349 .38363 Metetra
.444 .878 .816 r
.27349 .38363 .27597 .38303 .28707 .37983 .28474 .37865 Metetra
.628 .847 .983 r
.28474 .37865 .28707 .37983 .29821 .37669 .29593 .37501 Metetra
.927 .55 .268 r
.29593 .37501 .29821 .37669 .30691 .41067 .3046 .40902 Metetra
.689 .813 .941 r
.3046 .40902 .30691 .41067 .31845 .40489 .3161 .40421 Metetra
.808 .92 .913 r
.3161 .40421 .31845 .40489 .33013 .3975 .32788 .39543 Metetra
.611 .75 .944 r
.32788 .39543 .33013 .3975 .34159 .39452 .33933 .39267 Metetra
.896 .786 .732 r
.33933 .39267 .34159 .39452 .35406 .37356 .35182 .3717 Metetra
.899 .784 .725 r
.35182 .3717 .35406 .37356 .3665 .35175 .36429 .34986 Metetra
.879 .793 .761 r
.36429 .34986 .3665 .35175 .37863 .33484 .37647 .33252 Metetra
.802 .34 0 r
.37647 .33252 .37863 .33484 .38918 .35401 .38701 .35169 Metetra
.826 .373 0 r
.38701 .35169 .38918 .35401 .39988 .37496 .3977 .37264 Metetra
.847 .402 0 r
.3977 .37264 .39988 .37496 .41075 .39785 .40856 .39554 Metetra
.903 .768 .702 r
.40856 .39554 .41075 .39785 .42339 .37254 .42122 .37051 Metetra
.872 .435 .045 r
.42122 .37051 .42339 .37254 .4345 .39819 .43233 .39585 Metetra
.956 .619 .323 r
.43233 .39585 .4345 .39819 .44475 .47036 .44253 .46805 Metetra
.829 .377 0 r
.44253 .46805 .44475 .47036 .45665 .49328 .45441 .49153 Metetra
.938 .791 .671 r
.45441 .49153 .45665 .49328 .46972 .46162 .46751 .45984 Metetra
.941 .787 .663 r
.46751 .45984 .46972 .46162 .48265 .42874 .48047 .42692 Metetra
.943 .784 .655 r
.48047 .42692 .48265 .42874 .49543 .39461 .49329 .39275 Metetra
.945 .781 .647 r
.49329 .39275 .49543 .39461 .50804 .35922 .50594 .35732 Metetra
.649 .797 .953 r
.50594 .35732 .50804 .35922 .52043 .35576 .51833 .35324 Metetra
.925 .541 .16 r
.51833 .35324 .52043 .35576 .53299 .40104 .53088 .39853 Metetra
.931 .553 .179 r
.53088 .39853 .53299 .40104 .54604 .45106 .5439 .44857 Metetra
.9 .495 .088 r
.5439 .44857 .54604 .45106 .55946 .49022 .55731 .48786 Metetra
.645 .763 .934 r
.55731 .48786 .55946 .49022 .57266 .48609 .57052 .48373 Metetra
.645 .763 .934 r
.57052 .48373 .57266 .48609 .58593 .48195 .5838 .47958 Metetra
.645 .763 .934 r
.5838 .47958 .58593 .48195 .59926 .47779 .59715 .47541 Metetra
.645 .763 .934 r
.59715 .47541 .59926 .47779 .61265 .47361 .61056 .47121 Metetra
.645 .763 .934 r
.61056 .47121 .61265 .47361 .62611 .46941 .62403 .467 Metetra
.645 .763 .934 r
.62403 .467 .62611 .46941 .63964 .46519 .63757 .46277 Metetra
.645 .763 .934 r
.63757 .46277 .63964 .46519 .65323 .46095 .65117 .45851 Metetra
.645 .763 .934 r
.65117 .45851 .65323 .46095 .66688 .45668 .66484 .45424 Metetra
.645 .763 .934 r
.66484 .45424 .66688 .45668 .68061 .4524 .67858 .44994 Metetra
.645 .763 .934 r
.67858 .44994 .68061 .4524 .6944 .4481 .69238 .44563 Metetra
.645 .763 .934 r
.69238 .44563 .6944 .4481 .70825 .44377 .70625 .44129 Metetra
.645 .763 .934 r
.70625 .44129 .70825 .44377 .72218 .43942 .72019 .43693 Metetra
.645 .763 .934 r
.72019 .43693 .72218 .43942 .73617 .43506 .7342 .43255 Metetra
.645 .763 .934 r
.7342 .43255 .73617 .43506 .75023 .43067 .74828 .42815 Metetra
.645 .763 .934 r
.74828 .42815 .75023 .43067 .76436 .42626 .76242 .42373 Metetra
.645 .763 .934 r
.76242 .42373 .76436 .42626 .77856 .42182 .77664 .41928 Metetra
.645 .763 .934 r
.77664 .41928 .77856 .42182 .79284 .41737 .79093 .41481 Metetra
.645 .763 .934 r
.79093 .41481 .79284 .41737 .80718 .41289 .80528 .41032 Metetra
.645 .763 .934 r
.80528 .41032 .80718 .41289 .82159 .40839 .81971 .40581 Metetra
.078 .584 .889 r
.17233 .41949 .17479 .42057 .18491 .42295 .18252 .42125 Metetra
.866 .782 .767 r
.18252 .42125 .18491 .42295 .19714 .40532 .19464 .40496 Metetra
.496 0 0 r
.19464 .40496 .19714 .40532 .20718 .40956 .2046 .41002 Metetra
.851 .98 .864 r
.2046 .41002 .20718 .40956 .21884 .39778 .21621 .39896 Metetra
.9 .984 .787 r
.21621 .39896 .21884 .39778 .23069 .38378 .22817 .38403 Metetra
.933 .904 .771 r
.22817 .38403 .23069 .38378 .24274 .36728 .24039 .36591 Metetra
.704 .836 .946 r
.24039 .36591 .24274 .36728 .25342 .36644 .25144 .3609 Metetra
.245 .312 .735 r
.25144 .3609 .25342 .36644 .26342 .37462 .26143 .36905 Metetra
.208 .288 .727 r
.26143 .36905 .26342 .37462 .27349 .38363 .27149 .37802 Metetra
.608 .534 .746 r
.27149 .37802 .27349 .38363 .28474 .37865 .28259 .37497 Metetra
.616 .619 .831 r
.28259 .37497 .28474 .37865 .29593 .37501 .29372 .37226 Metetra
.934 .556 .212 r
.29372 .37226 .29593 .37501 .3046 .40902 .30237 .40627 Metetra
.712 .719 .854 r
.30237 .40627 .3046 .40902 .3161 .40421 .31396 .40017 Metetra
.707 .644 .784 r
.31396 .40017 .3161 .40421 .32788 .39543 .32566 .39278 Metetra
.628 .702 .899 r
.32566 .39278 .32788 .39543 .33933 .39267 .33713 .38973 Metetra
.863 .733 .718 r
.33713 .38973 .33933 .39267 .35182 .3717 .34965 .36874 Metetra
.867 .733 .712 r
.34965 .36874 .35182 .3717 .36429 .34986 .36213 .34689 Metetra
.839 .732 .747 r
.36213 .34689 .36429 .34986 .37647 .33252 .37429 .33037 Metetra
.813 .349 0 r
.37429 .33037 .37647 .33252 .38701 .35169 .38482 .34954 Metetra
.835 .38 0 r
.38482 .34954 .38701 .35169 .3977 .37264 .39551 .37049 Metetra
.854 .408 .001 r
.39551 .37049 .3977 .37264 .40856 .39554 .40635 .39341 Metetra
.909 .775 .701 r
.40635 .39341 .40856 .39554 .42122 .37051 .41905 .36798 Metetra
.858 .425 0 r
.41905 .36798 .42122 .37051 .43233 .39585 .43014 .39347 Metetra
.956 .619 .323 r
.43014 .39347 .43233 .39585 .44253 .46805 .44031 .46571 Metetra
.816 .36 0 r
.44031 .46571 .44253 .46805 .45441 .49153 .45219 .48837 Metetra
.904 .74 .668 r
.45219 .48837 .45441 .49153 .46751 .45984 .46532 .45666 Metetra
.908 .739 .661 r
.46532 .45666 .46751 .45984 .48047 .42692 .47831 .42373 Metetra
.911 .738 .654 r
.47831 .42373 .48047 .42692 .49329 .39275 .49116 .38955 Metetra
.915 .738 .648 r
.49116 .38955 .49329 .39275 .50594 .35732 .50383 .35411 Metetra
.615 .665 .875 r
.50383 .35411 .50594 .35732 .51833 .35324 .51624 .3512 Metetra
.928 .542 .186 r
.51624 .3512 .51833 .35324 .53088 .39853 .52876 .39652 Metetra
.932 .553 .202 r
.52876 .39652 .53088 .39853 .5439 .44857 .54176 .44659 Metetra
.905 .498 .119 r
.54176 .44659 .5439 .44857 .55731 .48786 .55515 .4855 Metetra
.645 .763 .934 r
.55515 .4855 .55731 .48786 .57052 .48373 .56838 .48136 Metetra
.645 .763 .934 r
.56838 .48136 .57052 .48373 .5838 .47958 .58167 .4772 Metetra
.645 .763 .934 r
.58167 .4772 .5838 .47958 .59715 .47541 .59503 .47301 Metetra
.645 .763 .934 r
.59503 .47301 .59715 .47541 .61056 .47121 .60845 .46881 Metetra
.645 .763 .934 r
.60845 .46881 .61056 .47121 .62403 .467 .62194 .46458 Metetra
.645 .763 .934 r
.62194 .46458 .62403 .467 .63757 .46277 .63549 .46034 Metetra
.645 .763 .934 r
.63549 .46034 .63757 .46277 .65117 .45851 .64911 .45607 Metetra
.645 .763 .934 r
.64911 .45607 .65117 .45851 .66484 .45424 .66279 .45179 Metetra
.645 .763 .934 r
.66279 .45179 .66484 .45424 .67858 .44994 .67654 .44748 Metetra
.645 .763 .934 r
.67654 .44748 .67858 .44994 .69238 .44563 .69036 .44315 Metetra
.645 .763 .934 r
.69036 .44315 .69238 .44563 .70625 .44129 .70425 .4388 Metetra
.645 .763 .934 r
.70425 .4388 .70625 .44129 .72019 .43693 .7182 .43443 Metetra
.645 .763 .934 r
.7182 .43443 .72019 .43693 .7342 .43255 .73222 .43004 Metetra
.645 .763 .934 r
.73222 .43004 .7342 .43255 .74828 .42815 .74631 .42562 Metetra
.645 .763 .934 r
.74631 .42562 .74828 .42815 .76242 .42373 .76048 .42119 Metetra
.645 .763 .934 r
.76048 .42119 .76242 .42373 .77664 .41928 .77471 .41673 Metetra
.645 .763 .934 r
.77471 .41673 .77664 .41928 .79093 .41481 .78901 .41225 Metetra
.645 .763 .934 r
.78901 .41225 .79093 .41481 .80528 .41032 .80338 .40775 Metetra
.645 .763 .934 r
.80338 .40775 .80528 .41032 .81971 .40581 .81783 .40322 Metetra
.44 .573 .891 r
.17009 .4164 .17233 .41949 .18252 .42125 .18032 .41777 Metetra
.814 .692 .73 r
.18032 .41777 .18252 .42125 .19464 .40496 .19247 .40128 Metetra
.367 .489 .85 r
.19247 .40128 .19464 .40496 .2046 .41002 .20261 .4045 Metetra
.732 .602 .712 r
.20261 .4045 .2046 .41002 .21621 .39896 .21432 .39237 Metetra
.728 .58 .688 r
.21432 .39237 .21621 .39896 .22817 .38403 .2262 .37834 Metetra
.755 .61 .698 r
.2262 .37834 .22817 .38403 .24039 .36591 .23818 .36307 Metetra
.508 .627 .904 r
.23818 .36307 .24039 .36591 .25144 .3609 .2488 .36302 Metetra
.666 .228 .2 r
.2488 .36302 .25144 .3609 .26143 .36905 .2588 .3712 Metetra
.68 .246 .213 r
.2588 .3712 .26143 .36905 .27149 .37802 .26887 .38021 Metetra
.26887 .38021 .27149 .37802 .28259 .37497 .28027 .37353 Metetra
.528 .787 .992 r
.28027 .37353 .28259 .37497 .29372 .37226 .29134 .37174 Metetra
.909 .539 .315 r
.29134 .37174 .29372 .37226 .30237 .40627 .29997 .4058 Metetra
.659 .929 .972 r
.29997 .4058 .30237 .40627 .31396 .40017 .31152 .40052 Metetra
.805 .991 .878 r
.31152 .40052 .31396 .40017 .32566 .39278 .32341 .39052 Metetra
.612 .732 .931 r
.32341 .39052 .32566 .39278 .33713 .38973 .33487 .38778 Metetra
.893 .781 .731 r
.33487 .38778 .33713 .38973 .34965 .36874 .34741 .36678 Metetra
.897 .78 .724 r
.34741 .36678 .34965 .36874 .36213 .34689 .35992 .3449 Metetra
.871 .789 .767 r
.35992 .3449 .36213 .34689 .37429 .33037 .37209 .32835 Metetra
.821 .355 0 r
.37209 .32835 .37429 .33037 .38482 .34954 .38262 .34753 Metetra
.841 .385 0 r
.38262 .34753 .38482 .34954 .39551 .37049 .3933 .36849 Metetra
.858 .411 .018 r
.3933 .36849 .39551 .37049 .40635 .39341 .40414 .39141 Metetra
.912 .783 .705 r
.40414 .39141 .40635 .39341 .41905 .36798 .41685 .36638 Metetra
.874 .433 .076 r
.41685 .36638 .41905 .36798 .43014 .39347 .42796 .39104 Metetra
.956 .619 .322 r
.42796 .39104 .43014 .39347 .44031 .46571 .43808 .46331 Metetra
.811 .354 0 r
.43808 .46331 .44031 .46571 .45219 .48837 .44996 .4858 Metetra
.918 .761 .67 r
.44996 .4858 .45219 .48837 .46532 .45666 .46312 .45407 Metetra
.922 .759 .663 r
.46312 .45407 .46532 .45666 .47831 .42373 .47614 .42111 Metetra
.925 .757 .655 r
.47614 .42111 .47831 .42373 .49116 .38955 .48902 .38691 Metetra
.928 .756 .648 r
.48902 .38691 .49116 .38955 .50383 .35411 .50172 .35144 Metetra
.568 .69 .923 r
.50172 .35144 .50383 .35411 .51624 .3512 .51413 .3497 Metetra
.928 .542 .212 r
.51413 .3497 .51624 .3512 .52876 .39652 .52664 .39507 Metetra
.932 .552 .227 r
.52664 .39507 .52876 .39652 .54176 .44659 .53962 .44519 Metetra
.906 .495 .148 r
.53962 .44519 .54176 .44659 .55515 .4855 .55299 .48314 Metetra
.645 .763 .934 r
.55299 .48314 .55515 .4855 .56838 .48136 .56623 .47898 Metetra
.645 .763 .934 r
.56623 .47898 .56838 .48136 .58167 .4772 .57954 .47481 Metetra
.645 .763 .934 r
.57954 .47481 .58167 .4772 .59503 .47301 .59291 .47061 Metetra
.645 .763 .934 r
.59291 .47061 .59503 .47301 .60845 .46881 .60634 .4664 Metetra
.645 .763 .934 r
.60634 .4664 .60845 .46881 .62194 .46458 .61984 .46216 Metetra
.645 .763 .934 r
.61984 .46216 .62194 .46458 .63549 .46034 .63341 .4579 Metetra
.645 .763 .934 r
.63341 .4579 .63549 .46034 .64911 .45607 .64704 .45363 Metetra
.645 .763 .934 r
.64704 .45363 .64911 .45607 .66279 .45179 .66074 .44933 Metetra
.645 .763 .934 r
.66074 .44933 .66279 .45179 .67654 .44748 .6745 .44501 Metetra
.645 .763 .934 r
.6745 .44501 .67654 .44748 .69036 .44315 .68833 .44067 Metetra
.645 .763 .934 r
.68833 .44067 .69036 .44315 .70425 .4388 .70223 .43631 Metetra
.645 .763 .934 r
.70223 .43631 .70425 .4388 .7182 .43443 .7162 .43192 Metetra
.645 .763 .934 r
.7162 .43192 .7182 .43443 .73222 .43004 .73024 .42752 Metetra
.645 .763 .934 r
.73024 .42752 .73222 .43004 .74631 .42562 .74435 .42309 Metetra
.645 .763 .934 r
.74435 .42309 .74631 .42562 .76048 .42119 .75852 .41864 Metetra
.645 .763 .934 r
.75852 .41864 .76048 .42119 .77471 .41673 .77277 .41417 Metetra
.645 .763 .934 r
.77277 .41417 .77471 .41673 .78901 .41225 .78709 .40968 Metetra
.645 .763 .934 r
.78709 .40968 .78901 .41225 .80338 .40775 .80148 .40517 Metetra
.645 .763 .934 r
.80148 .40517 .80338 .40775 .81783 .40322 .81594 .40063 Metetra
.172 .6 .939 r
.16766 .41489 .17009 .4164 .18032 .41777 .17784 .41681 Metetra
.89 .829 .781 r
.17784 .41681 .18032 .41777 .19247 .40128 .19 .40045 Metetra
.421 0 0 r
.19 .40045 .19247 .40128 .20261 .4045 .19995 .40556 Metetra
.819 1 .825 r
.19995 .40556 .20261 .4045 .21432 .39237 .21161 .39423 Metetra
.836 .991 .733 r
.21161 .39423 .21432 .39237 .2262 .37834 .22356 .37982 Metetra
.937 .964 .742 r
.22356 .37982 .2262 .37834 .23818 .36307 .23587 .36117 Metetra
.682 .778 .923 r
.23587 .36117 .23818 .36307 .2488 .36302 .24687 .35678 Metetra
.288 .315 .716 r
.24687 .35678 .2488 .36302 .2588 .3712 .25687 .36492 Metetra
.257 .295 .71 r
.25687 .36492 .2588 .3712 .26887 .38021 .26692 .37389 Metetra
.606 .515 .725 r
.26692 .37389 .26887 .38021 .28027 .37353 .27805 .3706 Metetra
.62 .672 .878 r
.27805 .3706 .28027 .37353 .29134 .37174 .2892 .36783 Metetra
.924 .552 .136 r
.2892 .36783 .29134 .37174 .29997 .4058 .29781 .40185 Metetra
.677 .636 .801 r
.29781 .40185 .29997 .4058 .31152 .40052 .30939 .39626 Metetra
.716 .639 .771 r
.30939 .39626 .31152 .40052 .32341 .39052 .32117 .38798 Metetra
.606 .704 .914 r
.32117 .38798 .32341 .39052 .33487 .38778 .33263 .38548 Metetra
.882 .764 .727 r
.33263 .38548 .33487 .38778 .34741 .36678 .34519 .36445 Metetra
.886 .762 .72 r
.34519 .36445 .34741 .36678 .35992 .3449 .35772 .34256 Metetra
.863 .767 .755 r
.35772 .34256 .35992 .3449 .37209 .32835 .36994 .32546 Metetra
.753 .307 0 r
.36994 .32546 .37209 .32835 .38262 .34753 .38046 .34463 Metetra
.787 .346 0 r
.38046 .34463 .38262 .34753 .3933 .36849 .39112 .36559 Metetra
.815 .38 0 r
.39112 .36559 .3933 .36849 .40414 .39141 .40195 .3885 Metetra
.885 .743 .7 r
.40195 .3885 .40414 .39141 .41685 .36638 .41467 .36377 Metetra
.842 .406 0 r
.41467 .36377 .41685 .36638 .42796 .39104 .42578 .38817 Metetra
.959 .622 .312 r
.42578 .38817 .42796 .39104 .43808 .46331 .43586 .46045 Metetra
.794 .351 0 r
.43586 .46045 .43808 .46331 .44996 .4858 .4477 .48381 Metetra
.932 .782 .671 r
.4477 .48381 .44996 .4858 .46312 .45407 .4609 .45204 Metetra
.935 .779 .663 r
.4609 .45204 .46312 .45407 .47614 .42111 .47395 .41905 Metetra
.938 .777 .655 r
.47395 .41905 .47614 .42111 .48902 .38691 .48686 .38482 Metetra
.94 .774 .647 r
.48686 .38482 .48902 .38691 .50172 .35144 .4996 .34932 Metetra
.607 .76 .952 r
.4996 .34932 .50172 .35144 .51413 .3497 .51203 .34633 Metetra
.915 .536 .112 r
.51203 .34633 .51413 .3497 .52664 .39507 .52451 .39168 Metetra
.923 .549 .136 r
.52451 .39168 .52664 .39507 .53962 .44519 .53746 .44179 Metetra
.874 .478 .017 r
.53746 .44179 .53962 .44519 .55299 .48314 .55082 .48077 Metetra
.645 .763 .934 r
.55082 .48077 .55299 .48314 .56623 .47898 .56408 .4766 Metetra
.645 .763 .934 r
.56408 .4766 .56623 .47898 .57954 .47481 .57739 .47241 Metetra
.645 .763 .934 r
.57739 .47241 .57954 .47481 .59291 .47061 .59078 .46821 Metetra
.645 .763 .934 r
.59078 .46821 .59291 .47061 .60634 .4664 .60423 .46398 Metetra
.645 .763 .934 r
.60423 .46398 .60634 .4664 .61984 .46216 .61774 .45973 Metetra
.645 .763 .934 r
.61774 .45973 .61984 .46216 .63341 .4579 .63132 .45546 Metetra
.645 .763 .934 r
.63132 .45546 .63341 .4579 .64704 .45363 .64497 .45117 Metetra
.645 .763 .934 r
.64497 .45117 .64704 .45363 .66074 .44933 .65868 .44686 Metetra
.645 .763 .934 r
.65868 .44686 .66074 .44933 .6745 .44501 .67246 .44253 Metetra
.645 .763 .934 r
.67246 .44253 .6745 .44501 .68833 .44067 .6863 .43818 Metetra
.645 .763 .934 r
.6863 .43818 .68833 .44067 .70223 .43631 .70022 .43381 Metetra
.645 .763 .934 r
.70022 .43381 .70223 .43631 .7162 .43192 .7142 .42941 Metetra
.645 .763 .934 r
.7142 .42941 .7162 .43192 .73024 .42752 .72825 .42499 Metetra
.645 .763 .934 r
.72825 .42499 .73024 .42752 .74435 .42309 .74237 .42055 Metetra
.645 .763 .934 r
.74237 .42055 .74435 .42309 .75852 .41864 .75657 .41609 Metetra
.645 .763 .934 r
.75657 .41609 .75852 .41864 .77277 .41417 .77083 .41161 Metetra
.645 .763 .934 r
.77083 .41161 .77277 .41417 .78709 .40968 .78516 .4071 Metetra
.645 .763 .934 r
.78516 .4071 .78709 .40968 .80148 .40517 .79957 .40258 Metetra
.645 .763 .934 r
.79957 .40258 .80148 .40517 .81594 .40063 .81405 .39802 Metetra
.431 .57 .892 r
.16541 .4118 .16766 .41489 .17784 .41681 .17563 .41328 Metetra
.811 .69 .731 r
.17563 .41328 .17784 .41681 .19 .40045 .18778 .3971 Metetra
.339 .5 .872 r
.18778 .3971 .19 .40045 .19995 .40556 .19793 .4003 Metetra
.738 .611 .718 r
.19793 .4003 .19995 .40556 .21161 .39423 .20967 .38814 Metetra
.738 .594 .696 r
.20967 .38814 .21161 .39423 .22356 .37982 .22159 .37408 Metetra
.758 .611 .696 r
.22159 .37408 .22356 .37982 .23587 .36117 .23364 .35829 Metetra
.5 .621 .902 r
.23364 .35829 .23587 .36117 .24687 .35678 .24426 .35839 Metetra
.671 .213 .156 r
.24426 .35839 .24687 .35678 .25687 .36492 .25426 .36656 Metetra
.687 .234 .171 r
.25426 .36656 .25687 .36492 .26692 .37389 .26432 .37556 Metetra
.26432 .37556 .26692 .37389 .27805 .3706 .27574 .36884 Metetra
.535 .754 .977 r
.27574 .36884 .27805 .3706 .2892 .36783 .28681 .36731 Metetra
.909 .538 .315 r
.28681 .36731 .2892 .36783 .29781 .40185 .2954 .4014 Metetra
.664 .931 .971 r
.2954 .4014 .29781 .40185 .30939 .39626 .30698 .396 Metetra
.831 .953 .896 r
.30698 .396 .30939 .39626 .32117 .38798 .31889 .38605 Metetra
.59 .76 .96 r
.31889 .38605 .32117 .38798 .33263 .38548 .33035 .3836 Metetra
.895 .785 .732 r
.33035 .3836 .33263 .38548 .34519 .36445 .34293 .36255 Metetra
.899 .783 .725 r
.34293 .36255 .34519 .36445 .35772 .34256 .35549 .34063 Metetra
.878 .793 .761 r
.35549 .34063 .35772 .34256 .36994 .32546 .36774 .32328 Metetra
.813 .348 0 r
.36774 .32328 .36994 .32546 .38046 .34463 .37826 .34246 Metetra
.835 .379 0 r
.37826 .34246 .38046 .34463 .39112 .36559 .38891 .36342 Metetra
.853 .407 0 r
.38891 .36342 .39112 .36559 .40195 .3885 .39973 .38634 Metetra
.906 .776 .706 r
.39973 .38634 .40195 .3885 .41467 .36377 .41248 .36167 Metetra
.862 .421 .02 r
.41248 .36167 .41467 .36377 .42578 .38817 .42357 .38609 Metetra
.954 .617 .329 r
.42357 .38609 .42578 .38817 .43586 .46045 .4336 .45841 Metetra
.83 .37 0 r
.4336 .45841 .43586 .46045 .4477 .48381 .44547 .48095 Metetra
.912 .751 .669 r
.44547 .48095 .4477 .48381 .4609 .45204 .45869 .44917 Metetra
.915 .75 .662 r
.45869 .44917 .4609 .45204 .47395 .41905 .47177 .41616 Metetra
.919 .749 .655 r
.47177 .41616 .47395 .41905 .48686 .38482 .48471 .38191 Metetra
.922 .747 .648 r
.48471 .38191 .48686 .38482 .4996 .34932 .49748 .34639 Metetra
.559 .664 .907 r
.49748 .34639 .4996 .34932 .51203 .34633 .50991 .34498 Metetra
.927 .542 .219 r
.50991 .34498 .51203 .34633 .52451 .39168 .52237 .39038 Metetra
.931 .551 .233 r
.52237 .39038 .52451 .39168 .53746 .44179 .53531 .44055 Metetra
.906 .494 .157 r
.53531 .44055 .53746 .44179 .55082 .48077 .54864 .47839 Metetra
.645 .763 .934 r
.54864 .47839 .55082 .48077 .56408 .4766 .56191 .47421 Metetra
.645 .763 .934 r
.56191 .47421 .56408 .4766 .57739 .47241 .57525 .47001 Metetra
.645 .763 .934 r
.57525 .47001 .57739 .47241 .59078 .46821 .58864 .46579 Metetra
.645 .763 .934 r
.58864 .46579 .59078 .46821 .60423 .46398 .60211 .46155 Metetra
.645 .763 .934 r
.60211 .46155 .60423 .46398 .61774 .45973 .61563 .45729 Metetra
.645 .763 .934 r
.61563 .45729 .61774 .45973 .63132 .45546 .62923 .45301 Metetra
.645 .763 .934 r
.62923 .45301 .63132 .45546 .64497 .45117 .64288 .44871 Metetra
.645 .763 .934 r
.64288 .44871 .64497 .45117 .65868 .44686 .65661 .44439 Metetra
.645 .763 .934 r
.65661 .44439 .65868 .44686 .67246 .44253 .6704 .44005 Metetra
.645 .763 .934 r
.6704 .44005 .67246 .44253 .6863 .43818 .68427 .43568 Metetra
.645 .763 .934 r
.68427 .43568 .6863 .43818 .70022 .43381 .69819 .4313 Metetra
.645 .763 .934 r
.69819 .4313 .70022 .43381 .7142 .42941 .71219 .42689 Metetra
.645 .763 .934 r
.71219 .42689 .7142 .42941 .72825 .42499 .72626 .42246 Metetra
.645 .763 .934 r
.72626 .42246 .72825 .42499 .74237 .42055 .7404 .41801 Metetra
.645 .763 .934 r
.7404 .41801 .74237 .42055 .75657 .41609 .7546 .41353 Metetra
.645 .763 .934 r
.7546 .41353 .75657 .41609 .77083 .41161 .76888 .40904 Metetra
.645 .763 .934 r
.76888 .40904 .77083 .41161 .78516 .4071 .78323 .40452 Metetra
.645 .763 .934 r
.78323 .40452 .78516 .4071 .79957 .40258 .79765 .39998 Metetra
.645 .763 .934 r
.79765 .39998 .79957 .40258 .81405 .39802 .81215 .39541 Metetra
.277 .58 .942 r
.16305 .40959 .16541 .4118 .17563 .41328 .17319 .41183 Metetra
.874 .799 .773 r
.17319 .41183 .17563 .41328 .18778 .3971 .18537 .39556 Metetra
0 .371 .776 r
.18537 .39556 .18778 .3971 .19793 .4003 .19539 .39998 Metetra
.869 .914 .858 r
.19539 .39998 .19793 .4003 .20967 .38814 .20712 .38828 Metetra
.903 .931 .824 r
.20712 .38828 .20967 .38814 .22159 .37408 .21906 .37419 Metetra
.931 .893 .769 r
.21906 .37419 .22159 .37408 .23364 .35829 .23137 .3558 Metetra
.589 .694 .915 r
.23137 .3558 .23364 .35829 .24426 .35839 .24218 .35383 Metetra
.139 .294 .761 r
.24218 .35383 .24426 .35839 .25426 .36656 .25217 .36198 Metetra
.09 .262 .746 r
.25217 .36198 .25426 .36656 .26432 .37556 .26222 .37096 Metetra
.648 .59 .776 r
.26222 .37096 .26432 .37556 .27574 .36884 .27348 .36636 Metetra
.605 .705 .915 r
.27348 .36636 .27574 .36884 .28681 .36731 .28462 .36391 Metetra
.931 .556 .174 r
.28462 .36391 .28681 .36731 .2954 .4014 .29319 .39798 Metetra
.683 .667 .828 r
.29319 .39798 .2954 .4014 .30698 .396 .30477 .39257 Metetra
.743 .688 .798 r
.30477 .39257 .30698 .396 .31889 .38605 .31661 .38385 Metetra
.578 .728 .945 r
.31661 .38385 .31889 .38605 .33035 .3836 .32806 .3818 Metetra
.898 .79 .733 r
.32806 .3818 .33035 .3836 .34293 .36255 .34067 .36072 Metetra
.901 .788 .726 r
.34067 .36072 .34293 .36255 .35549 .34063 .35325 .33878 Metetra
.888 .795 .751 r
.35325 .33878 .35549 .34063 .36774 .32328 .36559 .32012 Metetra
.723 .289 0 r
.36559 .32012 .36774 .32328 .37826 .34246 .37609 .33928 Metetra
.762 .33 0 r
.37609 .33928 .37826 .34246 .38891 .36342 .38674 .36024 Metetra
.795 .367 0 r
.38674 .36024 .38891 .36342 .39973 .38634 .39754 .38315 Metetra
.875 .732 .7 r
.39754 .38315 .39973 .38634 .41248 .36167 .41029 .35899 Metetra
.838 .402 0 r
.41029 .35899 .41248 .36167 .42357 .38609 .42138 .38328 Metetra
.958 .622 .313 r
.42138 .38328 .42357 .38609 .4336 .45841 .43137 .45561 Metetra
.8 .355 0 r
.43137 .45561 .4336 .45841 .44547 .48095 .4432 .47901 Metetra
.934 .784 .671 r
.4432 .47901 .44547 .48095 .45869 .44917 .45645 .44719 Metetra
.936 .781 .663 r
.45645 .44719 .45869 .44917 .47177 .41616 .46957 .41415 Metetra
.939 .778 .655 r
.46957 .41415 .47177 .41616 .48471 .38191 .48254 .37986 Metetra
.942 .776 .647 r
.48254 .37986 .48471 .38191 .49748 .34639 .49535 .34431 Metetra
.586 .757 .96 r
.49535 .34431 .49748 .34639 .50991 .34498 .50779 .34174 Metetra
.917 .537 .122 r
.50779 .34174 .50991 .34498 .52237 .39038 .52023 .38713 Metetra
.925 .55 .144 r
.52023 .38713 .52237 .39038 .53531 .44055 .53314 .43729 Metetra
.878 .479 .026 r
.53314 .43729 .53531 .44055 .54864 .47839 .54646 .476 Metetra
.645 .763 .934 r
.54646 .476 .54864 .47839 .56191 .47421 .55975 .47181 Metetra
.645 .763 .934 r
.55975 .47181 .56191 .47421 .57525 .47001 .57309 .4676 Metetra
.645 .763 .934 r
.57309 .4676 .57525 .47001 .58864 .46579 .5865 .46337 Metetra
.645 .763 .934 r
.5865 .46337 .58864 .46579 .60211 .46155 .59998 .45912 Metetra
.645 .763 .934 r
.59998 .45912 .60211 .46155 .61563 .45729 .61352 .45485 Metetra
.645 .763 .934 r
.61352 .45485 .61563 .45729 .62923 .45301 .62713 .45056 Metetra
.645 .763 .934 r
.62713 .45056 .62923 .45301 .64288 .44871 .6408 .44625 Metetra
.645 .763 .934 r
.6408 .44625 .64288 .44871 .65661 .44439 .65454 .44191 Metetra
.645 .763 .934 r
.65454 .44191 .65661 .44439 .6704 .44005 .66835 .43756 Metetra
.645 .763 .934 r
.66835 .43756 .6704 .44005 .68427 .43568 .68222 .43318 Metetra
.645 .763 .934 r
.68222 .43318 .68427 .43568 .69819 .4313 .69617 .42878 Metetra
.645 .763 .934 r
.69617 .42878 .69819 .4313 .71219 .42689 .71018 .42436 Metetra
.645 .763 .934 r
.71018 .42436 .71219 .42689 .72626 .42246 .72426 .41992 Metetra
.645 .763 .934 r
.72426 .41992 .72626 .42246 .7404 .41801 .73841 .41545 Metetra
.645 .763 .934 r
.73841 .41545 .7404 .41801 .7546 .41353 .75263 .41097 Metetra
.645 .763 .934 r
.75263 .41097 .7546 .41353 .76888 .40904 .76693 .40646 Metetra
.645 .763 .934 r
.76693 .40646 .76888 .40904 .78323 .40452 .78129 .40193 Metetra
.645 .763 .934 r
.78129 .40193 .78323 .40452 .79765 .39998 .79573 .39737 Metetra
.645 .763 .934 r
.79573 .39737 .79765 .39998 .81215 .39541 .81024 .3928 Metetra
.377 .612 .942 r
.1607 .4072 .16305 .40959 .17319 .41183 .17094 .4086 Metetra
.81 .702 .746 r
.17094 .4086 .17319 .41183 .18537 .39556 .18298 .39373 Metetra
.102 .522 .909 r
.18298 .39373 .18537 .39556 .19539 .39998 .19315 .39682 Metetra
.787 .703 .772 r
.19315 .39682 .19539 .39998 .20712 .38828 .20489 .38501 Metetra
.805 .702 .752 r
.20489 .38501 .20712 .38828 .21906 .37419 .21684 .37091 Metetra
.828 .706 .729 r
.21684 .37091 .21906 .37419 .23137 .3558 .22909 .35341 Metetra
.526 .68 .935 r
.22909 .35341 .23137 .3558 .24218 .35383 .23979 .35262 Metetra
.581 .015 0 r
.23979 .35262 .24218 .35383 .25217 .36198 .24979 .36078 Metetra
.625 .066 0 r
.24979 .36078 .25217 .36198 .26222 .37096 .25984 .36977 Metetra
.745 .866 .936 r
.25984 .36977 .26222 .37096 .27348 .36636 .27126 .36337 Metetra
.524 .628 .896 r
.27126 .36337 .27348 .36636 .28462 .36391 .28224 .36298 Metetra
.916 .543 .299 r
.28224 .36298 .28462 .36391 .29319 .39798 .29079 .39709 Metetra
.741 .902 .95 r
.29079 .39709 .29319 .39798 .30477 .39257 .30247 .39053 Metetra
.779 .79 .862 r
.30247 .39053 .30477 .39257 .31661 .38385 .31431 .38195 Metetra
.583 .762 .964 r
.31431 .38195 .31661 .38385 .32806 .3818 .32579 .37958 Metetra
.885 .769 .728 r
.32579 .37958 .32806 .3818 .34067 .36072 .33842 .35848 Metetra
.889 .767 .721 r
.33842 .35848 .34067 .36072 .35325 .33878 .35103 .33652 Metetra
.875 .771 .744 r
.35103 .33652 .35325 .33878 .36559 .32012 .36339 .31785 Metetra
.807 .344 0 r
.36339 .31785 .36559 .32012 .37609 .33928 .37388 .33701 Metetra
.83 .376 0 r
.37388 .33701 .37609 .33928 .38674 .36024 .38452 .35797 Metetra
.85 .405 0 r
.38452 .35797 .38674 .36024 .39754 .38315 .39531 .38088 Metetra
.903 .772 .707 r
.39531 .38088 .39754 .38315 .41029 .35899 .4081 .3563 Metetra
.847 .415 0 r
.4081 .3563 .41029 .35899 .42138 .38328 .41916 .38141 Metetra
.953 .615 .334 r
.41916 .38141 .42138 .38328 .43137 .45561 .4291 .4538 Metetra
.827 .359 0 r
.4291 .4538 .43137 .45561 .4432 .47901 .44097 .47537 Metetra
.893 .725 .666 r
.44097 .47537 .4432 .47901 .45645 .44719 .45425 .44355 Metetra
.898 .725 .66 r
.45425 .44355 .45645 .44719 .46957 .41415 .4674 .4105 Metetra
.902 .725 .653 r
.4674 .4105 .46957 .41415 .48254 .37986 .48039 .3762 Metetra
.906 .725 .647 r
.48039 .3762 .48254 .37986 .49535 .34431 .49323 .34065 Metetra
.517 .59 .866 r
.49323 .34065 .49535 .34431 .50779 .34174 .50566 .34068 Metetra
.926 .54 .232 r
.50566 .34068 .50779 .34174 .52023 .38713 .51808 .38613 Metetra
.93 .55 .244 r
.51808 .38613 .52023 .38713 .53314 .43729 .53097 .43637 Metetra
.903 .491 .17 r
.53097 .43637 .53314 .43729 .54646 .476 .54428 .47361 Metetra
.645 .763 .934 r
.54428 .47361 .54646 .476 .55975 .47181 .55757 .46941 Metetra
.645 .763 .934 r
.55757 .46941 .55975 .47181 .57309 .4676 .57093 .46519 Metetra
.645 .763 .934 r
.57093 .46519 .57309 .4676 .5865 .46337 .58436 .46095 Metetra
.645 .763 .934 r
.58436 .46095 .5865 .46337 .59998 .45912 .59784 .45668 Metetra
.645 .763 .934 r
.59784 .45668 .59998 .45912 .61352 .45485 .6114 .4524 Metetra
.645 .763 .934 r
.6114 .4524 .61352 .45485 .62713 .45056 .62502 .4481 Metetra
.645 .763 .934 r
.62502 .4481 .62713 .45056 .6408 .44625 .63871 .44377 Metetra
.645 .763 .934 r
.63871 .44377 .6408 .44625 .65454 .44191 .65246 .43942 Metetra
.645 .763 .934 r
.65246 .43942 .65454 .44191 .66835 .43756 .66628 .43506 Metetra
.645 .763 .934 r
.66628 .43506 .66835 .43756 .68222 .43318 .68017 .43067 Metetra
.645 .763 .934 r
.68017 .43067 .68222 .43318 .69617 .42878 .69413 .42626 Metetra
.645 .763 .934 r
.69413 .42626 .69617 .42878 .71018 .42436 .70816 .42182 Metetra
.645 .763 .934 r
.70816 .42182 .71018 .42436 .72426 .41992 .72226 .41737 Metetra
.645 .763 .934 r
.72226 .41737 .72426 .41992 .73841 .41545 .73642 .41289 Metetra
.645 .763 .934 r
.73642 .41289 .73841 .41545 .75263 .41097 .75066 .40839 Metetra
.645 .763 .934 r
.75066 .40839 .75263 .41097 .76693 .40646 .76497 .40387 Metetra
.645 .763 .934 r
.76497 .40387 .76693 .40646 .78129 .40193 .77935 .39933 Metetra
.645 .763 .934 r
.77935 .39933 .78129 .40193 .79573 .39737 .7938 .39476 Metetra
.645 .763 .934 r
.7938 .39476 .79573 .39737 .81024 .3928 .80833 .39017 Metetra
.359 .591 .933 r
.15836 .40468 .1607 .4072 .17094 .4086 .16856 .40644 Metetra
.844 .76 .769 r
.16856 .40644 .17094 .4086 .18298 .39373 .18064 .39137 Metetra
.217 .53 .921 r
.18064 .39137 .18298 .39373 .19315 .39682 .19081 .39445 Metetra
.811 .752 .797 r
.19081 .39445 .19315 .39682 .20489 .38501 .20256 .3827 Metetra
.834 .755 .776 r
.20256 .3827 .20489 .38501 .21684 .37091 .21453 .36859 Metetra
.858 .752 .745 r
.21453 .36859 .21684 .37091 .22909 .35341 .22682 .35081 Metetra
.511 .653 .923 r
.22682 .35081 .22909 .35341 .23979 .35262 .23749 .35046 Metetra
0 .12 .611 r
.23749 .35046 .23979 .35262 .24979 .36078 .24748 .35861 Metetra
0 .06 .551 r
.24748 .35861 .24979 .36078 .25984 .36977 .25754 .36759 Metetra
.731 .767 .882 r
.25754 .36759 .25984 .36977 .27126 .36337 .26895 .36128 Metetra
.502 .707 .962 r
.26895 .36128 .27126 .36337 .28224 .36298 .27997 .36056 Metetra
.933 .555 .233 r
.27997 .36056 .28224 .36298 .29079 .39709 .2885 .39467 Metetra
.73 .752 .87 r
.2885 .39467 .29079 .39709 .30247 .39053 .30019 .38807 Metetra
.757 .754 .849 r
.30019 .38807 .30247 .39053 .31431 .38195 .31201 .38007 Metetra
.583 .765 .965 r
.31201 .38007 .31431 .38195 .32579 .37958 .32349 .37767 Metetra
.895 .785 .732 r
.32349 .37767 .32579 .37958 .33842 .35848 .33615 .35655 Metetra
.899 .783 .725 r
.33615 .35655 .33842 .35848 .35103 .33652 .34878 .33457 Metetra
.889 .787 .743 r
.34878 .33457 .35103 .33652 .36339 .31785 .3612 .31512 Metetra
.772 .32 0 r
.3612 .31512 .36339 .31785 .37388 .33701 .37169 .33428 Metetra
.802 .356 0 r
.37169 .33428 .37388 .33701 .38452 .35797 .38232 .35523 Metetra
.828 .388 0 r
.38232 .35523 .38452 .35797 .39531 .38088 .3931 .37814 Metetra
.89 .751 .702 r
.3931 .37814 .39531 .38088 .4081 .3563 .40591 .35352 Metetra
.85 .422 0 r
.40591 .35352 .4081 .3563 .41916 .38141 .41693 .37923 Metetra
.955 .617 .328 r
.41693 .37923 .41916 .38141 .4291 .4538 .42683 .45166 Metetra
.813 .347 0 r
.42683 .45166 .4291 .4538 .44097 .47537 .4387 .47324 Metetra
.93 .778 .671 r
.4387 .47324 .44097 .47537 .45425 .44355 .45201 .44138 Metetra
.932 .775 .663 r
.45201 .44138 .45425 .44355 .4674 .4105 .46519 .4083 Metetra
.935 .773 .655 r
.46519 .4083 .4674 .4105 .48039 .3762 .47822 .37398 Metetra
.938 .77 .648 r
.47822 .37398 .48039 .3762 .49323 .34065 .49109 .33839 Metetra
.48 .694 .962 r
.49109 .33839 .49323 .34065 .50566 .34068 .50353 .338 Metetra
.924 .541 .155 r
.50353 .338 .50566 .34068 .51808 .38613 .51593 .38346 Metetra
.93 .553 .174 r
.51593 .38346 .51808 .38613 .53097 .43637 .52879 .43371 Metetra
.889 .481 .059 r
.52879 .43371 .53097 .43637 .54428 .47361 .54209 .47121 Metetra
.645 .763 .934 r
.54209 .47121 .54428 .47361 .55757 .46941 .55539 .467 Metetra
.645 .763 .934 r
.55539 .467 .55757 .46941 .57093 .46519 .56877 .46277 Metetra
.645 .763 .934 r
.56877 .46277 .57093 .46519 .58436 .46095 .5822 .45851 Metetra
.645 .763 .934 r
.5822 .45851 .58436 .46095 .59784 .45668 .59571 .45424 Metetra
.645 .763 .934 r
.59571 .45424 .59784 .45668 .6114 .4524 .60927 .44994 Metetra
.645 .763 .934 r
.60927 .44994 .6114 .4524 .62502 .4481 .62291 .44563 Metetra
.645 .763 .934 r
.62291 .44563 .62502 .4481 .63871 .44377 .63661 .44129 Metetra
.645 .763 .934 r
.63661 .44129 .63871 .44377 .65246 .43942 .65038 .43693 Metetra
.645 .763 .934 r
.65038 .43693 .65246 .43942 .66628 .43506 .66421 .43255 Metetra
.645 .763 .934 r
.66421 .43255 .66628 .43506 .68017 .43067 .67812 .42815 Metetra
.645 .763 .934 r
.67812 .42815 .68017 .43067 .69413 .42626 .69209 .42373 Metetra
.645 .763 .934 r
.69209 .42373 .69413 .42626 .70816 .42182 .70613 .41928 Metetra
.645 .763 .934 r
.70613 .41928 .70816 .42182 .72226 .41737 .72025 .41481 Metetra
.645 .763 .934 r
.72025 .41481 .72226 .41737 .73642 .41289 .73443 .41032 Metetra
.645 .763 .934 r
.73443 .41032 .73642 .41289 .75066 .40839 .74868 .40581 Metetra
.645 .763 .934 r
.74868 .40581 .75066 .40839 .76497 .40387 .76301 .40128 Metetra
.645 .763 .934 r
.76301 .40128 .76497 .40387 .77935 .39933 .7774 .39672 Metetra
.645 .763 .934 r
.7774 .39672 .77935 .39933 .7938 .39476 .79187 .39214 Metetra
.645 .763 .934 r
.79187 .39214 .7938 .39476 .80833 .39017 .80641 .38754 Metetra
.358 .649 .966 r
.15596 .4027 .15836 .40468 .16856 .40644 .16624 .40372 Metetra
.816 .728 .769 r
.16624 .40372 .16856 .40644 .18064 .39137 .17818 .39014 Metetra
0 .516 .855 r
.17818 .39014 .18064 .39137 .19081 .39445 .1884 .39274 Metetra
.831 .799 .822 r
.1884 .39274 .19081 .39445 .20256 .3827 .20015 .38116 Metetra
.86 .805 .795 r
.20015 .38116 .20256 .3827 .21453 .36859 .21214 .36703 Metetra
.884 .792 .753 r
.21214 .36703 .21453 .36859 .22682 .35081 .2245 .34871 Metetra
.534 .714 .955 r
.2245 .34871 .22682 .35081 .23749 .35046 .23525 .34753 Metetra
0 .208 .729 r
.23525 .34753 .23749 .35046 .24748 .35861 .24524 .35568 Metetra
0 .153 .685 r
.24524 .35568 .24748 .35861 .25754 .36759 .25529 .36465 Metetra
.721 .706 .835 r
.25529 .36465 .25754 .36759 .26895 .36128 .26675 .35795 Metetra
.467 .574 .879 r
.26675 .35795 .26895 .36128 .27997 .36056 .27763 .35895 Metetra
.926 .549 .272 r
.27763 .35895 .27997 .36056 .2885 .39467 .28614 .39309 Metetra
.773 .832 .898 r
.28614 .39309 .2885 .39467 .30019 .38807 .29793 .38535 Metetra
.742 .732 .843 r
.29793 .38535 .30019 .38807 .31201 .38007 .30972 .37778 Metetra
.601 .729 .935 r
.30972 .37778 .31201 .38007 .32349 .37767 .32122 .37525 Metetra
.88 .759 .726 r
.32122 .37525 .32349 .37767 .33615 .35655 .3339 .35411 Metetra
.884 .758 .719 r
.3339 .35411 .33615 .35655 .34878 .33457 .34656 .33211 Metetra
.872 .761 .737 r
.34656 .33211 .34878 .33457 .3612 .31512 .35899 .31277 Metetra
.803 .341 0 r
.35899 .31277 .3612 .31512 .37169 .33428 .36947 .33193 Metetra
.827 .373 0 r
.36947 .33193 .37169 .33428 .38232 .35523 .38009 .35288 Metetra
.847 .402 0 r
.38009 .35288 .38232 .35523 .3931 .37814 .39086 .3758 Metetra
.902 .769 .705 r
.39086 .3758 .3931 .37814 .40591 .35352 .40371 .351 Metetra
.864 .433 .01 r
.40371 .351 .40591 .35352 .41693 .37923 .41471 .37694 Metetra
.955 .618 .325 r
.41471 .37694 .41693 .37923 .42683 .45166 .42456 .44941 Metetra
.785 .313 0 r
.42456 .44941 .42683 .45166 .4387 .47324 .43645 .46968 Metetra
.896 .728 .667 r
.43645 .46968 .4387 .47324 .45201 .44138 .44979 .43782 Metetra
.9 .728 .66 r
.44979 .43782 .45201 .44138 .46519 .4083 .463 .40473 Metetra
.904 .728 .653 r
.463 .40473 .46519 .4083 .47822 .37398 .47606 .3704 Metetra
.908 .728 .647 r
.47606 .3704 .47822 .37398 .49109 .33839 .48896 .3348 Metetra
.442 .556 .875 r
.48896 .3348 .49109 .33839 .50353 .338 .50138 .3366 Metetra
.927 .542 .217 r
.50138 .3366 .50353 .338 .51593 .38346 .51377 .38211 Metetra
.931 .551 .231 r
.51377 .38211 .51593 .38346 .52879 .43371 .52661 .43242 Metetra
.901 .485 .142 r
.52661 .43242 .52879 .43371 .54209 .47121 .53989 .46881 Metetra
.645 .763 .934 r
.53989 .46881 .54209 .47121 .55539 .467 .55321 .46458 Metetra
.645 .763 .934 r
.55321 .46458 .55539 .467 .56877 .46277 .56659 .46034 Metetra
.645 .763 .934 r
.56659 .46034 .56877 .46277 .5822 .45851 .58004 .45607 Metetra
.645 .763 .934 r
.58004 .45607 .5822 .45851 .59571 .45424 .59356 .45179 Metetra
.645 .763 .934 r
.59356 .45179 .59571 .45424 .60927 .44994 .60714 .44748 Metetra
.645 .763 .934 r
.60714 .44748 .60927 .44994 .62291 .44563 .62079 .44315 Metetra
.645 .763 .934 r
.62079 .44315 .62291 .44563 .63661 .44129 .63451 .4388 Metetra
.645 .763 .934 r
.63451 .4388 .63661 .44129 .65038 .43693 .64829 .43443 Metetra
.645 .763 .934 r
.64829 .43443 .65038 .43693 .66421 .43255 .66214 .43004 Metetra
.645 .763 .934 r
.66214 .43004 .66421 .43255 .67812 .42815 .67606 .42562 Metetra
.645 .763 .934 r
.67606 .42562 .67812 .42815 .69209 .42373 .69005 .42119 Metetra
.645 .763 .934 r
.69005 .42119 .69209 .42373 .70613 .41928 .7041 .41673 Metetra
.645 .763 .934 r
.7041 .41673 .70613 .41928 .72025 .41481 .71823 .41225 Metetra
.645 .763 .934 r
.71823 .41225 .72025 .41481 .73443 .41032 .73243 .40775 Metetra
.645 .763 .934 r
.73243 .40775 .73443 .41032 .74868 .40581 .7467 .40322 Metetra
.645 .763 .934 r
.7467 .40322 .74868 .40581 .76301 .40128 .76104 .39868 Metetra
.645 .763 .934 r
.76104 .39868 .76301 .40128 .7774 .39672 .77545 .39411 Metetra
.645 .763 .934 r
.77545 .39411 .7774 .39672 .79187 .39214 .78993 .38951 Metetra
.645 .763 .934 r
.78993 .38951 .79187 .39214 .80641 .38754 .80449 .3849 Metetra
.394 .621 .943 r
.15359 .4003 .15596 .4027 .16624 .40372 .16387 .40146 Metetra
.835 .755 .775 r
.16387 .40146 .16624 .40372 .17818 .39014 .17589 .38723 Metetra
.352 .549 .906 r
.17589 .38723 .17818 .39014 .1884 .39274 .18613 .38959 Metetra
.788 .705 .772 r
.18613 .38959 .1884 .39274 .20015 .38116 .19792 .3777 Metetra
.8 .693 .748 r
.19792 .3777 .20015 .38116 .21214 .36703 .20993 .36356 Metetra
.822 .698 .728 r
.20993 .36356 .21214 .36703 .2245 .34871 .2222 .34633 Metetra
.466 .658 .944 r
.2222 .34633 .2245 .34871 .23525 .34753 .23283 .34649 Metetra
.602 .035 0 r
.23283 .34649 .23525 .34753 .24524 .35568 .24282 .35464 Metetra
.642 .084 0 r
.24282 .35464 .24524 .35568 .25529 .36465 .25288 .36362 Metetra
.774 .883 .925 r
.25288 .36362 .25529 .36465 .26675 .35795 .2644 .35624 Metetra
.361 .687 .98 r
.2644 .35624 .26675 .35795 .27763 .35895 .27533 .35679 Metetra
.931 .554 .247 r
.27533 .35679 .27763 .35895 .28614 .39309 .28381 .39094 Metetra
.748 .779 .878 r
.28381 .39094 .28614 .39309 .29793 .38535 .29557 .38379 Metetra
.787 .836 .89 r
.29557 .38379 .29793 .38535 .30972 .37778 .30743 .37544 Metetra
.599 .724 .932 r
.30743 .37544 .30972 .37778 .32122 .37525 .31894 .37296 Metetra
.884 .766 .727 r
.31894 .37296 .32122 .37525 .3339 .35411 .33164 .3518 Metetra
.888 .765 .721 r
.33164 .3518 .3339 .35411 .34656 .33211 .34432 .32978 Metetra
.876 .768 .74 r
.34432 .32978 .34656 .33211 .35899 .31277 .35677 .31055 Metetra
.812 .347 0 r
.35677 .31055 .35899 .31277 .36947 .33193 .36724 .32971 Metetra
.834 .379 0 r
.36724 .32971 .36947 .33193 .38009 .35288 .37785 .35067 Metetra
.853 .407 0 r
.37785 .35067 .38009 .35288 .39086 .3758 .38861 .3736 Metetra
.906 .776 .707 r
.38861 .3736 .39086 .3758 .40371 .351 .40148 .34885 Metetra
.872 .438 .043 r
.40148 .34885 .40371 .351 .41471 .37694 .41248 .37455 Metetra
.956 .619 .323 r
.41248 .37455 .41471 .37694 .42456 .44941 .42229 .44705 Metetra
.786 .318 0 r
.42229 .44705 .42456 .44941 .43645 .46968 .43416 .46775 Metetra
.935 .785 .672 r
.43416 .46775 .43645 .46968 .44979 .43782 .44753 .43585 Metetra
.937 .783 .663 r
.44753 .43585 .44979 .43782 .463 .40473 .46077 .40273 Metetra
.94 .78 .655 r
.46077 .40273 .463 .40473 .47606 .3704 .47387 .36836 Metetra
.942 .777 .647 r
.47387 .36836 .47606 .3704 .48896 .3348 .4868 .33273 Metetra
.354 .651 .967 r
.4868 .33273 .48896 .3348 .50138 .3366 .49924 .33395 Metetra
.925 .541 .157 r
.49924 .33395 .50138 .3366 .51377 .38211 .5116 .37947 Metetra
.931 .553 .176 r
.5116 .37947 .51377 .38211 .52661 .43242 .52442 .42979 Metetra
.886 .475 .053 r
.52442 .42979 .52661 .43242 .53989 .46881 .53768 .4664 Metetra
.645 .763 .934 r
.53768 .4664 .53989 .46881 .55321 .46458 .55102 .46216 Metetra
.645 .763 .934 r
.55102 .46216 .55321 .46458 .56659 .46034 .56442 .4579 Metetra
.645 .763 .934 r
.56442 .4579 .56659 .46034 .58004 .45607 .57788 .45363 Metetra
.645 .763 .934 r
.57788 .45363 .58004 .45607 .59356 .45179 .59141 .44933 Metetra
.645 .763 .934 r
.59141 .44933 .59356 .45179 .60714 .44748 .60501 .44501 Metetra
.645 .763 .934 r
.60501 .44501 .60714 .44748 .62079 .44315 .61867 .44067 Metetra
.645 .763 .934 r
.61867 .44067 .62079 .44315 .63451 .4388 .6324 .43631 Metetra
.645 .763 .934 r
.6324 .43631 .63451 .4388 .64829 .43443 .64619 .43192 Metetra
.645 .763 .934 r
.64619 .43192 .64829 .43443 .66214 .43004 .66006 .42752 Metetra
.645 .763 .934 r
.66006 .42752 .66214 .43004 .67606 .42562 .67399 .42309 Metetra
.645 .763 .934 r
.67399 .42309 .67606 .42562 .69005 .42119 .68799 .41864 Metetra
.645 .763 .934 r
.68799 .41864 .69005 .42119 .7041 .41673 .70207 .41417 Metetra
.645 .763 .934 r
.70207 .41417 .7041 .41673 .71823 .41225 .71621 .40968 Metetra
.645 .763 .934 r
.71621 .40968 .71823 .41225 .73243 .40775 .73042 .40517 Metetra
.645 .763 .934 r
.73042 .40517 .73243 .40775 .7467 .40322 .7447 .40063 Metetra
.645 .763 .934 r
.7447 .40063 .7467 .40322 .76104 .39868 .75906 .39607 Metetra
.645 .763 .934 r
.75906 .39607 .76104 .39868 .77545 .39411 .77349 .39148 Metetra
.645 .763 .934 r
.77349 .39148 .77545 .39411 .78993 .38951 .78799 .38688 Metetra
.645 .763 .934 r
.78799 .38688 .78993 .38951 .80449 .3849 .80256 .38225 Metetra
.355 .669 .974 r
.15116 .39849 .15359 .4003 .16387 .40146 .16148 .39926 Metetra
.828 .76 .788 r
.16148 .39926 .16387 .40146 .17589 .38723 .17339 .38616 Metetra
0 .482 .806 r
.17339 .38616 .17589 .38723 .18613 .38959 .18361 .38886 Metetra
.86 .881 .852 r
.18361 .38886 .18613 .38959 .19792 .3777 .19539 .37724 Metetra
.892 .886 .819 r
.19539 .37724 .19792 .3777 .20993 .36356 .20741 .36308 Metetra
.918 .855 .764 r
.20741 .36308 .20993 .36356 .2222 .34633 .21986 .34432 Metetra
.568 .737 .955 r
.21986 .34432 .2222 .34633 .23283 .34649 .23068 .34245 Metetra
.053 .275 .767 r
.23068 .34245 .23283 .34649 .24282 .35464 .24067 .35059 Metetra
0 .236 .746 r
.24067 .35059 .24282 .35464 .25288 .36362 .25071 .35955 Metetra
.693 .635 .787 r
.25071 .35955 .25288 .36362 .2644 .35624 .26218 .35296 Metetra
.437 .564 .885 r
.26218 .35296 .2644 .35624 .27533 .35679 .27303 .35446 Metetra
.932 .555 .239 r
.27303 .35446 .27533 .35679 .28381 .39094 .2815 .38863 Metetra
.758 .766 .859 r
.2815 .38863 .28381 .39094 .29557 .38379 .29331 .38078 Metetra
.742 .714 .825 r
.29331 .38078 .29557 .38379 .30743 .37544 .30516 .37279 Metetra
.595 .695 .912 r
.30516 .37279 .30743 .37544 .31894 .37296 .31666 .37051 Metetra
.879 .759 .725 r
.31666 .37051 .31894 .37296 .33164 .3518 .32938 .34934 Metetra
.883 .758 .719 r
.32938 .34934 .33164 .3518 .34432 .32978 .34209 .3273 Metetra
.871 .76 .737 r
.34209 .3273 .34432 .32978 .35677 .31055 .35456 .30804 Metetra
.793 .333 0 r
.35456 .30804 .35677 .31055 .36724 .32971 .36502 .3272 Metetra
.819 .367 0 r
.36502 .3272 .36724 .32971 .37785 .35067 .37562 .34816 Metetra
.841 .398 0 r
.37562 .34816 .37785 .35067 .38861 .3736 .38637 .37109 Metetra
.896 .763 .706 r
.38637 .37109 .38861 .3736 .40148 .34885 .39926 .34659 Metetra
.865 .428 .022 r
.39926 .34659 .40148 .34885 .41248 .37455 .41026 .37175 Metetra
.958 .621 .315 r
.41026 .37175 .41248 .37455 .42229 .44705 .42002 .44427 Metetra
.743 .286 0 r
.42002 .44427 .42229 .44705 .43416 .46775 .4319 .46461 Metetra
.906 .742 .668 r
.4319 .46461 .43416 .46775 .44753 .43585 .4453 .43269 Metetra
.909 .742 .661 r
.4453 .43269 .44753 .43585 .46077 .40273 .45857 .39955 Metetra
.913 .741 .654 r
.45857 .39955 .46077 .40273 .47387 .36836 .47169 .36517 Metetra
.917 .74 .647 r
.47169 .36517 .47387 .36836 .4868 .33273 .48465 .32953 Metetra
.386 .557 .9 r
.48465 .32953 .4868 .33273 .49924 .33395 .49709 .33195 Metetra
.928 .542 .191 r
.49709 .33195 .49924 .33395 .5116 .37947 .50943 .37751 Metetra
.932 .553 .207 r
.50943 .37751 .5116 .37947 .52442 .42979 .52222 .42787 Metetra
.896 .479 .099 r
.52222 .42787 .52442 .42979 .53768 .4664 .53547 .46398 Metetra
.645 .763 .934 r
.53547 .46398 .53768 .4664 .55102 .46216 .54882 .45973 Metetra
.645 .763 .934 r
.54882 .45973 .55102 .46216 .56442 .4579 .56223 .45546 Metetra
.645 .763 .934 r
.56223 .45546 .56442 .4579 .57788 .45363 .57571 .45117 Metetra
.645 .763 .934 r
.57571 .45117 .57788 .45363 .59141 .44933 .58925 .44686 Metetra
.645 .763 .934 r
.58925 .44686 .59141 .44933 .60501 .44501 .60286 .44253 Metetra
.645 .763 .934 r
.60286 .44253 .60501 .44501 .61867 .44067 .61654 .43818 Metetra
.645 .763 .934 r
.61654 .43818 .61867 .44067 .6324 .43631 .63028 .43381 Metetra
.645 .763 .934 r
.63028 .43381 .6324 .43631 .64619 .43192 .64409 .42941 Metetra
.645 .763 .934 r
.64409 .42941 .64619 .43192 .66006 .42752 .65797 .42499 Metetra
.645 .763 .934 r
.65797 .42499 .66006 .42752 .67399 .42309 .67192 .42055 Metetra
.645 .763 .934 r
.67192 .42055 .67399 .42309 .68799 .41864 .68594 .41609 Metetra
.645 .763 .934 r
.68594 .41609 .68799 .41864 .70207 .41417 .70002 .41161 Metetra
.645 .763 .934 r
.70002 .41161 .70207 .41417 .71621 .40968 .71418 .4071 Metetra
.645 .763 .934 r
.71418 .4071 .71621 .40968 .73042 .40517 .72841 .40258 Metetra
.645 .763 .934 r
.72841 .40258 .73042 .40517 .7447 .40063 .74271 .39802 Metetra
.645 .763 .934 r
.74271 .39802 .7447 .40063 .75906 .39607 .75708 .39345 Metetra
.645 .763 .934 r
.75708 .39345 .75906 .39607 .77349 .39148 .77152 .38885 Metetra
.645 .763 .934 r
.77152 .38885 .77349 .39148 .78799 .38688 .78604 .38423 Metetra
.645 .763 .934 r
.78604 .38423 .78799 .38688 .80256 .38225 .80063 .37959 Metetra
.419 .633 .943 r
.14878 .39607 .15116 .39849 .16148 .39926 .1591 .3969 Metetra
.832 .75 .773 r
.1591 .3969 .16148 .39926 .17339 .38616 .17115 .38265 Metetra
.411 .53 .867 r
.17115 .38265 .17339 .38616 .18361 .38886 .18143 .38477 Metetra
.765 .659 .745 r
.18143 .38477 .18361 .38886 .19539 .37724 .19327 .37262 Metetra
.77 .644 .723 r
.19327 .37262 .19539 .37724 .20741 .36308 .20531 .35846 Metetra
.787 .651 .712 r
.20531 .35846 .20741 .36308 .21986 .34432 .21754 .34203 Metetra
.432 .652 .952 r
.21754 .34203 .21986 .34432 .23068 .34245 .22814 .34254 Metetra
.67 .139 0 r
.22814 .34254 .23068 .34245 .24067 .35059 .23814 .35069 Metetra
.694 .172 0 r
.23814 .35069 .24067 .35059 .25071 .35955 .24818 .35967 Metetra
.753 .978 .918 r
.24818 .35967 .25071 .35955 .26218 .35296 .25978 .35169 Metetra
.248 .676 .962 r
.25978 .35169 .26218 .35296 .27303 .35446 .2707 .3525 Metetra
.929 .552 .257 r
.2707 .3525 .27303 .35446 .2815 .38863 .27914 .38669 Metetra
.747 .798 .894 r
.27914 .38669 .2815 .38863 .29331 .38078 .2909 .37975 Metetra
.815 .887 .896 r
.2909 .37975 .29331 .38078 .30516 .37279 .30286 .37045 Metetra
.596 .724 .933 r
.30286 .37045 .30516 .37279 .31666 .37051 .31438 .36801 Metetra
.878 .756 .725 r
.31438 .36801 .31666 .37051 .32938 .34934 .32712 .34682 Metetra
.882 .755 .718 r
.32712 .34682 .32938 .34934 .34209 .3273 .33985 .32476 Metetra
.866 .758 .742 r
.33985 .32476 .34209 .3273 .35456 .30804 .3523 .30617 Metetra
.829 .361 0 r
.3523 .30617 .35456 .30804 .36502 .3272 .36276 .32535 Metetra
.847 .39 .005 r
.36276 .32535 .36502 .3272 .37562 .34816 .37335 .34632 Metetra
.862 .415 .04 r
.37335 .34632 .37562 .34816 .38637 .37109 .38409 .36926 Metetra
.916 .793 .71 r
.38409 .36926 .38637 .37109 .39926 .34659 .39701 .34454 Metetra
.869 .431 .041 r
.39701 .34454 .39926 .34659 .41026 .37175 .40801 .3696 Metetra
.954 .617 .329 r
.40801 .3696 .41026 .37175 .42002 .44427 .41773 .44216 Metetra
.803 .332 0 r
.41773 .44216 .42002 .44427 .4319 .46461 .42959 .46294 Metetra
.941 .796 .672 r
.42959 .46294 .4319 .46461 .4453 .43269 .44302 .43099 Metetra
.943 .792 .663 r
.44302 .43099 .4453 .43269 .45857 .39955 .45633 .39781 Metetra
.946 .789 .655 r
.45633 .39781 .45857 .39955 .47169 .36517 .46949 .36339 Metetra
.948 .786 .647 r
.46949 .36339 .47169 .36517 .48465 .32953 .48248 .3277 Metetra
.289 .644 .967 r
.48248 .3277 .48465 .32953 .49709 .33195 .49494 .32925 Metetra
.925 .541 .155 r
.49494 .32925 .49709 .33195 .50943 .37751 .50725 .37482 Metetra
.931 .553 .175 r
.50725 .37482 .50943 .37751 .52222 .42787 .52002 .42519 Metetra
.884 .472 .046 r
.52002 .42519 .52222 .42787 .53547 .46398 .53326 .46155 Metetra
.645 .763 .934 r
.53326 .46155 .53547 .46398 .54882 .45973 .54662 .45729 Metetra
.645 .763 .934 r
.54662 .45729 .54882 .45973 .56223 .45546 .56004 .45301 Metetra
.645 .763 .934 r
.56004 .45301 .56223 .45546 .57571 .45117 .57353 .44871 Metetra
.645 .763 .934 r
.57353 .44871 .57571 .45117 .58925 .44686 .58709 .44439 Metetra
.645 .763 .934 r
.58709 .44439 .58925 .44686 .60286 .44253 .60071 .44005 Metetra
.645 .763 .934 r
.60071 .44005 .60286 .44253 .61654 .43818 .6144 .43568 Metetra
.645 .763 .934 r
.6144 .43568 .61654 .43818 .63028 .43381 .62816 .4313 Metetra
.645 .763 .934 r
.62816 .4313 .63028 .43381 .64409 .42941 .64198 .42689 Metetra
.645 .763 .934 r
.64198 .42689 .64409 .42941 .65797 .42499 .65588 .42246 Metetra
.645 .763 .934 r
.65588 .42246 .65797 .42499 .67192 .42055 .66984 .41801 Metetra
.645 .763 .934 r
.66984 .41801 .67192 .42055 .68594 .41609 .68387 .41353 Metetra
.645 .763 .934 r
.68387 .41353 .68594 .41609 .70002 .41161 .69797 .40904 Metetra
.645 .763 .934 r
.69797 .40904 .70002 .41161 .71418 .4071 .71215 .40452 Metetra
.645 .763 .934 r
.71215 .40452 .71418 .4071 .72841 .40258 .72639 .39998 Metetra
.645 .763 .934 r
.72639 .39998 .72841 .40258 .74271 .39802 .7407 .39541 Metetra
.645 .763 .934 r
.7407 .39541 .74271 .39802 .75708 .39345 .75509 .39083 Metetra
.645 .763 .934 r
.75509 .39083 .75708 .39345 .77152 .38885 .76955 .38622 Metetra
.645 .763 .934 r
.76955 .38622 .77152 .38885 .78604 .38423 .78408 .38158 Metetra
.645 .763 .934 r
.78408 .38158 .78604 .38423 .80063 .37959 .79869 .37693 Metetra
.317 .679 .977 r
.1463 .39451 .14878 .39607 .1591 .3969 .15664 .39523 Metetra
.847 .796 .802 r
.15664 .39523 .1591 .3969 .17115 .38265 .1686 .38195 Metetra
.232 0 0 r
.1686 .38195 .17115 .38265 .18143 .38477 .17877 .3851 Metetra
.862 .968 .863 r
.17877 .3851 .18143 .38477 .19327 .37262 .19057 .37361 Metetra
.893 .983 .807 r
.19057 .37361 .19327 .37262 .20531 .35846 .20263 .35941 Metetra
.945 .935 .755 r
.20263 .35941 .20531 .35846 .21754 .34203 .21517 .34015 Metetra
.625 .77 .95 r
.21517 .34015 .21754 .34203 .22814 .34254 .22612 .33706 Metetra
.221 .303 .737 r
.22612 .33706 .22814 .34254 .23814 .35069 .2361 .34518 Metetra
.182 .278 .728 r
.2361 .34518 .23814 .35069 .24818 .35967 .24614 .35413 Metetra
.655 .565 .741 r
.24614 .35413 .24818 .35967 .25978 .35169 .25756 .34829 Metetra
.459 .567 .877 r
.25756 .34829 .25978 .35169 .2707 .3525 .26845 .34944 Metetra
.934 .557 .199 r
.26845 .34944 .2707 .3525 .27914 .38669 .27687 .38361 Metetra
.738 .709 .824 r
.27687 .38361 .27914 .38669 .2909 .37975 .2887 .37577 Metetra
.716 .654 .787 r
.2887 .37577 .2909 .37975 .30286 .37045 .30057 .36791 Metetra
.597 .707 .92 r
.30057 .36791 .30286 .37045 .31438 .36801 .31209 .3655 Metetra
.878 .757 .725 r
.31209 .3655 .31438 .36801 .32712 .34682 .32486 .3443 Metetra
.882 .756 .718 r
.32486 .3443 .32712 .34682 .33985 .32476 .33761 .32222 Metetra
.867 .758 .741 r
.33761 .32222 .33985 .32476 .3523 .30617 .35009 .30349 Metetra
.779 .325 0 r
.35009 .30349 .3523 .30617 .36276 .32535 .36053 .32266 Metetra
.808 .36 0 r
.36053 .32266 .36276 .32535 .37335 .34632 .37112 .34363 Metetra
.832 .392 0 r
.37112 .34363 .37335 .34632 .38409 .36926 .38185 .36656 Metetra
.892 .755 .703 r
.38185 .36656 .38409 .36926 .39701 .34454 .39479 .34188 Metetra
.85 .416 0 r
.39479 .34188 .39701 .34454 .40801 .3696 .40578 .36692 Metetra
.957 .62 .318 r
.40578 .36692 .40801 .3696 .41773 .44216 .41545 .43951 Metetra
.761 .3 0 r
.41545 .43951 .41773 .44216 .42959 .46294 .4273 .46007 Metetra
.913 .753 .67 r
.4273 .46007 .42959 .46294 .44302 .43099 .44077 .4281 Metetra
.916 .751 .662 r
.44077 .4281 .44302 .43099 .45633 .39781 .4541 .3949 Metetra
.92 .75 .655 r
.4541 .3949 .45633 .39781 .46949 .36339 .46729 .36046 Metetra
.923 .749 .648 r
.46729 .36046 .46949 .36339 .48248 .3277 .48032 .32476 Metetra
.389 .582 .918 r
.48032 .32476 .48248 .3277 .49494 .32925 .49278 .32674 Metetra
.926 .542 .166 r
.49278 .32674 .49494 .32925 .50725 .37482 .50507 .37232 Metetra
.932 .553 .184 r
.50507 .37232 .50725 .37482 .52002 .42519 .51781 .42271 Metetra
.889 .475 .063 r
.51781 .42271 .52002 .42519 .53326 .46155 .53103 .45912 Metetra
.645 .763 .934 r
.53103 .45912 .53326 .46155 .54662 .45729 .54441 .45485 Metetra
.645 .763 .934 r
.54441 .45485 .54662 .45729 .56004 .45301 .55785 .45056 Metetra
.645 .763 .934 r
.55785 .45056 .56004 .45301 .57353 .44871 .57135 .44625 Metetra
.645 .763 .934 r
.57135 .44625 .57353 .44871 .58709 .44439 .58492 .44191 Metetra
.645 .763 .934 r
.58492 .44191 .58709 .44439 .60071 .44005 .59856 .43756 Metetra
.645 .763 .934 r
.59856 .43756 .60071 .44005 .6144 .43568 .61226 .43318 Metetra
.645 .763 .934 r
.61226 .43318 .6144 .43568 .62816 .4313 .62603 .42878 Metetra
.645 .763 .934 r
.62603 .42878 .62816 .4313 .64198 .42689 .63987 .42436 Metetra
.645 .763 .934 r
.63987 .42436 .64198 .42689 .65588 .42246 .65378 .41992 Metetra
.645 .763 .934 r
.65378 .41992 .65588 .42246 .66984 .41801 .66776 .41545 Metetra
.645 .763 .934 r
.66776 .41545 .66984 .41801 .68387 .41353 .6818 .41097 Metetra
.645 .763 .934 r
.6818 .41097 .68387 .41353 .69797 .40904 .69592 .40646 Metetra
.645 .763 .934 r
.69592 .40646 .69797 .40904 .71215 .40452 .71011 .40193 Metetra
.645 .763 .934 r
.71011 .40193 .71215 .40452 .72639 .39998 .72437 .39737 Metetra
.645 .763 .934 r
.72437 .39737 .72639 .39998 .7407 .39541 .7387 .3928 Metetra
.645 .763 .934 r
.7387 .3928 .7407 .39541 .75509 .39083 .7531 .3882 Metetra
.645 .763 .934 r
.7531 .3882 .75509 .39083 .76955 .38622 .76757 .38357 Metetra
.645 .763 .934 r
.76757 .38357 .76955 .38622 .78408 .38158 .78212 .37893 Metetra
.645 .763 .934 r
.78212 .37893 .78408 .38158 .79869 .37693 .79674 .37425 Metetra
.443 .618 .925 r
.14395 .39183 .1463 .39451 .15664 .39523 .15428 .39258 Metetra
.825 .734 .765 r
.15428 .39258 .15664 .39523 .1686 .38195 .16638 .37815 Metetra
.42 .516 .85 r
.16638 .37815 .1686 .38195 .17877 .3851 .17666 .38034 Metetra
.749 .632 .73 r
.17666 .38034 .17877 .3851 .19057 .37361 .18853 .36816 Metetra
.752 .615 .708 r
.18853 .36816 .19057 .37361 .20263 .35941 .2006 .35396 Metetra
.768 .623 .699 r
.2006 .35396 .20263 .35941 .21517 .34015 .21286 .33765 Metetra
.461 .645 .937 r
.21286 .33765 .21517 .34015 .22612 .33706 .22349 .33794 Metetra
.674 .18 .068 r
.22349 .33794 .22612 .33706 .2361 .34518 .23348 .34608 Metetra
.692 .206 .09 r
.23348 .34608 .2361 .34518 .24614 .35413 .24352 .35506 Metetra
.628 .959 .818 r
.24352 .35506 .24614 .35413 .25756 .34829 .25514 .34715 Metetra
.235 .682 .954 r
.25514 .34715 .25756 .34829 .26845 .34944 .26608 .3478 Metetra
.926 .549 .272 r
.26608 .3478 .26845 .34944 .27687 .38361 .27447 .382 Metetra
.751 .831 .913 r
.27447 .382 .27687 .38361 .2887 .37577 .28625 .37512 Metetra
.82 .922 .904 r
.28625 .37512 .2887 .37577 .30057 .36791 .29825 .36569 Metetra
.598 .738 .942 r
.29825 .36569 .30057 .36791 .31209 .3655 .30978 .36314 Metetra
.882 .764 .727 r
.30978 .36314 .31209 .3655 .32486 .3443 .32258 .34191 Metetra
.886 .762 .72 r
.32258 .34191 .32486 .3443 .33761 .32222 .33535 .31982 Metetra
.868 .766 .747 r
.33535 .31982 .33761 .32222 .35009 .30349 .34782 .30158 Metetra
.827 .36 0 r
.34782 .30158 .35009 .30349 .36053 .32266 .35826 .32076 Metetra
.846 .389 .001 r
.35826 .32076 .36053 .32266 .37112 .34363 .36884 .34174 Metetra
.862 .414 .036 r
.36884 .34174 .37112 .34363 .38185 .36656 .37956 .36469 Metetra
.916 .791 .709 r
.37956 .36469 .38185 .36656 .39479 .34188 .39254 .3398 Metetra
.869 .43 .039 r
.39254 .3398 .39479 .34188 .40578 .36692 .40351 .36484 Metetra
.954 .616 .33 r
.40351 .36484 .40578 .36692 .41545 .43951 .41314 .43747 Metetra
.808 .337 0 r
.41314 .43747 .41545 .43951 .4273 .46007 .42498 .45832 Metetra
.939 .793 .672 r
.42498 .45832 .4273 .46007 .44077 .4281 .43848 .42631 Metetra
.942 .79 .663 r
.43848 .42631 .44077 .4281 .4541 .3949 .45185 .39307 Metetra
.944 .786 .655 r
.45185 .39307 .4541 .3949 .46729 .36046 .46508 .35859 Metetra
.947 .783 .647 r
.46508 .35859 .46729 .36046 .48032 .32476 .47814 .32285 Metetra
.315 .651 .97 r
.47814 .32285 .48032 .32476 .49278 .32674 .49061 .32421 Metetra
.926 .542 .165 r
.49061 .32421 .49278 .32674 .50507 .37232 .50288 .3698 Metetra
.931 .553 .183 r
.50288 .3698 .50507 .37232 .51781 .42271 .5156 .42021 Metetra
.888 .475 .062 r
.5156 .42021 .51781 .42271 .53103 .45912 .52881 .45668 Metetra
.645 .763 .934 r
.52881 .45668 .53103 .45912 .54441 .45485 .54219 .4524 Metetra
.645 .763 .934 r
.54219 .4524 .54441 .45485 .55785 .45056 .55564 .4481 Metetra
.645 .763 .934 r
.55564 .4481 .55785 .45056 .57135 .44625 .56916 .44377 Metetra
.645 .763 .934 r
.56916 .44377 .57135 .44625 .58492 .44191 .58275 .43942 Metetra
.645 .763 .934 r
.58275 .43942 .58492 .44191 .59856 .43756 .5964 .43506 Metetra
.645 .763 .934 r
.5964 .43506 .59856 .43756 .61226 .43318 .61011 .43067 Metetra
.645 .763 .934 r
.61011 .43067 .61226 .43318 .62603 .42878 .6239 .42626 Metetra
.645 .763 .934 r
.6239 .42626 .62603 .42878 .63987 .42436 .63775 .42182 Metetra
.645 .763 .934 r
.63775 .42182 .63987 .42436 .65378 .41992 .65167 .41737 Metetra
.645 .763 .934 r
.65167 .41737 .65378 .41992 .66776 .41545 .66567 .41289 Metetra
.645 .763 .934 r
.66567 .41289 .66776 .41545 .6818 .41097 .67973 .40839 Metetra
.645 .763 .934 r
.67973 .40839 .6818 .41097 .69592 .40646 .69386 .40387 Metetra
.645 .763 .934 r
.69386 .40387 .69592 .40646 .71011 .40193 .70806 .39933 Metetra
.645 .763 .934 r
.70806 .39933 .71011 .40193 .72437 .39737 .72234 .39476 Metetra
.645 .763 .934 r
.72234 .39476 .72437 .39737 .7387 .3928 .73668 .39017 Metetra
.645 .763 .934 r
.73668 .39017 .7387 .3928 .7531 .3882 .7511 .38556 Metetra
.645 .763 .934 r
.7511 .38556 .7531 .3882 .76757 .38357 .76559 .38092 Metetra
.645 .763 .934 r
.76559 .38092 .76757 .38357 .78212 .37893 .78016 .37626 Metetra
.645 .763 .934 r
.78016 .37626 .78212 .37893 .79674 .37425 .79479 .37158 Metetra
.322 .669 .975 r
.14147 .39014 .14395 .39183 .15428 .39258 .15179 .39099 Metetra
.853 .801 .799 r
.15179 .39099 .15428 .39258 .16638 .37815 .16384 .37725 Metetra
0 .395 .705 r
.16384 .37725 .16638 .37815 .17666 .38034 .17401 .38046 Metetra
.864 .954 .867 r
.17401 .38046 .17666 .38034 .18853 .36816 .18583 .36902 Metetra
.897 .976 .812 r
.18583 .36902 .18853 .36816 .2006 .35396 .19792 .35479 Metetra
.943 .93 .759 r
.19792 .35479 .2006 .35396 .21286 .33765 .21049 .33565 Metetra
.626 .759 .942 r
.21049 .33565 .21286 .33765 .22349 .33794 .22145 .33257 Metetra
.209 .301 .739 r
.22145 .33257 .22349 .33794 .23348 .34608 .23143 .34068 Metetra
.168 .274 .73 r
.23143 .34068 .23348 .34608 .24352 .35506 .24146 .34962 Metetra
.654 .568 .746 r
.24146 .34962 .24352 .35506 .25514 .34715 .25289 .34394 Metetra
.475 .592 .89 r
.25289 .34394 .25514 .34715 .26608 .3478 .26383 .34459 Metetra
.934 .557 .191 r
.26383 .34459 .26608 .3478 .27447 .382 .2722 .37877 Metetra
.733 .699 .818 r
.2722 .37877 .27447 .382 .28625 .37512 .28406 .37096 Metetra
.706 .642 .783 r
.28406 .37096 .28625 .37512 .29825 .36569 .29592 .36344 Metetra
.604 .737 .939 r
.29592 .36344 .29825 .36569 .30978 .36314 .30748 .36074 Metetra
.881 .762 .726 r
.30748 .36074 .30978 .36314 .32258 .34191 .32029 .33949 Metetra
.885 .761 .72 r
.32029 .33949 .32258 .34191 .33535 .31982 .33309 .31738 Metetra
.87 .765 .744 r
.33309 .31738 .33535 .31982 .34782 .30158 .3456 .29879 Metetra
.771 .319 0 r
.3456 .29879 .34782 .30158 .35826 .32076 .35603 .31796 Metetra
.801 .356 0 r
.35603 .31796 .35826 .32076 .36884 .34174 .36659 .33893 Metetra
.827 .388 0 r
.36659 .33893 .36884 .34174 .37956 .36469 .3773 .36188 Metetra
.891 .75 .7 r
.3773 .36188 .37956 .36469 .39254 .3398 .39032 .3368 Metetra
.841 .415 0 r
.39032 .3368 .39254 .3398 .40351 .36484 .40126 .36245 Metetra
.956 .619 .324 r
.40126 .36245 .40351 .36484 .41314 .43747 .41083 .43511 Metetra
.785 .316 0 r
.41083 .43511 .41314 .43747 .42498 .45832 .42268 .45568 Metetra
.918 .761 .67 r
.42268 .45568 .42498 .45832 .43848 .42631 .43621 .42364 Metetra
.922 .759 .663 r
.43621 .42364 .43848 .42631 .45185 .39307 .44961 .39038 Metetra
.925 .757 .655 r
.44961 .39038 .45185 .39307 .46508 .35859 .46287 .35588 Metetra
.928 .756 .648 r
.46287 .35588 .46508 .35859 .47814 .32285 .47597 .32011 Metetra
.407 .613 .934 r
.47597 .32011 .47814 .32285 .49061 .32421 .48845 .32146 Metetra
.924 .541 .154 r
.48845 .32146 .49061 .32421 .50288 .3698 .50069 .36706 Metetra
.93 .553 .174 r
.50069 .36706 .50288 .3698 .5156 .42021 .51338 .41748 Metetra
.885 .474 .049 r
.51338 .41748 .5156 .42021 .52881 .45668 .52657 .45424 Metetra
.645 .763 .934 r
.52657 .45424 .52881 .45668 .54219 .4524 .53997 .44994 Metetra
.645 .763 .934 r
.53997 .44994 .54219 .4524 .55564 .4481 .55344 .44563 Metetra
.645 .763 .934 r
.55344 .44563 .55564 .4481 .56916 .44377 .56697 .44129 Metetra
.645 .763 .934 r
.56697 .44129 .56916 .44377 .58275 .43942 .58056 .43693 Metetra
.645 .763 .934 r
.58056 .43693 .58275 .43942 .5964 .43506 .59423 .43255 Metetra
.645 .763 .934 r
.59423 .43255 .5964 .43506 .61011 .43067 .60796 .42815 Metetra
.645 .763 .934 r
.60796 .42815 .61011 .43067 .6239 .42626 .62176 .42373 Metetra
.645 .763 .934 r
.62176 .42373 .6239 .42626 .63775 .42182 .63563 .41928 Metetra
.645 .763 .934 r
.63563 .41928 .63775 .42182 .65167 .41737 .64956 .41481 Metetra
.645 .763 .934 r
.64956 .41481 .65167 .41737 .66567 .41289 .66357 .41032 Metetra
.645 .763 .934 r
.66357 .41032 .66567 .41289 .67973 .40839 .67765 .40581 Metetra
.645 .763 .934 r
.67765 .40581 .67973 .40839 .69386 .40387 .69179 .40128 Metetra
.645 .763 .934 r
.69179 .40128 .69386 .40387 .70806 .39933 .70601 .39672 Metetra
.645 .763 .934 r
.70601 .39672 .70806 .39933 .72234 .39476 .7203 .39214 Metetra
.645 .763 .934 r
.7203 .39214 .72234 .39476 .73668 .39017 .73466 .38754 Metetra
.645 .763 .934 r
.73466 .38754 .73668 .39017 .7511 .38556 .7491 .38291 Metetra
.645 .763 .934 r
.7491 .38291 .7511 .38556 .76559 .38092 .7636 .37826 Metetra
.645 .763 .934 r
.7636 .37826 .76559 .38092 .78016 .37626 .77818 .37359 Metetra
.645 .763 .934 r
.77818 .37359 .78016 .37626 .79479 .37158 .79284 .36889 Metetra
.463 .624 .922 r
.13911 .38742 .14147 .39014 .15179 .39099 .14948 .38788 Metetra
.802 .709 .762 r
.14948 .38788 .15179 .39099 .16384 .37725 .16149 .37454 Metetra
.347 .569 .922 r
.16149 .37454 .16384 .37725 .17401 .38046 .17178 .37661 Metetra
.77 .671 .754 r
.17178 .37661 .17401 .38046 .18583 .36902 .18366 .36466 Metetra
.777 .656 .729 r
.18366 .36466 .18583 .36902 .19792 .35479 .19577 .35044 Metetra
.801 .664 .713 r
.19577 .35044 .19792 .35479 .21049 .33565 .20818 .333 Metetra
.523 .659 .921 r
.20818 .333 .21049 .33565 .22145 .33257 .21891 .33234 Metetra
.66 .113 0 r
.21891 .33234 .22145 .33257 .23143 .34068 .2289 .34046 Metetra
.686 .15 0 r
.2289 .34046 .23143 .34068 .24146 .34962 .23893 .34942 Metetra
.764 .96 .933 r
.23893 .34942 .24146 .34962 .25289 .34394 .25055 .34169 Metetra
.327 .61 .951 r
.25055 .34169 .25289 .34394 .26383 .34459 .26141 .3434 Metetra
.919 .545 .29 r
.26141 .3434 .26383 .34459 .2722 .37877 .26976 .37763 Metetra
.778 .879 .92 r
.26976 .37763 .2722 .37877 .28406 .37096 .28163 .36983 Metetra
.8 .881 .905 r
.28163 .36983 .28406 .37096 .29592 .36344 .29359 .36116 Metetra
.598 .733 .939 r
.29359 .36116 .29592 .36344 .30748 .36074 .30514 .35861 Metetra
.889 .776 .73 r
.30514 .35861 .30748 .36074 .32029 .33949 .31799 .33735 Metetra
.893 .774 .723 r
.31799 .33735 .32029 .33949 .33309 .31738 .33081 .31521 Metetra
.879 .779 .748 r
.33081 .31521 .33309 .31738 .3456 .29879 .34335 .29646 Metetra
.807 .344 0 r
.34335 .29646 .3456 .29879 .35603 .31796 .35377 .31564 Metetra
.83 .376 0 r
.35377 .31564 .35603 .31796 .36659 .33893 .36432 .33662 Metetra
.85 .405 0 r
.36432 .33662 .36659 .33893 .3773 .36188 .37502 .35957 Metetra
.904 .772 .706 r
.37502 .35957 .3773 .36188 .39032 .3368 .38805 .33467 Metetra
.87 .433 .041 r
.38805 .33467 .39032 .3368 .40126 .36245 .39899 .36001 Metetra
.956 .619 .323 r
.39899 .36001 .40126 .36245 .41083 .43511 .40852 .4327 Metetra
.772 .301 0 r
.40852 .4327 .41083 .43511 .42268 .45568 .42038 .45274 Metetra
.912 .751 .669 r
.42038 .45274 .42268 .45568 .43621 .42364 .43394 .42069 Metetra
.915 .75 .662 r
.43394 .42069 .43621 .42364 .44961 .39038 .44737 .38741 Metetra
.919 .748 .655 r
.44737 .38741 .44961 .39038 .46287 .35588 .46066 .35288 Metetra
.922 .747 .648 r
.46066 .35288 .46287 .35588 .47597 .32011 .47379 .3171 Metetra
.35 .556 .912 r
.47379 .3171 .47597 .32011 .48845 .32146 .48626 .31979 Metetra
.928 .542 .206 r
.48626 .31979 .48845 .32146 .50069 .36706 .49848 .36544 Metetra
.932 .552 .221 r
.49848 .36544 .50069 .36706 .51338 .41748 .51115 .41591 Metetra
.898 .479 .12 r
.51115 .41591 .51338 .41748 .52657 .45424 .52433 .45179 Metetra
.645 .763 .934 r
.52433 .45179 .52657 .45424 .53997 .44994 .53774 .44748 Metetra
.645 .763 .934 r
.53774 .44748 .53997 .44994 .55344 .44563 .55122 .44315 Metetra
.645 .763 .934 r
.55122 .44315 .55344 .44563 .56697 .44129 .56477 .4388 Metetra
.645 .763 .934 r
.56477 .4388 .56697 .44129 .58056 .43693 .57838 .43443 Metetra
.645 .763 .934 r
.57838 .43443 .58056 .43693 .59423 .43255 .59205 .43004 Metetra
.645 .763 .934 r
.59205 .43004 .59423 .43255 .60796 .42815 .6058 .42562 Metetra
.645 .763 .934 r
.6058 .42562 .60796 .42815 .62176 .42373 .61961 .42119 Metetra
.645 .763 .934 r
.61961 .42119 .62176 .42373 .63563 .41928 .6335 .41673 Metetra
.645 .763 .934 r
.6335 .41673 .63563 .41928 .64956 .41481 .64745 .41225 Metetra
.645 .763 .934 r
.64745 .41225 .64956 .41481 .66357 .41032 .66147 .40775 Metetra
.645 .763 .934 r
.66147 .40775 .66357 .41032 .67765 .40581 .67556 .40322 Metetra
.645 .763 .934 r
.67556 .40322 .67765 .40581 .69179 .40128 .68972 .39868 Metetra
.645 .763 .934 r
.68972 .39868 .69179 .40128 .70601 .39672 .70395 .39411 Metetra
.645 .763 .934 r
.70395 .39411 .70601 .39672 .7203 .39214 .71826 .38951 Metetra
.645 .763 .934 r
.71826 .38951 .7203 .39214 .73466 .38754 .73264 .3849 Metetra
.645 .763 .934 r
.73264 .3849 .73466 .38754 .7491 .38291 .74709 .38026 Metetra
.645 .763 .934 r
.74709 .38026 .7491 .38291 .7636 .37826 .76161 .37559 Metetra
.645 .763 .934 r
.76161 .37559 .7636 .37826 .77818 .37359 .77621 .3709 Metetra
.645 .763 .934 r
.77621 .3709 .77818 .37359 .79284 .36889 .79088 .36619 Metetra
.314 .665 .974 r
.13661 .38573 .13911 .38742 .14948 .38788 .14694 .38664 Metetra
.867 .825 .804 r
.14694 .38664 .14948 .38788 .16149 .37454 .15905 .37254 Metetra
.099 .506 .905 r
.15905 .37254 .16149 .37454 .17178 .37661 .16921 .37585 Metetra
.858 .88 .854 r
.16921 .37585 .17178 .37661 .18366 .36466 .18107 .36427 Metetra
.894 .891 .82 r
.18107 .36427 .18366 .36466 .19577 .35044 .19321 .35001 Metetra
.92 .859 .764 r
.19321 .35001 .19577 .35044 .20818 .333 .20579 .33111 Metetra
.616 .768 .953 r
.20579 .33111 .20818 .333 .21891 .33234 .21675 .32819 Metetra
.06 .274 .765 r
.21675 .32819 .21891 .33234 .2289 .34046 .22672 .33629 Metetra
.002 .236 .745 r
.22672 .33629 .2289 .34046 .23893 .34942 .23675 .34523 Metetra
.675 .624 .79 r
.23675 .34523 .23893 .34942 .25055 .34169 .2482 .33952 Metetra
.429 .671 .963 r
.2482 .33952 .25055 .34169 .26141 .3434 .25918 .33983 Metetra
.931 .557 .171 r
.25918 .33983 .26141 .3434 .26976 .37763 .2675 .37404 Metetra
.718 .675 .807 r
.2675 .37404 .26976 .37763 .28163 .36983 .27936 .36658 Metetra
.736 .7 .817 r
.27936 .36658 .28163 .36983 .29359 .36116 .29128 .35856 Metetra
.604 .705 .915 r
.29128 .35856 .29359 .36116 .30514 .35861 .30284 .35596 Metetra
.874 .751 .723 r
.30284 .35596 .30514 .35861 .31799 .33735 .31571 .33467 Metetra
.878 .75 .717 r
.31571 .33467 .31799 .33735 .33081 .31521 .32855 .31252 Metetra
.861 .752 .741 r
.32855 .31252 .33081 .31521 .34335 .29646 .3411 .29408 Metetra
.804 .341 0 r
.3411 .29408 .34335 .29646 .35377 .31564 .35151 .31325 Metetra
.828 .374 0 r
.35151 .31325 .35377 .31564 .36432 .33662 .36205 .33423 Metetra
.848 .403 0 r
.36205 .33423 .36432 .33662 .37502 .35957 .37274 .35719 Metetra
.902 .769 .705 r
.37274 .35719 .37502 .35957 .38805 .33467 .3858 .33221 Metetra
.86 .425 .006 r
.3858 .33221 .38805 .33467 .39899 .36001 .39673 .35743 Metetra
.957 .62 .32 r
.39673 .35743 .39899 .36001 .40852 .4327 .40621 .43015 Metetra
.78 .318 0 r
.40621 .43015 .40852 .4327 .42038 .45274 .41803 .45116 Metetra
.943 .8 .672 r
.41803 .45116 .42038 .45274 .43394 .42069 .43162 .41906 Metetra
.946 .796 .663 r
.43162 .41906 .43394 .42069 .44737 .38741 .44509 .38574 Metetra
.948 .793 .655 r
.44509 .38574 .44737 .38741 .46066 .35288 .45842 .35117 Metetra
.95 .789 .647 r
.45842 .35117 .46066 .35288 .47379 .3171 .47159 .31535 Metetra
.322 .674 .976 r
.47159 .31535 .47379 .3171 .48626 .31979 .48409 .31628 Metetra
.915 .537 .113 r
.48409 .31628 .48626 .31979 .49848 .36544 .49629 .3619 Metetra
.923 .55 .136 r
.49629 .3619 .49848 .36544 .51115 .41591 .50892 .41235 Metetra
.86 .46 0 r
.50892 .41235 .51115 .41591 .52433 .45179 .52208 .44933 Metetra
.645 .763 .934 r
.52208 .44933 .52433 .45179 .53774 .44748 .53551 .44501 Metetra
.645 .763 .934 r
.53551 .44501 .53774 .44748 .55122 .44315 .549 .44067 Metetra
.645 .763 .934 r
.549 .44067 .55122 .44315 .56477 .4388 .56256 .43631 Metetra
.645 .763 .934 r
.56256 .43631 .56477 .4388 .57838 .43443 .57618 .43192 Metetra
.645 .763 .934 r
.57618 .43192 .57838 .43443 .59205 .43004 .58987 .42752 Metetra
.645 .763 .934 r
.58987 .42752 .59205 .43004 .6058 .42562 .60363 .42309 Metetra
.645 .763 .934 r
.60363 .42309 .6058 .42562 .61961 .42119 .61746 .41864 Metetra
.645 .763 .934 r
.61746 .41864 .61961 .42119 .6335 .41673 .63136 .41417 Metetra
.645 .763 .934 r
.63136 .41417 .6335 .41673 .64745 .41225 .64533 .40968 Metetra
.645 .763 .934 r
.64533 .40968 .64745 .41225 .66147 .40775 .65936 .40517 Metetra
.645 .763 .934 r
.65936 .40517 .66147 .40775 .67556 .40322 .67347 .40063 Metetra
.645 .763 .934 r
.67347 .40063 .67556 .40322 .68972 .39868 .68764 .39607 Metetra
.645 .763 .934 r
.68764 .39607 .68972 .39868 .70395 .39411 .70189 .39148 Metetra
.645 .763 .934 r
.70189 .39148 .70395 .39411 .71826 .38951 .71621 .38688 Metetra
.645 .763 .934 r
.71621 .38688 .71826 .38951 .73264 .3849 .7306 .38225 Metetra
.645 .763 .934 r
.7306 .38225 .73264 .3849 .74709 .38026 .74507 .37759 Metetra
.645 .763 .934 r
.74507 .37759 .74709 .38026 .76161 .37559 .75961 .37292 Metetra
.645 .763 .934 r
.75961 .37292 .76161 .37559 .77621 .3709 .77422 .36821 Metetra
.645 .763 .934 r
.77422 .36821 .77621 .3709 .79088 .36619 .78891 .36349 Metetra
.479 .623 .914 r
.13425 .3829 .13661 .38573 .14694 .38664 .14465 .38315 Metetra
.784 .689 .76 r
.14465 .38315 .14694 .38664 .15905 .37254 .15659 .3707 Metetra
.226 .601 .95 r
.15659 .3707 .15905 .37254 .16921 .37585 .16691 .37265 Metetra
.786 .705 .774 r
.16691 .37265 .16921 .37585 .18107 .36427 .1788 .36084 Metetra
.802 .698 .75 r
.1788 .36084 .18107 .36427 .19321 .35001 .19095 .34658 Metetra
.83 .703 .724 r
.19095 .34658 .19321 .35001 .20579 .33111 .20348 .32827 Metetra
.556 .656 .902 r
.20348 .32827 .20579 .33111 .21675 .32819 .21429 .32702 Metetra
.585 .018 0 r
.21429 .32702 .21675 .32819 .22672 .33629 .22426 .33513 Metetra
.628 .068 0 r
.22426 .33513 .22672 .33629 .23675 .34523 .23429 .34407 Metetra
.779 .872 .916 r
.23429 .34407 .23675 .34523 .2482 .33952 .24593 .33639 Metetra
.353 .537 .897 r
.24593 .33639 .2482 .33952 .25918 .33983 .25671 .33897 Metetra
.914 .541 .302 r
.25671 .33897 .25918 .33983 .2675 .37404 .26502 .37322 Metetra
.796 .91 .919 r
.26502 .37322 .2675 .37404 .27936 .36658 .27697 .36475 Metetra
.776 .814 .883 r
.27697 .36475 .27936 .36658 .29128 .35856 .28891 .35658 Metetra
.584 .76 .962 r
.28891 .35658 .29128 .35856 .30284 .35596 .30048 .35411 Metetra
.898 .791 .733 r
.30048 .35411 .30284 .35596 .31571 .33467 .31337 .33281 Metetra
.902 .788 .726 r
.31337 .33281 .31571 .33467 .32855 .31252 .32624 .31063 Metetra
.891 .795 .748 r
.32624 .31063 .32855 .31252 .3411 .29408 .33886 .29132 Metetra
.776 .323 0 r
.33886 .29132 .3411 .29408 .35151 .31325 .34926 .31049 Metetra
.806 .359 0 r
.34926 .31049 .35151 .31325 .36205 .33423 .35979 .33147 Metetra
.83 .391 0 r
.35979 .33147 .36205 .33423 .37274 .35719 .37047 .35442 Metetra
.891 .753 .703 r
.37047 .35442 .37274 .35719 .3858 .33221 .38354 .32961 Metetra
.858 .425 0 r
.38354 .32961 .3858 .33221 .39673 .35743 .39445 .35507 Metetra
.955 .618 .325 r
.39445 .35507 .39673 .35743 .40621 .43015 .40389 .42783 Metetra
.767 .291 0 r
.40389 .42783 .40621 .43015 .41803 .45116 .41575 .44729 Metetra
.89 .721 .665 r
.41575 .44729 .41803 .45116 .43162 .41906 .42937 .41518 Metetra
.895 .721 .659 r
.42937 .41518 .43162 .41906 .44509 .38574 .44287 .38186 Metetra
.899 .721 .652 r
.44287 .38186 .44509 .38574 .45842 .35117 .45622 .34729 Metetra
.903 .721 .646 r
.45622 .34729 .45842 .35117 .47159 .31535 .46942 .31146 Metetra
.355 .491 .858 r
.46942 .31146 .47159 .31535 .48409 .31628 .48188 .31525 Metetra
.925 .539 .233 r
.48188 .31525 .48409 .31628 .49629 .3619 .49406 .36094 Metetra
.929 .549 .246 r
.49406 .36094 .49629 .3619 .50892 .41235 .50668 .41147 Metetra
.897 .478 .158 r
.50668 .41147 .50892 .41235 .52208 .44933 .51983 .44686 Metetra
.645 .763 .934 r
.51983 .44686 .52208 .44933 .53551 .44501 .53327 .44253 Metetra
.645 .763 .934 r
.53327 .44253 .53551 .44501 .549 .44067 .54677 .43818 Metetra
.645 .763 .934 r
.54677 .43818 .549 .44067 .56256 .43631 .56034 .43381 Metetra
.645 .763 .934 r
.56034 .43381 .56256 .43631 .57618 .43192 .57398 .42941 Metetra
.645 .763 .934 r
.57398 .42941 .57618 .43192 .58987 .42752 .58769 .42499 Metetra
.645 .763 .934 r
.58769 .42499 .58987 .42752 .60363 .42309 .60146 .42055 Metetra
.645 .763 .934 r
.60146 .42055 .60363 .42309 .61746 .41864 .61531 .41609 Metetra
.645 .763 .934 r
.61531 .41609 .61746 .41864 .63136 .41417 .62922 .41161 Metetra
.645 .763 .934 r
.62922 .41161 .63136 .41417 .64533 .40968 .6432 .4071 Metetra
.645 .763 .934 r
.6432 .4071 .64533 .40968 .65936 .40517 .65725 .40258 Metetra
.645 .763 .934 r
.65725 .40258 .65936 .40517 .67347 .40063 .67137 .39802 Metetra
.645 .763 .934 r
.67137 .39802 .67347 .40063 .68764 .39607 .68556 .39345 Metetra
.645 .763 .934 r
.68556 .39345 .68764 .39607 .70189 .39148 .69982 .38885 Metetra
.645 .763 .934 r
.69982 .38885 .70189 .39148 .71621 .38688 .71416 .38423 Metetra
.645 .763 .934 r
.71416 .38423 .71621 .38688 .7306 .38225 .72857 .37959 Metetra
.645 .763 .934 r
.72857 .37959 .7306 .38225 .74507 .37759 .74305 .37492 Metetra
.645 .763 .934 r
.74305 .37492 .74507 .37759 .75961 .37292 .7576 .37023 Metetra
.645 .763 .934 r
.7576 .37023 .75961 .37292 .77422 .36821 .77223 .36552 Metetra
.645 .763 .934 r
.77223 .36552 .77422 .36821 .78891 .36349 .78694 .36078 Metetra
.25 .674 .963 r
.1317 .38159 .13425 .3829 .14465 .38315 .14204 .38237 Metetra
.882 .857 .812 r
.14204 .38237 .14465 .38315 .15659 .3707 .15422 .36807 Metetra
.198 .498 .905 r
.15422 .36807 .15659 .3707 .16691 .37265 .16435 .3716 Metetra
.851 .856 .846 r
.16435 .3716 .16691 .37265 .1788 .36084 .17624 .35999 Metetra
.882 .857 .812 r
.17624 .35999 .1788 .36084 .19095 .34658 .18841 .3457 Metetra
.907 .832 .76 r
.18841 .3457 .19095 .34658 .20348 .32827 .20103 .32683 Metetra
.631 .822 .974 r
.20103 .32683 .20348 .32827 .21429 .32702 .21207 .3233 Metetra
0 .255 .763 r
.21207 .3233 .21429 .32702 .22426 .33513 .22204 .33139 Metetra
0 .21 .735 r
.22204 .33139 .22426 .33513 .23429 .34407 .23206 .34032 Metetra
.677 .647 .813 r
.23206 .34032 .23429 .34407 .24593 .33639 .2435 .33488 Metetra
.363 .715 .987 r
.2435 .33488 .24593 .33639 .25671 .33897 .25451 .33498 Metetra
.926 .555 .144 r
.25451 .33498 .25671 .33897 .26502 .37322 .26279 .3692 Metetra
.705 .649 .791 r
.26279 .3692 .26502 .37322 .27697 .36475 .27465 .36189 Metetra
.752 .73 .832 r
.27465 .36189 .27697 .36475 .28891 .35658 .28662 .35354 Metetra
.608 .672 .886 r
.28662 .35354 .28891 .35658 .30048 .35411 .2982 .35088 Metetra
.858 .726 .716 r
.2982 .35088 .30048 .35411 .31337 .33281 .31111 .32956 Metetra
.863 .726 .71 r
.31111 .32956 .31337 .33281 .32624 .31063 .324 .30738 Metetra
.841 .724 .736 r
.324 .30738 .32624 .31063 .33886 .29132 .33655 .28953 Metetra
.832 .364 0 r
.33655 .28953 .33886 .29132 .34926 .31049 .34695 .30871 Metetra
.849 .392 .017 r
.34695 .30871 .34926 .31049 .35979 .33147 .35747 .3297 Metetra
.864 .416 .051 r
.35747 .3297 .35979 .33147 .37047 .35442 .36814 .35267 Metetra
.92 .798 .709 r
.36814 .35267 .37047 .35442 .38354 .32961 .38126 .3276 Metetra
.869 .429 .044 r
.38126 .3276 .38354 .32961 .39445 .35507 .39218 .35247 Metetra
.957 .62 .32 r
.39218 .35247 .39445 .35507 .40389 .42783 .40156 .42525 Metetra
.784 .323 0 r
.40156 .42525 .40389 .42783 .41575 .44729 .41336 .44651 Metetra
.961 .831 .67 r
.41336 .44651 .41575 .44729 .42937 .41518 .42702 .41435 Metetra
.963 .825 .661 r
.42702 .41435 .42937 .41518 .44287 .38186 .44056 .38097 Metetra
.964 .82 .652 r
.44056 .38097 .44287 .38186 .45622 .34729 .45395 .34635 Metetra
.966 .815 .643 r
.45395 .34635 .45622 .34729 .46942 .31146 .46719 .31046 Metetra
.195 .675 .931 r
.46719 .31046 .46942 .31146 .48188 .31525 .47971 .31112 Metetra
.902 .53 .077 r
.47971 .31112 .48188 .31525 .49406 .36094 .49186 .35677 Metetra
.913 .545 .103 r
.49186 .35677 .49406 .36094 .50668 .41147 .50444 .40726 Metetra
.83 .444 0 r
.50444 .40726 .50668 .41147 .51983 .44686 .51757 .44439 Metetra
.645 .763 .934 r
.51757 .44439 .51983 .44686 .53327 .44253 .53102 .44005 Metetra
.645 .763 .934 r
.53102 .44005 .53327 .44253 .54677 .43818 .54454 .43568 Metetra
.645 .763 .934 r
.54454 .43568 .54677 .43818 .56034 .43381 .55812 .4313 Metetra
.645 .763 .934 r
.55812 .4313 .56034 .43381 .57398 .42941 .57178 .42689 Metetra
.645 .763 .934 r
.57178 .42689 .57398 .42941 .58769 .42499 .5855 .42246 Metetra
.645 .763 .934 r
.5855 .42246 .58769 .42499 .60146 .42055 .59928 .41801 Metetra
.645 .763 .934 r
.59928 .41801 .60146 .42055 .61531 .41609 .61314 .41353 Metetra
.645 .763 .934 r
.61314 .41353 .61531 .41609 .62922 .41161 .62707 .40904 Metetra
.645 .763 .934 r
.62707 .40904 .62922 .41161 .6432 .4071 .64106 .40452 Metetra
.645 .763 .934 r
.64106 .40452 .6432 .4071 .65725 .40258 .65513 .39998 Metetra
.645 .763 .934 r
.65513 .39998 .65725 .40258 .67137 .39802 .66926 .39541 Metetra
.645 .763 .934 r
.66926 .39541 .67137 .39802 .68556 .39345 .68347 .39083 Metetra
.645 .763 .934 r
.68347 .39083 .68556 .39345 .69982 .38885 .69775 .38622 Metetra
.645 .763 .934 r
.69775 .38622 .69982 .38885 .71416 .38423 .7121 .38158 Metetra
.645 .763 .934 r
.7121 .38158 .71416 .38423 .72857 .37959 .72652 .37693 Metetra
.645 .763 .934 r
.72652 .37693 .72857 .37959 .74305 .37492 .74102 .37225 Metetra
.645 .763 .934 r
.74102 .37225 .74305 .37492 .7576 .37023 .75559 .36754 Metetra
.645 .763 .934 r
.75559 .36754 .7576 .37023 .77223 .36552 .77024 .36281 Metetra
.645 .763 .934 r
.77024 .36281 .77223 .36552 .78694 .36078 .78496 .35806 Metetra
.477 .593 .89 r
.12937 .37841 .1317 .38159 .14204 .38237 .13974 .37894 Metetra
.789 .693 .759 r
.13974 .37894 .14204 .38237 .15422 .36807 .15176 .36609 Metetra
.202 .572 .939 r
.15176 .36609 .15422 .36807 .16435 .3716 .16203 .36847 Metetra
.789 .709 .776 r
.16203 .36847 .16435 .3716 .17624 .35999 .17396 .3566 Metetra
.804 .7 .751 r
.17396 .3566 .17624 .35999 .18841 .3457 .18614 .3423 Metetra
.833 .705 .723 r
.18614 .3423 .18841 .3457 .20103 .32683 .19876 .3236 Metetra
.572 .633 .874 r
.19876 .3236 .20103 .32683 .21207 .3233 .2096 .32207 Metetra
.578 .011 0 r
.2096 .32207 .21207 .3233 .22204 .33139 .21957 .33017 Metetra
.622 .062 0 r
.21957 .33017 .22204 .33139 .23206 .34032 .22959 .33911 Metetra
.765 .868 .924 r
.22959 .33911 .23206 .34032 .2435 .33488 .2412 .33191 Metetra
.376 .565 .91 r
.2412 .33191 .2435 .33488 .25451 .33498 .25205 .3339 Metetra
.917 .543 .294 r
.25205 .3339 .25451 .33498 .26279 .3692 .26031 .36816 Metetra
.784 .891 .921 r
.26031 .36816 .26279 .3692 .27465 .36189 .27224 .36013 Metetra
.784 .821 .882 r
.27224 .36013 .27465 .36189 .28662 .35354 .28424 .35164 Metetra
.565 .763 .971 r
.28424 .35164 .28662 .35354 .2982 .35088 .29579 .34945 Metetra
.91 .813 .738 r
.29579 .34945 .2982 .35088 .31111 .32956 .30873 .3281 Metetra
.914 .809 .73 r
.30873 .3281 .31111 .32956 .324 .30738 .32165 .30589 Metetra
.904 .818 .751 r
.32165 .30589 .324 .30738 .33655 .28953 .33433 .28634 Metetra
.735 .297 0 r
.33433 .28634 .33655 .28953 .34695 .30871 .34471 .30552 Metetra
.772 .337 0 r
.34471 .30552 .34695 .30871 .35747 .3297 .35522 .32649 Metetra
.803 .373 0 r
.35522 .32649 .35747 .3297 .36814 .35267 .36588 .34945 Metetra
.878 .735 .701 r
.36588 .34945 .36814 .35267 .38126 .3276 .37899 .32499 Metetra
.851 .415 0 r
.37899 .32499 .38126 .3276 .39218 .35247 .3899 .34981 Metetra
.957 .62 .319 r
.3899 .34981 .39218 .35247 .40156 .42525 .39924 .42262 Metetra
.76 .295 0 r
.39924 .42262 .40156 .42525 .41336 .44651 .41106 .44283 Metetra
.895 .728 .666 r
.41106 .44283 .41336 .44651 .42702 .41435 .42475 .41067 Metetra
.899 .727 .66 r
.42475 .41067 .42702 .41435 .44056 .38097 .43831 .37728 Metetra
.903 .727 .653 r
.43831 .37728 .44056 .38097 .45395 .34635 .45174 .34265 Metetra
.907 .727 .646 r
.45174 .34265 .45395 .34635 .46719 .31046 .46501 .30676 Metetra
.377 .518 .872 r
.46501 .30676 .46719 .31046 .47971 .31112 .47749 .30981 Metetra
.926 .54 .222 r
.47749 .30981 .47971 .31112 .49186 .35677 .48962 .35552 Metetra
.93 .55 .235 r
.48962 .35552 .49186 .35677 .50444 .40726 .50218 .40607 Metetra
.898 .48 .144 r
.50218 .40607 .50444 .40726 .51757 .44439 .5153 .44191 Metetra
.645 .763 .934 r
.5153 .44191 .51757 .44439 .53102 .44005 .52877 .43756 Metetra
.645 .763 .934 r
.52877 .43756 .53102 .44005 .54454 .43568 .5423 .43318 Metetra
.645 .763 .934 r
.5423 .43318 .54454 .43568 .55812 .4313 .5559 .42878 Metetra
.645 .763 .934 r
.5559 .42878 .55812 .4313 .57178 .42689 .56956 .42436 Metetra
.645 .763 .934 r
.56956 .42436 .57178 .42689 .5855 .42246 .5833 .41992 Metetra
.645 .763 .934 r
.5833 .41992 .5855 .42246 .59928 .41801 .5971 .41545 Metetra
.645 .763 .934 r
.5971 .41545 .59928 .41801 .61314 .41353 .61097 .41097 Metetra
.645 .763 .934 r
.61097 .41097 .61314 .41353 .62707 .40904 .62491 .40646 Metetra
.645 .763 .934 r
.62491 .40646 .62707 .40904 .64106 .40452 .63892 .40193 Metetra
.645 .763 .934 r
.63892 .40193 .64106 .40452 .65513 .39998 .653 .39737 Metetra
.645 .763 .934 r
.653 .39737 .65513 .39998 .66926 .39541 .66715 .3928 Metetra
.645 .763 .934 r
.66715 .3928 .66926 .39541 .68347 .39083 .68137 .3882 Metetra
.645 .763 .934 r
.68137 .3882 .68347 .39083 .69775 .38622 .69567 .38357 Metetra
.645 .763 .934 r
.69567 .38357 .69775 .38622 .7121 .38158 .71003 .37893 Metetra
.645 .763 .934 r
.71003 .37893 .7121 .38158 .72652 .37693 .72447 .37425 Metetra
.645 .763 .934 r
.72447 .37425 .72652 .37693 .74102 .37225 .73899 .36956 Metetra
.645 .763 .934 r
.73899 .36956 .74102 .37225 .75559 .36754 .75357 .36484 Metetra
.645 .763 .934 r
.75357 .36484 .75559 .36754 .77024 .36281 .76824 .3601 Metetra
.645 .763 .934 r
.76824 .3601 .77024 .36281 .78496 .35806 .78297 .35533 Metetra
.214 .666 .948 r
.12679 .37722 .12937 .37841 .13974 .37894 .13713 .37805 Metetra
.881 .848 .807 r
.13713 .37805 .13974 .37894 .15176 .36609 .14937 .36349 Metetra
.171 .486 .9 r
.14937 .36349 .15176 .36609 .16203 .36847 .15948 .3672 Metetra
.845 .839 .839 r
.15948 .3672 .16203 .36847 .17396 .3566 .1714 .35556 Metetra
.877 .845 .809 r
.1714 .35556 .17396 .3566 .18614 .3423 .18361 .34125 Metetra
.902 .822 .758 r
.18361 .34125 .18614 .3423 .19876 .3236 .19627 .32231 Metetra
.639 .84 .978 r
.19627 .32231 .19876 .3236 .2096 .32207 .20735 .31851 Metetra
0 .245 .759 r
.20735 .31851 .2096 .32207 .21957 .33017 .21732 .32659 Metetra
0 .198 .727 r
.21732 .32659 .21957 .33017 .22959 .33911 .22734 .33551 Metetra
.675 .655 .823 r
.22734 .33551 .22959 .33911 .2412 .33191 .23877 .33031 Metetra
.405 .725 .989 r
.23877 .33031 .2412 .33191 .25205 .3339 .24982 .33008 Metetra
.929 .557 .157 r
.24982 .33008 .25205 .3339 .26031 .36816 .25805 .36431 Metetra
.706 .659 .8 r
.25805 .36431 .26031 .36816 .27224 .36013 .26992 .35718 Metetra
.752 .724 .827 r
.26992 .35718 .27224 .36013 .28424 .35164 .28193 .34868 Metetra
.607 .679 .892 r
.28193 .34868 .28424 .35164 .29579 .34945 .29352 .34602 Metetra
.853 .718 .713 r
.29352 .34602 .29579 .34945 .30873 .3281 .30648 .32466 Metetra
.858 .718 .707 r
.30648 .32466 .30873 .3281 .32165 .30589 .31942 .30244 Metetra
.834 .715 .734 r
.31942 .30244 .32165 .30589 .33433 .28634 .332 .28475 Metetra
.837 .369 .005 r
.332 .28475 .33433 .28634 .34471 .30552 .34238 .30394 Metetra
.853 .395 .04 r
.34238 .30394 .34471 .30552 .35522 .32649 .35288 .32493 Metetra
.866 .419 .071 r
.35288 .32493 .35522 .32649 .36588 .34945 .36353 .34791 Metetra
.926 .808 .711 r
.36353 .34791 .36588 .34945 .37899 .32499 .3767 .3228 Metetra
.864 .423 .025 r
.3767 .3228 .37899 .32499 .3899 .34981 .3876 .34751 Metetra
.955 .618 .327 r
.3876 .34751 .3899 .34981 .39924 .42262 .39689 .42035 Metetra
.808 .343 0 r
.39689 .42035 .39924 .42262 .41106 .44283 .40866 .44189 Metetra
.958 .825 .67 r
.40866 .44189 .41106 .44283 .42475 .41067 .42239 .40968 Metetra
.959 .82 .662 r
.42239 .40968 .42475 .41067 .43831 .37728 .43599 .37624 Metetra
.961 .815 .653 r
.43599 .37624 .43831 .37728 .45174 .34265 .44946 .34155 Metetra
.963 .81 .644 r
.44946 .34155 .45174 .34265 .46501 .30676 .46277 .3056 Metetra
.267 .708 .962 r
.46277 .3056 .46501 .30676 .47749 .30981 .47531 .30586 Metetra
.907 .533 .09 r
.47531 .30586 .47749 .30981 .48962 .35552 .48741 .35154 Metetra
.917 .547 .115 r
.48741 .35154 .48962 .35552 .50218 .40607 .49994 .40206 Metetra
.844 .453 0 r
.49994 .40206 .50218 .40607 .5153 .44191 .51303 .43942 Metetra
.645 .763 .934 r
.51303 .43942 .5153 .44191 .52877 .43756 .52651 .43506 Metetra
.645 .763 .934 r
.52651 .43506 .52877 .43756 .5423 .43318 .54005 .43067 Metetra
.645 .763 .934 r
.54005 .43067 .5423 .43318 .5559 .42878 .55367 .42626 Metetra
.645 .763 .934 r
.55367 .42626 .5559 .42878 .56956 .42436 .56735 .42182 Metetra
.645 .763 .934 r
.56735 .42182 .56956 .42436 .5833 .41992 .58109 .41737 Metetra
.645 .763 .934 r
.58109 .41737 .5833 .41992 .5971 .41545 .59491 .41289 Metetra
.645 .763 .934 r
.59491 .41289 .5971 .41545 .61097 .41097 .6088 .40839 Metetra
.645 .763 .934 r
.6088 .40839 .61097 .41097 .62491 .40646 .62275 .40387 Metetra
.645 .763 .934 r
.62275 .40387 .62491 .40646 .63892 .40193 .63677 .39933 Metetra
.645 .763 .934 r
.63677 .39933 .63892 .40193 .653 .39737 .65087 .39476 Metetra
.645 .763 .934 r
.65087 .39476 .653 .39737 .66715 .3928 .66503 .39017 Metetra
.645 .763 .934 r
.66503 .39017 .66715 .3928 .68137 .3882 .67927 .38556 Metetra
.645 .763 .934 r
.67927 .38556 .68137 .3882 .69567 .38357 .69358 .38092 Metetra
.645 .763 .934 r
.69358 .38092 .69567 .38357 .71003 .37893 .70796 .37626 Metetra
.645 .763 .934 r
.70796 .37626 .71003 .37893 .72447 .37425 .72242 .37158 Metetra
.645 .763 .934 r
.72242 .37158 .72447 .37425 .73899 .36956 .73695 .36687 Metetra
.645 .763 .934 r
.73695 .36687 .73899 .36956 .75357 .36484 .75155 .36214 Metetra
.645 .763 .934 r
.75155 .36214 .75357 .36484 .76824 .3601 .76623 .35738 Metetra
.645 .763 .934 r
.76623 .35738 .76824 .3601 .78297 .35533 .78098 .3526 Metetra
.408 .541 .878 r
.12447 .37381 .12679 .37722 .13713 .37805 .13469 .37569 Metetra
.84 .752 .767 r
.13469 .37569 .13713 .37805 .14937 .36349 .14702 .36044 Metetra
.234 .478 .886 r
.14702 .36044 .14937 .36349 .15948 .3672 .15713 .36421 Metetra
.794 .718 .781 r
.15713 .36421 .15948 .3672 .1714 .35556 .16909 .35231 Metetra
.808 .708 .754 r
.16909 .35231 .1714 .35556 .18361 .34125 .18131 .33798 Metetra
.839 .711 .723 r
.18131 .33798 .18361 .34125 .19627 .32231 .19402 .31882 Metetra
.578 .619 .856 r
.19402 .31882 .19627 .32231 .20735 .31851 .20488 .31713 Metetra
.556 0 0 r
.20488 .31713 .20735 .31851 .21732 .32659 .21485 .32522 Metetra
.603 .045 0 r
.21485 .32522 .21732 .32659 .22734 .33551 .22487 .33414 Metetra
.709 .849 .95 r
.22487 .33414 .22734 .33551 .23877 .33031 .23634 .32869 Metetra
.481 .758 .991 r
.23634 .32869 .23877 .33031 .24982 .33008 .24747 .32754 Metetra
.933 .556 .232 r
.24747 .32754 .24982 .33008 .25805 .36431 .25568 .36178 Metetra
.72 .747 .874 r
.25568 .36178 .25805 .36431 .26992 .35718 .2675 .35544 Metetra
.787 .824 .881 r
.2675 .35544 .26992 .35718 .28193 .34868 .27953 .34679 Metetra
.548 .759 .975 r
.27953 .34679 .28193 .34868 .29352 .34602 .29108 .34487 Metetra
.919 .828 .741 r
.29108 .34487 .29352 .34602 .30648 .32466 .30407 .32348 Metetra
.922 .824 .732 r
.30407 .32348 .30648 .32466 .31942 .30244 .31704 .30122 Metetra
.914 .833 .751 r
.31704 .30122 .31942 .30244 .332 .28475 .32978 .28124 Metetra
.699 .276 0 r
.32978 .28124 .332 .28475 .34238 .30394 .34015 .30041 Metetra
.741 .319 0 r
.34015 .30041 .34238 .30394 .35288 .32493 .35064 .32139 Metetra
.777 .358 0 r
.35064 .32139 .35288 .32493 .36353 .34791 .36127 .34435 Metetra
.868 .723 .699 r
.36127 .34435 .36353 .34791 .3767 .3228 .37442 .32021 Metetra
.848 .409 0 r
.37442 .32021 .3767 .3228 .3876 .34751 .38533 .3446 Metetra
.958 .622 .314 r
.38533 .3446 .3876 .34751 .39689 .42035 .39456 .41745 Metetra
.787 .339 0 r
.39456 .41745 .39689 .42035 .40866 .44189 .40628 .44007 Metetra
.939 .792 .672 r
.40628 .44007 .40866 .44189 .42239 .40968 .42005 .40782 Metetra
.941 .789 .664 r
.42005 .40782 .42239 .40968 .43599 .37624 .43369 .37434 Metetra
.944 .786 .655 r
.43369 .37434 .43599 .37624 .44946 .34155 .44719 .33961 Metetra
.946 .782 .647 r
.44719 .33961 .44946 .34155 .46277 .3056 .46054 .30363 Metetra
.476 .731 .982 r
.46054 .30363 .46277 .3056 .47531 .30586 .47311 .30272 Metetra
.921 .54 .136 r
.47311 .30272 .47531 .30586 .48741 .35154 .48518 .34839 Metetra
.928 .552 .157 r
.48518 .34839 .48741 .35154 .49994 .40206 .49768 .39891 Metetra
.882 .478 .036 r
.49768 .39891 .49994 .40206 .51303 .43942 .51075 .43693 Metetra
.645 .763 .934 r
.51075 .43693 .51303 .43942 .52651 .43506 .52424 .43255 Metetra
.645 .763 .934 r
.52424 .43255 .52651 .43506 .54005 .43067 .5378 .42815 Metetra
.645 .763 .934 r
.5378 .42815 .54005 .43067 .55367 .42626 .55143 .42373 Metetra
.645 .763 .934 r
.55143 .42373 .55367 .42626 .56735 .42182 .56512 .41928 Metetra
.645 .763 .934 r
.56512 .41928 .56735 .42182 .58109 .41737 .57888 .41481 Metetra
.645 .763 .934 r
.57888 .41481 .58109 .41737 .59491 .41289 .59271 .41032 Metetra
.645 .763 .934 r
.59271 .41032 .59491 .41289 .6088 .40839 .60661 .40581 Metetra
.645 .763 .934 r
.60661 .40581 .6088 .40839 .62275 .40387 .62058 .40128 Metetra
.645 .763 .934 r
.62058 .40128 .62275 .40387 .63677 .39933 .63462 .39672 Metetra
.645 .763 .934 r
.63462 .39672 .63677 .39933 .65087 .39476 .64873 .39214 Metetra
.645 .763 .934 r
.64873 .39214 .65087 .39476 .66503 .39017 .66291 .38754 Metetra
.645 .763 .934 r
.66291 .38754 .66503 .39017 .67927 .38556 .67716 .38291 Metetra
.645 .763 .934 r
.67716 .38291 .67927 .38556 .69358 .38092 .69149 .37826 Metetra
.645 .763 .934 r
.69149 .37826 .69358 .38092 .70796 .37626 .70589 .37359 Metetra
.645 .763 .934 r
.70589 .37359 .70796 .37626 .72242 .37158 .72036 .36889 Metetra
.645 .763 .934 r
.72036 .36889 .72242 .37158 .73695 .36687 .7349 .36417 Metetra
.645 .763 .934 r
.7349 .36417 .73695 .36687 .75155 .36214 .74952 .35942 Metetra
.645 .763 .934 r
.74952 .35942 .75155 .36214 .76623 .35738 .76422 .35465 Metetra
.645 .763 .934 r
.76422 .35465 .76623 .35738 .78098 .3526 .77899 .34986 Metetra
.107 .603 .903 r
.12187 .37266 .12447 .37381 .13469 .37569 .13213 .37418 Metetra
.871 .802 .78 r
.13213 .37418 .13469 .37569 .14702 .36044 .14456 .35828 Metetra
.006 .43 .862 r
.14456 .35828 .14702 .36044 .15713 .36421 .15461 .36257 Metetra
.833 .81 .828 r
.15461 .36257 .15713 .36421 .16909 .35231 .16656 .35098 Metetra
.868 .824 .802 r
.16656 .35098 .16909 .35231 .18131 .33798 .1788 .33663 Metetra
.894 .806 .754 r
.1788 .33663 .18131 .33798 .19402 .31882 .19151 .31759 Metetra
.632 .847 .982 r
.19151 .31759 .19402 .31882 .20488 .31713 .2026 .31383 Metetra
0 .226 .746 r
.2026 .31383 .20488 .31713 .21485 .32522 .21256 .32191 Metetra
0 .175 .709 r
.21256 .32191 .21485 .32522 .22487 .33414 .22258 .33082 Metetra
.659 .667 .846 r
.22258 .33082 .22487 .33414 .23634 .32869 .23396 .32643 Metetra
.567 .723 .946 r
.23396 .32643 .23634 .32869 .24747 .32754 .24516 .32452 Metetra
.934 .558 .206 r
.24516 .32452 .24747 .32754 .25568 .36178 .25335 .35875 Metetra
.712 .709 .845 r
.25335 .35875 .25568 .36178 .2675 .35544 .26518 .35227 Metetra
.74 .709 .822 r
.26518 .35227 .2675 .35544 .27953 .34679 .27718 .34413 Metetra
.611 .706 .912 r
.27718 .34413 .27953 .34679 .29108 .34487 .28881 .34131 Metetra
.85 .713 .711 r
.28881 .34131 .29108 .34487 .30407 .32348 .30181 .31991 Metetra
.855 .714 .706 r
.30181 .31991 .30407 .32348 .31704 .30122 .3148 .29765 Metetra
.832 .711 .731 r
.3148 .29765 .31704 .30122 .32978 .28124 .32743 .27979 Metetra
.839 .372 .022 r
.32743 .27979 .32978 .28124 .34015 .30041 .33779 .29898 Metetra
.854 .398 .055 r
.33779 .29898 .34015 .30041 .35064 .32139 .34827 .31997 Metetra
.867 .42 .085 r
.34827 .31997 .35064 .32139 .36127 .34435 .3589 .34296 Metetra
.93 .815 .71 r
.3589 .34296 .36127 .34435 .37442 .32021 .37213 .31763 Metetra
.857 .422 0 r
.37213 .31763 .37442 .32021 .38533 .3446 .38299 .3428 Metetra
.952 .614 .336 r
.38299 .3428 .38533 .3446 .39456 .41745 .39218 .41572 Metetra
.84 .376 0 r
.39218 .41572 .39456 .41745 .40628 .44007 .4039 .43817 Metetra
.937 .789 .672 r
.4039 .43817 .40628 .44007 .42005 .40782 .4177 .40588 Metetra
.94 .786 .664 r
.4177 .40588 .42005 .40782 .43369 .37434 .43138 .37237 Metetra
.942 .783 .655 r
.43138 .37237 .43369 .37434 .44719 .33961 .44492 .3376 Metetra
.945 .78 .647 r
.44492 .3376 .44719 .33961 .46054 .30363 .4583 .30158 Metetra
.537 .751 .975 r
.4583 .30158 .46054 .30363 .47311 .30272 .4709 .29971 Metetra
.923 .541 .143 r
.4709 .29971 .47311 .30272 .48518 .34839 .48295 .34538 Metetra
.929 .552 .164 r
.48295 .34538 .48518 .34839 .49768 .39891 .49542 .3959 Metetra
.888 .484 .052 r
.49542 .3959 .49768 .39891 .51075 .43693 .50846 .43443 Metetra
.645 .763 .934 r
.50846 .43443 .51075 .43693 .52424 .43255 .52197 .43004 Metetra
.645 .763 .934 r
.52197 .43004 .52424 .43255 .5378 .42815 .53554 .42562 Metetra
.645 .763 .934 r
.53554 .42562 .5378 .42815 .55143 .42373 .54918 .42119 Metetra
.645 .763 .934 r
.54918 .42119 .55143 .42373 .56512 .41928 .56289 .41673 Metetra
.645 .763 .934 r
.56289 .41673 .56512 .41928 .57888 .41481 .57667 .41225 Metetra
.645 .763 .934 r
.57667 .41225 .57888 .41481 .59271 .41032 .59051 .40775 Metetra
.645 .763 .934 r
.59051 .40775 .59271 .41032 .60661 .40581 .60442 .40322 Metetra
.645 .763 .934 r
.60442 .40322 .60661 .40581 .62058 .40128 .61841 .39868 Metetra
.645 .763 .934 r
.61841 .39868 .62058 .40128 .63462 .39672 .63246 .39411 Metetra
.645 .763 .934 r
.63246 .39411 .63462 .39672 .64873 .39214 .64659 .38951 Metetra
.645 .763 .934 r
.64659 .38951 .64873 .39214 .66291 .38754 .66078 .3849 Metetra
.645 .763 .934 r
.66078 .3849 .66291 .38754 .67716 .38291 .67505 .38026 Metetra
.645 .763 .934 r
.67505 .38026 .67716 .38291 .69149 .37826 .68939 .37559 Metetra
.645 .763 .934 r
.68939 .37559 .69149 .37826 .70589 .37359 .7038 .3709 Metetra
.645 .763 .934 r
.7038 .3709 .70589 .37359 .72036 .36889 .71829 .36619 Metetra
.645 .763 .934 r
.71829 .36619 .72036 .36889 .7349 .36417 .73285 .36146 Metetra
.645 .763 .934 r
.73285 .36146 .7349 .36417 .74952 .35942 .74749 .3567 Metetra
.645 .763 .934 r
.74749 .3567 .74952 .35942 .76422 .35465 .7622 .35191 Metetra
.645 .763 .934 r
.7622 .35191 .76422 .35465 .77899 .34986 .77698 .3471 Metetra
.314 .497 .878 r
.11954 .36931 .12187 .37266 .13213 .37418 .1296 .37246 Metetra
.874 .783 .757 r
.1296 .37246 .13213 .37418 .14456 .35828 .14229 .35453 Metetra
.231 .417 .84 r
.14229 .35453 .14456 .35828 .15461 .36257 .15227 .35936 Metetra
.786 .706 .776 r
.15227 .35936 .15461 .36257 .16656 .35098 .16425 .34761 Metetra
.805 .703 .752 r
.16425 .34761 .16656 .35098 .1788 .33663 .1765 .33325 Metetra
.836 .707 .722 r
.1765 .33325 .1788 .33663 .19151 .31759 .18923 .31418 Metetra
.575 .623 .863 r
.18923 .31418 .19151 .31759 .2026 .31383 .20011 .31254 Metetra
.57 .003 0 r
.20011 .31254 .2026 .31383 .21256 .32191 .21007 .32062 Metetra
.615 .055 0 r
.21007 .32062 .21256 .32191 .22258 .33082 .22008 .32954 Metetra
.636 .847 .981 r
.22008 .32954 .22258 .33082 .23396 .32643 .23143 .32564 Metetra
.634 .896 .986 r
.23143 .32564 .23396 .32643 .24516 .32452 .24287 .32118 Metetra
.934 .558 .189 r
.24287 .32118 .24516 .32452 .25335 .35875 .25103 .3554 Metetra
.676 .677 .843 r
.25103 .3554 .25335 .35875 .26518 .35227 .26277 .35026 Metetra
.763 .8 .883 r
.26277 .35026 .26518 .35227 .27718 .34413 .27475 .34249 Metetra
.563 .792 .985 r
.27475 .34249 .27718 .34413 .28881 .34131 .28636 .34004 Metetra
.916 .823 .74 r
.28636 .34004 .28881 .34131 .30181 .31991 .29939 .31862 Metetra
.919 .819 .732 r
.29939 .31862 .30181 .31991 .3148 .29765 .31241 .29632 Metetra
.911 .827 .751 r
.31241 .29632 .3148 .29765 .32743 .27979 .3252 .27639 Metetra
.714 .285 0 r
.3252 .27639 .32743 .27979 .33779 .29898 .33555 .29556 Metetra
.754 .327 0 r
.33555 .29556 .33779 .29898 .34827 .31997 .34602 .31654 Metetra
.788 .365 0 r
.34602 .31654 .34827 .31997 .3589 .34296 .35662 .33951 Metetra
.874 .727 .697 r
.35662 .33951 .3589 .34296 .37213 .31763 .36985 .31467 Metetra
.847 .419 0 r
.36985 .31467 .37213 .31763 .38299 .3428 .38068 .34032 Metetra
.956 .619 .323 r
.38068 .34032 .38299 .3428 .39218 .41572 .38982 .41327 Metetra
.836 .387 0 r
.38982 .41327 .39218 .41572 .4039 .43817 .40146 .43746 Metetra
.962 .834 .669 r
.40146 .43746 .4039 .43817 .4177 .40588 .41531 .40511 Metetra
.964 .828 .66 r
.41531 .40511 .4177 .40588 .43138 .37237 .42903 .37154 Metetra
.966 .823 .651 r
.42903 .37154 .43138 .37237 .44492 .3376 .44261 .33672 Metetra
.967 .818 .643 r
.44261 .33672 .44492 .3376 .4583 .30158 .45603 .30064 Metetra
.639 .903 .984 r
.45603 .30064 .4583 .30158 .4709 .29971 .4687 .29554 Metetra
.903 .531 .079 r
.4687 .29554 .4709 .29971 .48295 .34538 .48072 .34117 Metetra
.913 .546 .105 r
.48072 .34117 .48295 .34538 .49542 .3959 .49316 .39166 Metetra
.857 .474 0 r
.49316 .39166 .49542 .3959 .50846 .43443 .50617 .43192 Metetra
.645 .763 .934 r
.50617 .43192 .50846 .43443 .52197 .43004 .51969 .42752 Metetra
.645 .763 .934 r
.51969 .42752 .52197 .43004 .53554 .42562 .53328 .42309 Metetra
.645 .763 .934 r
.53328 .42309 .53554 .42562 .54918 .42119 .54693 .41864 Metetra
.645 .763 .934 r
.54693 .41864 .54918 .42119 .56289 .41673 .56065 .41417 Metetra
.645 .763 .934 r
.56065 .41417 .56289 .41673 .57667 .41225 .57444 .40968 Metetra
.645 .763 .934 r
.57444 .40968 .57667 .41225 .59051 .40775 .5883 .40517 Metetra
.645 .763 .934 r
.5883 .40517 .59051 .40775 .60442 .40322 .60223 .40063 Metetra
.645 .763 .934 r
.60223 .40063 .60442 .40322 .61841 .39868 .61623 .39607 Metetra
.645 .763 .934 r
.61623 .39607 .61841 .39868 .63246 .39411 .6303 .39148 Metetra
.645 .763 .934 r
.6303 .39148 .63246 .39411 .64659 .38951 .64444 .38688 Metetra
.645 .763 .934 r
.64444 .38688 .64659 .38951 .66078 .3849 .65865 .38225 Metetra
.645 .763 .934 r
.65865 .38225 .66078 .3849 .67505 .38026 .67293 .37759 Metetra
.645 .763 .934 r
.67293 .37759 .67505 .38026 .68939 .37559 .68729 .37292 Metetra
.645 .763 .934 r
.68729 .37292 .68939 .37559 .7038 .3709 .70171 .36821 Metetra
.645 .763 .934 r
.70171 .36821 .7038 .3709 .71829 .36619 .71622 .36349 Metetra
.645 .763 .934 r
.71622 .36349 .71829 .36619 .73285 .36146 .73079 .35874 Metetra
.645 .763 .934 r
.73079 .35874 .73285 .36146 .74749 .3567 .74544 .35397 Metetra
.645 .763 .934 r
.74544 .35397 .74749 .3567 .7622 .35191 .76017 .34917 Metetra
.645 .763 .934 r
.76017 .34917 .7622 .35191 .77698 .3471 .77497 .34435 Metetra
.026 .555 .857 r
.11691 .36824 .11954 .36931 .1296 .37246 .12713 .37015 Metetra
.852 .754 .755 r
.12713 .37015 .1296 .37246 .14229 .35453 .13971 .35328 Metetra
0 .288 .656 r
.13971 .35328 .14229 .35453 .15227 .35936 .14972 .35793 Metetra
.838 .828 .838 r
.14972 .35793 .15227 .35936 .16425 .34761 .16168 .34645 Metetra
.874 .837 .807 r
.16168 .34645 .16425 .34761 .1765 .33325 .17395 .33208 Metetra
.899 .816 .756 r
.17395 .33208 .1765 .33325 .18923 .31418 .18671 .31303 Metetra
.639 .857 .982 r
.18671 .31303 .18923 .31418 .20011 .31254 .19783 .30905 Metetra
0 .237 .754 r
.19783 .30905 .20011 .31254 .21007 .32062 .20779 .31712 Metetra
0 .188 .72 r
.20779 .31712 .21007 .32062 .22008 .32954 .2178 .32602 Metetra
.64 .648 .842 r
.2178 .32602 .22008 .32954 .23143 .32564 .22914 .32225 Metetra
.622 .65 .857 r
.22914 .32225 .23143 .32564 .24287 .32118 .24046 .31915 Metetra
.929 .552 .256 r
.24046 .31915 .24287 .32118 .25103 .3554 .2486 .35339 Metetra
.725 .795 .907 r
.2486 .35339 .25103 .3554 .26277 .35026 .26043 .34717 Metetra
.732 .712 .832 r
.26043 .34717 .26277 .35026 .27475 .34249 .27241 .33958 Metetra
.624 .691 .892 r
.27241 .33958 .27475 .34249 .28636 .34004 .28408 .33639 Metetra
.848 .71 .71 r
.28408 .33639 .28636 .34004 .29939 .31862 .29714 .31495 Metetra
.853 .711 .705 r
.29714 .31495 .29939 .31862 .31241 .29632 .31018 .29265 Metetra
.828 .707 .731 r
.31018 .29265 .31241 .29632 .3252 .27639 .32283 .27498 Metetra
.84 .373 .027 r
.32283 .27498 .3252 .27639 .33555 .29556 .33317 .29417 Metetra
.855 .398 .059 r
.33317 .29417 .33555 .29556 .34602 .31654 .34363 .31517 Metetra
.867 .421 .089 r
.34363 .31517 .34602 .31654 .35662 .33951 .35423 .33816 Metetra
.933 .816 .707 r
.35423 .33816 .35662 .33951 .36985 .31467 .36754 .31233 Metetra
.871 .437 .036 r
.36754 .31233 .36985 .31467 .38068 .34032 .37835 .33828 Metetra
.953 .616 .332 r
.37835 .33828 .38068 .34032 .38982 .41327 .38743 .41128 Metetra
.837 .376 0 r
.38743 .41128 .38982 .41327 .40146 .43746 .39912 .4341 Metetra
.904 .739 .668 r
.39912 .4341 .40146 .43746 .41531 .40511 .41299 .40174 Metetra
.907 .738 .661 r
.41299 .40174 .41531 .40511 .42903 .37154 .42674 .36815 Metetra
.911 .738 .654 r
.42674 .36815 .42903 .37154 .44261 .33672 .44036 .33332 Metetra
.915 .737 .647 r
.44036 .33332 .44261 .33672 .45603 .30064 .45381 .29723 Metetra
.62 .666 .873 r
.45381 .29723 .45603 .30064 .4687 .29554 .46646 .29385 Metetra
.927 .541 .206 r
.46646 .29385 .4687 .29554 .48072 .34117 .47846 .33952 Metetra
.932 .551 .221 r
.47846 .33952 .48072 .34117 .49316 .39166 .49087 .39006 Metetra
.908 .499 .148 r
.49087 .39006 .49316 .39166 .50617 .43192 .50387 .42941 Metetra
.645 .763 .934 r
.50387 .42941 .50617 .43192 .51969 .42752 .51741 .42499 Metetra
.645 .763 .934 r
.51741 .42499 .51969 .42752 .53328 .42309 .53101 .42055 Metetra
.645 .763 .934 r
.53101 .42055 .53328 .42309 .54693 .41864 .54467 .41609 Metetra
.645 .763 .934 r
.54467 .41609 .54693 .41864 .56065 .41417 .55841 .41161 Metetra
.645 .763 .934 r
.55841 .41161 .56065 .41417 .57444 .40968 .57221 .4071 Metetra
.645 .763 .934 r
.57221 .4071 .57444 .40968 .5883 .40517 .58609 .40258 Metetra
.645 .763 .934 r
.58609 .40258 .5883 .40517 .60223 .40063 .60003 .39802 Metetra
.645 .763 .934 r
.60003 .39802 .60223 .40063 .61623 .39607 .61404 .39345 Metetra
.645 .763 .934 r
.61404 .39345 .61623 .39607 .6303 .39148 .62812 .38885 Metetra
.645 .763 .934 r
.62812 .38885 .6303 .39148 .64444 .38688 .64228 .38423 Metetra
.645 .763 .934 r
.64228 .38423 .64444 .38688 .65865 .38225 .6565 .37959 Metetra
.645 .763 .934 r
.6565 .37959 .65865 .38225 .67293 .37759 .6708 .37492 Metetra
.645 .763 .934 r
.6708 .37492 .67293 .37759 .68729 .37292 .68517 .37023 Metetra
.645 .763 .934 r
.68517 .37023 .68729 .37292 .70171 .36821 .69962 .36552 Metetra
.645 .763 .934 r
.69962 .36552 .70171 .36821 .71622 .36349 .71414 .36078 Metetra
.645 .763 .934 r
.71414 .36078 .71622 .36349 .73079 .35874 .72873 .35602 Metetra
.645 .763 .934 r
.72873 .35602 .73079 .35874 .74544 .35397 .7434 .35123 Metetra
.645 .763 .934 r
.7434 .35123 .74544 .35397 .76017 .34917 .75814 .34642 Metetra
.645 .763 .934 r
.75814 .34642 .76017 .34917 .77497 .34435 .77296 .34158 Metetra
.308 .508 .889 r
.11454 .36504 .11691 .36824 .12713 .37015 .12463 .36803 Metetra
.866 .762 .746 r
.12463 .36803 .12713 .37015 .13971 .35328 .13743 .3495 Metetra
.247 .426 .842 r
.13743 .3495 .13971 .35328 .14972 .35793 .14744 .35411 Metetra
.769 .675 .759 r
.14744 .35411 .14972 .35793 .16168 .34645 .15944 .34231 Metetra
.785 .668 .735 r
.15944 .34231 .16168 .34645 .17395 .33208 .17173 .32793 Metetra
.811 .676 .715 r
.17173 .32793 .17395 .33208 .18671 .31303 .18439 .30984 Metetra
.561 .635 .882 r
.18439 .30984 .18671 .31303 .19783 .30905 .19525 .3085 Metetra
.64 .08 0 r
.19525 .3085 .19783 .30905 .20779 .31712 .20521 .31658 Metetra
.671 .122 0 r
.20521 .31658 .20779 .31712 .2178 .32602 .21522 .32549 Metetra
.592 .907 .982 r
.21522 .32549 .2178 .32602 .22914 .32225 .22661 .32128 Metetra
.668 .887 .978 r
.22661 .32128 .22914 .32225 .24046 .31915 .23811 .31641 Metetra
.934 .556 .223 r
.23811 .31641 .24046 .31915 .2486 .35339 .24622 .35065 Metetra
.685 .724 .879 r
.24622 .35065 .2486 .35339 .26043 .34717 .25797 .34553 Metetra
.768 .835 .903 r
.25797 .34553 .26043 .34717 .27241 .33958 .26998 .33782 Metetra
.601 .793 .973 r
.26998 .33782 .27241 .33958 .28408 .33639 .28165 .33477 Metetra
.906 .804 .737 r
.28165 .33477 .28408 .33639 .29714 .31495 .29473 .31331 Metetra
.909 .802 .729 r
.29473 .31331 .29714 .31495 .31018 .29265 .30779 .29098 Metetra
.896 .811 .756 r
.30779 .29098 .31018 .29265 .32283 .27498 .32056 .272 Metetra
.762 .314 0 r
.32056 .272 .32283 .27498 .33317 .29417 .33089 .29118 Metetra
.794 .352 0 r
.33089 .29118 .33317 .29417 .34363 .31517 .34134 .31217 Metetra
.821 .385 0 r
.34134 .31217 .34363 .31517 .35423 .33816 .35192 .33516 Metetra
.889 .746 .697 r
.35192 .33516 .35423 .33816 .36754 .31233 .36525 .30951 Metetra
.862 .435 .002 r
.36525 .30951 .36754 .31233 .37835 .33828 .37601 .33599 Metetra
.955 .617 .327 r
.37601 .33599 .37835 .33828 .38743 .41128 .38505 .40904 Metetra
.841 .388 0 r
.38505 .40904 .38743 .41128 .39912 .4341 .39669 .43295 Metetra
.954 .817 .671 r
.39669 .43295 .39912 .4341 .41299 .40174 .4106 .40054 Metetra
.956 .813 .662 r
.4106 .40054 .41299 .40174 .42674 .36815 .42439 .3669 Metetra
.957 .808 .654 r
.42439 .3669 .42674 .36815 .44036 .33332 .43804 .33201 Metetra
.959 .804 .645 r
.43804 .33201 .44036 .33332 .45381 .29723 .45154 .29587 Metetra
.685 .875 .97 r
.45154 .29587 .45381 .29723 .46646 .29385 .46425 .29025 Metetra
.915 .537 .113 r
.46425 .29025 .46646 .29385 .47846 .33952 .47621 .33591 Metetra
.923 .55 .136 r
.47621 .33591 .47846 .33952 .49087 .39006 .4886 .38642 Metetra
.881 .489 .032 r
.4886 .38642 .49087 .39006 .50387 .42941 .50157 .42689 Metetra
.645 .763 .934 r
.50157 .42689 .50387 .42941 .51741 .42499 .51512 .42246 Metetra
.645 .763 .934 r
.51512 .42246 .51741 .42499 .53101 .42055 .52873 .41801 Metetra
.645 .763 .934 r
.52873 .41801 .53101 .42055 .54467 .41609 .54241 .41353 Metetra
.645 .763 .934 r
.54241 .41353 .54467 .41609 .55841 .41161 .55616 .40904 Metetra
.645 .763 .934 r
.55616 .40904 .55841 .41161 .57221 .4071 .56998 .40452 Metetra
.645 .763 .934 r
.56998 .40452 .57221 .4071 .58609 .40258 .58386 .39998 Metetra
.645 .763 .934 r
.58386 .39998 .58609 .40258 .60003 .39802 .59782 .39541 Metetra
.645 .763 .934 r
.59782 .39541 .60003 .39802 .61404 .39345 .61185 .39083 Metetra
.645 .763 .934 r
.61185 .39083 .61404 .39345 .62812 .38885 .62595 .38622 Metetra
.645 .763 .934 r
.62595 .38622 .62812 .38885 .64228 .38423 .64012 .38158 Metetra
.645 .763 .934 r
.64012 .38158 .64228 .38423 .6565 .37959 .65436 .37693 Metetra
.645 .763 .934 r
.65436 .37693 .6565 .37959 .6708 .37492 .66867 .37225 Metetra
.645 .763 .934 r
.66867 .37225 .6708 .37492 .68517 .37023 .68306 .36754 Metetra
.645 .763 .934 r
.68306 .36754 .68517 .37023 .69962 .36552 .69752 .36281 Metetra
.645 .763 .934 r
.69752 .36281 .69962 .36552 .71414 .36078 .71205 .35806 Metetra
.645 .763 .934 r
.71205 .35806 .71414 .36078 .72873 .35602 .72666 .35328 Metetra
.645 .763 .934 r
.72666 .35328 .72873 .35602 .7434 .35123 .74134 .34848 Metetra
.645 .763 .934 r
.74134 .34848 .7434 .35123 .75814 .34642 .7561 .34365 Metetra
.645 .763 .934 r
.7561 .34365 .75814 .34642 .77296 .34158 .77094 .3388 Metetra
.054 .579 .869 r
.11189 .36402 .11454 .36504 .12463 .36803 .12216 .36562 Metetra
.847 .75 .756 r
.12216 .36562 .12463 .36803 .13743 .3495 .13475 .34899 Metetra
.443 0 0 r
.13475 .34899 .13743 .3495 .14744 .35411 .14474 .35371 Metetra
.861 .915 .866 r
.14474 .35371 .14744 .35411 .15944 .34231 .15673 .34227 Metetra
.904 .914 .817 r
.15673 .34227 .15944 .34231 .17173 .32793 .1691 .32737 Metetra
.915 .854 .767 r
.1691 .32737 .17173 .32793 .18439 .30984 .18186 .30864 Metetra
.679 .86 .968 r
.18186 .30864 .18439 .30984 .19525 .3085 .19308 .30389 Metetra
.106 .279 .757 r
.19308 .30389 .19525 .3085 .20521 .31658 .20303 .31194 Metetra
.053 .244 .741 r
.20303 .31194 .20521 .31658 .21522 .32549 .21303 .32083 Metetra
.622 .582 .788 r
.21303 .32083 .21522 .32549 .22661 .32128 .22437 .31721 Metetra
.608 .604 .822 r
.22437 .31721 .22661 .32128 .23811 .31641 .23569 .3144 Metetra
.929 .551 .257 r
.23569 .3144 .23811 .31641 .24622 .35065 .24377 .34866 Metetra
.73 .798 .906 r
.24377 .34866 .24622 .35065 .25797 .34553 .25565 .34224 Metetra
.729 .7 .823 r
.25565 .34224 .25797 .34553 .26998 .33782 .26766 .33454 Metetra
.625 .664 .868 r
.26766 .33454 .26998 .33782 .28165 .33477 .27935 .33124 Metetra
.852 .716 .712 r
.27935 .33124 .28165 .33477 .29473 .31331 .29245 .30977 Metetra
.857 .716 .707 r
.29245 .30977 .29473 .31331 .30779 .29098 .30554 .28744 Metetra
.828 .713 .737 r
.30554 .28744 .30779 .29098 .32056 .272 .3182 .27028 Metetra
.834 .366 0 r
.3182 .27028 .32056 .272 .33089 .29118 .32852 .28947 Metetra
.851 .393 .028 r
.32852 .28947 .33089 .29118 .34134 .31217 .33896 .31048 Metetra
.865 .417 .06 r
.33896 .31048 .34134 .31217 .35192 .33516 .34954 .33348 Metetra
.925 .802 .705 r
.34954 .33348 .35192 .33516 .36525 .30951 .36291 .30751 Metetra
.876 .44 .064 r
.36291 .30751 .36525 .30951 .37601 .33599 .37369 .33326 Metetra
.957 .62 .319 r
.37369 .33326 .37601 .33599 .38505 .40904 .38268 .40633 Metetra
.803 .35 0 r
.38268 .40633 .38505 .40904 .39669 .43295 .39436 .42899 Metetra
.891 .721 .665 r
.39436 .42899 .39669 .43295 .4106 .40054 .4083 .39657 Metetra
.895 .721 .658 r
.4083 .39657 .4106 .40054 .42439 .3669 .42211 .36293 Metetra
.899 .721 .652 r
.42211 .36293 .42439 .3669 .43804 .33201 .4358 .32804 Metetra
.903 .721 .646 r
.4358 .32804 .43804 .33201 .45154 .29587 .44932 .2919 Metetra
.607 .625 .844 r
.44932 .2919 .45154 .29587 .46425 .29025 .46198 .28889 Metetra
.926 .54 .22 r
.46198 .28889 .46425 .29025 .47621 .33591 .47393 .3346 Metetra
.93 .55 .233 r
.47393 .3346 .47621 .33591 .4886 .38642 .48629 .38517 Metetra
.907 .498 .165 r
.48629 .38517 .4886 .38642 .50157 .42689 .49926 .42436 Metetra
.645 .763 .934 r
.49926 .42436 .50157 .42689 .51512 .42246 .51282 .41992 Metetra
.645 .763 .934 r
.51282 .41992 .51512 .42246 .52873 .41801 .52644 .41545 Metetra
.645 .763 .934 r
.52644 .41545 .52873 .41801 .54241 .41353 .54014 .41097 Metetra
.645 .763 .934 r
.54014 .41097 .54241 .41353 .55616 .40904 .5539 .40646 Metetra
.645 .763 .934 r
.5539 .40646 .55616 .40904 .56998 .40452 .56774 .40193 Metetra
.645 .763 .934 r
.56774 .40193 .56998 .40452 .58386 .39998 .58164 .39737 Metetra
.645 .763 .934 r
.58164 .39737 .58386 .39998 .59782 .39541 .59561 .3928 Metetra
.645 .763 .934 r
.59561 .3928 .59782 .39541 .61185 .39083 .60965 .3882 Metetra
.645 .763 .934 r
.60965 .3882 .61185 .39083 .62595 .38622 .62376 .38357 Metetra
.645 .763 .934 r
.62376 .38357 .62595 .38622 .64012 .38158 .63795 .37893 Metetra
.645 .763 .934 r
.63795 .37893 .64012 .38158 .65436 .37693 .6522 .37425 Metetra
.645 .763 .934 r
.6522 .37425 .65436 .37693 .66867 .37225 .66653 .36956 Metetra
.645 .763 .934 r
.66653 .36956 .66867 .37225 .68306 .36754 .68093 .36484 Metetra
.645 .763 .934 r
.68093 .36484 .68306 .36754 .69752 .36281 .69541 .3601 Metetra
.645 .763 .934 r
.69541 .3601 .69752 .36281 .71205 .35806 .70996 .35533 Metetra
.645 .763 .934 r
.70996 .35533 .71205 .35806 .72666 .35328 .72458 .35054 Metetra
.645 .763 .934 r
.72458 .35054 .72666 .35328 .74134 .34848 .73929 .34573 Metetra
.645 .763 .934 r
.73929 .34573 .74134 .34848 .7561 .34365 .75406 .34089 Metetra
.645 .763 .934 r
.75406 .34089 .7561 .34365 .77094 .3388 .76891 .33602 Metetra
.382 .552 .898 r
.10951 .36086 .11189 .36402 .12216 .36562 .11973 .36278 Metetra
.841 .728 .739 r
.11973 .36278 .12216 .36562 .13475 .34899 .13249 .34498 Metetra
.324 .454 .838 r
.13249 .34498 .13475 .34899 .14474 .35371 .14259 .34874 Metetra
.746 .628 .728 r
.14259 .34874 .14474 .35371 .15673 .34227 .15468 .33648 Metetra
.748 .608 .703 r
.15468 .33648 .15673 .34227 .1691 .32737 .16699 .32208 Metetra
.774 .632 .704 r
.16699 .32208 .1691 .32737 .18186 .30864 .17951 .30564 Metetra
.528 .637 .902 r
.17951 .30564 .18186 .30864 .19308 .30389 .19031 .30494 Metetra
.665 .174 .074 r
.19031 .30494 .19308 .30389 .20303 .31194 .20027 .31302 Metetra
.684 .2 .095 r
.20027 .31302 .20303 .31194 .21303 .32083 .21027 .32194 Metetra
.4 .841 .722 r
.21027 .32194 .21303 .32083 .22437 .31721 .22184 .3161 Metetra
.59 .854 .994 r
.22184 .3161 .22437 .31721 .23569 .3144 .23322 .31272 Metetra
.925 .548 .271 r
.23322 .31272 .23569 .3144 .24377 .34866 .24129 .347 Metetra
.694 .826 .946 r
.24129 .347 .24377 .34866 .25565 .34224 .25307 .3418 Metetra
.815 .944 .909 r
.25307 .3418 .25565 .34224 .26766 .33454 .26525 .33229 Metetra
.612 .748 .941 r
.26525 .33229 .26766 .33454 .27935 .33124 .27693 .32925 Metetra
.895 .785 .732 r
.27693 .32925 .27935 .33124 .29245 .30977 .29006 .30775 Metetra
.899 .783 .725 r
.29006 .30775 .29245 .30977 .30554 .28744 .30317 .28539 Metetra
.877 .793 .764 r
.30317 .28539 .30554 .28744 .3182 .27028 .31587 .26788 Metetra
.807 .344 0 r
.31587 .26788 .3182 .27028 .32852 .28947 .32619 .28708 Metetra
.83 .376 0 r
.32619 .28708 .32852 .28947 .33896 .31048 .33662 .30809 Metetra
.85 .404 0 r
.33662 .30809 .33896 .31048 .34954 .33348 .34718 .33109 Metetra
.905 .771 .703 r
.34718 .33109 .34954 .33348 .36291 .30751 .36057 .30544 Metetra
.872 .433 .05 r
.36057 .30544 .36291 .30751 .37369 .33326 .37136 .33075 Metetra
.956 .619 .323 r
.37136 .33075 .37369 .33326 .38268 .40633 .3803 .40385 Metetra
.825 .371 0 r
.3803 .40385 .38268 .40633 .39436 .42899 .39193 .42718 Metetra
.94 .794 .672 r
.39193 .42718 .39436 .42899 .4083 .39657 .40591 .39473 Metetra
.942 .79 .664 r
.40591 .39473 .4083 .39657 .42211 .36293 .41977 .36104 Metetra
.945 .787 .655 r
.41977 .36104 .42211 .36293 .4358 .32804 .43349 .32612 Metetra
.947 .784 .647 r
.43349 .32612 .4358 .32804 .44932 .2919 .44705 .28993 Metetra
.621 .795 .965 r
.44705 .28993 .44932 .2919 .46198 .28889 .45974 .28619 Metetra
.925 .542 .161 r
.45974 .28619 .46198 .28889 .47393 .3346 .47166 .33191 Metetra
.931 .553 .18 r
.47166 .33191 .47393 .3346 .48629 .38517 .48399 .38251 Metetra
.898 .493 .085 r
.48399 .38251 .48629 .38517 .49926 .42436 .49694 .42182 Metetra
.645 .763 .934 r
.49694 .42182 .49926 .42436 .51282 .41992 .51051 .41737 Metetra
.645 .763 .934 r
.51051 .41737 .51282 .41992 .52644 .41545 .52415 .41289 Metetra
.645 .763 .934 r
.52415 .41289 .52644 .41545 .54014 .41097 .53786 .40839 Metetra
.645 .763 .934 r
.53786 .40839 .54014 .41097 .5539 .40646 .55164 .40387 Metetra
.645 .763 .934 r
.55164 .40387 .5539 .40646 .56774 .40193 .56549 .39933 Metetra
.645 .763 .934 r
.56549 .39933 .56774 .40193 .58164 .39737 .5794 .39476 Metetra
.645 .763 .934 r
.5794 .39476 .58164 .39737 .59561 .3928 .59339 .39017 Metetra
.645 .763 .934 r
.59339 .39017 .59561 .3928 .60965 .3882 .60744 .38556 Metetra
.645 .763 .934 r
.60744 .38556 .60965 .3882 .62376 .38357 .62157 .38092 Metetra
.645 .763 .934 r
.62157 .38092 .62376 .38357 .63795 .37893 .63577 .37626 Metetra
.645 .763 .934 r
.63577 .37626 .63795 .37893 .6522 .37425 .65004 .37158 Metetra
.645 .763 .934 r
.65004 .37158 .6522 .37425 .66653 .36956 .66439 .36687 Metetra
.645 .763 .934 r
.66439 .36687 .66653 .36956 .68093 .36484 .6788 .36214 Metetra
.645 .763 .934 r
.6788 .36214 .68093 .36484 .69541 .3601 .6933 .35738 Metetra
.645 .763 .934 r
.6933 .35738 .69541 .3601 .70996 .35533 .70786 .3526 Metetra
.645 .763 .934 r
.70786 .3526 .70996 .35533 .72458 .35054 .7225 .34779 Metetra
.645 .763 .934 r
.7225 .34779 .72458 .35054 .73929 .34573 .73722 .34296 Metetra
.645 .763 .934 r
.73722 .34296 .73929 .34573 .75406 .34089 .75201 .33811 Metetra
.645 .763 .934 r
.75201 .33811 .75406 .34089 .76891 .33602 .76688 .33323 Metetra
.122 .624 .903 r
.10684 .35982 .10951 .36086 .11973 .36278 .11717 .36097 Metetra
.863 .785 .773 r
.11717 .36097 .11973 .36278 .13249 .34498 .12973 .34488 Metetra
.491 0 0 r
.12973 .34488 .13249 .34498 .14259 .34874 .13973 .34959 Metetra
.833 .995 .848 r
.13973 .34959 .14259 .34874 .15468 .33648 .15174 .33819 Metetra
.883 .992 .761 r
.15174 .33819 .15468 .33648 .16699 .32208 .16423 .32251 Metetra
.933 .917 .776 r
.16423 .32251 .16699 .32208 .17951 .30564 .17698 .30426 Metetra
.719 .847 .943 r
.17698 .30426 .17951 .30564 .19031 .30494 .18832 .29857 Metetra
.258 .297 .712 r
.18832 .29857 .19031 .30494 .20027 .31302 .19827 .30661 Metetra
.225 .275 .705 r
.19827 .30661 .20027 .31302 .21027 .32194 .20826 .31549 Metetra
.602 .514 .727 r
.20826 .31549 .21027 .32194 .22184 .3161 .2196 .31194 Metetra
.589 .591 .822 r
.2196 .31194 .22184 .3161 .23322 .31272 .23087 .30976 Metetra
.934 .557 .212 r
.23087 .30976 .23322 .31272 .24129 .347 .23891 .34403 Metetra
.719 .718 .848 r
.23891 .34403 .24129 .347 .25307 .3418 .25083 .33725 Metetra
.702 .63 .773 r
.25083 .33725 .25307 .3418 .26525 .33229 .26288 .3294 Metetra
.628 .697 .895 r
.26288 .3294 .26525 .33229 .27693 .32925 .27459 .32605 Metetra
.861 .731 .717 r
.27459 .32605 .27693 .32925 .29006 .30775 .28774 .30455 Metetra
.866 .731 .711 r
.28774 .30455 .29006 .30775 .30317 .28539 .30088 .28217 Metetra
.835 .729 .748 r
.30088 .28217 .30317 .28539 .31587 .26788 .31354 .26556 Metetra
.812 .347 0 r
.31354 .26556 .31587 .26788 .32619 .28708 .32384 .28476 Metetra
.834 .378 0 r
.32384 .28476 .32619 .28708 .33662 .30809 .33426 .30577 Metetra
.853 .406 0 r
.33426 .30577 .33662 .30809 .34718 .33109 .34482 .32878 Metetra
.909 .774 .701 r
.34482 .32878 .34718 .33109 .36057 .30544 .35825 .30271 Metetra
.856 .423 0 r
.35825 .30271 .36057 .30544 .37136 .33075 .36902 .32815 Metetra
.956 .619 .322 r
.36902 .32815 .37136 .33075 .3803 .40385 .37791 .40128 Metetra
.806 .349 0 r
.37791 .40128 .3803 .40385 .39193 .42718 .38958 .42361 Metetra
.9 .733 .667 r
.38958 .42361 .39193 .42718 .40591 .39473 .40358 .39114 Metetra
.903 .733 .66 r
.40358 .39114 .40591 .39473 .41977 .36104 .41747 .35745 Metetra
.907 .732 .653 r
.41747 .35745 .41977 .36104 .43349 .32612 .43122 .32251 Metetra
.911 .732 .646 r
.43122 .32251 .43349 .32612 .44705 .28993 .44482 .28632 Metetra
.582 .637 .871 r
.44482 .28632 .44705 .28993 .45974 .28619 .45748 .2841 Metetra
.927 .542 .19 r
.45748 .2841 .45974 .28619 .47166 .33191 .46937 .32985 Metetra
.932 .552 .206 r
.46937 .32985 .47166 .33191 .48399 .38251 .48168 .38048 Metetra
.904 .494 .12 r
.48168 .38048 .48399 .38251 .49694 .42182 .49462 .41928 Metetra
.645 .763 .934 r
.49462 .41928 .49694 .42182 .51051 .41737 .5082 .41481 Metetra
.645 .763 .934 r
.5082 .41481 .51051 .41737 .52415 .41289 .52186 .41032 Metetra
.645 .763 .934 r
.52186 .41032 .52415 .41289 .53786 .40839 .53558 .40581 Metetra
.645 .763 .934 r
.53558 .40581 .53786 .40839 .55164 .40387 .54937 .40128 Metetra
.645 .763 .934 r
.54937 .40128 .55164 .40387 .56549 .39933 .56323 .39672 Metetra
.645 .763 .934 r
.56323 .39672 .56549 .39933 .5794 .39476 .57716 .39214 Metetra
.645 .763 .934 r
.57716 .39214 .5794 .39476 .59339 .39017 .59116 .38754 Metetra
.645 .763 .934 r
.59116 .38754 .59339 .39017 .60744 .38556 .60523 .38291 Metetra
.645 .763 .934 r
.60523 .38291 .60744 .38556 .62157 .38092 .61937 .37826 Metetra
.645 .763 .934 r
.61937 .37826 .62157 .38092 .63577 .37626 .63359 .37359 Metetra
.645 .763 .934 r
.63359 .37359 .63577 .37626 .65004 .37158 .64788 .36889 Metetra
.645 .763 .934 r
.64788 .36889 .65004 .37158 .66439 .36687 .66224 .36417 Metetra
.645 .763 .934 r
.66224 .36417 .66439 .36687 .6788 .36214 .67667 .35942 Metetra
.645 .763 .934 r
.67667 .35942 .6788 .36214 .6933 .35738 .69118 .35465 Metetra
.645 .763 .934 r
.69118 .35465 .6933 .35738 .70786 .3526 .70576 .34986 Metetra
.645 .763 .934 r
.70576 .34986 .70786 .3526 .7225 .34779 .72042 .34504 Metetra
.645 .763 .934 r
.72042 .34504 .7225 .34779 .73722 .34296 .73515 .34019 Metetra
.645 .763 .934 r
.73515 .34019 .73722 .34296 .75201 .33811 .74996 .33532 Metetra
.645 .763 .934 r
.74996 .33532 .75201 .33811 .76688 .33323 .76484 .33043 Metetra
.448 .568 .883 r
.10448 .35642 .10684 .35982 .11717 .36097 .11482 .35747 Metetra
.819 .699 .732 r
.11482 .35747 .11717 .36097 .12973 .34488 .12751 .34046 Metetra
.396 .47 .819 r
.12751 .34046 .12973 .34488 .13973 .34959 .13773 .34334 Metetra
.723 .586 .702 r
.13773 .34334 .13973 .34959 .15174 .33819 .14988 .33071 Metetra
.718 .563 .678 r
.14988 .33071 .15174 .33819 .16423 .32251 .16223 .31628 Metetra
.745 .599 .694 r
.16223 .31628 .16423 .32251 .17698 .30426 .17463 .30116 Metetra
.488 .612 .901 r
.17463 .30116 .17698 .30426 .18832 .29857 .18535 .30127 Metetra
.646 .214 .208 r
.18535 .30127 .18832 .29857 .19827 .30661 .19531 .30935 Metetra
.66 .232 .22 r
.19531 .30935 .19827 .30661 .20826 .31549 .20531 .31827 Metetra
.20531 .31827 .20826 .31549 .2196 .31194 .21705 .3109 Metetra
.471 .819 .998 r
.21705 .3109 .2196 .31194 .23087 .30976 .22831 .30895 Metetra
.912 .538 .303 r
.22831 .30895 .23087 .30976 .23891 .34403 .23633 .34328 Metetra
.678 .912 .975 r
.23633 .34328 .23891 .34403 .25083 .33725 .24815 .3378 Metetra
.806 .995 .863 r
.24815 .3378 .25083 .33725 .26288 .3294 .26047 .32706 Metetra
.614 .74 .936 r
.26047 .32706 .26288 .3294 .27459 .32605 .27216 .324 Metetra
.894 .783 .732 r
.27216 .324 .27459 .32605 .28774 .30455 .28534 .30247 Metetra
.897 .781 .724 r
.28534 .30247 .28774 .30455 .30088 .28217 .2985 .28007 Metetra
.87 .792 .772 r
.2985 .28007 .30088 .28217 .31354 .26556 .31118 .26344 Metetra
.821 .355 0 r
.31118 .26344 .31354 .26556 .32384 .28476 .32148 .28264 Metetra
.841 .384 0 r
.32148 .28264 .32384 .28476 .33426 .30577 .33189 .30366 Metetra
.858 .411 .021 r
.33189 .30366 .33426 .30577 .34482 .32878 .34243 .32668 Metetra
.913 .784 .705 r
.34243 .32668 .34482 .32878 .35825 .30271 .35587 .30097 Metetra
.871 .429 .069 r
.35587 .30097 .35825 .30271 .36902 .32815 .36668 .32564 Metetra
.956 .619 .324 r
.36668 .32564 .36902 .32815 .37791 .40128 .37551 .3988 Metetra
.815 .357 0 r
.37551 .3988 .37791 .40128 .38958 .42361 .38716 .42139 Metetra
.931 .779 .671 r
.38716 .42139 .38958 .42361 .40358 .39114 .4012 .38889 Metetra
.933 .777 .664 r
.4012 .38889 .40358 .39114 .41747 .35745 .41512 .35516 Metetra
.936 .774 .656 r
.41512 .35516 .41747 .35745 .43122 .32251 .42891 .32019 Metetra
.939 .772 .648 r
.42891 .32019 .43122 .32251 .44482 .28632 .44254 .28397 Metetra
.548 .729 .959 r
.44254 .28397 .44482 .28632 .45748 .2841 .45521 .28205 Metetra
.927 .542 .192 r
.45521 .28205 .45748 .2841 .46937 .32985 .46708 .32783 Metetra
.932 .552 .208 r
.46708 .32783 .46937 .32985 .48168 .38048 .47936 .3785 Metetra
.902 .491 .118 r
.47936 .3785 .48168 .38048 .49462 .41928 .49229 .41673 Metetra
.645 .763 .934 r
.49229 .41673 .49462 .41928 .5082 .41481 .50589 .41225 Metetra
.645 .763 .934 r
.50589 .41225 .5082 .41481 .52186 .41032 .51955 .40775 Metetra
.645 .763 .934 r
.51955 .40775 .52186 .41032 .53558 .40581 .53329 .40322 Metetra
.645 .763 .934 r
.53329 .40322 .53558 .40581 .54937 .40128 .54709 .39868 Metetra
.645 .763 .934 r
.54709 .39868 .54937 .40128 .56323 .39672 .56097 .39411 Metetra
.645 .763 .934 r
.56097 .39411 .56323 .39672 .57716 .39214 .57491 .38951 Metetra
.645 .763 .934 r
.57491 .38951 .57716 .39214 .59116 .38754 .58893 .3849 Metetra
.645 .763 .934 r
.58893 .3849 .59116 .38754 .60523 .38291 .60301 .38026 Metetra
.645 .763 .934 r
.60301 .38026 .60523 .38291 .61937 .37826 .61717 .37559 Metetra
.645 .763 .934 r
.61717 .37559 .61937 .37826 .63359 .37359 .6314 .3709 Metetra
.645 .763 .934 r
.6314 .3709 .63359 .37359 .64788 .36889 .6457 .36619 Metetra
.645 .763 .934 r
.6457 .36619 .64788 .36889 .66224 .36417 .66008 .36146 Metetra
.645 .763 .934 r
.66008 .36146 .66224 .36417 .67667 .35942 .67453 .3567 Metetra
.645 .763 .934 r
.67453 .3567 .67667 .35942 .69118 .35465 .68905 .35191 Metetra
.645 .763 .934 r
.68905 .35191 .69118 .35465 .70576 .34986 .70365 .3471 Metetra
.645 .763 .934 r
.70365 .3471 .70576 .34986 .72042 .34504 .71832 .34227 Metetra
.645 .763 .934 r
.71832 .34227 .72042 .34504 .73515 .34019 .73307 .33741 Metetra
.645 .763 .934 r
.73307 .33741 .73515 .34019 .74996 .33532 .7479 .33253 Metetra
.645 .763 .934 r
.7479 .33253 .74996 .33532 .76484 .33043 .7628 .32762 Metetra
.201 .625 .949 r
.10187 .35487 .10448 .35642 .11482 .35747 .11216 .35634 Metetra
.885 .825 .783 r
.11216 .35634 .11482 .35747 .12751 .34046 .1248 .33988 Metetra
.442 0 0 r
.1248 .33988 .12751 .34046 .13773 .34334 .13478 .34471 Metetra
.797 .999 .805 r
.13478 .34471 .13773 .34334 .14988 .33071 .14685 .33302 Metetra
.81 .983 .706 r
.14685 .33302 .14988 .33071 .16223 .31628 .1593 .31799 Metetra
.929 .971 .742 r
.1593 .31799 .16223 .31628 .17463 .30116 .17215 .29918 Metetra
.69 .783 .922 r
.17215 .29918 .17463 .30116 .18535 .30127 .18342 .29429 Metetra
.288 .298 .697 r
.18342 .29429 .18535 .30127 .19531 .30935 .19337 .30233 Metetra
.258 .278 .691 r
.19337 .30233 .19531 .30935 .20531 .31827 .20335 .3112 Metetra
.6 .499 .711 r
.20335 .3112 .20531 .31827 .21705 .3109 .21473 .30746 Metetra
.602 .642 .862 r
.21473 .30746 .21705 .3109 .22831 .30895 .22605 .30489 Metetra
.928 .558 .15 r
.22605 .30489 .22831 .30895 .23633 .34328 .23404 .33918 Metetra
.682 .641 .802 r
.23404 .33918 .23633 .34328 .24815 .3378 .24593 .33306 Metetra
.71 .627 .762 r
.24593 .33306 .24815 .3378 .26047 .32706 .25807 .32434 Metetra
.607 .705 .913 r
.25807 .32434 .26047 .32706 .27216 .324 .26976 .32151 Metetra
.882 .763 .727 r
.26976 .32151 .27216 .324 .28534 .30247 .28296 .29996 Metetra
.886 .762 .72 r
.28296 .29996 .28534 .30247 .2985 .28007 .29615 .27755 Metetra
.86 .767 .758 r
.29615 .27755 .2985 .28007 .31118 .26344 .30889 .26031 Metetra
.753 .309 0 r
.30889 .26031 .31118 .26344 .32148 .28264 .31917 .2795 Metetra
.786 .347 0 r
.31917 .2795 .32148 .28264 .33189 .30366 .32957 .30052 Metetra
.815 .382 0 r
.32957 .30052 .33189 .30366 .34243 .32668 .3401 .32353 Metetra
.884 .741 .698 r
.3401 .32353 .34243 .32668 .35587 .30097 .35355 .29812 Metetra
.84 .404 0 r
.35355 .29812 .35587 .30097 .36668 .32564 .36435 .32257 Metetra
.959 .622 .313 r
.36435 .32257 .36668 .32564 .37551 .3988 .37313 .39573 Metetra
.791 .347 0 r
.37313 .39573 .37551 .3988 .38716 .42139 .38474 .41892 Metetra
.925 .771 .671 r
.38474 .41892 .38716 .42139 .4012 .38889 .39882 .38639 Metetra
.928 .769 .663 r
.39882 .38639 .4012 .38889 .41512 .35516 .41277 .35264 Metetra
.931 .767 .655 r
.41277 .35264 .41512 .35516 .42891 .32019 .4266 .31764 Metetra
.934 .764 .648 r
.4266 .31764 .42891 .32019 .44254 .28397 .44027 .28138 Metetra
.589 .724 .937 r
.44027 .28138 .44254 .28397 .45521 .28205 .45296 .27868 Metetra
.919 .54 .129 r
.45296 .27868 .45521 .28205 .46708 .32783 .46481 .32445 Metetra
.927 .552 .15 r
.46481 .32445 .46708 .32783 .47936 .3785 .47705 .37511 Metetra
.882 .483 .036 r
.47705 .37511 .47936 .3785 .49229 .41673 .48995 .41417 Metetra
.645 .763 .934 r
.48995 .41417 .49229 .41673 .50589 .41225 .50356 .40968 Metetra
.645 .763 .934 r
.50356 .40968 .50589 .41225 .51955 .40775 .51724 .40517 Metetra
.645 .763 .934 r
.51724 .40517 .51955 .40775 .53329 .40322 .53099 .40063 Metetra
.645 .763 .934 r
.53099 .40063 .53329 .40322 .54709 .39868 .54481 .39607 Metetra
.645 .763 .934 r
.54481 .39607 .54709 .39868 .56097 .39411 .5587 .39148 Metetra
.645 .763 .934 r
.5587 .39148 .56097 .39411 .57491 .38951 .57266 .38688 Metetra
.645 .763 .934 r
.57266 .38688 .57491 .38951 .58893 .3849 .58669 .38225 Metetra
.645 .763 .934 r
.58669 .38225 .58893 .3849 .60301 .38026 .60079 .37759 Metetra
.645 .763 .934 r
.60079 .37759 .60301 .38026 .61717 .37559 .61496 .37292 Metetra
.645 .763 .934 r
.61496 .37292 .61717 .37559 .6314 .3709 .62921 .36821 Metetra
.645 .763 .934 r
.62921 .36821 .6314 .3709 .6457 .36619 .64352 .36349 Metetra
.645 .763 .934 r
.64352 .36349 .6457 .36619 .66008 .36146 .65791 .35874 Metetra
.645 .763 .934 r
.65791 .35874 .66008 .36146 .67453 .3567 .67238 .35397 Metetra
.645 .763 .934 r
.67238 .35397 .67453 .3567 .68905 .35191 .68692 .34917 Metetra
.645 .763 .934 r
.68692 .34917 .68905 .35191 .70365 .3471 .70153 .34435 Metetra
.645 .763 .934 r
.70153 .34435 .70365 .3471 .71832 .34227 .71622 .3395 Metetra
.645 .763 .934 r
.71622 .3395 .71832 .34227 .73307 .33741 .73099 .33462 Metetra
.645 .763 .934 r
.73099 .33462 .73307 .33741 .7479 .33253 .74583 .32973 Metetra
.645 .763 .934 r
.74583 .32973 .7479 .33253 .7628 .32762 .76075 .3248 Metetra
.428 .564 .889 r
.09948 .35155 .10187 .35487 .11216 .35634 .1098 .35284 Metetra
.818 .7 .734 r
.1098 .35284 .11216 .35634 .1248 .33988 .12249 .33606 Metetra
.348 .483 .854 r
.12249 .33606 .1248 .33988 .13478 .34471 .13269 .33914 Metetra
.736 .608 .715 r
.13269 .33914 .13478 .34471 .14685 .33302 .14486 .32657 Metetra
.736 .59 .693 r
.14486 .32657 .14685 .33302 .1593 .31799 .15725 .31211 Metetra
.759 .613 .697 r
.15725 .31211 .1593 .31799 .17215 .29918 .16979 .29607 Metetra
.499 .616 .899 r
.16979 .29607 .17215 .29918 .18342 .29429 .18054 .29595 Metetra
.658 .19 .13 r
.18054 .29595 .18342 .29429 .19337 .30233 .19049 .30402 Metetra
.674 .212 .147 r
.19049 .30402 .19337 .30233 .20335 .3112 .20049 .31292 Metetra
.20049 .31292 .20335 .3112 .21473 .30746 .21222 .30591 Metetra
.525 .787 .993 r
.21222 .30591 .21473 .30746 .22605 .30489 .22349 .30397 Metetra
.914 .539 .299 r
.22349 .30397 .22605 .30489 .23404 .33918 .23145 .33831 Metetra
.687 .904 .973 r
.23145 .33831 .23404 .33918 .24593 .33306 .2433 .33275 Metetra
.835 .95 .894 r
.2433 .33275 .24593 .33306 .25807 .32434 .25562 .32228 Metetra
.592 .762 .96 r
.25562 .32228 .25807 .32434 .26976 .32151 .26731 .31954 Metetra
.896 .788 .733 r
.26731 .31954 .26976 .32151 .28296 .29996 .28053 .29797 Metetra
.9 .786 .726 r
.28053 .29797 .28296 .29996 .29615 .27755 .29375 .27552 Metetra
.878 .796 .765 r
.29375 .27552 .29615 .27755 .30889 .26031 .30654 .25793 Metetra
.809 .346 0 r
.30654 .25793 .30889 .26031 .31917 .2795 .31681 .27713 Metetra
.832 .377 0 r
.31681 .27713 .31917 .2795 .32957 .30052 .3272 .29814 Metetra
.851 .405 0 r
.3272 .29814 .32957 .30052 .3401 .32353 .33772 .32116 Metetra
.905 .774 .706 r
.33772 .32116 .3401 .32353 .35355 .29812 .35119 .29585 Metetra
.86 .418 .016 r
.35119 .29585 .35355 .29812 .36435 .32257 .36198 .32031 Metetra
.954 .617 .328 r
.36198 .32031 .36435 .32257 .37313 .39573 .37071 .39351 Metetra
.829 .37 0 r
.37071 .39351 .37313 .39573 .38474 .41892 .38232 .41632 Metetra
.922 .766 .671 r
.38232 .41632 .38474 .41892 .39882 .38639 .39643 .38376 Metetra
.925 .764 .663 r
.39643 .38376 .39882 .38639 .41277 .35264 .41043 .34998 Metetra
.928 .762 .655 r
.41043 .34998 .41277 .35264 .4266 .31764 .42428 .31496 Metetra
.931 .76 .648 r
.42428 .31496 .4266 .31764 .44027 .28138 .43799 .27867 Metetra
.557 .7 .935 r
.43799 .27867 .44027 .28138 .45296 .27868 .45067 .27678 Metetra
.927 .541 .198 r
.45067 .27678 .45296 .27868 .46481 .32445 .46249 .32259 Metetra
.932 .551 .214 r
.46249 .32259 .46481 .32445 .47705 .37511 .47472 .37329 Metetra
.903 .491 .128 r
.47472 .37329 .47705 .37511 .48995 .41417 .4876 .41161 Metetra
.645 .763 .934 r
.4876 .41161 .48995 .41417 .50356 .40968 .50123 .4071 Metetra
.645 .763 .934 r
.50123 .4071 .50356 .40968 .51724 .40517 .51493 .40258 Metetra
.645 .763 .934 r
.51493 .40258 .51724 .40517 .53099 .40063 .52869 .39802 Metetra
.645 .763 .934 r
.52869 .39802 .53099 .40063 .54481 .39607 .54252 .39345 Metetra
.645 .763 .934 r
.54252 .39345 .54481 .39607 .5587 .39148 .55643 .38885 Metetra
.645 .763 .934 r
.55643 .38885 .5587 .39148 .57266 .38688 .5704 .38423 Metetra
.645 .763 .934 r
.5704 .38423 .57266 .38688 .58669 .38225 .58444 .37959 Metetra
.645 .763 .934 r
.58444 .37959 .58669 .38225 .60079 .37759 .59856 .37492 Metetra
.645 .763 .934 r
.59856 .37492 .60079 .37759 .61496 .37292 .61275 .37023 Metetra
.645 .763 .934 r
.61275 .37023 .61496 .37292 .62921 .36821 .62701 .36552 Metetra
.645 .763 .934 r
.62701 .36552 .62921 .36821 .64352 .36349 .64134 .36078 Metetra
.645 .763 .934 r
.64134 .36078 .64352 .36349 .65791 .35874 .65574 .35602 Metetra
.645 .763 .934 r
.65574 .35602 .65791 .35874 .67238 .35397 .67022 .35123 Metetra
.645 .763 .934 r
.67022 .35123 .67238 .35397 .68692 .34917 .68478 .34642 Metetra
.645 .763 .934 r
.68478 .34642 .68692 .34917 .70153 .34435 .69941 .34158 Metetra
.645 .763 .934 r
.69941 .34158 .70153 .34435 .71622 .3395 .71411 .33672 Metetra
.645 .763 .934 r
.71411 .33672 .71622 .3395 .73099 .33462 .7289 .33183 Metetra
.645 .763 .934 r
.7289 .33183 .73099 .33462 .74583 .32973 .74376 .32692 Metetra
.645 .763 .934 r
.74376 .32692 .74583 .32973 .76075 .3248 .75869 .32198 Metetra
.29 .584 .942 r
.09697 .34916 .09948 .35155 .1098 .35284 .10719 .35113 Metetra
.869 .79 .77 r
.10719 .35113 .1098 .35284 .12249 .33606 .1199 .33444 Metetra
0 .386 .785 r
.1199 .33444 .12249 .33606 .13269 .33914 .12996 .3386 Metetra
.866 .899 .855 r
.12996 .3386 .13269 .33914 .14486 .32657 .1421 .3265 Metetra
.9 .917 .824 r
.1421 .3265 .14486 .32657 .15725 .31211 .15451 .31201 Metetra
.926 .883 .773 r
.15451 .31201 .15725 .31211 .16979 .29607 .16738 .29339 Metetra
.583 .69 .915 r
.16738 .29339 .16979 .29607 .18054 .29595 .17835 .29129 Metetra
.099 .275 .755 r
.17835 .29129 .18054 .29595 .19049 .30402 .1883 .29933 Metetra
.045 .239 .738 r
.1883 .29933 .19049 .30402 .20049 .31292 .19828 .30821 Metetra
.651 .596 .781 r
.19828 .30821 .20049 .31292 .21222 .30591 .20982 .30316 Metetra
.602 .696 .909 r
.20982 .30316 .21222 .30591 .22349 .30397 .22115 .30055 Metetra
.934 .559 .19 r
.22115 .30055 .22349 .30397 .23145 .33831 .22909 .33488 Metetra
.686 .679 .838 r
.22909 .33488 .23145 .33831 .2433 .33275 .24097 .32914 Metetra
.744 .689 .799 r
.24097 .32914 .2433 .33275 .25562 .32228 .25318 .31999 Metetra
.58 .735 .949 r
.25318 .31999 .25562 .32228 .26731 .31954 .26485 .31761 Metetra
.898 .79 .734 r
.26485 .31761 .26731 .31954 .28053 .29797 .2781 .29601 Metetra
.901 .788 .726 r
.2781 .29601 .28053 .29797 .29375 .27552 .29134 .27354 Metetra
.887 .795 .753 r
.29134 .27354 .29375 .27552 .30654 .25793 .30425 .25459 Metetra
.731 .296 0 r
.30425 .25459 .30654 .25793 .31681 .27713 .31451 .27377 Metetra
.769 .337 0 r
.31451 .27377 .31681 .27713 .3272 .29814 .32489 .29477 Metetra
.8 .373 0 r
.32489 .29477 .3272 .29814 .33772 .32116 .33539 .31777 Metetra
.877 .733 .699 r
.33539 .31777 .33772 .32116 .35119 .29585 .34886 .29294 Metetra
.838 .403 0 r
.34886 .29294 .35119 .29585 .36198 .32031 .35963 .31738 Metetra
.958 .621 .316 r
.35963 .31738 .36198 .32031 .37071 .39351 .36831 .3906 Metetra
.806 .359 0 r
.36831 .3906 .37071 .39351 .38232 .41632 .37989 .41403 Metetra
.93 .778 .671 r
.37989 .41403 .38232 .41632 .39643 .38376 .39403 .38144 Metetra
.932 .775 .663 r
.39403 .38144 .39643 .38376 .41043 .34998 .40806 .34763 Metetra
.935 .773 .656 r
.40806 .34763 .41043 .34998 .42428 .31496 .42195 .31257 Metetra
.938 .77 .648 r
.42195 .31257 .42428 .31496 .43799 .27867 .4357 .27626 Metetra
.586 .74 .949 r
.4357 .27626 .43799 .27867 .45067 .27678 .44841 .27351 Metetra
.921 .54 .135 r
.44841 .27351 .45067 .27678 .46249 .32259 .46021 .31931 Metetra
.928 .552 .156 r
.46021 .31931 .46249 .32259 .47472 .37329 .47239 .37001 Metetra
.885 .485 .044 r
.47239 .37001 .47472 .37329 .4876 .41161 .48525 .40904 Metetra
.645 .763 .934 r
.48525 .40904 .4876 .41161 .50123 .4071 .49889 .40452 Metetra
.645 .763 .934 r
.49889 .40452 .50123 .4071 .51493 .40258 .5126 .39998 Metetra
.645 .763 .934 r
.5126 .39998 .51493 .40258 .52869 .39802 .52638 .39541 Metetra
.645 .763 .934 r
.52638 .39541 .52869 .39802 .54252 .39345 .54023 .39083 Metetra
.645 .763 .934 r
.54023 .39083 .54252 .39345 .55643 .38885 .55414 .38622 Metetra
.645 .763 .934 r
.55414 .38622 .55643 .38885 .5704 .38423 .56813 .38158 Metetra
.645 .763 .934 r
.56813 .38158 .5704 .38423 .58444 .37959 .58219 .37693 Metetra
.645 .763 .934 r
.58219 .37693 .58444 .37959 .59856 .37492 .59632 .37225 Metetra
.645 .763 .934 r
.59632 .37225 .59856 .37492 .61275 .37023 .61052 .36754 Metetra
.645 .763 .934 r
.61052 .36754 .61275 .37023 .62701 .36552 .6248 .36281 Metetra
.645 .763 .934 r
.6248 .36281 .62701 .36552 .64134 .36078 .63915 .35806 Metetra
.645 .763 .934 r
.63915 .35806 .64134 .36078 .65574 .35602 .65357 .35328 Metetra
.645 .763 .934 r
.65357 .35328 .65574 .35602 .67022 .35123 .66806 .34848 Metetra
.645 .763 .934 r
.66806 .34848 .67022 .35123 .68478 .34642 .68263 .34365 Metetra
.645 .763 .934 r
.68263 .34365 .68478 .34642 .69941 .34158 .69728 .3388 Metetra
.645 .763 .934 r
.69728 .3388 .69941 .34158 .71411 .33672 .712 .33393 Metetra
.645 .763 .934 r
.712 .33393 .71411 .33672 .7289 .33183 .7268 .32902 Metetra
.645 .763 .934 r
.7268 .32902 .7289 .33183 .74376 .32692 .74168 .3241 Metetra
.645 .763 .934 r
.74168 .3241 .74376 .32692 .75869 .32198 .75663 .31914 Metetra
.353 .598 .939 r
.09447 .34659 .09697 .34916 .10719 .35113 .10476 .3481 Metetra
.825 .721 .75 r
.10476 .3481 .10719 .35113 .1199 .33444 .11737 .33227 Metetra
.113 .505 .907 r
.11737 .33227 .1199 .33444 .12996 .3386 .12754 .33553 Metetra
.795 .718 .78 r
.12754 .33553 .12996 .3386 .1421 .3265 .1397 .32336 Metetra
.814 .718 .759 r
.1397 .32336 .1421 .3265 .15451 .31201 .15213 .30885 Metetra
.838 .719 .734 r
.15213 .30885 .15451 .31201 .16738 .29339 .16495 .2908 Metetra
.534 .679 .931 r
.16495 .2908 .16738 .29339 .17835 .29129 .17582 .28966 Metetra
.519 0 0 r
.17582 .28966 .17835 .29129 .1883 .29933 .18576 .2977 Metetra
.572 .018 0 r
.18576 .2977 .1883 .29933 .19828 .30821 .19575 .30659 Metetra
.732 .831 .926 r
.19575 .30659 .19828 .30821 .20982 .30316 .20742 .30032 Metetra
.547 .666 .915 r
.20742 .30032 .20982 .30316 .22115 .30055 .21863 .29899 Metetra
.923 .546 .276 r
.21863 .29899 .22115 .30055 .22909 .33488 .22655 .33334 Metetra
.735 .846 .932 r
.22655 .33334 .22909 .33488 .24097 .32914 .23851 .32684 Metetra
.776 .781 .857 r
.23851 .32684 .24097 .32914 .25318 .31999 .25071 .31791 Metetra
.585 .759 .962 r
.25071 .31791 .25318 .31999 .26485 .31761 .26241 .3153 Metetra
.887 .772 .729 r
.26241 .3153 .26485 .31761 .2781 .29601 .27569 .29369 Metetra
.891 .771 .722 r
.27569 .29369 .2781 .29601 .29134 .27354 .28896 .27119 Metetra
.877 .776 .746 r
.28896 .27119 .29134 .27354 .30425 .25459 .3019 .25203 Metetra
.8 .339 0 r
.3019 .25203 .30425 .25459 .31451 .27377 .31215 .27121 Metetra
.824 .372 0 r
.31215 .27121 .31451 .27377 .32489 .29477 .32251 .29221 Metetra
.845 .401 0 r
.32251 .29221 .32489 .29477 .33539 .31777 .333 .31521 Metetra
.9 .767 .706 r
.333 .31521 .33539 .31777 .34886 .29294 .34652 .29007 Metetra
.849 .416 0 r
.34652 .29007 .34886 .29294 .35963 .31738 .35724 .31524 Metetra
.954 .616 .331 r
.35724 .31524 .35963 .31738 .36831 .3906 .36586 .38851 Metetra
.827 .362 0 r
.36586 .38851 .36831 .3906 .37989 .41403 .37749 .41071 Metetra
.906 .743 .668 r
.37749 .41071 .37989 .41403 .39403 .38144 .39166 .37811 Metetra
.91 .742 .661 r
.39166 .37811 .39403 .38144 .40806 .34763 .40572 .34428 Metetra
.914 .741 .654 r
.40572 .34428 .40806 .34763 .42195 .31257 .41965 .30921 Metetra
.917 .74 .647 r
.41965 .30921 .42195 .31257 .4357 .27626 .43343 .27288 Metetra
.538 .636 .896 r
.43343 .27288 .4357 .27626 .44841 .27351 .44611 .27175 Metetra
.927 .541 .205 r
.44611 .27175 .44841 .27351 .46021 .31931 .45788 .3176 Metetra
.931 .551 .22 r
.45788 .3176 .46021 .31931 .47239 .37001 .47004 .36835 Metetra
.903 .49 .135 r
.47004 .36835 .47239 .37001 .48525 .40904 .48289 .40646 Metetra
.645 .763 .934 r
.48289 .40646 .48525 .40904 .49889 .40452 .49655 .40193 Metetra
.645 .763 .934 r
.49655 .40193 .49889 .40452 .5126 .39998 .51027 .39737 Metetra
.645 .763 .934 r
.51027 .39737 .5126 .39998 .52638 .39541 .52406 .3928 Metetra
.645 .763 .934 r
.52406 .3928 .52638 .39541 .54023 .39083 .53793 .3882 Metetra
.645 .763 .934 r
.53793 .3882 .54023 .39083 .55414 .38622 .55186 .38357 Metetra
.645 .763 .934 r
.55186 .38357 .55414 .38622 .56813 .38158 .56586 .37893 Metetra
.645 .763 .934 r
.56586 .37893 .56813 .38158 .58219 .37693 .57993 .37425 Metetra
.645 .763 .934 r
.57993 .37425 .58219 .37693 .59632 .37225 .59408 .36956 Metetra
.645 .763 .934 r
.59408 .36956 .59632 .37225 .61052 .36754 .60829 .36484 Metetra
.645 .763 .934 r
.60829 .36484 .61052 .36754 .6248 .36281 .62258 .3601 Metetra
.645 .763 .934 r
.62258 .3601 .6248 .36281 .63915 .35806 .63695 .35533 Metetra
.645 .763 .934 r
.63695 .35533 .63915 .35806 .65357 .35328 .65138 .35054 Metetra
.645 .763 .934 r
.65138 .35054 .65357 .35328 .66806 .34848 .6659 .34573 Metetra
.645 .763 .934 r
.6659 .34573 .66806 .34848 .68263 .34365 .68048 .34089 Metetra
.645 .763 .934 r
.68048 .34089 .68263 .34365 .69728 .3388 .69514 .33602 Metetra
.645 .763 .934 r
.69514 .33602 .69728 .3388 .712 .33393 .70988 .33113 Metetra
.645 .763 .934 r
.70988 .33113 .712 .33393 .7268 .32902 .7247 .32621 Metetra
.645 .763 .934 r
.7247 .32621 .7268 .32902 .74168 .3241 .73959 .32127 Metetra
.645 .763 .934 r
.73959 .32127 .74168 .3241 .75663 .31914 .75456 .3163 Metetra
.35 .579 .928 r
.09199 .34384 .09447 .34659 .10476 .3481 .10225 .34558 Metetra
.841 .747 .76 r
.10225 .34558 .10476 .3481 .11737 .33227 .11489 .3296 Metetra
.235 .524 .916 r
.11489 .3296 .11737 .33227 .12754 .33553 .12511 .33254 Metetra
.798 .724 .782 r
.12511 .33254 .12754 .33553 .1397 .32336 .13729 .32031 Metetra
.817 .723 .761 r
.13729 .32031 .1397 .32336 .15213 .30885 .14973 .3058 Metetra
.839 .724 .737 r
.14973 .3058 .15213 .30885 .16495 .2908 .16254 .288 Metetra
.482 .638 .924 r
.16254 .288 .16495 .2908 .17582 .28966 .17329 .28792 Metetra
.501 0 0 r
.17329 .28792 .17582 .28966 .18576 .2977 .18323 .29597 Metetra
.556 .007 0 r
.18323 .29597 .18576 .2977 .19575 .30659 .19322 .30486 Metetra
.744 .822 .913 r
.19322 .30486 .19575 .30659 .20742 .30032 .20494 .29813 Metetra
.53 .722 .962 r
.20494 .29813 .20742 .30032 .21863 .29899 .21618 .2967 Metetra
.931 .553 .247 r
.21618 .2967 .21863 .29899 .22655 .33334 .22407 .33107 Metetra
.727 .777 .892 r
.22407 .33107 .22655 .33334 .23851 .32684 .23604 .32452 Metetra
.771 .78 .861 r
.23604 .32452 .23851 .32684 .25071 .31791 .24823 .31589 Metetra
.585 .765 .965 r
.24823 .31589 .25071 .31791 .26241 .3153 .25994 .31323 Metetra
.894 .784 .732 r
.25994 .31323 .26241 .3153 .27569 .29369 .27325 .29159 Metetra
.898 .782 .725 r
.27325 .29159 .27569 .29369 .28896 .27119 .28654 .26907 Metetra
.887 .786 .744 r
.28654 .26907 .28896 .27119 .3019 .25203 .29956 .24922 Metetra
.783 .328 0 r
.29956 .24922 .3019 .25203 .31215 .27121 .3098 .26839 Metetra
.811 .363 0 r
.3098 .26839 .31215 .27121 .32251 .29221 .32015 .28939 Metetra
.835 .394 0 r
.32015 .28939 .32251 .29221 .333 .31521 .33063 .31239 Metetra
.893 .756 .703 r
.33063 .31239 .333 .31521 .34652 .29007 .34417 .28718 Metetra
.854 .425 0 r
.34417 .28718 .34652 .29007 .35724 .31524 .35485 .31294 Metetra
.954 .617 .328 r
.35485 .31294 .35724 .31524 .36586 .38851 .36342 .38625 Metetra
.819 .355 0 r
.36342 .38625 .36586 .38851 .37749 .41071 .37504 .4083 Metetra
.927 .773 .671 r
.37504 .4083 .37749 .41071 .39166 .37811 .38925 .37566 Metetra
.93 .771 .663 r
.38925 .37566 .39166 .37811 .40572 .34428 .40335 .3418 Metetra
.933 .769 .656 r
.40335 .3418 .40572 .34428 .41965 .30921 .41731 .3067 Metetra
.935 .767 .648 r
.41731 .3067 .41965 .30921 .43343 .27288 .43113 .27034 Metetra
.519 .701 .953 r
.43113 .27034 .43343 .27288 .44611 .27175 .44382 .26909 Metetra
.926 .542 .165 r
.44382 .26909 .44611 .27175 .45788 .3176 .45556 .31494 Metetra
.932 .553 .184 r
.45556 .31494 .45788 .3176 .47004 .36835 .4677 .36571 Metetra
.895 .486 .078 r
.4677 .36571 .47004 .36835 .48289 .40646 .48053 .40387 Metetra
.645 .763 .934 r
.48053 .40387 .48289 .40646 .49655 .40193 .4942 .39933 Metetra
.645 .763 .934 r
.4942 .39933 .49655 .40193 .51027 .39737 .50793 .39476 Metetra
.645 .763 .934 r
.50793 .39476 .51027 .39737 .52406 .3928 .52174 .39017 Metetra
.645 .763 .934 r
.52174 .39017 .52406 .3928 .53793 .3882 .53562 .38556 Metetra
.645 .763 .934 r
.53562 .38556 .53793 .3882 .55186 .38357 .54956 .38092 Metetra
.645 .763 .934 r
.54956 .38092 .55186 .38357 .56586 .37893 .56358 .37626 Metetra
.645 .763 .934 r
.56358 .37626 .56586 .37893 .57993 .37425 .57767 .37158 Metetra
.645 .763 .934 r
.57767 .37158 .57993 .37425 .59408 .36956 .59183 .36687 Metetra
.645 .763 .934 r
.59183 .36687 .59408 .36956 .60829 .36484 .60606 .36214 Metetra
.645 .763 .934 r
.60606 .36214 .60829 .36484 .62258 .3601 .62036 .35738 Metetra
.645 .763 .934 r
.62036 .35738 .62258 .3601 .63695 .35533 .63474 .3526 Metetra
.645 .763 .934 r
.63474 .3526 .63695 .35533 .65138 .35054 .64919 .34779 Metetra
.645 .763 .934 r
.64919 .34779 .65138 .35054 .6659 .34573 .66372 .34296 Metetra
.645 .763 .934 r
.66372 .34296 .6659 .34573 .68048 .34089 .67832 .33811 Metetra
.645 .763 .934 r
.67832 .33811 .68048 .34089 .69514 .33602 .693 .33323 Metetra
.645 .763 .934 r
.693 .33323 .69514 .33602 .70988 .33113 .70776 .32832 Metetra
.645 .763 .934 r
.70776 .32832 .70988 .33113 .7247 .32621 .72259 .32339 Metetra
.645 .763 .934 r
.72259 .32339 .7247 .32621 .73959 .32127 .7375 .31843 Metetra
.645 .763 .934 r
.7375 .31843 .73959 .32127 .75456 .3163 .75249 .31345 Metetra
.301 .633 .964 r
.0894 .34183 .09199 .34384 .10225 .34558 .09972 .3431 Metetra
.834 .751 .772 r
.09972 .3431 .10225 .34558 .11489 .3296 .11223 .32832 Metetra
0 .469 .812 r
.11223 .32832 .11489 .3296 .12511 .33254 .12245 .33128 Metetra
.847 .843 .84 r
.12245 .33128 .12511 .33254 .13729 .32031 .1346 .31939 Metetra
.881 .856 .812 r
.1346 .31939 .13729 .32031 .14973 .3058 .14707 .30485 Metetra
.906 .832 .762 r
.14707 .30485 .14973 .3058 .16254 .288 .16005 .28581 Metetra
.552 .726 .955 r
.16005 .28581 .16254 .288 .17329 .28792 .171 .28407 Metetra
0 .246 .758 r
.171 .28407 .17329 .28792 .18323 .29597 .18093 .2921 Metetra
0 .2 .729 r
.18093 .2921 .18323 .29597 .19322 .30486 .19091 .30097 Metetra
.689 .652 .808 r
.19091 .30097 .19322 .30486 .20494 .29813 .20259 .2947 Metetra
.511 .604 .882 r
.20259 .2947 .20494 .29813 .21618 .2967 .21372 .29442 Metetra
.931 .553 .247 r
.21372 .29442 .21618 .2967 .22407 .33107 .22158 .32879 Metetra
.752 .781 .877 r
.22158 .32879 .22407 .33107 .23604 .32452 .23366 .32119 Metetra
.728 .701 .825 r
.23366 .32119 .23604 .32452 .24823 .31589 .24578 .31344 Metetra
.601 .73 .935 r
.24578 .31344 .24823 .31589 .25994 .31323 .25751 .31064 Metetra
.88 .76 .726 r
.25751 .31064 .25994 .31323 .27325 .29159 .27084 .28898 Metetra
.884 .759 .719 r
.27084 .28898 .27325 .29159 .28654 .26907 .28416 .26645 Metetra
.873 .761 .736 r
.28416 .26645 .28654 .26907 .29956 .24922 .29721 .24659 Metetra
.796 .336 0 r
.29721 .24659 .29956 .24922 .3098 .26839 .30743 .26576 Metetra
.821 .37 0 r
.30743 .26576 .3098 .26839 .32015 .28939 .31777 .28676 Metetra
.843 .4 0 r
.31777 .28676 .32015 .28939 .33063 .31239 .32824 .30976 Metetra
.899 .764 .704 r
.32824 .30976 .33063 .31239 .34417 .28718 .34182 .28436 Metetra
.86 .431 0 r
.34182 .28436 .34417 .28718 .35485 .31294 .35246 .31045 Metetra
.956 .618 .325 r
.35246 .31045 .35485 .31294 .36342 .38625 .36098 .3838 Metetra
.795 .328 0 r
.36098 .3838 .36342 .38625 .37504 .4083 .37263 .40488 Metetra
.905 .74 .668 r
.37263 .40488 .37504 .4083 .38925 .37566 .38688 .37223 Metetra
.908 .74 .661 r
.38688 .37223 .38925 .37566 .40335 .3418 .401 .33836 Metetra
.912 .739 .654 r
.401 .33836 .40335 .3418 .41731 .3067 .415 .30325 Metetra
.916 .738 .647 r
.415 .30325 .41731 .3067 .43113 .27034 .42885 .26687 Metetra
.484 .604 .896 r
.42885 .26687 .43113 .27034 .44382 .26909 .44151 .26707 Metetra
.927 .541 .194 r
.44151 .26707 .44382 .26909 .45556 .31494 .45323 .31296 Metetra
.932 .552 .21 r
.45323 .31296 .45556 .31494 .4677 .36571 .46533 .36377 Metetra
.9 .486 .114 r
.46533 .36377 .4677 .36571 .48053 .40387 .47816 .40128 Metetra
.645 .763 .934 r
.47816 .40128 .48053 .40387 .4942 .39933 .49184 .39672 Metetra
.645 .763 .934 r
.49184 .39672 .4942 .39933 .50793 .39476 .50559 .39214 Metetra
.645 .763 .934 r
.50559 .39214 .50793 .39476 .52174 .39017 .51941 .38754 Metetra
.645 .763 .934 r
.51941 .38754 .52174 .39017 .53562 .38556 .5333 .38291 Metetra
.645 .763 .934 r
.5333 .38291 .53562 .38556 .54956 .38092 .54726 .37826 Metetra
.645 .763 .934 r
.54726 .37826 .54956 .38092 .56358 .37626 .56129 .37359 Metetra
.645 .763 .934 r
.56129 .37359 .56358 .37626 .57767 .37158 .57539 .36889 Metetra
.645 .763 .934 r
.57539 .36889 .57767 .37158 .59183 .36687 .58957 .36417 Metetra
.645 .763 .934 r
.58957 .36417 .59183 .36687 .60606 .36214 .60382 .35942 Metetra
.645 .763 .934 r
.60382 .35942 .60606 .36214 .62036 .35738 .61814 .35465 Metetra
.645 .763 .934 r
.61814 .35465 .62036 .35738 .63474 .3526 .63253 .34986 Metetra
.645 .763 .934 r
.63253 .34986 .63474 .3526 .64919 .34779 .647 .34504 Metetra
.645 .763 .934 r
.647 .34504 .64919 .34779 .66372 .34296 .66154 .34019 Metetra
.645 .763 .934 r
.66154 .34019 .66372 .34296 .67832 .33811 .67616 .33532 Metetra
.645 .763 .934 r
.67616 .33532 .67832 .33811 .693 .33323 .69086 .33043 Metetra
.645 .763 .934 r
.69086 .33043 .693 .33323 .70776 .32832 .70563 .32551 Metetra
.645 .763 .934 r
.70563 .32551 .70776 .32832 .72259 .32339 .72047 .32056 Metetra
.645 .763 .934 r
.72047 .32056 .72259 .32339 .7375 .31843 .7354 .31559 Metetra
.645 .763 .934 r
.7354 .31559 .7375 .31843 .75249 .31345 .75041 .31059 Metetra
.37 .603 .938 r
.08689 .33921 .0894 .34183 .09972 .3431 .09721 .34052 Metetra
.836 .745 .764 r
.09721 .34052 .09972 .3431 .11223 .32832 .10982 .32505 Metetra
.343 .527 .892 r
.10982 .32505 .11223 .32832 .12245 .33128 .1201 .32749 Metetra
.776 .682 .759 r
.1201 .32749 .12245 .33128 .1346 .31939 .13232 .31517 Metetra
.785 .669 .735 r
.13232 .31517 .1346 .31939 .14707 .30485 .1448 .30063 Metetra
.806 .675 .719 r
.1448 .30063 .14707 .30485 .16005 .28581 .1576 .28325 Metetra
.448 .647 .943 r
.1576 .28325 .16005 .28581 .171 .28407 .16832 .28347 Metetra
.633 .071 0 r
.16832 .28347 .171 .28407 .18093 .2921 .17826 .29151 Metetra
.665 .113 0 r
.17826 .29151 .18093 .2921 .19091 .30097 .18824 .30039 Metetra
.76 .932 .943 r
.18824 .30039 .19091 .30097 .20259 .2947 .20006 .29296 Metetra
.439 .733 .989 r
.20006 .29296 .20259 .2947 .21372 .29442 .21123 .29233 Metetra
.929 .551 .256 r
.21123 .29233 .21372 .29442 .22158 .32879 .21906 .32672 Metetra
.741 .797 .898 r
.21906 .32672 .22158 .32879 .23366 .32119 .2311 .31976 Metetra
.793 .859 .899 r
.2311 .31976 .23366 .32119 .24578 .31344 .24333 .31098 Metetra
.601 .729 .934 r
.24333 .31098 .24578 .31344 .25751 .31064 .25506 .30817 Metetra
.883 .765 .727 r
.25506 .30817 .25751 .31064 .27084 .28898 .26842 .28649 Metetra
.887 .764 .72 r
.26842 .28649 .27084 .28898 .28416 .26645 .28177 .26394 Metetra
.875 .767 .74 r
.28177 .26394 .28416 .26645 .29721 .24659 .29482 .24431 Metetra
.815 .35 0 r
.29482 .24431 .29721 .24659 .30743 .26576 .30503 .26348 Metetra
.837 .38 0 r
.30503 .26348 .30743 .26576 .31777 .28676 .31536 .28449 Metetra
.855 .408 .007 r
.31536 .28449 .31777 .28676 .32824 .30976 .32581 .30749 Metetra
.909 .78 .707 r
.32581 .30749 .32824 .30976 .34182 .28436 .33942 .28207 Metetra
.873 .438 .046 r
.33942 .28207 .34182 .28436 .35246 .31045 .35006 .30798 Metetra
.955 .618 .325 r
.35006 .30798 .35246 .31045 .36098 .3838 .35853 .38136 Metetra
.801 .336 0 r
.35853 .38136 .36098 .3838 .37263 .40488 .37016 .40275 Metetra
.933 .784 .672 r
.37016 .40275 .37263 .40488 .38688 .37223 .38444 .37007 Metetra
.936 .781 .664 r
.38444 .37007 .38688 .37223 .401 .33836 .39861 .33616 Metetra
.939 .778 .656 r
.39861 .33616 .401 .33836 .415 .30325 .41264 .30101 Metetra
.941 .776 .648 r
.41264 .30101 .415 .30325 .42885 .26687 .42653 .2646 Metetra
.443 .693 .972 r
.42653 .2646 .42885 .26687 .44151 .26707 .43921 .26436 Metetra
.926 .542 .164 r
.43921 .26436 .44151 .26707 .45323 .31296 .4509 .31026 Metetra
.931 .553 .183 r
.4509 .31026 .45323 .31296 .46533 .36377 .46297 .36109 Metetra
.892 .481 .07 r
.46297 .36109 .46533 .36377 .47816 .40128 .47578 .39868 Metetra
.645 .763 .934 r
.47578 .39868 .47816 .40128 .49184 .39672 .48948 .39411 Metetra
.645 .763 .934 r
.48948 .39411 .49184 .39672 .50559 .39214 .50324 .38951 Metetra
.645 .763 .934 r
.50324 .38951 .50559 .39214 .51941 .38754 .51707 .3849 Metetra
.645 .763 .934 r
.51707 .3849 .51941 .38754 .5333 .38291 .53098 .38026 Metetra
.645 .763 .934 r
.53098 .38026 .5333 .38291 .54726 .37826 .54495 .37559 Metetra
.645 .763 .934 r
.54495 .37559 .54726 .37826 .56129 .37359 .559 .3709 Metetra
.645 .763 .934 r
.559 .3709 .56129 .37359 .57539 .36889 .57312 .36619 Metetra
.645 .763 .934 r
.57312 .36619 .57539 .36889 .58957 .36417 .58731 .36146 Metetra
.645 .763 .934 r
.58731 .36146 .58957 .36417 .60382 .35942 .60157 .3567 Metetra
.645 .763 .934 r
.60157 .3567 .60382 .35942 .61814 .35465 .6159 .35191 Metetra
.645 .763 .934 r
.6159 .35191 .61814 .35465 .63253 .34986 .63031 .3471 Metetra
.645 .763 .934 r
.63031 .3471 .63253 .34986 .647 .34504 .6448 .34227 Metetra
.645 .763 .934 r
.6448 .34227 .647 .34504 .66154 .34019 .65936 .33741 Metetra
.645 .763 .934 r
.65936 .33741 .66154 .34019 .67616 .33532 .67399 .33253 Metetra
.645 .763 .934 r
.67399 .33253 .67616 .33532 .69086 .33043 .6887 .32762 Metetra
.645 .763 .934 r
.6887 .32762 .69086 .33043 .70563 .32551 .70349 .32268 Metetra
.645 .763 .934 r
.70349 .32268 .70563 .32551 .72047 .32056 .71835 .31772 Metetra
.645 .763 .934 r
.71835 .31772 .72047 .32056 .7354 .31559 .7333 .31274 Metetra
.645 .763 .934 r
.7333 .31274 .7354 .31559 .75041 .31059 .74832 .30772 Metetra
.311 .655 .971 r
.08427 .33734 .08689 .33921 .09721 .34052 .09464 .33828 Metetra
.837 .766 .784 r
.09464 .33828 .09721 .34052 .10982 .32505 .1071 .32408 Metetra
0 .42 .728 r
.1071 .32408 .10982 .32505 .1201 .32749 .11732 .32706 Metetra
.865 .91 .861 r
.11732 .32706 .1201 .32749 .13232 .31517 .12951 .31515 Metetra
.9 .92 .824 r
.12951 .31515 .13232 .31517 .1448 .30063 .14202 .30058 Metetra
.929 .881 .766 r
.14202 .30058 .1448 .30063 .1576 .28325 .15508 .28112 Metetra
.585 .746 .953 r
.15508 .28112 .1576 .28325 .16832 .28347 .16612 .2787 Metetra
.102 .273 .753 r
.16612 .2787 .16832 .28347 .17826 .29151 .17605 .28672 Metetra
.049 .238 .736 r
.17605 .28672 .17826 .29151 .18824 .30039 .18602 .29557 Metetra
.67 .603 .772 r
.18602 .29557 .18824 .30039 .20006 .29296 .19772 .28934 Metetra
.485 .578 .874 r
.19772 .28934 .20006 .29296 .21123 .29233 .20878 .28968 Metetra
.933 .556 .232 r
.20878 .28968 .21123 .29233 .21906 .32672 .2166 .32408 Metetra
.747 .752 .856 r
.2166 .32408 .21906 .32672 .2311 .31976 .22872 .31625 Metetra
.73 .693 .815 r
.22872 .31625 .2311 .31976 .24333 .31098 .2409 .30817 Metetra
.596 .697 .913 r
.2409 .30817 .24333 .31098 .25506 .30817 .25262 .30555 Metetra
.879 .759 .725 r
.25262 .30555 .25506 .30817 .26842 .28649 .266 .28385 Metetra
.883 .758 .719 r
.266 .28385 .26842 .28649 .28177 .26394 .27938 .26128 Metetra
.871 .76 .737 r
.27938 .26128 .28177 .26394 .29482 .24431 .29245 .24155 Metetra
.788 .331 0 r
.29245 .24155 .29482 .24431 .30503 .26348 .30266 .26072 Metetra
.815 .366 0 r
.30266 .26072 .30503 .26348 .31536 .28449 .31298 .28172 Metetra
.838 .396 0 r
.31298 .28172 .31536 .28449 .32581 .30749 .32341 .30473 Metetra
.895 .759 .704 r
.32341 .30473 .32581 .30749 .33942 .28207 .33704 .27954 Metetra
.864 .428 .016 r
.33704 .27954 .33942 .28207 .35006 .30798 .34769 .30499 Metetra
.958 .622 .315 r
.34769 .30499 .35006 .30798 .35853 .38136 .3561 .37838 Metetra
.758 .303 0 r
.3561 .37838 .35853 .38136 .37016 .40275 .36774 .39936 Metetra
.905 .742 .668 r
.36774 .39936 .37016 .40275 .38444 .37007 .38205 .36666 Metetra
.909 .741 .661 r
.38205 .36666 .38444 .37007 .39861 .33616 .39625 .33274 Metetra
.913 .74 .654 r
.39625 .33274 .39861 .33616 .41264 .30101 .41032 .29757 Metetra
.917 .739 .647 r
.41032 .29757 .41264 .30101 .42653 .2646 .42424 .26115 Metetra
.444 .586 .9 r
.42424 .26115 .42653 .2646 .43921 .26436 .43689 .26215 Metetra
.927 .542 .187 r
.43689 .26215 .43921 .26436 .4509 .31026 .44855 .30808 Metetra
.932 .552 .203 r
.44855 .30808 .4509 .31026 .46297 .36109 .4606 .35894 Metetra
.897 .482 .099 r
.4606 .35894 .46297 .36109 .47578 .39868 .4734 .39607 Metetra
.645 .763 .934 r
.4734 .39607 .47578 .39868 .48948 .39411 .48711 .39148 Metetra
.645 .763 .934 r
.48711 .39148 .48948 .39411 .50324 .38951 .50088 .38688 Metetra
.645 .763 .934 r
.50088 .38688 .50324 .38951 .51707 .3849 .51473 .38225 Metetra
.645 .763 .934 r
.51473 .38225 .51707 .3849 .53098 .38026 .52865 .37759 Metetra
.645 .763 .934 r
.52865 .37759 .53098 .38026 .54495 .37559 .54264 .37292 Metetra
.645 .763 .934 r
.54264 .37292 .54495 .37559 .559 .3709 .5567 .36821 Metetra
.645 .763 .934 r
.5567 .36821 .559 .3709 .57312 .36619 .57083 .36349 Metetra
.645 .763 .934 r
.57083 .36349 .57312 .36619 .58731 .36146 .58503 .35874 Metetra
.645 .763 .934 r
.58503 .35874 .58731 .36146 .60157 .3567 .59931 .35397 Metetra
.645 .763 .934 r
.59931 .35397 .60157 .3567 .6159 .35191 .61366 .34917 Metetra
.645 .763 .934 r
.61366 .34917 .6159 .35191 .63031 .3471 .62809 .34435 Metetra
.645 .763 .934 r
.62809 .34435 .63031 .3471 .6448 .34227 .64259 .3395 Metetra
.645 .763 .934 r
.64259 .3395 .6448 .34227 .65936 .33741 .65716 .33462 Metetra
.645 .763 .934 r
.65716 .33462 .65936 .33741 .67399 .33253 .67181 .32973 Metetra
.645 .763 .934 r
.67181 .32973 .67399 .33253 .6887 .32762 .68654 .3248 Metetra
.645 .763 .934 r
.68654 .3248 .6887 .32762 .70349 .32268 .70134 .31985 Metetra
.645 .763 .934 r
.70134 .31985 .70349 .32268 .71835 .31772 .71623 .31488 Metetra
.645 .763 .934 r
.71623 .31488 .71835 .31772 .7333 .31274 .73119 .30988 Metetra
.645 .763 .934 r
.73119 .30988 .7333 .31274 .74832 .30772 .74622 .30485 Metetra
.389 .614 .94 r
.08174 .33472 .08427 .33734 .09464 .33828 .0921 .33576 Metetra
.838 .749 .765 r
.0921 .33576 .09464 .33828 .1071 .32408 .10475 .32027 Metetra
.385 .509 .86 r
.10475 .32027 .1071 .32408 .11732 .32706 .11505 .32259 Metetra
.761 .652 .742 r
.11505 .32259 .11732 .32706 .12951 .31515 .12732 .31012 Metetra
.766 .638 .719 r
.12732 .31012 .12951 .31515 .14202 .30058 .13984 .29555 Metetra
.784 .645 .708 r
.13984 .29555 .14202 .30058 .15508 .28112 .15261 .27864 Metetra
.439 .652 .949 r
.15261 .27864 .15508 .28112 .16612 .2787 .16334 .27887 Metetra
.657 .124 0 r
.16334 .27887 .16612 .2787 .17605 .28672 .17327 .28691 Metetra
.681 .158 0 r
.17327 .28691 .17605 .28672 .18602 .29557 .18325 .29578 Metetra
.722 .978 .917 r
.18325 .29578 .18602 .29557 .19772 .28934 .19512 .28804 Metetra
.361 .744 .988 r
.19512 .28804 .19772 .28934 .20878 .28968 .20628 .28758 Metetra
.929 .551 .256 r
.20628 .28758 .20878 .28968 .2166 .32408 .21407 .32199 Metetra
.738 .797 .899 r
.21407 .32199 .2166 .32408 .22872 .31625 .22612 .31513 Metetra
.81 .887 .9 r
.22612 .31513 .22872 .31625 .2409 .30817 .23843 .30574 Metetra
.601 .732 .937 r
.23843 .30574 .2409 .30817 .25262 .30555 .25018 .3029 Metetra
.878 .757 .725 r
.25018 .3029 .25262 .30555 .266 .28385 .26359 .28118 Metetra
.882 .756 .718 r
.26359 .28118 .266 .28385 .27938 .26128 .27698 .25859 Metetra
.867 .759 .742 r
.27698 .25859 .27938 .26128 .29245 .24155 .29003 .23954 Metetra
.826 .358 0 r
.29003 .23954 .29245 .24155 .30266 .26072 .30023 .25872 Metetra
.845 .387 0 r
.30023 .25872 .30266 .26072 .31298 .28172 .31053 .27973 Metetra
.861 .412 .035 r
.31053 .27973 .31298 .28172 .32341 .30473 .32096 .30275 Metetra
.916 .793 .709 r
.32096 .30275 .32341 .30473 .33704 .27954 .33463 .27726 Metetra
.87 .433 .039 r
.33463 .27726 .33704 .27954 .34769 .30499 .34526 .30276 Metetra
.954 .616 .33 r
.34526 .30276 .34769 .30499 .3561 .37838 .35362 .3762 Metetra
.814 .345 0 r
.35362 .3762 .3561 .37838 .36774 .39936 .36523 .39761 Metetra
.942 .798 .672 r
.36523 .39761 .36774 .39936 .38205 .36666 .37958 .36487 Metetra
.944 .794 .664 r
.37958 .36487 .38205 .36666 .39625 .33274 .39382 .33091 Metetra
.947 .791 .656 r
.39382 .33091 .39625 .33274 .41032 .29757 .40793 .2957 Metetra
.949 .788 .647 r
.40793 .2957 .41032 .29757 .42424 .26115 .42189 .25923 Metetra
.392 .706 .985 r
.42189 .25923 .42424 .26115 .43689 .26215 .43458 .25921 Metetra
.925 .542 .154 r
.43458 .25921 .43689 .26215 .44855 .30808 .44622 .30515 Metetra
.931 .553 .174 r
.44622 .30515 .44855 .30808 .4606 .35894 .45823 .35602 Metetra
.887 .478 .053 r
.45823 .35602 .4606 .35894 .4734 .39607 .471 .39345 Metetra
.645 .763 .934 r
.471 .39345 .4734 .39607 .48711 .39148 .48473 .38885 Metetra
.645 .763 .934 r
.48473 .38885 .48711 .39148 .50088 .38688 .49852 .38423 Metetra
.645 .763 .934 r
.49852 .38423 .50088 .38688 .51473 .38225 .51238 .37959 Metetra
.645 .763 .934 r
.51238 .37959 .51473 .38225 .52865 .37759 .52631 .37492 Metetra
.645 .763 .934 r
.52631 .37492 .52865 .37759 .54264 .37292 .54032 .37023 Metetra
.645 .763 .934 r
.54032 .37023 .54264 .37292 .5567 .36821 .55439 .36552 Metetra
.645 .763 .934 r
.55439 .36552 .5567 .36821 .57083 .36349 .56854 .36078 Metetra
.645 .763 .934 r
.56854 .36078 .57083 .36349 .58503 .35874 .58276 .35602 Metetra
.645 .763 .934 r
.58276 .35602 .58503 .35874 .59931 .35397 .59705 .35123 Metetra
.645 .763 .934 r
.59705 .35123 .59931 .35397 .61366 .34917 .61142 .34642 Metetra
.645 .763 .934 r
.61142 .34642 .61366 .34917 .62809 .34435 .62586 .34158 Metetra
.645 .763 .934 r
.62586 .34158 .62809 .34435 .64259 .3395 .64037 .33672 Metetra
.645 .763 .934 r
.64037 .33672 .64259 .3395 .65716 .33462 .65496 .33183 Metetra
.645 .763 .934 r
.65496 .33183 .65716 .33462 .67181 .32973 .66963 .32692 Metetra
.645 .763 .934 r
.66963 .32692 .67181 .32973 .68654 .3248 .68437 .32198 Metetra
.645 .763 .934 r
.68437 .32198 .68654 .3248 .70134 .31985 .69919 .31701 Metetra
.645 .763 .934 r
.69919 .31701 .70134 .31985 .71623 .31488 .71409 .31202 Metetra
.645 .763 .934 r
.71409 .31202 .71623 .31488 .73119 .30988 .72907 .30701 Metetra
.645 .763 .934 r
.72907 .30701 .73119 .30988 .74622 .30485 .74412 .30196 Metetra
.311 .664 .973 r
.0791 .33292 .08174 .33472 .0921 .33576 .08949 .33373 Metetra
.843 .78 .791 r
.08949 .33373 .0921 .33576 .10475 .32027 .10197 .31962 Metetra
.261 0 0 r
.10197 .31962 .10475 .32027 .11505 .32259 .11216 .32283 Metetra
.863 .961 .866 r
.11216 .32283 .11505 .32259 .12732 .31012 .12437 .311 Metetra
.897 .974 .815 r
.12437 .311 .12732 .31012 .13984 .29555 .13692 .29639 Metetra
.943 .926 .759 r
.13692 .29639 .13984 .29555 .15261 .27864 .15008 .27652 Metetra
.626 .759 .942 r
.15008 .27652 .15261 .27864 .16334 .27887 .16124 .2732 Metetra
.191 .284 .731 r
.16124 .2732 .16334 .27887 .17327 .28691 .17116 .2812 Metetra
.149 .257 .72 r
.17116 .2812 .17327 .28691 .18325 .29578 .18112 .29004 Metetra
.647 .561 .744 r
.18112 .29004 .18325 .29578 .19512 .28804 .19279 .28422 Metetra
.488 .567 .862 r
.19279 .28422 .19512 .28804 .20628 .28758 .20386 .28458 Metetra
.935 .558 .216 r
.20386 .28458 .20628 .28758 .21407 .32199 .21162 .31899 Metetra
.74 .726 .839 r
.21162 .31899 .21407 .32199 .22612 .31513 .22378 .31104 Metetra
.715 .658 .793 r
.22378 .31104 .22612 .31513 .23843 .30574 .23598 .30301 Metetra
.597 .705 .919 r
.23598 .30301 .23843 .30574 .25018 .3029 .24772 .30034 Metetra
.881 .762 .726 r
.24772 .30034 .25018 .3029 .26359 .28118 .26115 .2786 Metetra
.885 .761 .72 r
.26115 .2786 .26359 .28118 .27698 .25859 .27458 .25599 Metetra
.871 .764 .741 r
.27458 .25599 .27698 .25859 .29003 .23954 .28767 .23657 Metetra
.774 .322 0 r
.28767 .23657 .29003 .23954 .30023 .25872 .29786 .25574 Metetra
.804 .358 0 r
.29786 .25574 .30023 .25872 .31053 .27973 .30815 .27675 Metetra
.829 .391 0 r
.30815 .27675 .31053 .27973 .32096 .30275 .31856 .29976 Metetra
.89 .751 .702 r
.31856 .29976 .32096 .30275 .33463 .27726 .33224 .27448 Metetra
.855 .421 0 r
.33224 .27448 .33463 .27726 .34526 .30276 .34287 .29978 Metetra
.958 .622 .316 r
.34287 .29978 .34526 .30276 .35362 .3762 .35118 .37323 Metetra
.761 .305 0 r
.35118 .37323 .35362 .3762 .36523 .39761 .3628 .39423 Metetra
.906 .742 .668 r
.3628 .39423 .36523 .39761 .37958 .36487 .37718 .36147 Metetra
.91 .742 .661 r
.37718 .36147 .37958 .36487 .39382 .33091 .39145 .32749 Metetra
.913 .741 .654 r
.39145 .32749 .39382 .33091 .40793 .2957 .40559 .29227 Metetra
.917 .74 .647 r
.40559 .29227 .40793 .2957 .42189 .25923 .41959 .25579 Metetra
.441 .586 .901 r
.41959 .25579 .42189 .25923 .43458 .25921 .43225 .2568 Metetra
.927 .542 .179 r
.43225 .2568 .43458 .25921 .44622 .30515 .44386 .30276 Metetra
.932 .553 .196 r
.44386 .30276 .44622 .30515 .45823 .35602 .45585 .35366 Metetra
.895 .481 .087 r
.45585 .35366 .45823 .35602 .471 .39345 .46861 .39083 Metetra
.645 .763 .934 r
.46861 .39083 .471 .39345 .48473 .38885 .48234 .38622 Metetra
.645 .763 .934 r
.48234 .38622 .48473 .38885 .49852 .38423 .49615 .38158 Metetra
.645 .763 .934 r
.49615 .38158 .49852 .38423 .51238 .37959 .51002 .37693 Metetra
.645 .763 .934 r
.51002 .37693 .51238 .37959 .52631 .37492 .52397 .37225 Metetra
.645 .763 .934 r
.52397 .37225 .52631 .37492 .54032 .37023 .53799 .36754 Metetra
.645 .763 .934 r
.53799 .36754 .54032 .37023 .55439 .36552 .55208 .36281 Metetra
.645 .763 .934 r
.55208 .36281 .55439 .36552 .56854 .36078 .56624 .35806 Metetra
.645 .763 .934 r
.56624 .35806 .56854 .36078 .58276 .35602 .58047 .35328 Metetra
.645 .763 .934 r
.58047 .35328 .58276 .35602 .59705 .35123 .59478 .34848 Metetra
.645 .763 .934 r
.59478 .34848 .59705 .35123 .61142 .34642 .60916 .34365 Metetra
.645 .763 .934 r
.60916 .34365 .61142 .34642 .62586 .34158 .62362 .3388 Metetra
.645 .763 .934 r
.62362 .3388 .62586 .34158 .64037 .33672 .63815 .33393 Metetra
.645 .763 .934 r
.63815 .33393 .64037 .33672 .65496 .33183 .65276 .32902 Metetra
.645 .763 .934 r
.65276 .32902 .65496 .33183 .66963 .32692 .66744 .3241 Metetra
.645 .763 .934 r
.66744 .3241 .66963 .32692 .68437 .32198 .6822 .31914 Metetra
.645 .763 .934 r
.6822 .31914 .68437 .32198 .69919 .31701 .69704 .31416 Metetra
.645 .763 .934 r
.69704 .31416 .69919 .31701 .71409 .31202 .71195 .30916 Metetra
.645 .763 .934 r
.71195 .30916 .71409 .31202 .72907 .30701 .72695 .30413 Metetra
.645 .763 .934 r
.72695 .30413 .72907 .30701 .74412 .30196 .74202 .29907 Metetra
.41 .612 .932 r
.07658 .33017 .0791 .33292 .08949 .33373 .08696 .33105 Metetra
.832 .741 .764 r
.08696 .33105 .08949 .33373 .10197 .31962 .09961 .3158 Metetra
.377 .505 .86 r
.09961 .3158 .10197 .31962 .11216 .32283 .1099 .31822 Metetra
.757 .647 .739 r
.1099 .31822 .11216 .32283 .12437 .311 .1222 .30576 Metetra
.762 .631 .715 r
.1222 .30576 .12437 .311 .13692 .29639 .13475 .29115 Metetra
.782 .639 .704 r
.13475 .29115 .13692 .29639 .15008 .27652 .14761 .27391 Metetra
.484 .661 .939 r
.14761 .27391 .15008 .27652 .16124 .2732 .15842 .27355 Metetra
.658 .132 0 r
.15842 .27355 .16124 .2732 .17116 .2812 .16834 .28157 Metetra
.681 .164 0 r
.16834 .28157 .17116 .2812 .18112 .29004 .17831 .29044 Metetra
.69 .977 .902 r
.17831 .29044 .18112 .29004 .19279 .28422 .19019 .28286 Metetra
.346 .731 .985 r
.19019 .28286 .19279 .28422 .20386 .28458 .20133 .28262 Metetra
.927 .55 .262 r
.20133 .28262 .20386 .28458 .21162 .31899 .20906 .31706 Metetra
.743 .812 .907 r
.20906 .31706 .21162 .31899 .22378 .31104 .22114 .31008 Metetra
.814 .902 .903 r
.22114 .31008 .22378 .31104 .23598 .30301 .23349 .30055 Metetra
.597 .73 .937 r
.23349 .30055 .23598 .30301 .24772 .30034 .24525 .29778 Metetra
.881 .763 .726 r
.24525 .29778 .24772 .30034 .26115 .2786 .25871 .27602 Metetra
.886 .761 .72 r
.25871 .27602 .26115 .2786 .27458 .25599 .27216 .25339 Metetra
.869 .765 .745 r
.27216 .25339 .27458 .25599 .28767 .23657 .28524 .23446 Metetra
.823 .356 0 r
.28524 .23446 .28767 .23657 .29786 .25574 .29542 .25364 Metetra
.843 .385 0 r
.29542 .25364 .29786 .25574 .30815 .27675 .3057 .27465 Metetra
.859 .411 .027 r
.3057 .27465 .30815 .27675 .31856 .29976 .3161 .29768 Metetra
.914 .789 .709 r
.3161 .29768 .31856 .29976 .33224 .27448 .32982 .27226 Metetra
.868 .429 .039 r
.32982 .27226 .33224 .27448 .34287 .29978 .34044 .29742 Metetra
.955 .617 .328 r
.34044 .29742 .34287 .29978 .35118 .37323 .34869 .37091 Metetra
.809 .341 0 r
.34869 .37091 .35118 .37323 .3628 .39423 .36029 .39233 Metetra
.939 .793 .672 r
.36029 .39233 .3628 .39423 .37718 .36147 .37471 .35953 Metetra
.942 .79 .664 r
.37471 .35953 .37718 .36147 .39145 .32749 .38902 .32551 Metetra
.944 .787 .656 r
.38902 .32551 .39145 .32749 .40559 .29227 .4032 .29025 Metetra
.946 .783 .648 r
.4032 .29025 .40559 .29227 .41959 .25579 .41723 .25373 Metetra
.384 .688 .979 r
.41723 .25373 .41959 .25579 .43225 .2568 .42993 .25399 Metetra
.925 .542 .161 r
.42993 .25399 .43225 .2568 .44386 .30276 .44151 .29996 Metetra
.931 .553 .18 r
.44151 .29996 .44386 .30276 .45585 .35366 .45346 .35087 Metetra
.889 .478 .062 r
.45346 .35087 .45585 .35366 .46861 .39083 .4662 .3882 Metetra
.645 .763 .934 r
.4662 .3882 .46861 .39083 .48234 .38622 .47995 .38357 Metetra
.645 .763 .934 r
.47995 .38357 .48234 .38622 .49615 .38158 .49377 .37893 Metetra
.645 .763 .934 r
.49377 .37893 .49615 .38158 .51002 .37693 .50766 .37425 Metetra
.645 .763 .934 r
.50766 .37425 .51002 .37693 .52397 .37225 .52162 .36956 Metetra
.645 .763 .934 r
.52162 .36956 .52397 .37225 .53799 .36754 .53565 .36484 Metetra
.645 .763 .934 r
.53565 .36484 .53799 .36754 .55208 .36281 .54976 .3601 Metetra
.645 .763 .934 r
.54976 .3601 .55208 .36281 .56624 .35806 .56393 .35533 Metetra
.645 .763 .934 r
.56393 .35533 .56624 .35806 .58047 .35328 .57818 .35054 Metetra
.645 .763 .934 r
.57818 .35054 .58047 .35328 .59478 .34848 .59251 .34573 Metetra
.645 .763 .934 r
.59251 .34573 .59478 .34848 .60916 .34365 .6069 .34089 Metetra
.645 .763 .934 r
.6069 .34089 .60916 .34365 .62362 .3388 .62137 .33602 Metetra
.645 .763 .934 r
.62137 .33602 .62362 .3388 .63815 .33393 .63592 .33113 Metetra
.645 .763 .934 r
.63592 .33113 .63815 .33393 .65276 .32902 .65054 .32621 Metetra
.645 .763 .934 r
.65054 .32621 .65276 .32902 .66744 .3241 .66524 .32127 Metetra
.645 .763 .934 r
.66524 .32127 .66744 .3241 .6822 .31914 .68002 .3163 Metetra
.645 .763 .934 r
.68002 .3163 .6822 .31914 .69704 .31416 .69487 .31131 Metetra
.645 .763 .934 r
.69487 .31131 .69704 .31416 .71195 .30916 .7098 .30629 Metetra
.645 .763 .934 r
.7098 .30629 .71195 .30916 .72695 .30413 .72482 .30124 Metetra
.645 .763 .934 r
.72482 .30124 .72695 .30413 .74202 .29907 .73991 .29617 Metetra
.336 .651 .969 r
.07395 .32813 .07658 .33017 .08696 .33105 .08433 .32901 Metetra
.845 .78 .788 r
.08433 .32901 .08696 .33105 .09961 .3158 .09689 .3146 Metetra
0 .439 .775 r
.09689 .3146 .09961 .3158 .1099 .31822 .10709 .3177 Metetra
.862 .904 .861 r
.10709 .3177 .1099 .31822 .1222 .30576 .11934 .30581 Metetra
.901 .925 .825 r
.11934 .30581 .1222 .30576 .13475 .29115 .13192 .29118 Metetra
.931 .885 .765 r
.13192 .29118 .13475 .29115 .14761 .27391 .14509 .2716 Metetra
.611 .738 .936 r
.14509 .2716 .14761 .27391 .15842 .27355 .15621 .26867 Metetra
.108 .272 .75 r
.15621 .26867 .15842 .27355 .16834 .28157 .16613 .27666 Metetra
.056 .238 .734 r
.16613 .27666 .16834 .28157 .17831 .29044 .17608 .2855 Metetra
.663 .596 .77 r
.17608 .2855 .17831 .29044 .19019 .28286 .18779 .27951 Metetra
.485 .601 .893 r
.18779 .27951 .19019 .28286 .20133 .28262 .1989 .2796 Metetra
.935 .558 .216 r
.1989 .2796 .20133 .28262 .20906 .31706 .20661 .31403 Metetra
.738 .725 .839 r
.20661 .31403 .20906 .31706 .22114 .31008 .21878 .30614 Metetra
.717 .667 .8 r
.21878 .30614 .22114 .31008 .23349 .30055 .231 .29816 Metetra
.598 .737 .942 r
.231 .29816 .23349 .30055 .24525 .29778 .24277 .29533 Metetra
.885 .768 .728 r
.24277 .29533 .24525 .29778 .25871 .27602 .25625 .27355 Metetra
.889 .767 .721 r
.25625 .27355 .25871 .27602 .27216 .25339 .26973 .2509 Metetra
.875 .77 .743 r
.26973 .2509 .27216 .25339 .28524 .23446 .28287 .23147 Metetra
.773 .322 0 r
.28287 .23147 .28524 .23446 .29542 .25364 .29304 .25065 Metetra
.803 .358 0 r
.29304 .25065 .29542 .25364 .3057 .27465 .3033 .27165 Metetra
.829 .391 0 r
.3033 .27165 .3057 .27465 .3161 .29768 .31369 .29467 Metetra
.89 .75 .701 r
.31369 .29467 .3161 .29768 .32982 .27226 .32744 .26917 Metetra
.847 .42 0 r
.32744 .26917 .32982 .27226 .34044 .29742 .33802 .2948 Metetra
.956 .619 .323 r
.33802 .2948 .34044 .29742 .34869 .37091 .34621 .36832 Metetra
.788 .322 0 r
.34621 .36832 .34869 .37091 .36029 .39233 .35782 .38932 Metetra
.915 .755 .669 r
.35782 .38932 .36029 .39233 .37471 .35953 .37227 .3565 Metetra
.918 .754 .662 r
.37227 .3565 .37471 .35953 .38902 .32551 .38662 .32246 Metetra
.921 .752 .655 r
.38662 .32246 .38902 .32551 .4032 .29025 .40083 .28717 Metetra
.925 .751 .647 r
.40083 .28717 .4032 .29025 .41723 .25373 .4149 .25063 Metetra
.438 .615 .924 r
.4149 .25063 .41723 .25373 .42993 .25399 .42759 .25133 Metetra
.926 .542 .168 r
.42759 .25133 .42993 .25399 .44151 .29996 .43915 .29731 Metetra
.932 .553 .186 r
.43915 .29731 .44151 .29996 .45346 .35087 .45107 .34824 Metetra
.892 .48 .072 r
.45107 .34824 .45346 .35087 .4662 .3882 .46379 .38556 Metetra
.645 .763 .934 r
.46379 .38556 .4662 .3882 .47995 .38357 .47755 .38092 Metetra
.645 .763 .934 r
.47755 .38092 .47995 .38357 .49377 .37893 .49139 .37626 Metetra
.645 .763 .934 r
.49139 .37626 .49377 .37893 .50766 .37425 .50529 .37158 Metetra
.645 .763 .934 r
.50529 .37158 .50766 .37425 .52162 .36956 .51927 .36687 Metetra
.645 .763 .934 r
.51927 .36687 .52162 .36956 .53565 .36484 .53331 .36214 Metetra
.645 .763 .934 r
.53331 .36214 .53565 .36484 .54976 .3601 .54743 .35738 Metetra
.645 .763 .934 r
.54743 .35738 .54976 .3601 .56393 .35533 .56162 .3526 Metetra
.645 .763 .934 r
.56162 .3526 .56393 .35533 .57818 .35054 .57589 .34779 Metetra
.645 .763 .934 r
.57589 .34779 .57818 .35054 .59251 .34573 .59022 .34296 Metetra
.645 .763 .934 r
.59022 .34296 .59251 .34573 .6069 .34089 .60464 .33811 Metetra
.645 .763 .934 r
.60464 .33811 .6069 .34089 .62137 .33602 .61912 .33323 Metetra
.645 .763 .934 r
.61912 .33323 .62137 .33602 .63592 .33113 .63369 .32832 Metetra
.645 .763 .934 r
.63369 .32832 .63592 .33113 .65054 .32621 .64832 .32339 Metetra
.645 .763 .934 r
.64832 .32339 .65054 .32621 .66524 .32127 .66304 .31843 Metetra
.645 .763 .934 r
.66304 .31843 .66524 .32127 .68002 .3163 .67783 .31345 Metetra
.645 .763 .934 r
.67783 .31345 .68002 .3163 .69487 .31131 .6927 .30844 Metetra
.645 .763 .934 r
.6927 .30844 .69487 .31131 .7098 .30629 .70765 .30341 Metetra
.645 .763 .934 r
.70765 .30341 .7098 .30629 .72482 .30124 .72268 .29834 Metetra
.645 .763 .934 r
.72268 .29834 .72482 .30124 .73991 .29617 .73779 .29325 Metetra
.424 .62 .933 r
.07141 .32538 .07395 .32813 .08433 .32901 .08183 .32603 Metetra
.815 .726 .767 r
.08183 .32603 .08433 .32901 .09689 .3146 .09436 .31192 Metetra
.277 .552 .927 r
.09436 .31192 .09689 .3146 .10709 .3177 .10466 .31429 Metetra
.787 .704 .773 r
.10466 .31429 .10709 .3177 .11934 .30581 .11696 .30205 Metetra
.799 .691 .746 r
.11696 .30205 .11934 .30581 .13192 .29118 .12956 .28741 Metetra
.825 .697 .722 r
.12956 .28741 .13192 .29118 .14509 .2716 .14262 .26886 Metetra
.541 .674 .924 r
.14262 .26886 .14509 .2716 .15621 .26867 .15355 .26753 Metetra
.588 .018 0 r
.15355 .26753 .15621 .26867 .16613 .27666 .16347 .27554 Metetra
.629 .068 0 r
.16347 .27554 .16613 .27666 .17608 .2855 .17342 .28438 Metetra
.762 .885 .933 r
.17342 .28438 .17608 .2855 .18779 .27951 .18529 .27705 Metetra
.388 .637 .954 r
.18529 .27705 .18779 .27951 .1989 .2796 .19633 .27786 Metetra
.925 .547 .271 r
.19633 .27786 .1989 .2796 .20661 .31403 .20401 .31232 Metetra
.767 .835 .904 r
.20401 .31232 .20661 .31403 .21878 .30614 .2162 .30447 Metetra
.788 .84 .891 r
.2162 .30447 .21878 .30614 .231 .29816 .2285 .29567 Metetra
.591 .726 .938 r
.2285 .29567 .231 .29816 .24277 .29533 .24027 .29303 Metetra
.889 .775 .73 r
.24027 .29303 .24277 .29533 .25625 .27355 .25378 .27123 Metetra
.893 .773 .723 r
.25378 .27123 .25625 .27355 .26973 .2509 .26728 .24855 Metetra
.88 .778 .744 r
.26728 .24855 .26973 .2509 .28287 .23147 .28046 .22888 Metetra
.801 .34 0 r
.28046 .22888 .28287 .23147 .29304 .25065 .29062 .24805 Metetra
.826 .373 0 r
.29062 .24805 .29304 .25065 .3033 .27165 .30087 .26906 Metetra
.846 .402 0 r
.30087 .26906 .3033 .27165 .31369 .29467 .31124 .29208 Metetra
.9 .768 .706 r
.31124 .29208 .31369 .29467 .32744 .26917 .32501 .26682 Metetra
.867 .429 .03 r
.32501 .26682 .32744 .26917 .33802 .2948 .3356 .29209 Metetra
.957 .619 .322 r
.3356 .29209 .33802 .2948 .34621 .36832 .34373 .36564 Metetra
.777 .312 0 r
.34373 .36564 .34621 .36832 .35782 .38932 .35534 .38636 Metetra
.916 .757 .67 r
.35534 .38636 .35782 .38932 .37227 .3565 .36983 .35352 Metetra
.919 .756 .662 r
.36983 .35352 .37227 .3565 .38662 .32246 .38421 .31946 Metetra
.923 .754 .655 r
.38421 .31946 .38662 .32246 .40083 .28717 .39846 .28415 Metetra
.926 .753 .648 r
.39846 .28415 .40083 .28717 .4149 .25063 .41257 .24759 Metetra
.383 .591 .926 r
.41257 .24759 .4149 .25063 .42759 .25133 .42524 .24919 Metetra
.927 .541 .191 r
.42524 .24919 .42759 .25133 .43915 .29731 .43676 .2952 Metetra
.932 .552 .207 r
.43676 .2952 .43915 .29731 .45107 .34824 .44866 .34617 Metetra
.896 .479 .101 r
.44866 .34617 .45107 .34824 .46379 .38556 .46137 .38291 Metetra
.645 .763 .934 r
.46137 .38291 .46379 .38556 .47755 .38092 .47515 .37826 Metetra
.645 .763 .934 r
.47515 .37826 .47755 .38092 .49139 .37626 .48899 .37359 Metetra
.645 .763 .934 r
.48899 .37359 .49139 .37626 .50529 .37158 .50291 .36889 Metetra
.645 .763 .934 r
.50291 .36889 .50529 .37158 .51927 .36687 .5169 .36417 Metetra
.645 .763 .934 r
.5169 .36417 .51927 .36687 .53331 .36214 .53096 .35942 Metetra
.645 .763 .934 r
.53096 .35942 .53331 .36214 .54743 .35738 .5451 .35465 Metetra
.645 .763 .934 r
.5451 .35465 .54743 .35738 .56162 .3526 .5593 .34986 Metetra
.645 .763 .934 r
.5593 .34986 .56162 .3526 .57589 .34779 .57358 .34504 Metetra
.645 .763 .934 r
.57358 .34504 .57589 .34779 .59022 .34296 .58794 .34019 Metetra
.645 .763 .934 r
.58794 .34019 .59022 .34296 .60464 .33811 .60236 .33532 Metetra
.645 .763 .934 r
.60236 .33532 .60464 .33811 .61912 .33323 .61687 .33043 Metetra
.645 .763 .934 r
.61687 .33043 .61912 .33323 .63369 .32832 .63144 .32551 Metetra
.645 .763 .934 r
.63144 .32551 .63369 .32832 .64832 .32339 .6461 .32056 Metetra
.645 .763 .934 r
.6461 .32056 .64832 .32339 .66304 .31843 .66083 .31559 Metetra
.645 .763 .934 r
.66083 .31559 .66304 .31843 .67783 .31345 .67564 .31059 Metetra
.645 .763 .934 r
.67564 .31059 .67783 .31345 .6927 .30844 .69053 .30557 Metetra
.645 .763 .934 r
.69053 .30557 .6927 .30844 .70765 .30341 .70549 .30052 Metetra
.645 .763 .934 r
.70549 .30052 .70765 .30341 .72268 .29834 .72054 .29544 Metetra
.645 .763 .934 r
.72054 .29544 .72268 .29834 .73779 .29325 .73566 .29033 Metetra
.311 .652 .97 r
.06875 .32345 .07141 .32538 .08183 .32603 .07914 .32439 Metetra
.86 .804 .794 r
.07914 .32439 .08183 .32603 .09436 .31192 .09178 .30957 Metetra
.134 .505 .91 r
.09178 .30957 .09436 .31192 .10466 .31429 .10197 .3128 Metetra
.841 .827 .834 r
.10197 .3128 .10466 .31429 .11696 .30205 .11426 .30078 Metetra
.872 .833 .806 r
.11426 .30078 .11696 .30205 .12956 .28741 .12688 .28611 Metetra
.897 .813 .757 r
.12688 .28611 .12956 .28741 .14262 .26886 .14005 .26679 Metetra
.601 .76 .954 r
.14005 .26679 .14262 .26886 .15355 .26753 .15118 .26394 Metetra
0 .226 .747 r
.15118 .26394 .15355 .26753 .16347 .27554 .16109 .27192 Metetra
0 .176 .711 r
.16109 .27192 .16347 .27554 .17342 .28438 .17104 .28075 Metetra
.687 .668 .826 r
.17104 .28075 .17342 .28438 .18529 .27705 .18277 .27478 Metetra
.453 .688 .966 r
.18277 .27478 .18529 .27705 .19633 .27786 .19392 .27449 Metetra
.935 .56 .198 r
.19392 .27449 .19633 .27786 .20401 .31232 .20158 .30893 Metetra
.723 .699 .827 r
.20158 .30893 .20401 .31232 .2162 .30447 .21374 .30139 Metetra
.746 .725 .832 r
.21374 .30139 .2162 .30447 .2285 .29567 .22603 .29294 Metetra
.599 .709 .921 r
.22603 .29294 .2285 .29567 .24027 .29303 .23781 .29017 Metetra
.874 .75 .723 r
.23781 .29017 .24027 .29303 .25378 .27123 .25134 .26835 Metetra
.878 .749 .716 r
.25134 .26835 .25378 .27123 .26728 .24855 .26487 .24566 Metetra
.862 .751 .739 r
.26487 .24566 .26728 .24855 .28046 .22888 .27804 .22646 Metetra
.811 .346 0 r
.27804 .22646 .28046 .22888 .29062 .24805 .28818 .24563 Metetra
.833 .378 0 r
.28818 .24563 .29062 .24805 .30087 .26906 .29842 .26664 Metetra
.852 .406 0 r
.29842 .26664 .30087 .26906 .31124 .29208 .30878 .28966 Metetra
.905 .776 .707 r
.30878 .28966 .31124 .29208 .32501 .26682 .32259 .26422 Metetra
.861 .425 .008 r
.32259 .26422 .32501 .26682 .3356 .29209 .33316 .28947 Metetra
.956 .619 .323 r
.33316 .28947 .3356 .29209 .34373 .36564 .34124 .36304 Metetra
.796 .332 0 r
.34124 .36304 .34373 .36564 .35534 .38636 .3528 .38447 Metetra
.939 .794 .672 r
.3528 .38447 .35534 .38636 .36983 .35352 .36733 .35159 Metetra
.942 .791 .664 r
.36733 .35159 .36983 .35352 .38421 .31946 .38175 .31748 Metetra
.944 .787 .656 r
.38175 .31748 .38421 .31946 .39846 .28415 .39604 .28213 Metetra
.947 .784 .648 r
.39604 .28213 .39846 .28415 .41257 .24759 .41019 .24553 Metetra
.385 .691 .98 r
.41019 .24553 .41257 .24759 .42524 .24919 .42291 .24572 Metetra
.92 .541 .131 r
.42291 .24572 .42524 .24919 .43676 .2952 .43441 .29172 Metetra
.927 .553 .153 r
.43441 .29172 .43676 .2952 .44866 .34617 .44627 .34268 Metetra
.875 .472 .019 r
.44627 .34268 .44866 .34617 .46137 .38291 .45894 .38026 Metetra
.645 .763 .934 r
.45894 .38026 .46137 .38291 .47515 .37826 .47273 .37559 Metetra
.645 .763 .934 r
.47273 .37559 .47515 .37826 .48899 .37359 .4866 .3709 Metetra
.645 .763 .934 r
.4866 .3709 .48899 .37359 .50291 .36889 .50053 .36619 Metetra
.645 .763 .934 r
.50053 .36619 .50291 .36889 .5169 .36417 .51453 .36146 Metetra
.645 .763 .934 r
.51453 .36146 .5169 .36417 .53096 .35942 .52861 .3567 Metetra
.645 .763 .934 r
.52861 .3567 .53096 .35942 .5451 .35465 .54276 .35191 Metetra
.645 .763 .934 r
.54276 .35191 .5451 .35465 .5593 .34986 .55698 .3471 Metetra
.645 .763 .934 r
.55698 .3471 .5593 .34986 .57358 .34504 .57127 .34227 Metetra
.645 .763 .934 r
.57127 .34227 .57358 .34504 .58794 .34019 .58564 .33741 Metetra
.645 .763 .934 r
.58564 .33741 .58794 .34019 .60236 .33532 .60008 .33253 Metetra
.645 .763 .934 r
.60008 .33253 .60236 .33532 .61687 .33043 .6146 .32762 Metetra
.645 .763 .934 r
.6146 .32762 .61687 .33043 .63144 .32551 .6292 .32268 Metetra
.645 .763 .934 r
.6292 .32268 .63144 .32551 .6461 .32056 .64387 .31772 Metetra
.645 .763 .934 r
.64387 .31772 .6461 .32056 .66083 .31559 .65861 .31274 Metetra
.645 .763 .934 r
.65861 .31274 .66083 .31559 .67564 .31059 .67344 .30772 Metetra
.645 .763 .934 r
.67344 .30772 .67564 .31059 .69053 .30557 .68834 .30268 Metetra
.645 .763 .934 r
.68834 .30268 .69053 .30557 .70549 .30052 .70332 .29762 Metetra
.645 .763 .934 r
.70332 .29762 .70549 .30052 .72054 .29544 .71839 .29252 Metetra
.645 .763 .934 r
.71839 .29252 .72054 .29544 .73566 .29033 .73353 .2874 Metetra
.44 .619 .927 r
.06622 .3206 .06875 .32345 .07914 .32439 .07667 .32108 Metetra
.8 .709 .765 r
.07667 .32108 .07914 .32439 .09178 .30957 .08913 .30767 Metetra
.156 .568 .931 r
.08913 .30767 .09178 .30957 .10197 .3128 .09945 .30994 Metetra
.801 .735 .791 r
.09945 .30994 .10197 .3128 .11426 .30078 .11176 .29787 Metetra
.823 .734 .766 r
.11176 .29787 .11426 .30078 .12688 .28611 .12439 .28319 Metetra
.852 .733 .732 r
.12439 .28319 .12688 .28611 .14005 .26679 .13759 .26386 Metetra
.572 .671 .906 r
.13759 .26386 .14005 .26679 .15118 .26394 .14861 .26194 Metetra
.458 0 0 r
.14861 .26194 .15118 .26394 .16109 .27192 .15852 .26993 Metetra
.518 0 0 r
.15852 .26993 .16109 .27192 .17104 .28075 .16846 .27875 Metetra
.75 .803 .895 r
.16846 .27875 .17104 .28075 .18277 .27478 .18034 .27154 Metetra
.399 .568 .904 r
.18034 .27154 .18277 .27478 .19392 .27449 .19131 .27302 Metetra
.921 .544 .281 r
.19131 .27302 .19392 .27449 .20158 .30893 .19893 .30749 Metetra
.786 .861 .906 r
.19893 .30749 .20158 .30893 .21374 .30139 .21121 .29899 Metetra
.759 .777 .868 r
.21121 .29899 .21374 .30139 .22603 .29294 .22348 .2908 Metetra
.583 .759 .962 r
.22348 .2908 .22603 .29294 .23781 .29017 .23527 .28812 Metetra
.896 .788 .733 r
.23527 .28812 .23781 .29017 .25134 .26835 .24883 .26627 Metetra
.9 .786 .726 r
.24883 .26627 .25134 .26835 .26487 .24566 .26239 .24356 Metetra
.89 .791 .745 r
.26239 .24356 .26487 .24566 .27804 .22646 .27565 .22347 Metetra
.775 .323 0 r
.27565 .22347 .27804 .22646 .28818 .24563 .28578 .24263 Metetra
.805 .359 0 r
.28578 .24263 .28818 .24563 .29842 .26664 .29601 .26364 Metetra
.83 .391 0 r
.29601 .26364 .29842 .26664 .30878 .28966 .30635 .28665 Metetra
.89 .751 .703 r
.30635 .28665 .30878 .28966 .32259 .26422 .32018 .26132 Metetra
.855 .424 0 r
.32018 .26132 .32259 .26422 .33316 .28947 .33071 .28694 Metetra
.955 .618 .325 r
.33071 .28694 .33316 .28947 .34124 .36304 .33874 .36055 Metetra
.779 .306 0 r
.33874 .36055 .34124 .36304 .3528 .38447 .35036 .38068 Metetra
.898 .731 .666 r
.35036 .38068 .3528 .38447 .36733 .35159 .36492 .34778 Metetra
.902 .73 .659 r
.36492 .34778 .36733 .35159 .38175 .31748 .37937 .31367 Metetra
.906 .73 .653 r
.37937 .31367 .38175 .31748 .39604 .28213 .39369 .27832 Metetra
.91 .73 .646 r
.39369 .27832 .39604 .28213 .41019 .24553 .40787 .24171 Metetra
.384 .529 .878 r
.40787 .24171 .41019 .24553 .42291 .24572 .42052 .24416 Metetra
.926 .539 .213 r
.42052 .24416 .42291 .24572 .43441 .29172 .43199 .29021 Metetra
.93 .549 .227 r
.43199 .29021 .43441 .29172 .44627 .34268 .44382 .34123 Metetra
.897 .478 .132 r
.44382 .34123 .44627 .34268 .45894 .38026 .45651 .37759 Metetra
.645 .763 .934 r
.45651 .37759 .45894 .38026 .47273 .37559 .47031 .37292 Metetra
.645 .763 .934 r
.47031 .37292 .47273 .37559 .4866 .3709 .48419 .36821 Metetra
.645 .763 .934 r
.48419 .36821 .4866 .3709 .50053 .36619 .49814 .36349 Metetra
.645 .763 .934 r
.49814 .36349 .50053 .36619 .51453 .36146 .51216 .35874 Metetra
.645 .763 .934 r
.51216 .35874 .51453 .36146 .52861 .3567 .52625 .35397 Metetra
.645 .763 .934 r
.52625 .35397 .52861 .3567 .54276 .35191 .54041 .34917 Metetra
.645 .763 .934 r
.54041 .34917 .54276 .35191 .55698 .3471 .55464 .34435 Metetra
.645 .763 .934 r
.55464 .34435 .55698 .3471 .57127 .34227 .56895 .3395 Metetra
.645 .763 .934 r
.56895 .3395 .57127 .34227 .58564 .33741 .58334 .33462 Metetra
.645 .763 .934 r
.58334 .33462 .58564 .33741 .60008 .33253 .5978 .32973 Metetra
.645 .763 .934 r
.5978 .32973 .60008 .33253 .6146 .32762 .61233 .3248 Metetra
.645 .763 .934 r
.61233 .3248 .6146 .32762 .6292 .32268 .62694 .31985 Metetra
.645 .763 .934 r
.62694 .31985 .6292 .32268 .64387 .31772 .64163 .31488 Metetra
.645 .763 .934 r
.64163 .31488 .64387 .31772 .65861 .31274 .65639 .30988 Metetra
.645 .763 .934 r
.65639 .30988 .65861 .31274 .67344 .30772 .67123 .30485 Metetra
.645 .763 .934 r
.67123 .30485 .67344 .30772 .68834 .30268 .68615 .29979 Metetra
.645 .763 .934 r
.68615 .29979 .68834 .30268 .70332 .29762 .70115 .29471 Metetra
.645 .763 .934 r
.70115 .29471 .70332 .29762 .71839 .29252 .71623 .2896 Metetra
.645 .763 .934 r
.71623 .2896 .71839 .29252 .73353 .2874 .73139 .28447 Metetra
.256 .666 .965 r
.06348 .31907 .06622 .3206 .07667 .32108 .07389 .31988 Metetra
.875 .832 .801 r
.07389 .31988 .07667 .32108 .08913 .30767 .08661 .30475 Metetra
.195 .484 .897 r
.08661 .30475 .08913 .30767 .09945 .30994 .09676 .30827 Metetra
.836 .815 .829 r
.09676 .30827 .09945 .30994 .11176 .29787 .10908 .2962 Metetra
.861 .808 .797 r
.10908 .2962 .11176 .29787 .12439 .28319 .12174 .28151 Metetra
.886 .794 .752 r
.12174 .28151 .12439 .28319 .13759 .26386 .13496 .26225 Metetra
.623 .814 .974 r
.13496 .26225 .13759 .26386 .14861 .26194 .14618 .25871 Metetra
0 .201 .725 r
.14618 .25871 .14861 .26194 .15852 .26993 .15608 .26668 Metetra
0 .146 .681 r
.15608 .26668 .15852 .26993 .16846 .27875 .16603 .27549 Metetra
.687 .692 .849 r
.16603 .27549 .16846 .27875 .18034 .27154 .17773 .26987 Metetra
.421 .738 .992 r
.17773 .26987 .18034 .27154 .19131 .27302 .18894 .26923 Metetra
.933 .561 .178 r
.18894 .26923 .19131 .27302 .19893 .30749 .19653 .30368 Metetra
.708 .671 .812 r
.19653 .30368 .19893 .30749 .21121 .29899 .20869 .29641 Metetra
.768 .765 .85 r
.20869 .29641 .21121 .29899 .22348 .2908 .22105 .28749 Metetra
.602 .664 .883 r
.22105 .28749 .22348 .2908 .23527 .28812 .23285 .28467 Metetra
.858 .726 .715 r
.23285 .28467 .23527 .28812 .24883 .26627 .24643 .26282 Metetra
.863 .726 .709 r
.24643 .26282 .24883 .26627 .26239 .24356 .26001 .24009 Metetra
.841 .724 .735 r
.26001 .24009 .26239 .24356 .27565 .22347 .27316 .22164 Metetra
.832 .362 0 r
.27316 .22164 .27565 .22347 .28578 .24263 .28328 .24082 Metetra
.849 .39 .022 r
.28328 .24082 .28578 .24263 .29601 .26364 .2935 .26183 Metetra
.863 .414 .055 r
.2935 .26183 .29601 .26364 .30635 .28665 .30383 .28487 Metetra
.922 .803 .712 r
.30383 .28487 .30635 .28665 .32018 .26132 .3177 .25934 Metetra
.869 .426 .054 r
.3177 .25934 .32018 .26132 .33071 .28694 .32828 .28409 Metetra
.957 .62 .319 r
.32828 .28409 .33071 .28694 .33874 .36055 .33624 .35772 Metetra
.79 .332 0 r
.33624 .35772 .33874 .36055 .35036 .38068 .34776 .37953 Metetra
.955 .821 .672 r
.34776 .37953 .35036 .38068 .36492 .34778 .36237 .34659 Metetra
.957 .816 .663 r
.36237 .34659 .36492 .34778 .37937 .31367 .37686 .31242 Metetra
.959 .812 .654 r
.37686 .31242 .37937 .31367 .39369 .27832 .39123 .27701 Metetra
.961 .807 .646 r
.39123 .27701 .39369 .27832 .40787 .24171 .40546 .24035 Metetra
.321 .729 .979 r
.40546 .24035 .40787 .24171 .42052 .24416 .41821 .24011 Metetra
.912 .538 .103 r
.41821 .24011 .42052 .24416 .43199 .29021 .42965 .28613 Metetra
.921 .551 .127 r
.42965 .28613 .43199 .29021 .44382 .34123 .44144 .33712 Metetra
.856 .463 0 r
.44144 .33712 .44382 .34123 .45651 .37759 .45407 .37492 Metetra
.645 .763 .934 r
.45407 .37492 .45651 .37759 .47031 .37292 .46789 .37023 Metetra
.645 .763 .934 r
.46789 .37023 .47031 .37292 .48419 .36821 .48178 .36552 Metetra
.645 .763 .934 r
.48178 .36552 .48419 .36821 .49814 .36349 .49574 .36078 Metetra
.645 .763 .934 r
.49574 .36078 .49814 .36349 .51216 .35874 .50977 .35602 Metetra
.645 .763 .934 r
.50977 .35602 .51216 .35874 .52625 .35397 .52388 .35123 Metetra
.645 .763 .934 r
.52388 .35123 .52625 .35397 .54041 .34917 .53805 .34642 Metetra
.645 .763 .934 r
.53805 .34642 .54041 .34917 .55464 .34435 .5523 .34158 Metetra
.645 .763 .934 r
.5523 .34158 .55464 .34435 .56895 .3395 .56663 .33672 Metetra
.645 .763 .934 r
.56663 .33672 .56895 .3395 .58334 .33462 .58103 .33183 Metetra
.645 .763 .934 r
.58103 .33183 .58334 .33462 .5978 .32973 .5955 .32692 Metetra
.645 .763 .934 r
.5955 .32692 .5978 .32973 .61233 .3248 .61005 .32198 Metetra
.645 .763 .934 r
.61005 .32198 .61233 .3248 .62694 .31985 .62468 .31701 Metetra
.645 .763 .934 r
.62468 .31701 .62694 .31985 .64163 .31488 .63938 .31202 Metetra
.645 .763 .934 r
.63938 .31202 .64163 .31488 .65639 .30988 .65416 .30701 Metetra
.645 .763 .934 r
.65416 .30701 .65639 .30988 .67123 .30485 .66902 .30196 Metetra
.645 .763 .934 r
.66902 .30196 .67123 .30485 .68615 .29979 .68396 .29689 Metetra
.645 .763 .934 r
.68396 .29689 .68615 .29979 .70115 .29471 .69897 .29179 Metetra
.645 .763 .934 r
.69897 .29179 .70115 .29471 .71623 .2896 .71407 .28667 Metetra
.645 .763 .934 r
.71407 .28667 .71623 .2896 .73139 .28447 .72925 .28152 Metetra
.448 .593 .903 r
.06099 .31586 .06348 .31907 .07389 .31988 .07142 .31648 Metetra
.8 .705 .761 r
.07142 .31648 .07389 .31988 .08661 .30475 .08396 .30276 Metetra
.133 .545 .922 r
.08396 .30276 .08661 .30475 .09676 .30827 .09424 .30535 Metetra
.8 .732 .789 r
.09424 .30535 .09676 .30827 .10908 .2962 .10659 .29316 Metetra
.82 .728 .763 r
.10659 .29316 .10908 .2962 .12174 .28151 .11927 .27845 Metetra
.849 .728 .729 r
.11927 .27845 .12174 .28151 .13496 .26225 .13253 .25896 Metetra
.582 .647 .88 r
.13253 .25896 .13496 .26225 .14618 .25871 .14358 .25682 Metetra
.48 0 0 r
.14358 .25682 .14618 .25871 .15608 .26668 .15348 .26479 Metetra
.537 0 0 r
.15348 .26479 .15608 .26668 .16603 .27549 .16342 .27361 Metetra
.744 .813 .906 r
.16342 .27361 .16603 .27549 .17773 .26987 .17529 .26668 Metetra
.419 .585 .909 r
.17529 .26668 .17773 .26987 .18894 .26923 .1863 .26775 Metetra
.921 .544 .28 r
.1863 .26775 .18894 .26923 .19653 .30368 .19388 .30224 Metetra
.775 .861 .914 r
.19388 .30224 .19653 .30368 .20869 .29641 .20614 .29415 Metetra
.772 .79 .868 r
.20614 .29415 .20869 .29641 .22105 .28749 .21848 .28545 Metetra
.566 .763 .971 r
.21848 .28545 .22105 .28749 .23285 .28467 .23025 .28301 Metetra
.907 .807 .738 r
.23025 .28301 .23285 .28467 .24643 .26282 .24387 .26113 Metetra
.911 .804 .73 r
.24387 .26113 .24643 .26282 .26001 .24009 .25748 .23837 Metetra
.901 .812 .75 r
.25748 .23837 .26001 .24009 .27316 .22164 .27079 .21826 Metetra
.743 .305 0 r
.27079 .21826 .27316 .22164 .28328 .24082 .2809 .23743 Metetra
.778 .344 0 r
.2809 .23743 .28328 .24082 .2935 .26183 .2911 .25843 Metetra
.808 .379 0 r
.2911 .25843 .2935 .26183 .30383 .28487 .30142 .28145 Metetra
.878 .736 .701 r
.30142 .28145 .30383 .28487 .3177 .25934 .31528 .25643 Metetra
.847 .413 0 r
.31528 .25643 .3177 .25934 .32828 .28409 .32583 .28132 Metetra
.957 .62 .321 r
.32583 .28132 .32828 .28409 .33624 .35772 .33374 .35497 Metetra
.776 .312 0 r
.33374 .35497 .33624 .35772 .34776 .37953 .34531 .37575 Metetra
.899 .732 .666 r
.34531 .37575 .34776 .37953 .36237 .34659 .35994 .3428 Metetra
.903 .731 .659 r
.35994 .3428 .36237 .34659 .37686 .31242 .37447 .30862 Metetra
.907 .731 .653 r
.37447 .30862 .37686 .31242 .39123 .27701 .38887 .2732 Metetra
.91 .73 .646 r
.38887 .2732 .39123 .27701 .40546 .24035 .40313 .23653 Metetra
.406 .543 .881 r
.40313 .23653 .40546 .24035 .41821 .24011 .41581 .23847 Metetra
.926 .539 .211 r
.41581 .23847 .41821 .24011 .42965 .28613 .42722 .28453 Metetra
.931 .549 .225 r
.42722 .28453 .42965 .28613 .44144 .33712 .43898 .33558 Metetra
.898 .479 .13 r
.43898 .33558 .44144 .33712 .45407 .37492 .45162 .37225 Metetra
.645 .763 .934 r
.45162 .37225 .45407 .37492 .46789 .37023 .46545 .36754 Metetra
.645 .763 .934 r
.46545 .36754 .46789 .37023 .48178 .36552 .47936 .36281 Metetra
.645 .763 .934 r
.47936 .36281 .48178 .36552 .49574 .36078 .49333 .35806 Metetra
.645 .763 .934 r
.49333 .35806 .49574 .36078 .50977 .35602 .50738 .35328 Metetra
.645 .763 .934 r
.50738 .35328 .50977 .35602 .52388 .35123 .5215 .34848 Metetra
.645 .763 .934 r
.5215 .34848 .52388 .35123 .53805 .34642 .53569 .34365 Metetra
.645 .763 .934 r
.53569 .34365 .53805 .34642 .5523 .34158 .54996 .3388 Metetra
.645 .763 .934 r
.54996 .3388 .5523 .34158 .56663 .33672 .5643 .33393 Metetra
.645 .763 .934 r
.5643 .33393 .56663 .33672 .58103 .33183 .57871 .32902 Metetra
.645 .763 .934 r
.57871 .32902 .58103 .33183 .5955 .32692 .5932 .3241 Metetra
.645 .763 .934 r
.5932 .3241 .5955 .32692 .61005 .32198 .60777 .31914 Metetra
.645 .763 .934 r
.60777 .31914 .61005 .32198 .62468 .31701 .62241 .31416 Metetra
.645 .763 .934 r
.62241 .31416 .62468 .31701 .63938 .31202 .63713 .30916 Metetra
.645 .763 .934 r
.63713 .30916 .63938 .31202 .65416 .30701 .65192 .30413 Metetra
.645 .763 .934 r
.65192 .30413 .65416 .30701 .66902 .30196 .6668 .29907 Metetra
.645 .763 .934 r
.6668 .29907 .66902 .30196 .68396 .29689 .68175 .29398 Metetra
.645 .763 .934 r
.68175 .29398 .68396 .29689 .69897 .29179 .69679 .28887 Metetra
.645 .763 .934 r
.69679 .28887 .69897 .29179 .71407 .28667 .7119 .28373 Metetra
.645 .763 .934 r
.7119 .28373 .71407 .28667 .72925 .28152 .72709 .27856 Metetra
.241 .67 .96 r
.05821 .31446 .06099 .31586 .07142 .31648 .06864 .31517 Metetra
.873 .825 .798 r
.06864 .31517 .07142 .31648 .08396 .30276 .08142 .29992 Metetra
.173 .48 .897 r
.08142 .29992 .08396 .30276 .09424 .30535 .09156 .3035 Metetra
.831 .803 .824 r
.09156 .3035 .09424 .30535 .10659 .29316 .10391 .29143 Metetra
.859 .804 .795 r
.10391 .29143 .10659 .29316 .11927 .27845 .11661 .2767 Metetra
.884 .791 .752 r
.11661 .2767 .11927 .27845 .13253 .25896 .12986 .25748 Metetra
.633 .831 .977 r
.12986 .25748 .13253 .25896 .14358 .25682 .14114 .25362 Metetra
0 .196 .72 r
.14114 .25362 .14358 .25682 .15348 .26479 .15103 .26159 Metetra
0 .141 .674 r
.15103 .26159 .15348 .26479 .16342 .27361 .16097 .27039 Metetra
.685 .695 .854 r
.16097 .27039 .16342 .27361 .17529 .26668 .17268 .26486 Metetra
.443 .733 .989 r
.17268 .26486 .17529 .26668 .1863 .26775 .1839 .26412 Metetra
.934 .561 .188 r
.1839 .26412 .1863 .26775 .19388 .30224 .19144 .29858 Metetra
.711 .682 .82 r
.19144 .29858 .19388 .30224 .20614 .29415 .20363 .29131 Metetra
.762 .747 .839 r
.20363 .29131 .20614 .29415 .21848 .28545 .21601 .28232 Metetra
.605 .68 .895 r
.21601 .28232 .21848 .28545 .23025 .28301 .22784 .27938 Metetra
.854 .719 .713 r
.22784 .27938 .23025 .28301 .24387 .26113 .24148 .25748 Metetra
.859 .719 .707 r
.24148 .25748 .24387 .26113 .25748 .23837 .25511 .23472 Metetra
.834 .716 .734 r
.25511 .23472 .25748 .23837 .27079 .21826 .26827 .2166 Metetra
.835 .365 .005 r
.26827 .2166 .27079 .21826 .2809 .23743 .27837 .23578 Metetra
.851 .392 .039 r
.27837 .23578 .2809 .23743 .2911 .25843 .28856 .2568 Metetra
.864 .416 .071 r
.28856 .2568 .2911 .25843 .30142 .28145 .29887 .27984 Metetra
.927 .811 .712 r
.29887 .27984 .30142 .28145 .31528 .25643 .3128 .25413 Metetra
.864 .422 .028 r
.3128 .25413 .31528 .25643 .32583 .28132 .32335 .27889 Metetra
.955 .617 .327 r
.32335 .27889 .32583 .28132 .33374 .35497 .33121 .35257 Metetra
.813 .347 0 r
.33121 .35257 .33374 .35497 .34531 .37575 .3427 .37441 Metetra
.951 .814 .672 r
.3427 .37441 .34531 .37575 .35994 .3428 .35738 .3414 Metetra
.953 .81 .664 r
.35738 .3414 .35994 .3428 .37447 .30862 .37195 .30718 Metetra
.955 .806 .655 r
.37195 .30718 .37447 .30862 .38887 .2732 .3864 .27171 Metetra
.957 .801 .647 r
.3864 .27171 .38887 .2732 .40313 .23653 .4007 .23498 Metetra
.359 .732 .988 r
.4007 .23498 .40313 .23653 .41581 .23847 .41347 .23462 Metetra
.916 .539 .115 r
.41347 .23462 .41581 .23847 .42722 .28453 .42485 .28067 Metetra
.924 .552 .137 r
.42485 .28067 .42722 .28453 .43898 .33558 .43658 .33169 Metetra
.865 .468 0 r
.43658 .33169 .43898 .33558 .45162 .37225 .44917 .36956 Metetra
.645 .763 .934 r
.44917 .36956 .45162 .37225 .46545 .36754 .46301 .36484 Metetra
.645 .763 .934 r
.46301 .36484 .46545 .36754 .47936 .36281 .47693 .3601 Metetra
.645 .763 .934 r
.47693 .3601 .47936 .36281 .49333 .35806 .49092 .35533 Metetra
.645 .763 .934 r
.49092 .35533 .49333 .35806 .50738 .35328 .50498 .35054 Metetra
.645 .763 .934 r
.50498 .35054 .50738 .35328 .5215 .34848 .51912 .34573 Metetra
.645 .763 .934 r
.51912 .34573 .5215 .34848 .53569 .34365 .53332 .34089 Metetra
.645 .763 .934 r
.53332 .34089 .53569 .34365 .54996 .3388 .5476 .33602 Metetra
.645 .763 .934 r
.5476 .33602 .54996 .3388 .5643 .33393 .56196 .33113 Metetra
.645 .763 .934 r
.56196 .33113 .5643 .33393 .57871 .32902 .57639 .32621 Metetra
.645 .763 .934 r
.57639 .32621 .57871 .32902 .5932 .3241 .59089 .32127 Metetra
.645 .763 .934 r
.59089 .32127 .5932 .3241 .60777 .31914 .60548 .3163 Metetra
.645 .763 .934 r
.60548 .3163 .60777 .31914 .62241 .31416 .62013 .31131 Metetra
.645 .763 .934 r
.62013 .31131 .62241 .31416 .63713 .30916 .63487 .30629 Metetra
.645 .763 .934 r
.63487 .30629 .63713 .30916 .65192 .30413 .64968 .30124 Metetra
.645 .763 .934 r
.64968 .30124 .65192 .30413 .6668 .29907 .66457 .29617 Metetra
.645 .763 .934 r
.66457 .29617 .6668 .29907 .68175 .29398 .67954 .29106 Metetra
.645 .763 .934 r
.67954 .29106 .68175 .29398 .69679 .28887 .69459 .28594 Metetra
.645 .763 .934 r
.69459 .28594 .69679 .28887 .7119 .28373 .70972 .28078 Metetra
.645 .763 .934 r
.70972 .28078 .7119 .28373 .72709 .27856 .72494 .2756 Metetra
.401 .547 .886 r
.05575 .31097 .05821 .31446 .06864 .31517 .06605 .31252 Metetra
.835 .746 .765 r
.06605 .31252 .06864 .31517 .08142 .29992 .07888 .29703 Metetra
.18 .48 .896 r
.07888 .29703 .08142 .29992 .09156 .3035 .08901 .3006 Metetra
.802 .735 .789 r
.08901 .3006 .09156 .3035 .10391 .29143 .10141 .2883 Metetra
.818 .724 .762 r
.10141 .2883 .10391 .29143 .11661 .2767 .11413 .27355 Metetra
.848 .725 .727 r
.11413 .27355 .11661 .2767 .12986 .25748 .12745 .25389 Metetra
.58 .626 .862 r
.12745 .25389 .12986 .25748 .14114 .25362 .13851 .2518 Metetra
.491 0 0 r
.13851 .2518 .14114 .25362 .15103 .26159 .14841 .25976 Metetra
.547 0 0 r
.14841 .25976 .15103 .26159 .16097 .27039 .15834 .26856 Metetra
.712 .816 .93 r
.15834 .26856 .16097 .27039 .17268 .26486 .1701 .26274 Metetra
.497 .726 .974 r
.1701 .26274 .17268 .26486 .1839 .26412 .18137 .26158 Metetra
.932 .555 .24 r
.18137 .26158 .1839 .26412 .19144 .29858 .18889 .29605 Metetra
.725 .762 .882 r
.18889 .29605 .19144 .29858 .20363 .29131 .20103 .2893 Metetra
.786 .813 .874 r
.20103 .2893 .20363 .29131 .21601 .28232 .21344 .28017 Metetra
.553 .749 .968 r
.21344 .28017 .21601 .28232 .22784 .27938 .2252 .27802 Metetra
.915 .823 .741 r
.2252 .27802 .22784 .27938 .24148 .25748 .23887 .25609 Metetra
.919 .819 .732 r
.23887 .25609 .24148 .25748 .25511 .23472 .25254 .23329 Metetra
.91 .827 .752 r
.25254 .23329 .25511 .23472 .26827 .2166 .26591 .21291 Metetra
.713 .288 0 r
.26591 .21291 .26827 .2166 .27837 .23578 .276 .23207 Metetra
.753 .33 0 r
.276 .23207 .27837 .23578 .28856 .2568 .28618 .25308 Metetra
.787 .367 0 r
.28618 .25308 .28856 .2568 .29887 .27984 .29646 .2761 Metetra
.869 .724 .699 r
.29646 .2761 .29887 .27984 .3128 .25413 .31035 .25142 Metetra
.848 .408 0 r
.31035 .25142 .3128 .25413 .32335 .27889 .32092 .2757 Metetra
.959 .623 .314 r
.32092 .2757 .32335 .27889 .33121 .35257 .32871 .34939 Metetra
.784 .338 0 r
.32871 .34939 .33121 .35257 .3427 .37441 .34015 .37204 Metetra
.93 .779 .672 r
.34015 .37204 .3427 .37441 .35738 .3414 .35487 .33901 Metetra
.933 .776 .664 r
.35487 .33901 .35738 .3414 .37195 .30718 .36947 .30475 Metetra
.936 .774 .656 r
.36947 .30475 .37195 .30718 .3864 .27171 .38396 .26924 Metetra
.938 .771 .648 r
.38396 .26924 .3864 .27171 .4007 .23498 .3983 .23249 Metetra
.485 .699 .963 r
.3983 .23249 .4007 .23498 .41347 .23462 .41111 .23158 Metetra
.924 .542 .153 r
.41111 .23158 .41347 .23462 .42485 .28067 .42245 .27763 Metetra
.931 .553 .173 r
.42245 .27763 .42485 .28067 .43658 .33169 .43415 .32865 Metetra
.89 .483 .059 r
.43415 .32865 .43658 .33169 .44917 .36956 .44671 .36687 Metetra
.645 .763 .934 r
.44671 .36687 .44917 .36956 .46301 .36484 .46057 .36214 Metetra
.645 .763 .934 r
.46057 .36214 .46301 .36484 .47693 .3601 .4745 .35738 Metetra
.645 .763 .934 r
.4745 .35738 .47693 .3601 .49092 .35533 .4885 .3526 Metetra
.645 .763 .934 r
.4885 .3526 .49092 .35533 .50498 .35054 .50258 .34779 Metetra
.645 .763 .934 r
.50258 .34779 .50498 .35054 .51912 .34573 .51673 .34296 Metetra
.645 .763 .934 r
.51673 .34296 .51912 .34573 .53332 .34089 .53095 .33811 Metetra
.645 .763 .934 r
.53095 .33811 .53332 .34089 .5476 .33602 .54524 .33323 Metetra
.645 .763 .934 r
.54524 .33323 .5476 .33602 .56196 .33113 .55961 .32832 Metetra
.645 .763 .934 r
.55961 .32832 .56196 .33113 .57639 .32621 .57406 .32339 Metetra
.645 .763 .934 r
.57406 .32339 .57639 .32621 .59089 .32127 .58858 .31843 Metetra
.645 .763 .934 r
.58858 .31843 .59089 .32127 .60548 .3163 .60318 .31345 Metetra
.645 .763 .934 r
.60318 .31345 .60548 .3163 .62013 .31131 .61785 .30844 Metetra
.645 .763 .934 r
.61785 .30844 .62013 .31131 .63487 .30629 .6326 .30341 Metetra
.645 .763 .934 r
.6326 .30341 .63487 .30629 .64968 .30124 .64743 .29834 Metetra
.645 .763 .934 r
.64743 .29834 .64968 .30124 .66457 .29617 .66234 .29325 Metetra
.645 .763 .934 r
.66234 .29325 .66457 .29617 .67954 .29106 .67733 .28814 Metetra
.645 .763 .934 r
.67733 .28814 .67954 .29106 .69459 .28594 .69239 .28299 Metetra
.645 .763 .934 r
.69239 .28299 .69459 .28594 .70972 .28078 .70754 .27782 Metetra
.645 .763 .934 r
.70754 .27782 .70972 .28078 .72494 .2756 .72277 .27262 Metetra
.165 .639 .929 r
.05294 .30971 .05575 .31097 .06605 .31252 .06332 .31075 Metetra
.864 .794 .78 r
.06332 .31075 .06605 .31252 .07888 .29703 .07625 .29469 Metetra
.043 .451 .877 r
.07625 .29469 .07888 .29703 .08901 .3006 .08634 .29858 Metetra
.826 .792 .82 r
.08634 .29858 .08901 .3006 .10141 .2883 .09872 .28656 Metetra
.859 .804 .796 r
.09872 .28656 .10141 .2883 .11413 .27355 .11146 .27179 Metetra
.884 .791 .752 r
.11146 .27179 .11413 .27355 .12745 .25389 .12475 .25257 Metetra
.632 .848 .982 r
.12475 .25257 .12745 .25389 .13851 .2518 .13606 .24859 Metetra
0 .195 .719 r
.13606 .24859 .13851 .2518 .14841 .25976 .14595 .25654 Metetra
0 .14 .674 r
.14595 .25654 .14841 .25976 .15834 .26856 .15587 .26533 Metetra
.672 .691 .859 r
.15587 .26533 .15834 .26856 .1701 .26274 .16754 .26029 Metetra
.545 .711 .948 r
.16754 .26029 .1701 .26274 .18137 .26158 .17889 .25856 Metetra
.935 .558 .219 r
.17889 .25856 .18137 .26158 .18889 .29605 .18638 .29303 Metetra
.72 .725 .854 r
.18638 .29303 .18889 .29605 .20103 .2893 .19855 .28605 Metetra
.746 .717 .825 r
.19855 .28605 .20103 .2893 .21344 .28017 .21093 .27735 Metetra
.612 .708 .913 r
.21093 .27735 .21344 .28017 .2252 .27802 .2228 .27418 Metetra
.849 .711 .71 r
.2228 .27418 .2252 .27802 .23887 .25609 .23648 .25225 Metetra
.854 .712 .705 r
.23648 .25225 .23887 .25609 .25254 .23329 .25017 .22944 Metetra
.828 .708 .731 r
.25017 .22944 .25254 .23329 .26591 .21291 .26336 .21142 Metetra
.837 .368 .023 r
.26336 .21142 .26591 .21291 .276 .23207 .27344 .2306 Metetra
.852 .393 .056 r
.27344 .2306 .276 .23207 .28618 .25308 .28361 .25162 Metetra
.865 .416 .085 r
.28361 .25162 .28618 .25308 .29646 .2761 .29388 .27466 Metetra
.932 .819 .711 r
.29388 .27466 .29646 .2761 .31035 .25142 .3079 .24865 Metetra
.856 .421 0 r
.3079 .24865 .31035 .25142 .32092 .2757 .31839 .27384 Metetra
.951 .613 .337 r
.31839 .27384 .32092 .2757 .32871 .34939 .32613 .3476 Metetra
.836 .369 0 r
.32613 .3476 .32871 .34939 .34015 .37204 .33758 .36985 Metetra
.934 .785 .672 r
.33758 .36985 .34015 .37204 .35487 .33901 .35233 .33677 Metetra
.937 .782 .664 r
.35233 .33677 .35487 .33901 .36947 .30475 .36698 .30248 Metetra
.939 .779 .656 r
.36698 .30248 .36947 .30475 .38396 .26924 .38151 .26694 Metetra
.942 .776 .648 r
.38151 .26694 .38396 .26924 .3983 .23249 .39589 .23014 Metetra
.515 .729 .97 r
.39589 .23014 .3983 .23249 .41111 .23158 .40873 .22854 Metetra
.925 .542 .153 r
.40873 .22854 .41111 .23158 .42245 .27763 .42005 .27458 Metetra
.931 .553 .173 r
.42005 .27458 .42245 .27763 .43415 .32865 .43171 .32561 Metetra
.891 .485 .063 r
.43171 .32561 .43415 .32865 .44671 .36687 .44424 .36417 Metetra
.645 .763 .934 r
.44424 .36417 .44671 .36687 .46057 .36214 .45811 .35942 Metetra
.645 .763 .934 r
.45811 .35942 .46057 .36214 .4745 .35738 .47206 .35465 Metetra
.645 .763 .934 r
.47206 .35465 .4745 .35738 .4885 .3526 .48608 .34986 Metetra
.645 .763 .934 r
.48608 .34986 .4885 .3526 .50258 .34779 .50017 .34504 Metetra
.645 .763 .934 r
.50017 .34504 .50258 .34779 .51673 .34296 .51433 .34019 Metetra
.645 .763 .934 r
.51433 .34019 .51673 .34296 .53095 .33811 .52857 .33532 Metetra
.645 .763 .934 r
.52857 .33532 .53095 .33811 .54524 .33323 .54288 .33043 Metetra
.645 .763 .934 r
.54288 .33043 .54524 .33323 .55961 .32832 .55726 .32551 Metetra
.645 .763 .934 r
.55726 .32551 .55961 .32832 .57406 .32339 .57172 .32056 Metetra
.645 .763 .934 r
.57172 .32056 .57406 .32339 .58858 .31843 .58626 .31559 Metetra
.645 .763 .934 r
.58626 .31559 .58858 .31843 .60318 .31345 .60087 .31059 Metetra
.645 .763 .934 r
.60087 .31059 .60318 .31345 .61785 .30844 .61556 .30557 Metetra
.645 .763 .934 r
.61556 .30557 .61785 .30844 .6326 .30341 .63033 .30052 Metetra
.645 .763 .934 r
.63033 .30052 .6326 .30341 .64743 .29834 .64518 .29544 Metetra
.645 .763 .934 r
.64518 .29544 .64743 .29834 .66234 .29325 .6601 .29033 Metetra
.645 .763 .934 r
.6601 .29033 .66234 .29325 .67733 .28814 .6751 .2852 Metetra
.645 .763 .934 r
.6751 .2852 .67733 .28814 .69239 .28299 .69019 .28004 Metetra
.645 .763 .934 r
.69019 .28004 .69239 .28299 .70754 .27782 .70535 .27486 Metetra
.645 .763 .934 r
.70535 .27486 .70754 .27782 .72277 .27262 .7206 .26964 Metetra
.347 .528 .892 r
.05044 .30631 .05294 .30971 .06332 .31075 .06065 .30854 Metetra
.858 .767 .761 r
.06065 .30854 .06332 .31075 .07625 .29469 .07377 .29132 Metetra
.193 .444 .87 r
.07377 .29132 .07625 .29469 .08634 .29858 .08382 .29542 Metetra
.792 .72 .784 r
.08382 .29542 .08634 .29858 .09872 .28656 .09622 .28333 Metetra
.815 .72 .76 r
.09622 .28333 .09872 .28656 .11146 .27179 .10897 .26855 Metetra
.845 .721 .727 r
.10897 .26855 .11146 .27179 .12475 .25257 .12232 .24909 Metetra
.585 .637 .869 r
.12232 .24909 .12475 .25257 .13606 .24859 .13341 .24683 Metetra
.505 0 0 r
.13341 .24683 .13606 .24859 .14595 .25654 .1433 .25478 Metetra
.559 .007 0 r
.1433 .25478 .14595 .25654 .15587 .26533 .15322 .26358 Metetra
.677 .819 .951 r
.15322 .26358 .15587 .26533 .16754 .26029 .16488 .25873 Metetra
.594 .819 .986 r
.16488 .25873 .16754 .26029 .17889 .25856 .17641 .25548 Metetra
.935 .558 .216 r
.17641 .25548 .17889 .25856 .18638 .29303 .18387 .28994 Metetra
.704 .717 .859 r
.18387 .28994 .18638 .29303 .19855 .28605 .19598 .28363 Metetra
.755 .778 .871 r
.19598 .28363 .19855 .28605 .21093 .27735 .20831 .27557 Metetra
.577 .797 .983 r
.20831 .27557 .21093 .27735 .2228 .27418 .22016 .27265 Metetra
.911 .815 .739 r
.22016 .27265 .2228 .27418 .23648 .25225 .23388 .25069 Metetra
.915 .812 .731 r
.23388 .25069 .23648 .25225 .25017 .22944 .2476 .22785 Metetra
.904 .821 .754 r
.2476 .22785 .25017 .22944 .26336 .21142 .26098 .20788 Metetra
.73 .298 0 r
.26098 .20788 .26336 .21142 .27344 .2306 .27104 .22704 Metetra
.768 .338 0 r
.27104 .22704 .27344 .2306 .28361 .25162 .2812 .24805 Metetra
.8 .375 0 r
.2812 .24805 .28361 .25162 .29388 .27466 .29146 .27107 Metetra
.877 .731 .696 r
.29146 .27107 .29388 .27466 .3079 .24865 .30547 .24539 Metetra
.847 .422 0 r
.30547 .24539 .3079 .24865 .31839 .27384 .3159 .27129 Metetra
.955 .618 .325 r
.3159 .27129 .31839 .27384 .32613 .3476 .32358 .34508 Metetra
.826 .369 0 r
.32358 .34508 .32613 .3476 .33758 .36985 .33497 .36823 Metetra
.946 .805 .673 r
.33497 .36823 .33758 .36985 .35233 .33677 .34976 .33511 Metetra
.948 .801 .664 r
.34976 .33511 .35233 .33677 .36698 .30248 .36445 .30077 Metetra
.951 .797 .656 r
.36445 .30077 .36698 .30248 .38151 .26694 .37902 .26518 Metetra
.953 .794 .647 r
.37902 .26518 .38151 .26694 .39589 .23014 .39345 .22834 Metetra
.59 .814 .985 r
.39345 .22834 .39589 .23014 .40873 .22854 .40638 .22481 Metetra
.918 .54 .122 r
.40638 .22481 .40873 .22854 .42005 .27458 .41766 .27083 Metetra
.926 .553 .144 r
.41766 .27083 .42005 .27458 .43171 .32561 .42929 .32184 Metetra
.88 .485 .03 r
.42929 .32184 .43171 .32561 .44424 .36417 .44176 .36146 Metetra
.645 .763 .934 r
.44176 .36146 .44424 .36417 .45811 .35942 .45565 .3567 Metetra
.645 .763 .934 r
.45565 .3567 .45811 .35942 .47206 .35465 .46961 .35191 Metetra
.645 .763 .934 r
.46961 .35191 .47206 .35465 .48608 .34986 .48364 .3471 Metetra
.645 .763 .934 r
.48364 .3471 .48608 .34986 .50017 .34504 .49775 .34227 Metetra
.645 .763 .934 r
.49775 .34227 .50017 .34504 .51433 .34019 .51192 .33741 Metetra
.645 .763 .934 r
.51192 .33741 .51433 .34019 .52857 .33532 .52618 .33253 Metetra
.645 .763 .934 r
.52618 .33253 .52857 .33532 .54288 .33043 .5405 .32762 Metetra
.645 .763 .934 r
.5405 .32762 .54288 .33043 .55726 .32551 .5549 .32268 Metetra
.645 .763 .934 r
.5549 .32268 .55726 .32551 .57172 .32056 .56938 .31772 Metetra
.645 .763 .934 r
.56938 .31772 .57172 .32056 .58626 .31559 .58393 .31274 Metetra
.645 .763 .934 r
.58393 .31274 .58626 .31559 .60087 .31059 .59856 .30772 Metetra
.645 .763 .934 r
.59856 .30772 .60087 .31059 .61556 .30557 .61327 .30268 Metetra
.645 .763 .934 r
.61327 .30268 .61556 .30557 .63033 .30052 .62805 .29762 Metetra
.645 .763 .934 r
.62805 .29762 .63033 .30052 .64518 .29544 .64291 .29252 Metetra
.645 .763 .934 r
.64291 .29252 .64518 .29544 .6601 .29033 .65785 .2874 Metetra
.645 .763 .934 r
.65785 .2874 .6601 .29033 .6751 .2852 .67287 .28226 Metetra
.645 .763 .934 r
.67287 .28226 .6751 .2852 .69019 .28004 .68797 .27708 Metetra
.645 .763 .934 r
.68797 .27708 .69019 .28004 .70535 .27486 .70316 .27188 Metetra
.645 .763 .934 r
.70316 .27188 .70535 .27486 .7206 .26964 .71842 .26665 Metetra
.173 .655 .927 r
.0476 .30517 .05044 .30631 .06065 .30854 .05803 .30593 Metetra
.841 .749 .761 r
.05803 .30593 .06065 .30854 .07377 .29132 .07102 .28969 Metetra
0 .437 .818 r
.07102 .28969 .07377 .29132 .08382 .29542 .08116 .29322 Metetra
.819 .781 .817 r
.08116 .29322 .08382 .29542 .09622 .28333 .09354 .28137 Metetra
.853 .791 .791 r
.09354 .28137 .09622 .28333 .10897 .26855 .10632 .26657 Metetra
.876 .782 .754 r
.10632 .26657 .10897 .26855 .12232 .24909 .11957 .24792 Metetra
.631 .863 .986 r
.11957 .24792 .12232 .24909 .13341 .24683 .13091 .24381 Metetra
0 .179 .699 r
.13091 .24381 .13341 .24683 .1433 .25478 .1408 .25176 Metetra
0 .122 .65 r
.1408 .25176 .1433 .25478 .15322 .26358 .15071 .26054 Metetra
.68 .708 .869 r
.15071 .26054 .15322 .26358 .16488 .25873 .16243 .25529 Metetra
.562 .635 .881 r
.16243 .25529 .16488 .25873 .17641 .25548 .17379 .25355 Metetra
.926 .548 .264 r
.17379 .25355 .17641 .25548 .18387 .28994 .18122 .28803 Metetra
.755 .82 .903 r
.18122 .28803 .18387 .28994 .19598 .28363 .19348 .28048 Metetra
.734 .722 .84 r
.19348 .28048 .19598 .28363 .20831 .27557 .20579 .27263 Metetra
.642 .711 .897 r
.20579 .27263 .20831 .27557 .22016 .27265 .21776 .2686 Metetra
.844 .704 .707 r
.21776 .2686 .22016 .27265 .23388 .25069 .2315 .24663 Metetra
.849 .704 .702 r
.2315 .24663 .23388 .25069 .2476 .22785 .24524 .22379 Metetra
.817 .698 .733 r
.24524 .22379 .2476 .22785 .26098 .20788 .2584 .2066 Metetra
.838 .37 .044 r
.2584 .2066 .26098 .20788 .27104 .22704 .26845 .22578 Metetra
.852 .395 .075 r
.26845 .22578 .27104 .22704 .2812 .24805 .2786 .24681 Metetra
.864 .417 .102 r
.2786 .24681 .2812 .24805 .29146 .27107 .28884 .26987 Metetra
.94 .826 .704 r
.28884 .26987 .29146 .27107 .30547 .24539 .303 .24271 Metetra
.873 .444 .035 r
.303 .24271 .30547 .24539 .3159 .27129 .31335 .26948 Metetra
.95 .612 .338 r
.31335 .26948 .3159 .27129 .32358 .34508 .32097 .34335 Metetra
.826 .353 0 r
.32097 .34335 .32358 .34508 .33497 .36823 .33246 .36465 Metetra
.904 .74 .667 r
.33246 .36465 .33497 .36823 .34976 .33511 .34729 .33152 Metetra
.908 .739 .66 r
.34729 .33152 .34976 .33511 .36445 .30077 .36201 .29716 Metetra
.912 .738 .653 r
.36201 .29716 .36445 .30077 .37902 .26518 .37662 .26156 Metetra
.915 .737 .646 r
.37662 .26156 .37902 .26518 .39345 .22834 .39108 .22471 Metetra
.549 .634 .888 r
.39108 .22471 .39345 .22834 .40638 .22481 .40394 .22309 Metetra
.926 .539 .208 r
.40394 .22309 .40638 .22481 .41766 .27083 .4152 .26916 Metetra
.931 .549 .222 r
.4152 .26916 .41766 .27083 .42929 .32184 .42679 .32022 Metetra
.903 .49 .141 r
.42679 .32022 .42929 .32184 .44176 .36146 .43928 .35874 Metetra
.645 .763 .934 r
.43928 .35874 .44176 .36146 .45565 .3567 .45318 .35397 Metetra
.645 .763 .934 r
.45318 .35397 .45565 .3567 .46961 .35191 .46715 .34917 Metetra
.645 .763 .934 r
.46715 .34917 .46961 .35191 .48364 .3471 .4812 .34435 Metetra
.645 .763 .934 r
.4812 .34435 .48364 .3471 .49775 .34227 .49532 .3395 Metetra
.645 .763 .934 r
.49532 .3395 .49775 .34227 .51192 .33741 .50951 .33462 Metetra
.645 .763 .934 r
.50951 .33462 .51192 .33741 .52618 .33253 .52378 .32973 Metetra
.645 .763 .934 r
.52378 .32973 .52618 .33253 .5405 .32762 .53812 .3248 Metetra
.645 .763 .934 r
.53812 .3248 .5405 .32762 .5549 .32268 .55254 .31985 Metetra
.645 .763 .934 r
.55254 .31985 .5549 .32268 .56938 .31772 .56703 .31488 Metetra
.645 .763 .934 r
.56703 .31488 .56938 .31772 .58393 .31274 .5816 .30988 Metetra
.645 .763 .934 r
.5816 .30988 .58393 .31274 .59856 .30772 .59624 .30485 Metetra
.645 .763 .934 r
.59624 .30485 .59856 .30772 .61327 .30268 .61096 .29979 Metetra
.645 .763 .934 r
.61096 .29979 .61327 .30268 .62805 .29762 .62576 .29471 Metetra
.645 .763 .934 r
.62576 .29471 .62805 .29762 .64291 .29252 .64064 .2896 Metetra
.645 .763 .934 r
.64064 .2896 .64291 .29252 .65785 .2874 .6556 .28447 Metetra
.645 .763 .934 r
.6556 .28447 .65785 .2874 .67287 .28226 .67064 .2793 Metetra
.645 .763 .934 r
.67064 .2793 .67287 .28226 .68797 .27708 .68576 .27411 Metetra
.645 .763 .934 r
.68576 .27411 .68797 .27708 .70316 .27188 .70095 .26889 Metetra
.645 .763 .934 r
.70095 .26889 .70316 .27188 .71842 .26665 .71624 .26365 Metetra
.374 .571 .915 r
.04504 .30209 .0476 .30517 .05803 .30593 .05536 .30358 Metetra
.853 .761 .76 r
.05536 .30358 .05803 .30593 .07102 .28969 .06849 .28655 Metetra
.228 .486 .893 r
.06849 .28655 .07102 .28969 .08116 .29322 .07865 .2899 Metetra
.784 .711 .783 r
.07865 .2899 .08116 .29322 .09354 .28137 .09102 .27818 Metetra
.817 .722 .761 r
.09102 .27818 .09354 .28137 .10632 .26657 .10382 .26337 Metetra
.842 .724 .734 r
.10382 .26337 .10632 .26657 .11957 .24792 .11709 .24478 Metetra
.603 .67 .887 r
.11709 .24478 .11957 .24792 .13091 .24381 .12826 .242 Metetra
.495 0 0 r
.12826 .242 .13091 .24381 .1408 .25176 .13814 .24994 Metetra
.551 .001 0 r
.13814 .24994 .1408 .25176 .15071 .26054 .14805 .25873 Metetra
.694 .816 .941 r
.14805 .25873 .15071 .26054 .16243 .25529 .15979 .25342 Metetra
.575 .783 .977 r
.15979 .25342 .16243 .25529 .17379 .25355 .17127 .25072 Metetra
.934 .557 .229 r
.17127 .25072 .17379 .25355 .18122 .28803 .17867 .2852 Metetra
.737 .744 .858 r
.17867 .2852 .18122 .28803 .19348 .28048 .19094 .27757 Metetra
.71 .733 .869 r
.19094 .27757 .19348 .28048 .20579 .27263 .20313 .2711 Metetra
.645 .842 .976 r
.20313 .2711 .20579 .27263 .21776 .2686 .21514 .26667 Metetra
.901 .796 .735 r
.21514 .26667 .21776 .2686 .2315 .24663 .22891 .24468 Metetra
.904 .793 .727 r
.22891 .24468 .2315 .24663 .24524 .22379 .24268 .22181 Metetra
.885 .804 .764 r
.24268 .22181 .24524 .22379 .2584 .2066 .25597 .20342 Metetra
.766 .318 0 r
.25597 .20342 .2584 .2066 .26845 .22578 .26601 .22259 Metetra
.797 .355 0 r
.26601 .22259 .26845 .22578 .2786 .24681 .27614 .24361 Metetra
.824 .388 0 r
.27614 .24361 .2786 .24681 .28884 .26987 .28638 .26665 Metetra
.893 .745 .69 r
.28638 .26665 .28884 .26987 .303 .24271 .3006 .23898 Metetra
.858 .451 0 r
.3006 .23898 .303 .24271 .31335 .26948 .31079 .26762 Metetra
.951 .612 .337 r
.31079 .26762 .31335 .26948 .32097 .34335 .31836 .34157 Metetra
.823 .348 0 r
.31836 .34157 .32097 .34335 .33246 .36465 .32985 .36267 Metetra
.939 .793 .672 r
.32985 .36267 .33246 .36465 .34729 .33152 .34472 .3295 Metetra
.941 .79 .664 r
.34472 .3295 .34729 .33152 .36201 .29716 .35949 .2951 Metetra
.944 .786 .656 r
.35949 .2951 .36201 .29716 .37662 .26156 .37413 .25946 Metetra
.946 .783 .648 r
.37413 .25946 .37662 .26156 .39108 .22471 .38864 .22257 Metetra
.568 .773 .975 r
.38864 .22257 .39108 .22471 .40394 .22309 .40156 .21972 Metetra
.922 .542 .14 r
.40156 .21972 .40394 .22309 .4152 .26916 .41278 .26579 Metetra
.929 .554 .161 r
.41278 .26579 .4152 .26916 .42679 .32022 .42435 .31685 Metetra
.888 .486 .05 r
.42435 .31685 .42679 .32022 .43928 .35874 .43679 .35602 Metetra
.645 .763 .934 r
.43679 .35602 .43928 .35874 .45318 .35397 .4507 .35123 Metetra
.645 .763 .934 r
.4507 .35123 .45318 .35397 .46715 .34917 .46469 .34642 Metetra
.645 .763 .934 r
.46469 .34642 .46715 .34917 .4812 .34435 .47875 .34158 Metetra
.645 .763 .934 r
.47875 .34158 .4812 .34435 .49532 .3395 .49289 .33672 Metetra
.645 .763 .934 r
.49289 .33672 .49532 .3395 .50951 .33462 .50709 .33183 Metetra
.645 .763 .934 r
.50709 .33183 .50951 .33462 .52378 .32973 .52138 .32692 Metetra
.645 .763 .934 r
.52138 .32692 .52378 .32973 .53812 .3248 .53573 .32198 Metetra
.645 .763 .934 r
.53573 .32198 .53812 .3248 .55254 .31985 .55016 .31701 Metetra
.645 .763 .934 r
.55016 .31701 .55254 .31985 .56703 .31488 .56467 .31202 Metetra
.645 .763 .934 r
.56467 .31202 .56703 .31488 .5816 .30988 .57925 .30701 Metetra
.645 .763 .934 r
.57925 .30701 .5816 .30988 .59624 .30485 .59391 .30196 Metetra
.645 .763 .934 r
.59391 .30196 .59624 .30485 .61096 .29979 .60865 .29689 Metetra
.645 .763 .934 r
.60865 .29689 .61096 .29979 .62576 .29471 .62347 .29179 Metetra
.645 .763 .934 r
.62347 .29179 .62576 .29471 .64064 .2896 .63836 .28667 Metetra
.645 .763 .934 r
.63836 .28667 .64064 .2896 .6556 .28447 .65334 .28152 Metetra
.645 .763 .934 r
.65334 .28152 .6556 .28447 .67064 .2793 .66839 .27634 Metetra
.645 .763 .934 r
.66839 .27634 .67064 .2793 .68576 .27411 .68353 .27113 Metetra
.645 .763 .934 r
.68353 .27113 .68576 .27411 .70095 .26889 .69875 .2659 Metetra
.645 .763 .934 r
.69875 .2659 .70095 .26889 .71624 .26365 .71404 .26064 Metetra
.353 .714 .986 r
.04225 .30051 .04504 .30209 .05536 .30358 .05281 .30044 Metetra
.822 .722 .756 r
.05281 .30044 .05536 .30358 .06849 .28655 .06573 .28492 Metetra
.08 .551 .902 r
.06573 .28492 .06849 .28655 .07865 .2899 .07604 .28721 Metetra
.802 .749 .804 r
.07604 .28721 .07865 .2899 .09102 .27818 .08843 .27553 Metetra
.833 .752 .774 r
.08843 .27553 .09102 .27818 .10382 .26337 .10124 .26071 Metetra
.851 .75 .751 r
.10124 .26071 .10382 .26337 .11709 .24478 .11438 .24318 Metetra
.618 .818 .977 r
.11438 .24318 .11709 .24478 .12826 .242 .12566 .23963 Metetra
0 .116 .602 r
.12566 .23963 .12826 .242 .13814 .24994 .13554 .24756 Metetra
0 .056 .542 r
.13554 .24756 .13814 .24994 .14805 .25873 .14545 .25635 Metetra
.725 .771 .89 r
.14545 .25635 .14805 .25873 .15979 .25342 .15735 .24979 Metetra
.508 .598 .878 r
.15735 .24979 .15979 .25342 .17127 .25072 .16857 .24934 Metetra
.919 .542 .284 r
.16857 .24934 .17127 .25072 .17867 .2852 .17594 .28386 Metetra
.796 .872 .904 r
.17594 .28386 .17867 .2852 .19094 .27757 .18838 .27487 Metetra
.718 .751 .879 r
.18838 .27487 .19094 .27757 .20313 .2711 .20059 .26825 Metetra
.679 .73 .889 r
.20059 .26825 .20313 .2711 .21514 .26667 .2127 .26301 Metetra
.855 .72 .713 r
.2127 .26301 .21514 .26667 .22891 .24468 .22649 .24101 Metetra
.859 .72 .707 r
.22649 .24101 .22891 .24468 .24268 .22181 .24028 .21813 Metetra
.822 .715 .747 r
.24028 .21813 .24268 .22181 .25597 .20342 .2534 .20182 Metetra
.836 .366 .014 r
.2534 .20182 .25597 .20342 .26601 .22259 .26343 .22101 Metetra
.851 .392 .047 r
.26343 .22101 .26601 .22259 .27614 .24361 .27355 .24205 Metetra
.864 .415 .078 r
.27355 .24205 .27614 .24361 .28638 .26665 .28377 .26512 Metetra
.936 .808 .694 r
.28377 .26512 .28638 .26665 .3006 .23898 .29811 .23636 Metetra
.891 .472 .083 r
.29811 .23636 .3006 .23898 .31079 .26762 .30824 .26559 Metetra
.952 .614 .334 r
.30824 .26559 .31079 .26762 .31836 .34157 .31575 .3396 Metetra
.786 .298 0 r
.31575 .3396 .31836 .34157 .32985 .36267 .32737 .35859 Metetra
.894 .725 .664 r
.32737 .35859 .32985 .36267 .34472 .3295 .34227 .32541 Metetra
.898 .725 .658 r
.34227 .32541 .34472 .3295 .35949 .2951 .35706 .29101 Metetra
.902 .724 .651 r
.35706 .29101 .35949 .2951 .37413 .25946 .37174 .25536 Metetra
.906 .724 .645 r
.37174 .25536 .37413 .25946 .38864 .22257 .38628 .21847 Metetra
.492 .575 .867 r
.38628 .21847 .38864 .22257 .40156 .21972 .39909 .21849 Metetra
.924 .536 .225 r
.39909 .21849 .40156 .21972 .41278 .26579 .41028 .26461 Metetra
.928 .546 .238 r
.41028 .26461 .41278 .26579 .42435 .31685 .42182 .31575 Metetra
.899 .483 .159 r
.42182 .31575 .42435 .31685 .43679 .35602 .43429 .35328 Metetra
.645 .763 .934 r
.43429 .35328 .43679 .35602 .4507 .35123 .44822 .34848 Metetra
.645 .763 .934 r
.44822 .34848 .4507 .35123 .46469 .34642 .46222 .34365 Metetra
.645 .763 .934 r
.46222 .34365 .46469 .34642 .47875 .34158 .4763 .3388 Metetra
.645 .763 .934 r
.4763 .3388 .47875 .34158 .49289 .33672 .49045 .33393 Metetra
.645 .763 .934 r
.49045 .33393 .49289 .33672 .50709 .33183 .50467 .32902 Metetra
.645 .763 .934 r
.50467 .32902 .50709 .33183 .52138 .32692 .51896 .3241 Metetra
.645 .763 .934 r
.51896 .3241 .52138 .32692 .53573 .32198 .53334 .31914 Metetra
.645 .763 .934 r
.53334 .31914 .53573 .32198 .55016 .31701 .54778 .31416 Metetra
.645 .763 .934 r
.54778 .31416 .55016 .31701 .56467 .31202 .56231 .30916 Metetra
.645 .763 .934 r
.56231 .30916 .56467 .31202 .57925 .30701 .5769 .30413 Metetra
.645 .763 .934 r
.5769 .30413 .57925 .30701 .59391 .30196 .59158 .29907 Metetra
.645 .763 .934 r
.59158 .29907 .59391 .30196 .60865 .29689 .60634 .29398 Metetra
.645 .763 .934 r
.60634 .29398 .60865 .29689 .62347 .29179 .62117 .28887 Metetra
.645 .763 .934 r
.62117 .28887 .62347 .29179 .63836 .28667 .63608 .28373 Metetra
.645 .763 .934 r
.63608 .28373 .63836 .28667 .65334 .28152 .65107 .27856 Metetra
.645 .763 .934 r
.65107 .27856 .65334 .28152 .66839 .27634 .66614 .27337 Metetra
.645 .763 .934 r
.66614 .27337 .66839 .27634 .68353 .27113 .6813 .26815 Metetra
.645 .763 .934 r
.6813 .26815 .68353 .27113 .69875 .2659 .69653 .26289 Metetra
.645 .763 .934 r
.69653 .26289 .69875 .2659 .71404 .26064 .71185 .25762 Metetra
.325 .482 .862 r
.0398 .29666 .04225 .30051 .05281 .30044 .0499 .29958 Metetra
.899 .84 .778 r
.0499 .29958 .05281 .30044 .06573 .28492 .06321 .2816 Metetra
.1 .394 .85 r
.06321 .2816 .06573 .28492 .07604 .28721 .07314 .28651 Metetra
.853 .896 .866 r
.07314 .28651 .07604 .28721 .08843 .27553 .08553 .27495 Metetra
.89 .883 .819 r
.08553 .27495 .08843 .27553 .10124 .26071 .09836 .2601 Metetra
.921 .844 .751 r
.09836 .2601 .10124 .26071 .11438 .24318 .11202 .23898 Metetra
.625 .612 .818 r
.11202 .23898 .11438 .24318 .12566 .23963 .12333 .23521 Metetra
.019 .25 .753 r
.12333 .23521 .12566 .23963 .13554 .24756 .1332 .24312 Metetra
0 .209 .73 r
.1332 .24312 .13554 .24756 .14545 .25635 .14311 .25189 Metetra
.603 .593 .814 r
.14311 .25189 .14545 .25635 .15735 .24979 .15459 .24878 Metetra
.642 .886 .985 r
.15459 .24878 .15735 .24979 .16857 .24934 .16631 .24412 Metetra
.911 .556 .1 r
.16631 .24412 .16857 .24934 .17594 .28386 .17365 .27858 Metetra
.666 .593 .765 r
.17365 .27858 .17594 .28386 .18838 .27487 .18583 .27195 Metetra
.699 .73 .875 r
.18583 .27195 .18838 .27487 .20059 .26825 .19799 .26591 Metetra
.616 .755 .945 r
.19799 .26591 .20059 .26825 .2127 .26301 .20992 .26249 Metetra
.935 .867 .746 r
.20992 .26249 .2127 .26301 .22649 .24101 .22375 .24044 Metetra
.938 .861 .737 r
.22375 .24044 .22649 .24101 .24028 .21813 .23758 .21752 Metetra
.931 .873 .757 r
.23758 .21752 .24028 .21813 .2534 .20182 .25112 .19688 Metetra
0 0 .381 r
.25112 .19688 .2534 .20182 .26343 .22101 .26113 .21603 Metetra
0 0 .325 r
.26113 .21603 .26343 .22101 .27355 .24205 .27123 .23702 Metetra
.667 .305 0 r
.27123 .23702 .27355 .24205 .28377 .26512 .28143 .26004 Metetra
.846 .682 .679 r
.28143 .26004 .28377 .26512 .29811 .23636 .29561 .23368 Metetra
.879 .454 .05 r
.29561 .23368 .29811 .23636 .30824 .26559 .30585 .26121 Metetra
.963 .63 .292 r
.30585 .26121 .30824 .26559 .31575 .3396 .31329 .33516 Metetra
.696 .298 0 r
.31329 .33516 .31575 .3396 .32737 .35859 .32462 .35846 Metetra
.972 .858 .668 r
.32462 .35846 .32737 .35859 .34227 .32541 .33958 .3252 Metetra
.974 .851 .658 r
.33958 .3252 .34227 .32541 .35706 .29101 .35442 .29073 Metetra
.975 .845 .649 r
.35442 .29073 .35706 .29101 .37174 .25536 .36915 .25501 Metetra
.976 .838 .641 r
.36915 .25501 .37174 .25536 .38628 .21847 .38375 .21803 Metetra
.571 .922 .957 r
.38375 .21803 .38628 .21847 .39909 .21849 .39679 .21273 Metetra
.869 .519 .016 r
.39679 .21273 .39909 .21849 .41028 .26461 .40795 .25876 Metetra
.886 .537 .048 r
.40795 .25876 .41028 .26461 .42182 .31575 .41944 .3098 Metetra
.797 .448 0 r
.41944 .3098 .42182 .31575 .43429 .35328 .43178 .35054 Metetra
.645 .763 .934 r
.43178 .35054 .43429 .35328 .44822 .34848 .44573 .34573 Metetra
.645 .763 .934 r
.44573 .34573 .44822 .34848 .46222 .34365 .45974 .34089 Metetra
.645 .763 .934 r
.45974 .34089 .46222 .34365 .4763 .3388 .47383 .33602 Metetra
.645 .763 .934 r
.47383 .33602 .4763 .3388 .49045 .33393 .488 .33113 Metetra
.645 .763 .934 r
.488 .33113 .49045 .33393 .50467 .32902 .50224 .32621 Metetra
.645 .763 .934 r
.50224 .32621 .50467 .32902 .51896 .3241 .51655 .32127 Metetra
.645 .763 .934 r
.51655 .32127 .51896 .3241 .53334 .31914 .53093 .3163 Metetra
.645 .763 .934 r
.53093 .3163 .53334 .31914 .54778 .31416 .5454 .31131 Metetra
.645 .763 .934 r
.5454 .31131 .54778 .31416 .56231 .30916 .55993 .30629 Metetra
.645 .763 .934 r
.55993 .30629 .56231 .30916 .5769 .30413 .57455 .30124 Metetra
.645 .763 .934 r
.57455 .30124 .5769 .30413 .59158 .29907 .58924 .29617 Metetra
.645 .763 .934 r
.58924 .29617 .59158 .29907 .60634 .29398 .60401 .29106 Metetra
.645 .763 .934 r
.60401 .29106 .60634 .29398 .62117 .28887 .61886 .28594 Metetra
.645 .763 .934 r
.61886 .28594 .62117 .28887 .63608 .28373 .63379 .28078 Metetra
.645 .763 .934 r
.63379 .28078 .63608 .28373 .65107 .27856 .6488 .2756 Metetra
.645 .763 .934 r
.6488 .2756 .65107 .27856 .66614 .27337 .66389 .27039 Metetra
.645 .763 .934 r
.66389 .27039 .66614 .27337 .6813 .26815 .67906 .26515 Metetra
.645 .763 .934 r
.67906 .26515 .6813 .26815 .69653 .26289 .69431 .25988 Metetra
.645 .763 .934 r
.69431 .25988 .69653 .26289 .71185 .25762 .70964 .25459 Metetra
.582 .415 .62 r
.03879 .28355 .0398 .29666 .0499 .29958 .05023 .27751 Metetra
.544 .35 .568 r
.05023 .27751 .0499 .29958 .06321 .2816 .06153 .27259 Metetra
.706 .538 .658 r
.06153 .27259 .06321 .2816 .07314 .28651 .07447 .25681 Metetra
.464 .271 .534 r
.07447 .25681 .07314 .28651 .08553 .27495 .08413 .26378 Metetra
.653 .481 .639 r
.08413 .26378 .08553 .27495 .09836 .2601 .0966 .25147 Metetra
.693 .534 .667 r
.0966 .25147 .09836 .2601 .11202 .23898 .10922 .23799 Metetra
.063 .593 .866 r
.10922 .23799 .11202 .23898 .12333 .23521 .11987 .23932 Metetra
.405 0 .096 r
.11987 .23932 .12333 .23521 .1332 .24312 .13077 .23938 Metetra
.079 .343 .817 r
.13077 .23938 .1332 .24312 .14311 .25189 .141 .24543 Metetra
.789 .469 0 r
.141 .24543 .14311 .25189 .15459 .24878 .14857 .27449 Metetra
.238 0 .32 r
.14857 .27449 .15459 .24878 .16631 .24412 .1633 .24518 Metetra
.839 .999 .819 r
.1633 .24518 .16631 .24412 .17365 .27858 .17605 .23219 Metetra
.485 .275 .519 r
.17605 .23219 .17365 .27858 .18583 .27195 .18677 .23738 Metetra
.571 .354 .546 r
.18677 .23738 .18583 .27195 .19799 .26591 .19984 .2218 Metetra
.552 .331 .533 r
.19984 .2218 .19799 .26591 .20992 .26249 .21273 .20765 Metetra
.474 .262 .511 r
.21273 .20765 .20992 .26249 .22375 .24044 .22326 .21712 Metetra
.203 .088 .491 r
.22326 .21712 .22375 .24044 .23758 .21752 .23182 .24884 Metetra
.289 .044 .359 r
.23182 .24884 .23758 .21752 .25112 .19688 .24651 .21738 Metetra
.445 .158 .382 r
.24651 .21738 .25112 .19688 .26113 .21603 .2587 .21259 Metetra
.69 .696 .851 r
.2587 .21259 .26113 .21603 .27123 .23702 .27105 .20649 Metetra
.324 .166 .507 r
.27105 .20649 .27123 .23702 .28143 .26004 .2807 .23487 Metetra
.36 .205 .531 r
.2807 .23487 .28143 .26004 .29561 .23368 .29132 .25462 Metetra
.391 .111 .365 r
.29132 .25462 .29561 .23368 .30585 .26121 .30442 .24337 Metetra
.696 .48 .59 r
.30442 .24337 .30585 .26121 .31329 .33516 .31882 .21305 Metetra
.479 .254 .495 r
.31882 .21305 .31329 .33516 .32462 .35846 .3301 .22932 Metetra
.447 .228 .488 r
.3301 .22932 .32462 .35846 .33958 .3252 .34013 .27047 Metetra
.567 .338 .528 r
.34013 .27047 .33958 .3252 .35442 .29073 .35427 .24562 Metetra
.527 .311 .529 r
.35427 .24562 .35442 .29073 .36915 .25501 .36737 .23875 Metetra
0 0 .391 r
.36737 .23875 .36915 .25501 .38375 .21803 .37798 .28566 Metetra
.436 .19 .442 r
.37798 .28566 .38375 .21803 .39679 .21273 .39218 .26072 Metetra
.59 .312 .462 r
.39218 .26072 .39679 .21273 .40795 .25876 .40382 .29929 Metetra
.637 .347 .462 r
.40382 .29929 .40795 .25876 .41944 .3098 .41538 .3526 Metetra
.474 .21 .433 r
.41538 .3526 .41944 .3098 .43178 .35054 .42927 .34779 Metetra
.645 .763 .934 r
.42927 .34779 .43178 .35054 .44573 .34573 .44323 .34296 Metetra
.645 .763 .934 r
.44323 .34296 .44573 .34573 .45974 .34089 .45726 .33811 Metetra
.645 .763 .934 r
.45726 .33811 .45974 .34089 .47383 .33602 .47137 .33323 Metetra
.645 .763 .934 r
.47137 .33323 .47383 .33602 .488 .33113 .48554 .32832 Metetra
.645 .763 .934 r
.48554 .32832 .488 .33113 .50224 .32621 .49979 .32339 Metetra
.645 .763 .934 r
.49979 .32339 .50224 .32621 .51655 .32127 .51412 .31843 Metetra
.645 .763 .934 r
.51412 .31843 .51655 .32127 .53093 .3163 .52852 .31345 Metetra
.645 .763 .934 r
.52852 .31345 .53093 .3163 .5454 .31131 .543 .30844 Metetra
.645 .763 .934 r
.543 .30844 .5454 .31131 .55993 .30629 .55755 .30341 Metetra
.645 .763 .934 r
.55755 .30341 .55993 .30629 .57455 .30124 .57218 .29834 Metetra
.645 .763 .934 r
.57218 .29834 .57455 .30124 .58924 .29617 .58689 .29325 Metetra
.645 .763 .934 r
.58689 .29325 .58924 .29617 .60401 .29106 .60168 .28814 Metetra
.645 .763 .934 r
.60168 .28814 .60401 .29106 .61886 .28594 .61655 .28299 Metetra
.645 .763 .934 r
.61655 .28299 .61886 .28594 .63379 .28078 .63149 .27782 Metetra
.645 .763 .934 r
.63149 .27782 .63379 .28078 .6488 .2756 .64652 .27262 Metetra
.645 .763 .934 r
.64652 .27262 .6488 .2756 .66389 .27039 .66162 .2674 Metetra
.645 .763 .934 r
.66162 .2674 .66389 .27039 .67906 .26515 .67681 .26214 Metetra
.645 .763 .934 r
.67681 .26214 .67906 .26515 .69431 .25988 .69208 .25686 Metetra
.645 .763 .934 r
.69208 .25686 .69431 .25988 .70964 .25459 .70743 .25155 Metetra
.491 .128 .277 r
.03456 .29097 .03879 .28355 .05023 .27751 .04481 .29294 Metetra
.097 0 .192 r
.04481 .29294 .05023 .27751 .06153 .27259 .05889 .27005 Metetra
.637 .13 0 r
.05889 .27005 .06153 .27259 .07447 .25681 .0679 .28103 Metetra
.242 0 .311 r
.0679 .28103 .07447 .25681 .08413 .26378 .08238 .25507 Metetra
.593 .467 .677 r
.08238 .25507 .08413 .26378 .0966 .25147 .09377 .25042 Metetra
.901 .833 .769 r
.09377 .25042 .0966 .25147 .10922 .23799 .10713 .23173 Metetra
.355 .371 .739 r
.10713 .23173 .10922 .23799 .11987 .23932 .11733 .23636 Metetra
0 .291 .784 r
.11733 .23636 .11987 .23932 .13077 .23938 .12741 .24274 Metetra
.692 .281 .262 r
.12741 .24274 .13077 .23938 .141 .24543 .13688 .25499 Metetra
.432 .09 .285 r
.13688 .25499 .141 .24543 .14857 .27449 .14822 .25334 Metetra
.644 .432 .581 r
.14822 .25334 .14857 .27449 .1633 .24518 .16213 .23077 Metetra
0 0 .265 r
.16213 .23077 .1633 .24518 .17605 .23219 .16841 .27363 Metetra
.53 .261 .451 r
.16841 .27363 .17605 .23219 .18677 .23738 .17863 .28487 Metetra
.396 .147 .415 r
.17863 .28487 .18677 .23738 .19984 .2218 .19291 .25992 Metetra
.502 .233 .439 r
.19291 .25992 .19984 .2218 .21273 .20765 .20417 .26309 Metetra
.302 .073 .39 r
.20417 .26309 .21273 .20765 .22326 .21712 .22111 .21068 Metetra
.352 .37 .74 r
.22111 .21068 .22326 .21712 .23182 .24884 .2322 .21578 Metetra
.608 .385 .552 r
.2322 .21578 .23182 .24884 .24651 .21738 .24623 .19042 Metetra
.358 .197 .522 r
.24623 .19042 .24651 .21738 .2587 .21259 .25607 .21126 Metetra
.866 .42 .102 r
.25607 .21126 .2587 .21259 .27105 .20649 .26599 .23411 Metetra
.6 .309 .447 r
.26599 .23411 .27105 .20649 .2807 .23487 .276 .25919 Metetra
.343 .078 .36 r
.276 .25919 .2807 .23487 .29132 .25462 .28968 .24032 Metetra
.734 .521 .604 r
.28968 .24032 .29132 .25462 .30442 .24337 .30427 .2082 Metetra
.196 .064 .464 r
.30427 .2082 .30442 .24337 .31882 .21305 .31299 .25905 Metetra
.642 .358 .473 r
.31299 .25905 .31882 .21305 .3301 .22932 .32152 .32078 Metetra
.524 .267 .468 r
.32152 .32078 .3301 .22932 .34013 .27047 .33323 .34015 Metetra
.402 .162 .432 r
.33323 .34015 .34013 .27047 .35427 .24562 .34843 .30226 Metetra
.373 .134 .418 r
.34843 .30226 .35427 .24562 .36737 .23875 .36349 .26306 Metetra
.139 0 .292 r
.36349 .26306 .36737 .23875 .37798 .28566 .37838 .22255 Metetra
.551 .321 .52 r
.37838 .22255 .37798 .28566 .39218 .26072 .39221 .20109 Metetra
.354 .17 .487 r
.39221 .20109 .39218 .26072 .40382 .29929 .40314 .25063 Metetra
.292 .13 .482 r
.40314 .25063 .40382 .29929 .41538 .3526 .41441 .30567 Metetra
.436 .24 .515 r
.41441 .30567 .41538 .3526 .42927 .34779 .42736 .32525 Metetra
.719 .485 .57 r
.42736 .32525 .42927 .34779 .44323 .34296 .44235 .27905 Metetra
.6 .359 .524 r
.44235 .27905 .44323 .34296 .45726 .33811 .45708 .23146 Metetra
.401 .197 .485 r
.45708 .23146 .45726 .33811 .47137 .33323 .46951 .29557 Metetra
.37 .2 .517 r
.46951 .29557 .47137 .33323 .48554 .32832 .48308 .32551 Metetra
.645 .763 .934 r
.48308 .32551 .48554 .32832 .49979 .32339 .49735 .32056 Metetra
.645 .763 .934 r
.49735 .32056 .49979 .32339 .51412 .31843 .51169 .31559 Metetra
.645 .763 .934 r
.51169 .31559 .51412 .31843 .52852 .31345 .52611 .31059 Metetra
.645 .763 .934 r
.52611 .31059 .52852 .31345 .543 .30844 .5406 .30557 Metetra
.645 .763 .934 r
.5406 .30557 .543 .30844 .55755 .30341 .55517 .30052 Metetra
.645 .763 .934 r
.55517 .30052 .55755 .30341 .57218 .29834 .56981 .29544 Metetra
.645 .763 .934 r
.56981 .29544 .57218 .29834 .58689 .29325 .58454 .29033 Metetra
.645 .763 .934 r
.58454 .29033 .58689 .29325 .60168 .28814 .59934 .2852 Metetra
.645 .763 .934 r
.59934 .2852 .60168 .28814 .61655 .28299 .61422 .28004 Metetra
.645 .763 .934 r
.61422 .28004 .61655 .28299 .63149 .27782 .62918 .27486 Metetra
.645 .763 .934 r
.62918 .27486 .63149 .27782 .64652 .27262 .64423 .26964 Metetra
.645 .763 .934 r
.64423 .26964 .64652 .27262 .66162 .2674 .65935 .2644 Metetra
.645 .763 .934 r
.65935 .2644 .66162 .2674 .67681 .26214 .67455 .25913 Metetra
.645 .763 .934 r
.67455 .25913 .67681 .26214 .69208 .25686 .68984 .25383 Metetra
.645 .763 .934 r
.68984 .25383 .69208 .25686 .70743 .25155 .70521 .2485 Metetra
.825 .721 .75 r
.03199 .28779 .03456 .29097 .04481 .29294 .04505 .27159 Metetra
.634 .424 .581 r
.04505 .27159 .04481 .29294 .05889 .27005 .05872 .25115 Metetra
.545 .359 .58 r
.05872 .25115 .05889 .27005 .0679 .28103 .06994 .24684 Metetra
.462 .264 .524 r
.06994 .24684 .0679 .28103 .08238 .25507 .07945 .25463 Metetra
.913 .869 .782 r
.07945 .25463 .08238 .25507 .09377 .25042 .09275 .23656 Metetra
.427 .294 .596 r
.09275 .23656 .09377 .25042 .10713 .23173 .10268 .24258 Metetra
.709 .386 .43 r
.10268 .24258 .10713 .23173 .11733 .23636 .1098 .27047 Metetra
.467 .198 .422 r
.1098 .27047 .11733 .23636 .12741 .24274 .12141 .26618 Metetra
.646 .352 .459 r
.12141 .26618 .12741 .24274 .13688 .25499 .12837 .29885 Metetra
.345 .1 .392 r
.12837 .29885 .13688 .25499 .14822 .25334 .14363 .26686 Metetra
0 0 .119 r
.14363 .26686 .14822 .25334 .16213 .23077 .15805 .24065 Metetra
.718 .387 .417 r
.15805 .24065 .16213 .23077 .16841 .27363 .16607 .26871 Metetra
.619 .585 .794 r
.16607 .26871 .16841 .27363 .17863 .28487 .17798 .26467 Metetra
.532 .347 .576 r
.17798 .26467 .17863 .28487 .19291 .25992 .18985 .26159 Metetra
.968 .928 .691 r
.18985 .26159 .19291 .25992 .20417 .26309 .20425 .23495 Metetra
.608 .39 .56 r
.20425 .23495 .20417 .26309 .22111 .21068 .21799 .2138 Metetra
.828 .956 .615 r
.21799 .2138 .22111 .21068 .2322 .21578 .23157 .19348 Metetra
.47 .293 .558 r
.23157 .19348 .2322 .21578 .24623 .19042 .24273 .19841 Metetra
.784 .444 .411 r
.24273 .19841 .24623 .19042 .25607 .21126 .25097 .23746 Metetra
.362 .097 .371 r
.25097 .23746 .25607 .21126 .26599 .23411 .26445 .21982 Metetra
.711 .518 0 r
.26445 .21982 .26599 .23411 .276 .25919 .27121 .28391 Metetra
.033 0 .241 r
.27121 .28391 .276 .25919 .28968 .24032 .28724 .23654 Metetra
.64 .662 .855 r
.28724 .23654 .28968 .24032 .30427 .2082 .29982 .23206 Metetra
.75 .444 .466 r
.29982 .23206 .30427 .2082 .31299 .25905 .30676 .30949 Metetra
.324 .091 .397 r
.30676 .30949 .31299 .25905 .32152 .32078 .32247 .26434 Metetra
.438 .234 .505 r
.32247 .26434 .32152 .32078 .33323 .34015 .33382 .28574 Metetra
.612 .374 .532 r
.33382 .28574 .33323 .34015 .34843 .30226 .3493 .23996 Metetra
.495 .278 .512 r
.3493 .23996 .34843 .30226 .36349 .26306 .36194 .24228 Metetra
.476 .306 .571 r
.36194 .24228 .36349 .26306 .37838 .22255 .37462 .24649 Metetra
.039 0 .254 r
.37462 .24649 .37838 .22255 .39221 .20109 .38979 .19795 Metetra
.951 .599 .253 r
.38979 .19795 .39221 .20109 .40314 .25063 .39993 .26608 Metetra
.176 0 .256 r
.39993 .26608 .40314 .25063 .41441 .30567 .41409 .24231 Metetra
.307 .134 .475 r
.41409 .24231 .41441 .30567 .42736 .32525 .42526 .3095 Metetra
.796 .559 .579 r
.42526 .3095 .42736 .32525 .44235 .27905 .44048 .25456 Metetra
.529 .338 .565 r
.44048 .25456 .44235 .27905 .45708 .23146 .45415 .25085 Metetra
.775 .449 .435 r
.45415 .25085 .45708 .23146 .46951 .29557 .4664 .32762 Metetra
.463 .19 .413 r
.4664 .32762 .46951 .29557 .48308 .32551 .48061 .32268 Metetra
.645 .763 .934 r
.48061 .32268 .48308 .32551 .49735 .32056 .49489 .31772 Metetra
.645 .763 .934 r
.49489 .31772 .49735 .32056 .51169 .31559 .50925 .31274 Metetra
.645 .763 .934 r
.50925 .31274 .51169 .31559 .52611 .31059 .52368 .30772 Metetra
.645 .763 .934 r
.52368 .30772 .52611 .31059 .5406 .30557 .53819 .30268 Metetra
.645 .763 .934 r
.53819 .30268 .5406 .30557 .55517 .30052 .55277 .29762 Metetra
.645 .763 .934 r
.55277 .29762 .55517 .30052 .56981 .29544 .56744 .29252 Metetra
.645 .763 .934 r
.56744 .29252 .56981 .29544 .58454 .29033 .58218 .2874 Metetra
.645 .763 .934 r
.58218 .2874 .58454 .29033 .59934 .2852 .597 .28226 Metetra
.645 .763 .934 r
.597 .28226 .59934 .2852 .61422 .28004 .61189 .27708 Metetra
.645 .763 .934 r
.61189 .27708 .61422 .28004 .62918 .27486 .62687 .27188 Metetra
.645 .763 .934 r
.62687 .27188 .62918 .27486 .64423 .26964 .64193 .26665 Metetra
.645 .763 .934 r
.64193 .26665 .64423 .26964 .65935 .2644 .65707 .26139 Metetra
.645 .763 .934 r
.65707 .26139 .65935 .2644 .67455 .25913 .67229 .2561 Metetra
.645 .763 .934 r
.67229 .2561 .67455 .25913 .68984 .25383 .6876 .25079 Metetra
.645 .763 .934 r
.6876 .25079 .68984 .25383 .70521 .2485 .70298 .24544 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.25709 .16902 m
.26153 .17385 L
s
[(20)] .24822 .15935 .91837 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(40)] .50253 .05935 .75799 1 Mshowa
.125 Mabswid
.08191 .23761 m
.08475 .24034 L
s
.13899 .21527 m
.14177 .21805 L
s
.19737 .19241 m
.20009 .19525 L
s
.31821 .14509 m
.32081 .14804 L
s
.38078 .12059 m
.38331 .1236 L
s
.44485 .0955 m
.4473 .09858 L
s
.57768 .04348 m
.57998 .04668 L
s
.64658 .01651 m
.64878 .01977 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[30]:=",
  ImageSize->{539, 437.063},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008K0001]AP00`40o`000?l0003ooooooooooolM
oooo003ooooooooooagoool00?oooooooooo7Oooo`00oooooooooolMoooo003ooooooooooagoool0
0?oooooooooo7Oooo`00oooooooooolMoooo003ooooooooooagoool00?oooooooooo7Oooo`00oooo
oooooolMoooo003oooooN_ooo`80002Poooo003oooooN?ooo`8000000oooo`000000002Ooooo003o
ooooMOooo`<00003oooo0P0009ooool00?oooomcoooo0P0000Koool00`000?ooo`00002Noooo003o
ooooL?ooo`<00008oooo00@0003oooooool0002Moooo003oooooKOooo`<0000;oooo00@0003ooooo
ool0002Moooo003oooooJoooo`80000>oooo00D0003oooooooooool00000W?ooo`00ooooofSoool3
00004?ooo`030000oooooooo00;oool00`000?ooooooo`2Ioooo003oooooI_ooo`80000Coooo00<0
003oooooool00_ooo`030000oooooooo09Woool00?oooomSoooo0`0001Koool00`000?ooooooo`02
oooo00<0003oooooool0V?ooo`00ooooof7oool200000oooo`030000oooooooo01?oool00`000?oo
ooooo`03oooo00<0003oooooool0Uoooo`00oooooekoool300006oooo`030000oooooooo00?oool0
0`000?ooooooo`2Goooo003oooooG?ooo`80000Noooo00<0003oooooool01?ooo`030000oooooooo
09Koool00?oooomIoooo0`00023oool00`000?ooooooo`04oooo00<0003oooooool0U_ooo`00oooo
oeKoool300008oooo`030000oooooooo00Goool00`000?ooooooo`2Eoooo003oooooE?ooo`80000V
oooo00<0003oooooool00oooo`@0002Foooo003oooooDOooo`<0000Xoooo00<0003oooooool01_oo
o`030000oooooooo09Coool00?oooom?oooo0P0002_oool00`000?ooooooo`07oooo00<0003ooooo
ool0Toooo`00ooooodcoool30000;Oooo`030000oooooooo00Soool00`000?ooooooo`2Boooo003o
ooooB_ooo`80000`oooo00<0003oooooool02?ooo`030000oooooooo09;oool00?oooom7oooo0`00
03;oool00`000?ooooooo`09oooo00<0003oooooool0TOooo`00ooooodGoool20000=Oooo`030000
oooooooo00[oool00`000?ooooooo`2@oooo003ooooo@_ooo`<0000goooo00<0003oooooool02_oo
o`030000oooooooo093oool00?oooolDoooo0`0000;oool00`000?ooooooo`0Soooo0`000003oooo
0000oooo03Ooool00`000?ooooooo`0;oooo00<0003oooooool0Soooo`00oooooaGoool01P000?oo
ooooo`000?ooo`0002;oool200001?ooo`030000oooooooo03Koool00`000?ooooooo`0<oooo00<0
003oooooool0S_ooo`00oooooa?oool4000000Coool0003oool0000Ooooo0`0003ooool00`000?oo
ooooo`0<oooo00<0003oooooool0S_ooo`00oooooa?oool00`000?ooo`000002oooo00<0003oool0
00007Oooo`800012oooo00<0003oooooool03Oooo`030000oooooooo08goool00?oooolDoooo0P00
00;oool00`000?ooo`00000Joooo0`0004Goool00`000?ooooooo`0=oooo00<0003oooooool0S?oo
o`00oooooaGoool01@000?ooooooooooo`00000Ioooo0P0004Soool00`000?ooooooo`0=oooo00<0
003oooooool0S?ooo`00oooooc3oool30000B_ooo`030000oooooooo00koool00`000?ooooooo`2;
oooo003ooooo;_ooo`80001=oooo00<0003oooooool03_ooo`80002<oooo003ooooo:oooo`<0001?
oooo00<0003oooooool03?ooo`8000000oooo`000?ooo`2;oooo003ooooo:?ooo`<0001Boooo00<0
003oooooool04?ooo`030000oooooooo08Woool00?oooolVoooo0P0005Goool00`000?ooooooo`0A
oooo00<0003oooooool0R?ooo`00ooooob?oool30000Eoooo`030000oooooooo017oool00`000?oo
ooooo`28oooo003ooooo8Oooo`80001Joooo00<0003oooooool04_ooo`030000oooooooo08Ooool0
0?oooolNoooo0`0005coool00`000?ooooooo`0Boooo00<0003oooooool0Qoooo`00oooooacoool2
00000_ooo`030000oooooooo05[oool00`000?ooooooo`0Coooo00<0003oooooool0Q_ooo`00oooo
oaWoool300001?ooo`030000oooooooo05[oool00`000?ooooooo`0Doooo00<0003oooooool0QOoo
o`00oooooaKoool300002?ooo`030000oooooooo05Woool00`000?ooooooo`0Doooo00<0003ooooo
ool0QOooo`00oooooaCoool20000Ioooo`030000oooooooo01Goool00`000?ooooooo`24oooo003o
oooo4Oooo`<0001Yoooo00<0003oooooool05_ooo`030000oooooooo08?oool00?ooool?oooo0P00
06coool00`000?ooooooo`0Foooo00<0003oooooool0Poooo`00ooooo`coool30000K_ooo`030000
oooooooo01Ooool00`000?ooooooo`22oooo003ooooo2_ooo`80001aoooo00<0003oooooool06?oo
o`030000oooooooo087oool00?ooool7oooo0`0007Coool00`000?ooooooo`0Goooo00<0003ooooo
ool0POooo`00ooooo`Goool20000Moooo`030000oooooooo01Goool2000000?oool0003oool0POoo
o`00ooooo`;oool30000NOooo`030000oooooooo01Woool00`000?ooooooo`1ooooo003noooo0`00
07coool00`000?ooooooo`0Ioooo00<0003oooooool0Ooooo`00o?ooo`80001ooooo00<0003ooooo
ool06_ooo`030000oooooooo07koool00?Woool3000000?oool0003oool0O_ooo`030000oooooooo
01_oool00`000?ooooooo`1moooo003goooo0P0000Goool00`000?ooooooo`1loooo00<0003ooooo
ool06oooo`030000oooooooo07goool00?Coool30000Q_ooo`030000oooooooo01coool00`000?oo
ooooo`1loooo003boooo0P0008Woool00`000?ooooooo`0Moooo00<0003oooooool0Noooo`00kooo
o`<0002;oooo00<0003oooooool07Oooo`030000oooooooo07_oool00>goool20000S_ooo`030000
oooooooo01koool00`000?ooooooo`1joooo003Zoooo0`00093oool00`000?ooooooo`0Noooo00<0
003oooooool0N_ooo`00ioooo`<0002Coooo00<0003oooooool07oooo`030000oooooooo07Woool0
0>Goool20000U_ooo`030000oooooooo023oool00`000?ooooooo`1hoooo003Roooo0`0009Soool0
0`000?ooooooo`0Poooo00<0003oooooool0N?ooo`00h?ooo`80002Koooo00<0003oooooool08Ooo
o`030000oooooooo07Ooool00=goool30000WOooo`030000oooooooo01ooool2000000?oool0003o
ool0Moooo`00foooo`80002Poooo00<0003oooooool08_ooo`030000oooooooo07Koool00=Soool3
000000?oool0003oool0X?ooo`030000oooooooo02;oool00`000?ooooooo`1eoooo003Foooo0P00
00Goool00`000?ooooooo`2Noooo00<0003oooooool08oooo`030000oooooooo07Coool00=?oool3
0000Z?ooo`030000oooooooo02?oool00`000?ooooooo`1doooo003@oooo0`000:_oool00`000?oo
ooooo`0Toooo00<0003oooooool0Loooo`00c_ooo`80002^oooo00<0003oooooool09Oooo`030000
oooooooo07;oool00<_oool30000/?ooo`030000oooooooo02Goool00`000?ooooooo`0:oooo00<0
003oooooool00_ooo`030000oooooooo063oool00<Woool20000/oooo`030000oooooooo02Koool0
0`000?ooooooo`08oooo00<0003oool000000_ooo`030000oooo0000067oool00<Koool30000]Ooo
o`030000oooooooo02Ooool00`000?ooooooo`09oooo00H0003oooooool0003oool0001Qoooo0034
oooo0P000;Soool00`000?ooooooo`0Woooo00<0003oooooool01oooo`800003oooo00<0003oool0
0000HOooo`00`Oooo`<0002joooo00<0003oooooool0:?ooo`030000oooooooo00Koool00`000?oo
ooooo`02oooo00<0003oool00000HOooo`00_oooo`80002moooo00<0003oooooool0:Oooo`030000
oooooooo00Goool300000oooo`030000oooooooo063oool008ooool300000oooo`030000oooooooo
02Coool30000_oooo`030000oooooooo02Woool00`000?ooooooo`1^oooo002?oooo00<0003ooooo
ool00_ooo`030000oooo000002;oool30000`_ooo`030000oooooooo02Soool30000Koooo`00T?oo
o`070000oooooooooooo0000oooo0000023oool200000oooo`800030oooo00<0003oooooool09_oo
o`800003oooo00<0003oooooool0K?ooo`00T?ooo`070000oooooooooooo0000oooo000001goool3
0000aoooo`030000oooooooo02_oool00`000?ooooooo`1/oooo002?oooo00<0003oool000000_oo
o`030000oooo000001_oool20000b_ooo`030000oooooooo02coool00`000?ooooooo`1[oooo002@
oooo00<0003oooooool00_ooo`030000oooooooo01Ooool30000c?ooo`030000oooooooo02coool0
0`000?ooooooo`1[oooo002]oooo0P000<ooool00`000?ooooooo`0]oooo00<0003oooooool0J_oo
o`00Z_ooo`<0003Boooo00<0003oooooool0;Oooo`030000oooooooo06Woool00:Soool20000eOoo
o`030000oooooooo02goool00`000?ooooooo`1Yoooo002Uoooo0`000=Ooool00`000?ooooooo`0^
oooo00<0003oooooool0J?ooo`00X_ooo`<0003Joooo00<0003oooooool0;oooo`030000oooooooo
06Ooool00:3oool20000gOooo`030000oooooooo02ooool00`000?ooooooo`1Woooo002Moooo0`00
0=ooool00`000?ooooooo`0`oooo00<0003oooooool0I_ooo`00Voooo`80003Roooo00<0003ooooo
ool0<Oooo`030000oooooooo06Goool009Soool300000_ooo`030000oooooooo0=ooool00`000?oo
ooooo`0aoooo00<0003oooooool0IOooo`00U_ooo`800006oooo00<0003oooooool0g_ooo`030000
oooooooo033oool30000I_ooo`00Toooo`<0003Yoooo00<0003oooooool0<oooo`030000oooooooo
06?oool0097oool20000k?ooo`030000oooooooo03?oool00`000?ooooooo`1Soooo002>oooo0`00
0>koool00`000?ooooooo`0doooo00<0003oooooool0H_ooo`00Roooo`<0003aoooo00<0003ooooo
ool0=Oooo`030000oooooooo067oool008Woool20000m?ooo`030000oooooooo03Goool00`000?oo
ooooo`1Qoooo0026oooo0`000?Koool00`000?ooooooo`0foooo00<0003oooooool0H?ooo`00Q?oo
o`80003ioooo00<0003oooooool0=oooo`030000oooooooo05ooool0087oool30000noooo`030000
oooooooo03Ooool00`000?ooooooo`1Ooooo001ooooo0P0001Goool00`000?ooooooo`3Voooo00<0
003oooooool0>?ooo`030000oooooooo05koool007coool300005_ooo`80003Yoooo00<0003ooooo
ool0>?ooo`030000oooooooo05goool007Woool300000_ooo`80000?oooo0P0000Coool00`000<Qa
J@00003Xoooo00<0003oooooool0>?ooo`030000oooooooo05goool007Ooool200005Oooo`800000
0gQ;SP0000000003000000C8LFT0003oool0003Voooo00<0003oooooool0>Oooo`030000oooooooo
05coool007Coool300005oooo`800004N4^>0P0000;8LFT30000AOooo`030000oooooooo09goool0
0`000?ooooooo`0ioooo00<0003oooooool0G?ooo`00L_ooo`80000Ioooo00<0003Cm9d000000gQ;
SP030000Vf:=000000;8LFT00`00074XH@000015oooo0P0009koool00`000?ooooooo`0hoooo00<0
003oool00000GOooo`00Koooo`<0000Joooo00@0003Cm9gCm9d00003N4^>00<0002KHXd000000lQa
J@030000LBQQ000004?oool30000W_ooo`030000oooooooo03_oool00`000?ooooooo`1Joooo001]
oooo0P0001coool01@000=?dWM?dWM?dW@000002N4^>00D0002KHXfKHXfKHXd000000/QaJ@030000
LBQQ000004?oool30000W_ooo`030000oooooooo03_oool00`000?ooooooo`1Joooo001Zoooo0`00
01koool01@000=?dWM?dWM?dW@000002N4^>00D0002KHXfKHXfKHXd000000lQaJ@040000LBQQ0000
00001Oooo`030000oooooooo03Woool0100008eBQ@00000009goool00`000?ooooooo`0loooo00<0
003oooooool0FOooo`00J?ooo`80000Koooo00<0003oooooool00_ooo`030000doBMdoBM00;Cm9d0
0`0007Q;SP000004Vf:=00T00038LFW8LFW8LFT0001a:6400034D@0000000_ooo`<0000@oooo00<0
003oooooool09oooo`030000SE:5SE:50080002Moooo00<0003oooooool0?Oooo`030000oooooooo
05Soool006Goool300007?ooo`<00002oooo00<0003Cm9gCm9d00m?dW@030000N4^>000000BKHXd0
0`000<QaJLQaJ@02b75Y00<0001a:64000000`0000;MJaX200003oooo`030000oooooooo02Ooool0
0`0008eBQHeBQ@020000WOooo`030000oooooooo03goool00`000?ooooooo`1Hoooo001Roooo0`00
01koool01000080kL00004dBH`D00003doBM0P0000FKHXd00`000<QaJLQaJ@02b75Y100000?MJaX0
0`0009U?LP00000>oooo0P0002Soool200000XeBQ@@0002Koooo00<0003oooooool0?_ooo`030000
oooooooo05Ooool0063oool200008?ooo`040000P3]`P3]`00000TdBH`<0000015YN_@0000000=?d
W@800005Vf:=0P0000?8LFT00`000=e[6]e[6P04gF/J00<0002ICg8000003_ooo`030000_g5g0000
00Koool00`000?ooooooo`0Noooo00H0002=DXF=DXF=DXD0003cVD020000Voooo`030000oooooooo
03ooool00`000?ooooooo`1Foooo001Moooo0`0002;oool00`00080kL0000002CA9S0P000003ND>2
00000000009JG[d200001Y]RS@800003b75Y0P0000GMJaX0100009U?LYU?LP0000coool2000000>o
LGL0003oool01?ooo`<0000Noooo0P0000>=DXD00`000?>I@00000020000V_ooo`030000oooooooo
03ooool00`000?ooooooo`1Foooo001Koooo0P0000?oool200007oooo`040000P3]`P3]`00000TdB
H`800002ND>200D0001JG[eJG[eJG[d000001Y]RS@800003b75Y0P0000GMJaX0100009U?LYU?LP00
00coool2000000>oLGL0003oool01?ooo`<0000Moooo00<00009044000000heBQ@030000liU00000
0080002Joooo00<0003oooooool0@?ooo`030000oooooooo05Goool005Soool300009Oooo`090000
P3]`P3]`P3]`0000CA9S0000Vf>?0000009i@h801@0005YN_EYN_EYN_@000006Vf:=0P0000;8LFT0
100005`HGU`HGP0000;MJaX200000iU?LP030000oooooooo00[oool2000000>oLGL0003oool00ooo
o`050000<Q1f0000Y5]i000001coool2000018eBQ@H0002Ioooo00<0003oooooool0@Oooo`030000
oooooooo05Coool005Koool200009oooo`030000P3]`P3]`00:0>g02000000>KHhl0001i@h800WU3
PP800002FUjm00<0002KHXfKHXd00i]RS@030000h/g3000000;8LFT01@0005`HGU`HGP000=e[6P03
000019U?LP030000oooooooo00Soool01@000:>YfP000;maM`000004oooo0P0000>TFgT00`000?oo
ooooo`0Hoooo00<000090440000018eBQ@8000000o>I@000000000020000V?ooo`030000oooooooo
047oool00`000?ooooooo`1Doooo001Coooo0`0002Soool20000180kL08000000i]SS`0007U3PP02
ND>20P00009JG[d00`0009]RSI]RS@03Vf:=0P000004dK:k0000b75Y00000e`HGP040000G1QN0000
000019U?LP030000oooooooo00Soool00`000:>YfP000002_g5g00H0003oooooool0000b47H00003
Y5]i00<0003oooooool06?ooo`0300002@11000000B=DXD2000000?cVD00000000000P0009Soool0
0`000?ooooooo`12oooo00<0003oooooool0Doooo`00DOooo`80000Zoooo00<0001U9FX00000180k
L0040000Vf>?Vf>?00000gU3PP800002FUjm00<0002KHXfKHXd00Y]RS@8000001MVd/`0000000<Qa
J@000003G1QN00@0001L65h000000004VDmb0P0000Soool00`000:>YfP000003_g5g00H0003ooooo
ool0000b47H00004Y5]i00<0003oooooool05_ooo`8000000`T0@@0008eBQ@03SE:50P000003liU0
0000000000@0002Foooo00<0003oooooool0@?ooo`@0001Doooo001>oooo0`0002_oool00`0006DU
JP000005P3]`00<0002KHhl0000017U3PP800002FUjm00<0002KHXfKHXd00Y]RS@8000001MVd/`00
00000<QaJ@000002G1QN1@0000FICg8200001oooo`030000XjWJ000000>oLGL00`000?ooo`000002
<Q1f00<0002TFgVTFgT00ZAKN@030000oooooooo01Koool300001HeBQ@8000000o>I@00009M?MP05
0000U_ooo`030000oooooooo04;oool00`000?ooooooo`1Boooo001;oooo0`0002goool0100006DU
JVDUJP0000B0>g00100009]SSi]SS`0000Ai@h801@0003<FO@0005YN_@000003Vf:=0P000007fKBc
0000j/nk0000b75Y0000G1QN008000000mFg^`0000000006VDmb0P0000Koool010000:>YfZ>YfP00
00>oLGL00`000?ooo`000002<Q1f00<0002TFgVTFgT00jAKN@030000oooooooo01Goool00`0000T0
@@000005SE:50P000003liU00000Udmf00D0002Foooo00<0003oooooool0@oooo`030000oooooooo
057oool004Woool200001?ooo`030000oooooooo01Woool00`000?ooooooo`04oooo00<0003ooooo
ool01_ooo`040000IBEZIBEZ00000h0kL0050000Vf>?Vf>?Vf>?000000Ai@h801@0003<FO@0005YN
_@000003Vf:=0P000003fKBc00000000008000000e`HGP0000000002eKNk0`0000FICg800`000<IB
00000005oooo00@0002SZMX000000003_g5g0P0000<b47H00`000:AKNJAKN@03Y5]i00<0003ooooo
ool05?ooo`8000000`T0@@0008eBQ@04SE:50P0000;cVD04000000?]RCD0000000005oooo`030000
oooooooo07_oool00`000?ooooooo`14oooo00<0003oooooool0D?ooo`00A_ooo`<00005oooo1000
01Soool200001Oooo`@00005oooo00D0001U9FYU9FYU9FX000000h0kL0040000Vf>?Vf>?00001GU3
PP050000<aIm0000FUjm000000:KHXd2000000OI];<0003Zck/0003J][@0001L65h00P000003eKNk
0000000000800006VDmb0`0000Coool2000000>kQIX0002oLGL00kmaM`050000<Q1f<Q1f<Q1f0000
00FTFgT200005Oooo`<00006SE:500@0001J:g`0003cVD04000000C]RCD000000000000Foooo00<0
003oooooool0Noooo`030000oooooooo04Coool00`000?ooooooo`1@oooo0014oooo0P0000Soool0
10000;ERK[ERK[ERKP800002oooo0P0001;oool200001?ooo`0300000013000000:7@W<200000_oo
o`030000IBEZIBEZ009U9FX01000080kL80kL00000>KHhl00`0007U3PWU3PP03ND>200D0000c5Wd0
001JG[d000000Y]RS@030000fKBcfKBc00800002f[Jd0`000003eKNk0000i/no00<00006VDmb0`00
00;oool200000k^5VP030000_g5g_g5g00:oLGL01@00038@MS8@MS8@MP000005Y5]i0P0001Goool3
00001XeBQ@060000FR]l0000liU00000Udmf1P0001Goool20000OOooo`030000oooooooo04Goool0
0`000?ooooooo`1?oooo0011oooo0`0000Coool00`000?ooooooo`02oooo0P0000FeHVh3000000=W
01P0003oool03oooo`<00003oooo00<0000004<000001HM2L`800004IBEZ00<00020>g20>g000P00
00>KHhl00`0007U3PWU3PP03ND>21@0000:KHXd01@000=Vd/`000>[?^`000002f[Jd0P000004fkRd
0000000000000]Ni_0030000VDmbVDmb00BICg85000000>SZMX0002kQIX00[^5VP030000_g5g_g5g
00:oLGL01000038@MS8@MP0000JTFgT200005?ooo`040000NDjB000000001XeBQ@060000FR]l0000
liU00000Udmf1`0001Coool00`000<IbK`00001loooo00<0003oooooool0AOooo`030000oooooooo
04ooool003ooool200000_ooo`040000oooooooooooo10000004oooo0000KD^H00001KERKPP0000<
oooo0P0000:gHfX01P000?ooooooo`000000@`0000J7@W<00`0006DUJVDUJP02IBEZ00<00020>g20
>g000P0000>KHhl00`0007U3PWU3PP03ND>21@000006Vf:=0000fKBc0000j/nk00000]Zf]0040000
jm6k0000fkRd0P0000;G^K`200001YU?LPH00004^hFJ00<0002oLGNoLGL00[maM`040000<Q1f<Q1f
00001ZAKN@800008oooo0P0000Ooool2000000?oool0001iCY800P0000J=DXD00`0005X[O0000002
liU010000003kHTe0000000000<0000Boooo00<00036LVl00000O?ooo`030000oooooooo04Koool0
0`000?ooooooo`1>oooo000loooo0`0000Coool01P000?ooooooo`000>WNb000009]BiP300001[ER
KP030000Mc9/Mc9/008000000`1:b0000;57@`0200002_ooo`800002]f=Z00<0003oool000000P00
@`030000Qd9cQd9c00B7@W<00`0006DUJVDUJP02IBEZ00D00020>g00003gkK0000000Y]SS`030000
ND>2ND>200Ai@h82000000KK^;@00000002KHXd0003I];<200000mZf]08000001]^h]00000000=bi
]@000=Ni_0<00004VDmb00@0001G4eaG4e`00002200m00<0002kQIZkQIX00[^5VP030000_g5g_g5g
00:oLGL01000038@MS8@MP0000FTFgT0100008I4MhI4M`0000Ooool00`0007i7P`000003000000Ko
ool00000001O8V/0003oool400001XeBQ@030000FR]l000000;cVD04000000K]RCD000000000003]
RCH0000Aoooo0P000003aW9_0000oooo07_oool00`000?ooooooo`17oooo00<0003oooooool0COoo
o`00>_ooo`80000:oooo00<0003Yg/P000000Ve;V0030000i]G4000000FeHVh00`0007LbK7LbK003
Mc9/00<0002aAd>aAd<00[57@`800007oooo0`0000:gHfX200000`00@`030000Qd9cQd9c00>7@W<0
0`0006DUJVDUJP03IBEZ00D00020>g00003gkK0000000Y]SS`030000ND>2ND>200=i@h82000000?J
^;H0000000000P000004fKBc0000j/nk00000]Zf]0800002fkRd0P0000;L^KD010000>?:_P000000
00BICg801@0005LCG5LCG00000P0?@0200001;^5VP030000_g5g_g5g00:oLGL01000038@MS8@MP00
00FTFgT0100008I4MhI4M`0000Koool200001Gi7P`<0000015lRJ`00000007U>TP<00006SE:500<0
001J:g`000000_>I@0T000000nf9=P000?ooo`0?oooo0P000003aW9_0000oooo07_oool00`000?oo
ooooo`17oooo00<0003oooooool0COooo`00=oooo`<0000;oooo00L0003Yg/SYg/P0001]BiP0003V
eL@00P0000FeHVh00`0007LbK7LbK003Mc9/0P0000FaAd<00`000?ooooooo`04oooo0P000004Y6jD
0000]f=Z00001000@`030000Qd9cQd9c00>7@W<00`0006DUJVDUJP03IBEZ0P0000;gkK00100009]S
Si]SS`0000Ei@h82000000?J^;H0003WbkX00P000003fKBc0000000000;J][@010000>_A^`000=^h
]0800002g;Ve00H0003VbKT00000002fQ0000003VDmb00<0001G4eaG4e`00P000003Ea=L0000^hFJ
00BkQIX00`000;maMkmaM`02_g5g00<0000b47H000001JAKN@040000QTAgQTAg00001_ooo`800006
OTN300<0001iCY8000000P000004NDjB00008`1:00001XeBQ@030000FR]l000000;cVD000`0009M?
MP000006000000?]RCH0000000003oooo`8000000lIbK`000?ooo`1joooo0P0004[oool00`000?oo
ooooo`1<oooo000doooo0`0000Coool200001oooo`040000jMk8jMk8jMk80P000004i]G40000/HRZ
00001KERKP030000Mc9/Mc9/009g<V`010000:EJMJEJM@0000BaAd<00`000?ooooooo`03oooo0P00
00:TKY@00`000;MSJP000004001300<00027@W>7@W<00hM2L`030000IBEZIBEZ009U9FX00`00080k
L0000002mnf`00@0002KHhl000000004ND>20P000003f[Rf0000i/^l008000001=Vd/`000>[?^`00
00;J][@2000000CK^;@0003YcKX00002g;Ve0P000004h;ng0000]X@000000iU?LP040000Ea=L0000
200m0`0000BkQIX200001;maM`030000<Q1f000000FTFgT01@0008I4MhI4MhI4M`000005oooo0P00
00InAh<0100007U>TWU>TWU>TP<000000b<0BP0008eBQ@05SE:500@0001J:gaJ:g`00002liU02000
0004kHTf0000000000003Oooo`800002aW9_00<0003oooooool0M_ooo`<00002YL?_00<0003ooooo
ool0B?ooo`030000oooooooo04_oool003;oool200001?ooo`<000000h]KU00000000005oooo00<0
003Yg/SYg/P00^WNb0<00003/HRZ00<0002eHVjeHVh00[ERKP030000Mc9/Mc9/009g<V`01@000:EJ
MJEJMJEJM@000002/DM300<0001^5dP000000oooo`030000000N000000:TKY@00`000;MSJP000003
001300<00027@W>7@W<018M2L`030000IBEZIBEZ009U9FX200000oO]/0040000Vf>?000000000gU3
PP800002f[Rf00<0003Vbk`00000100000;J][@010000>_A^`000=^h]0800002g;Ve00D0003VbKT0
003P_kL000000[J400050000VDmbVDmb0000Ea=L00@0000015LCG0000;^5V[^5VP<00004_g5g00<0
000b47H000001JAKN@050000QTAgQTAgQTAg000000Coool00`0009aOR0000006OTN300<0001iCY9i
CY800P0000<S04X00`0008eBQHeBQ@04SE:500@0001J:gaJ:g`00002liU01@000004;@1100000000
kHTf0`0000goool200000lIbK`030000oooooooo07;oool400000jG3k`80001:oooo00<0003ooooo
ool0Boooo`00;oooo`<00004oooo0P0000B;Fi@0100007I3QP00000000?oool010000>WNb>WNb>WN
b0<00003/HRZ0P0000>eHVh00`0007LbK7LbK003Mc9/00D0002UFWFUFWFUFWD000000[57@`040000
KQM80000oooo100000>TKY@00`000;MSJP000003001300<00027@W>7@W<018M2L`030000IBEZIBEZ
009U9FX00`000?O]/?O]/002mnf`00@0002KHhl000000003ND>20P000009f[Rf0000i/^li/^l0000
f;Bd0000j/nk000000;J][@2000000?K^;@0000000000mbi]@8000000n2o]`0000000002]X@000T0
002ICg:ICg80001G4e`0001L=8L0003H[Zd00P000003^hFJ0000i;j`00800004_g5g00<0000b47H0
00001JAKN@050000QTAgQTAgQTAg000000Coool00`0009aOR0000006OTN300<0001iCY9iCY800P00
00<S04X00`0008eBQHeBQ@04SE:500@0001J:gaJ:g`00002liU01000008]0443000000C]RCH00000
0000000<oooo0P0000?6LVl00`000?ooooooo`1_oooo100000BU`nl2000000>U`nl000000000B?oo
o`<0001<oooo000]oooo0P0000Koool200001H]KU0080000MT>6MT>6MT>60000oooo0000jMk80`00
0003UgN]0000000000>aR:X200000kERKP030000Mc9/Mc9/00=g<V`00`000:EJMJEJM@02YEYe0P00
009^5dP4000000<001h0002TKY@00ZA^U08000001KMSJP000000@`00@`000006Qd9c00<0001U9FYU
9FX00VDUJP030000mnf`mnf`00;gkK02000000B=E8P0001i@h9i@h82000000WJ^;H0003VbkcVbk`0
003H];@0003Yd;d000000]Zf]0800002fkRd0P0000;L^KD010000>K9^@000>2o]`<00002]X@00P00
0004Ea=L0000G3B700000]R^[@<000001>Bn/0000?3C]00000BoLGL200001ZAKN@050000QTAgQTAg
QTAg000000Coool00`0009aOR0000007OTN300@0001iCY80000000038`1:00<0002=DXF=DXD018eB
Q@040000FR]lFR]l00000_>I@08000001=j4100002d0@Bd0@@<000000nf9=P000000000200001ooo
o`@000000iUKQP000<IbK`02aW9_00<0003oooooool0KOooo`<00002YL?_00<0002U`nl000000P00
0003YL?_0000000000:U`nl00`000?ooooooo`18oooo00<0003oooooool0BOooo`00:oooo`800008
oooo0P0000F;Fi@00`0007I3QWI3QP02MT>60`0000>GMjd00`000:MkX`000002/HRZ00<0003[f<00
00000kERKP030000Mc9/Mc9/009g<V`00`000:EJMJEJM@04YEYe1000009H6F@200000jA^U0050000
/M3`0000]f=Z0000008004<00`0008M2LhM2L`03Qd9c00<0001U9FYU9FX00VDUJP030000mnf`mnf`
00?gkK02000000B=E8P0001i@h9i@h82000000CJ^;H0003Vbk`00002f;Bd0P000003fKJe0000f[Jd
008000000m^h]00000000002g;Ve00H0003VbKT0003P_kL0003TaKT200000[J40080000025LCG000
05`dQ`000=R^[@000>o>/@0000;T_[0300001KmaM`030000Y5]iY5]i00BTFgT00`0008I4MhI4M`02
QTAg00@0003oooooool00002W5n800<0001nAh=nAh<01Gi7P`D000028`1:00<0002=DXF=DXD018eB
Q@050000FR]lFR]l0000liU0008000000iM?MP0002d0@@02;@110`000003kHTf0000000000<00004
oooo0P0000>7EY000`0009UKQP000003aW9_00<0003oooooool0J_ooo`@00003YL?_0`000004YL?_
0000000000000jG3k`<00019oooo00<0003oooooool0BOooo`00:oooo`800007oooo00<0002RK9@0
00001H]KU0030000MT>6MT>6009f@hH200000iMg[@040000Yg^SYg^SYg^S0P0000;[f<0200000[ER
KP030000Mc9/Mc9/009g<V`00`000:EJMJEJM@04YEYe00<0001H6FAH6F@00UPII0030000000N0000
00>TKY@3000000FgHfX0000004<004<000001HM2L`030000IBEZIBEZ009U9FX00`000?O]/?O]/003
mnf`0P000003SEB80000ND>2008000002MZh]P000>K;_>K;_0000=Rd]0000>W@_@000002fKJe0P00
0004fkRd0000jLfj00000]bi]@8000001^2o]`000>C5^@000>?4^00000>fQ00400000]R^[@800002
i;j`00@0003`dk@000000005_g5g00<0002TFgVTFgT01:AKN@030000QTAgQTAg00:6A7L010000?oo
ooooo`0000:LGhP00`0007i7Pgi7P`05OTN30`000005nMRV00008`1:8`1:000000J=DXD0200005X[
O5X[O0000?>I@00002d0@@0000@]0443000000?]RCH000000000100000?oool00`0008MFT8MFT002
QeJ@00<0002IFhH000000lIbK`030000oooooooo06Ooool400000ZG3k`@000001:G3k`0000000000
00BU`nl2000000>U`nl000000000B_ooo`030000oooooooo04Soool002_oool00`000?ooo`000005
oooo00@0002RK9BRK9@00005Re^D00<0001f@hIf@hH00WI3QP800003UgN]00@0002WNj>WNj>WNj<2
000000K[f<00003I_l00002eHVh00005Mc9/00<0002UFWFUFWD01:EJM@030000F1UTF1UT009H6F@2
00000jA^U0040000[[GN[[GN[[GN0P00000300130000Qd9c00F7@W<01@0006DUJVDUJVDUJP000006
mnf`0P000004SEB80000000000000]Zh]P070000i/^l0000f;Bd0000jM2m000000;I][D2000000CJ
^;H0000000000002g;Ve00T0003VbKT0003P_kL0003TaKT0003Sa;P000000kJ400@000002]R^[@00
0>o>/@000>Bn/0000?3C]0000>2k/P0000FoLGL00`000:AKNJAKN@04Y5]i00<00026A7N6A7L00XI4
M`040000oooooooo00000YaOR0030000OTN3OTN300EnAh<2000000?if:H0000000000R<0BP030000
SE:5SE:500B=DXD0200005X[O5X[O0000?>I@00002d0@@0000@]0444000000G]RCH000000000003]
RR/00P000003oooo0000000000>7EY001@0009UKQYUKQYUKQP000003aW9_00<0003oooooool0Hooo
o`@000000jG3k`000000000200000jG3k`800002YL?_00<0002U`nl000000P000003YL?_00000000
00:U`nl00`000?ooooooo`18oooo00<0003oooooool0Aoooo`008_ooo`030000oooooooo00Koool0
10000?ooooooo`0000Coool010000:9/U:9/U00000F;Fi@0100007I3QWI3QWI3QP80000013d0C`00
09Mg[@0000BWNj<3000000GI_l000000002eHVh000001GLbK0030000YEYeYEYe00>UFWD00`0005PI
I5PII003F1UT0P0000>TKY@00`000:jegZjegP03000000<004<00027@W<01HM2L`040000IBEZIBEZ
IBEZ100000?gkK000`0008eDR8eDR003000000KJ^;H0003VbkcVbk`0003H];@200000mVf]@800000
1=Zh]P000>W=^P0000;L^KD2000000CP_kL0003TaKT00002hlBh00@0002fQ02fQ02fQ00300000]R^
[@800002i;j`00D0003`dk@0003P^k8000001KmaM`030000Y5]iY5]i00BTFgT00`0008I4MhI4M`03
QTAg0P0000>LGhP00`0007i7Pgi7P`05OTN30P000003nMRV00000000008S04X00`0008eBQHeBQ@04
SE:500@0001J:gaJ:gaJ:g`4000012d0@@@000001Nf9=P00000000000>f::`0500000hMFT0050000
VE^6VE^6VE^6000000?6LVl00`000?ooooooo`1Ooooo100000>U`nl200000ZG3k`030000YL?_YL?_
00800003YL?_0`0000:U`nl200001:G3k`800019oooo00<0003oooooool0Aoooo`008Oooo`030000
oooo000000Koool00`000?ooooooo`02oooo00@0003oooooool00003XVbD00<0002;FiB;Fi@00h]K
U0060000MT>6MT>6MT>60000MTF80`0000BWNj<02@000>?Rd@000=G0aP000=Ni^`000;ERKP000004
Mc9/00<0002UFWFUFWD01:EJM@030000F1UTF1UT00=H6F@200000ZA^U0030000[[GN000000@00000
0`00@`0008M2L`05Qd9c1@0000>BFX/4000000J=E8P000000000003J^;H00002i/^l00D0003H];@0
003Yd;d000000]Vf]@8000001=Zh]P000>S>_00000;L^KD010000>K9^@000>2o]`800002hlBh0P00
00>fQ005000000O_c[40003T_[00003`dk@0003P^k800P0000FoLGL00`000:AKNJAKN@04Y5]i00<0
0026A7N6A7L00hI4M`800003W5n800<0001nAh=nAh<01Gi7P`040000nMRV0000i[VV0P0000038`1:
0000SE:500B=DXD200000eX[O0@00004;@1110000003kHTf0000000000L00003QeJ@00D0002IFhJI
FhJIFhH000000lIbK`030000oooooooo05goool3000000BU`nl0002U`nnU`nl200001:G3k`<00000
0jG3k`000000000200000ZG3k`<00004YL?_0P0000:U`nl00`000?ooooooo`17oooo00<0003ooooo
ool01oooo`D00002oooo00<0003oooooool00_ooo`030000oooooooo033oool0027oool00`000?oo
o`000006oooo00<0003oool000000oooo`030000oooo000000>RK9@00`0008]KU8]KU002Re^D00D0
001f@hIf@hIf@hH000000gI5R0030000Yg^SYg^S00:WNj<01P000>?Rd@000=G0aP000=6h`P800000
0kERKP0007LbK003Mc9/00<0002UFWFUFWD01:EJM@030000F1UTF1UT009H6F@300000ZA^U0<00002
[;3K0P00000400130000Qd9cQd9c1@0000>8F9<01P00099JRi9JRi9JR`0008eDR0D000001Jfjh`00
00000>K;_0000002f;Bd0P0000;I][D010000>[B_@000=Zh]P8000000m^i]`000=bi]@02000000SP
_kL0003TaKT0003Sa;P0003R`[P00002]X@00P0000;R`[P300000^Bn/0040000l=>d0000h;^b0P00
00FoLGL00`000:AKNJAKN@02Y5]i0P0000J6A7L200000iaOR0030000OTN3OTN300EnAh<010000?WH
YP000>JiYP8000000b<0BP0008eBQ@04SE:500<0003dcJD000000UX[O0<000000dXQN`0002d0@@02
;@1100D0001>8WT00000003]RCH02@0000:7EY000`0009UKQYUKQP02VE^600D00036LVo6LVo6LVl0
0000G?ooo`<00004YL?_0`0000:U`nl4000000BU`nl0000000000004YL?_0P0000:U`nl00`000:G3
k`00000200000jG3k`80001:oooo00<0003oooooool02?ooo`070000oooooooooooo0000oooo0000
00;oool00`000?ooo`00000aoooo000Qoooo00<0003oool000001_ooo`800005oooo00<0002RK9BR
K9@00Z9/U0030000Re^DRe^D00:;Fi@01@0007I3QWI3QWI3QP000003MTF800T0002WNj>WNj>WNj<0
003Sh]40003E`<H000000]6h`P030000h<S1000000Ag<V`200001ZEJM@030000F1UTF1UT009H6F@3
000000>TKY@0000000000P000005[;3K000000000000001300<000000ijEb`0008QHT`04R5RC00@0
002BFX^BFX^BFX/3000000>M`O40000000000Zfjh`800002i/^l00D0003H];@0003Yd;d000000]Vf
]@8000001=Zh]P000>S>_00000;K^KL01P000>K9^@0000000>C5^@0000;Sa;P00`000>;2^0000002
]X@00P000003h/:h0000hl>h008000002>Bn/0000?3C]0000>2k/P000>kA]P0000BoLGL00`00058G
I@000003Y5]i0P0000J6A7L00`0009aOR9aOR002W5n800<0001nAh=nAh<017i7P`<00002i[VV0P00
00038`1:0000SE:500>=DXD010000?C=Y@000000009J:g`01@0005X[O00004XQN`000003;@1100<0
001>8WT000000P000005kHTf000000000000kHX[00800002bhnD00<00027EY00000019UKQP050000
aW9_aW9_aW9_000005[oool300001:G3k`8000000jG3k`000000000200000jG3k`800002YL?_00<0
002U`nl000000P0000>U`nl300000ZG3k`@000000jG3k`0000000019oooo00<0003oooooool02?oo
o`070000oooooooooooo0000oooo000000;oool00`000?ooo`00000aoooo000Qoooo00<0003oool0
00001_ooo`030000oooooooo00?oool00`000:9/U:9/U003XVbD00<0002;FiB;Fi@00X]KU0040000
MT>6MT>6000017I5R0040000Yg^SYg^SYg^S0P0000;E`<H010000=6h`P000=[:bP8000001WLbK000
000000000=Vi^P0000JUFWD00`0005PII5PII002F1UT0`000003Y6jD0000000000<00002]]3^0P00
00BNUL/00`0008QHThQHT`03R5RC00@0002BFX/000000002/[[O0P000004[K[S0000000000000ZGG
n@8000001=Rd]0000>W@_@0000;I][D200000]Zh]P800002fkVg00X0003UbK/0003P_kL0003TaKT0
003Sa;P0003R`[P200000[J4008000001>;2^00000000>;2^0<000000o3C]0000>2k/P0300001;ma
M`030000DQMU000000:TFgT300001XI4M`030000W5n8W5n800:LGhP00`0007i7Pgi7P`04OTN300T0
003if:H0003V^JH0003abJL0000S04X0000018eBQ@040000m<fU0000000015X[O0030000BR5k0000
00<]04400`0004hRN@000002000000G]RCH000000000003]RR/00P0000;;Si@00`0008MFT0000004
VE^600D00036LVo6LVo6LVl00000Eoooo`<00002YL?_00<0002U`nl000000P000003YL?_00000000
00:U`nl00`000:G3k`00000200000jG3k`<00002YL?_10000003YL?_0000000000800003YL?_0P00
00:U`nl00`000?ooooooo`17oooo00<0003oooooool01oooo`070000oooooooooooo0000oooo0000
00;oool00`000?ooo`00000aoooo000Roooo00<0003oooooool01Oooo`030000oooooooo00?oool0
0`000:9/U:9/U003XVbD00<0002;FiB;Fi@00X]KU0040000MT>6MT>600001GI5R0090000Yg^S0000
hn;A0000eL360000dKS2000000;Jb/X500000]Vi^P030000YEYeYEYe00BUFWD0100005PII5PII5PI
I0H000000iblk`000000000400001IjEb`030000R5RCR5RC00:8F9<300000[:jg`8000000kO0h@00
00000002YMOi0`0000:T]^D300000mVf]@8000000mZh]P0000000003fkVg0P000004gkni0000i<Fi
00000^?4^0040000h/:h000000000[J400040000h/:h0000hl>h0P00000:iLRi000000000000h;^b
0000k]6f0000g[Vb00000kmaM`030000DQMU000000:TFgT300001XI4M`030000W5n8W5n800:LGhP0
0`0007i7Pgi7P`03OTN30P000003nMRV0000i[VV00<000000b<0BP0008eBQ@02SE:500@0003dcJD0
003X^ZD200000eX[O0030000BR5k000000<]04400`0004hRN@000002000000?]RCH0000000001000
00;;Si@200001YUKQP050000aW9_aW9_aW9_000005?oool400000jG3k`<000001:G3k`0000000000
00>U`nl300001:G3k`8000000jG3k`000000000200000jG3k`800002YL?_00<0002U`nl000000P00
00>U`nl20000B_ooo`030000oooooooo00Koool01`000?ooooooooooo`000?ooo`000002oooo00<0
003oool00000<Oooo`00:_ooo`030000oooooooo00;oool00`000:9/U:9/U003XVbD00<0000H0340
00000h]KU0030000MT>6000000IfAHP2000000CSh]40003E`<H00002dKS200<0003Jb/X000000]2h
`P070000h/[00000fKVj0000h/[0000000BUFWD00`0005PII5PII002F1UT1@0000>L_>l6000019jE
b`040000R5RCR5RCR5RC0P0000:b^]l2000000Bg`>400000002e^mh300001:Bfi@8000001>W@_@00
0=Vf]MVf]@8000001=Zh]P000>S>_00000;K^KL01@000>G9^`0000000>?6^P02000000OSa;P0003R
`[P0003R`[P0002fQ0000`000003hl>h0000h/:h008000000nC5^0000>36_P03000000?N^K800000
00000kmaM`090000DQMU0000Y5]i0000DQMU0000L3^1000000B6A7L00`0009aOR9aOR003W5n800<0
001nAh=nAh<00gi7P`080000nMRV0000i[VV0000lLVW0000jKbW0P0000>=DXD3000000?X^ZD00000
00000eX[O0030000BR5k000000<]04400`0004hRN@000002000000?]RCH0000000000`0000?;Si@2
00001YUKQP050000aW9_aW9_aW9_0000053oool400000ZG3k`@000001:G3k`000000000000BU`nl2
00000ZG3k`030000YL?_0000008000000jG3k`0000000002YL?_00<0002U`nl000000P0000>U`nl3
00000ZG3k`@000000jG3k`0000000019oooo00<0003oooooool01Oooo`800004oooo00<0003ooooo
ool00_ooo`030000oooooooo033oool002Woool00`000?ooooooo`02oooo0P0000FRK9@400000X]K
U0030000MT>6000000IfAHP01@000>?Rd@000=G0aP000002dKS200<0003Jb/X000000]2h`P030000
flg;000000;I^KX300001:EJM@040000F1UTF1UTF1UT0P000003k^;30000000000D000001A]5_`00
00000;k@i`000005WYG;00<00028F9>8F9<0100000:g`>400`000;Fkg[FkgP02000000>k^=L0002T
]^D00`000003Tlck0000000000;I][D010000>[B_@000=Zh]P800002fkVg00L0003UbK/0003O_kT0
003Sa[X000000^?4^08000000n;2^0000>71]`04000000GS`kP00000003Ub;T000000^C5^0800000
0nkA]P000=ji/P0200000kmaM`090000DQMU0000Y5]i0000DQMU0000L3^1000000B6A7L00`0009aO
R9aOR003W5n800<0001nAh=nAh<00gi7P`040000nMRV0000i[VV0P0000;Y_:L200000XeBQ@800000
1OC>Y`0000000?K>Y@000003FR]l00@0001:8G]:8G/00002;@1100<0001>8WT000000`000003kHTf
0000000000800003bhnD0P0000JIFhH01@000<IbKlIbKlIbK`00001=oooo10000003YL?_00000000
00800003YL?_0P0000:U`nl00`000:G3k`00000200000jG3k`<000001:G3k`000000000000>U`nl3
00000ZG3k`@000000jG3k`000000000200000jG3k`800002YL?_00<0003oooooool0A_ooo`800014
oooo000Yoooo0`000004oooo0000dkRo00001:9/U0070000ReVAReVA0000]8VX0000Re^D00<00005
MTF800<0003JiMd000000]G0aP050000dKS20000f/[:000000;@^<8010000=_=b`000=6i``800000
0n;:`00000000004YEYe00@0001H6FAH6FAH6F@2000000?^h/<00038Xk@00P0000>P`_400`0001]5
_`000003000019jEb`030000R5RC0000008000001L_Oi`00000000000;FkgP0200000k^he`800000
19?<n`000000000000:L]NT020000=Vf]@0000000=Zh]P000>S>_00000;K^KL2000000GO_kT0003S
a[X0003Ra;X00P000003h/:h0000h/:h00D000000n?3^0000>;2^00200000^C5^0080000i/Vi0000
0000g[Vb0000kLnf00000kmaM`070000DQMU0000Y5]i0000DQMU0000009`>h401@0008I4MhI4MhI4
M`000005W5n800<0001nAh=nAh<00Wi7P`<00002i[VV0P000004jKbW0000000000000XeBQ@040000
m<jW0000j;^W0`0000=J:g`0100004XQNdXQN`00008]04400`0004hRNDhRN@03000000?]RCH00000
00000P0000?;Si@00`0009UKQYUKQP05VE^600D00036LVo6LVo6LVl00000BOooo`@00003YL?_0P00
00:U`nl00`000:G3k`00000200000jG3k`<00002YL?_10000004YL?_0000000000001:G3k`800000
0jG3k`000000000200000jG3k`800002YL?_00<0002U`nl000000P0000>U`nl30000AOooo`800002
oooo00<0003oooooool0@Oooo`00:Oooo`040000oooooooo00000]>h_`030000XVbDXVbD00:RK9@0
1P0008]ITH]ITH]IT@000;B9Z0@00004MTF800@0003JiMd0003=_ld2000000WA^<80003Jb/[Jb/X0
003@^<80003KcL/000000]6i``050000flg;0000fKZj000000BUFWD00`0005PII5PII002000000G^
h/<00038Xk@0003akL802`0000>NUL/00`0008QHT`000003bmoW00@0002e^mh000000003^kSG0P00
0003`LON0000000000BL]NT3000000?Zd[d0003J^;H00P0000;K^KL03P000>G9^`000=no^@000>?6
^P000>;4^P000>73^@000>;2^0000>71]`D000001>;2^0000>G8^@0000;TaKP2000000KVbKT00000
0000003]ckH00002_g5g00<0001B5fEB5fD00P00009B5fD01000070kPG0kP@0000:6A7L00`0009aO
R9aOR004W5n800<0001nAh=nAh<00Wi7P`080000nMRV0000i[VV0000lLVW0000jKbW0`000006SE:5
00000000m<jW0000j;^W0P000005j;ZU0000FR]lFR]l0000009:8G/0100002d0@Bd0@@00009>8WT3
000000?]RCH0000000000P0000?;Si@00`0009UKQYUKQP05VE^600D00036LVo6LVo6LVl00000Aooo
o`<000000jG3k`000:G3k`0300000jG3k`<00002YL?_10000003YL?_0000000000800003YL?_0P00
00:U`nl00`000:G3k`000002000000>U`nl0000000000ZG3k`030000YL?_000000800003YL?_0`00
00:U`nl4000000>U`nl000000000BOooo`030000oooooooo047oool002Woool00`000?ooo`000003
dkRo00D0002RK9BRK9BRK9@0000018]IT@060000]8VX]8VX0000]8VX00000WI5R08000001][Ug@00
0<focLfoc@000<Rfb08000001=[:bP000=2h`]2h`P800002dKW300@0003KcL/0003A^/<300000jEJ
M@030000F1UTF1UT008000000nkR``000<RS]002000000C8YKD0001`Y_9`Y_82000000>E__<00000
000010000003WYG;0000000000;;gnL2000000>l_]/0002k^=L00k^he`050000`LON00000000_[OC
00D000001Hfom`00000000000=Zh]P0200000m^i]`8000001=no^@000>?6^P0000;Ra;X2000000GQ
`kT000000000003R`[P00P000005hl>h00000000iLRi000000;TaKP01P000>K9^@0000000>;3^000
00;]ckH010000;maMkmaM`00009B5fD200000U8GI@070000L3^1L3^1L3^10000QTAg000000JLGhP0
100007i7Pgi7Pgi7P`8000000oWHYP000>JiYP0200000^VlY`<000001heBQ@000?C>Y`000>RkY`00
0?G?Y`0300000UX[O0040000BR5kBR5k00000Rd0@@030000CR9iCR9i00<000001>f9=P0000000000
00C;Si@00`0009UKQYUKQP05VE^600<00036LVo6LVl00/IbK`030000oooooooo047oool300000jG3
k`<00004YL?_0P000003YL?_0000000000800003YL?_0P0000:U`nl00`000:G3k`00000200000jG3
k`<000001:G3k`000000000000>U`nl300001:G3k`8000000jG3k`000000000200000jG3k`800002
YL?_00<0003oooooool0Aoooo`030000oooooooo043oool002Woool00`000?ooo`000003dkRo00@0
002RK9BRK9@00005ReVA0P0000>dRJP00`0007I5R0000002f^GM00@0003=_lg=_ld00002b;K800<0
003Jb/X000000]2h`P070000flg;0000dKW30000flg;000000;A^/<00`000>;;`0000003YEYe00X0
001H6F@00000003^h/<00038Xk@0003akL800002b:Fe0P0000BE__<00`0000hl^`000005000000?;
gnL0002l_]/00P000003`M7W0000^kSG008000001<77gP000;jgdkjgd`8000000lW@g`0000000002
00000iZ^i@<00002fkVg00@0003UbK/000000002hlJj00h0003Ra;X0003Q`kT0003Q`kT0003Q`KL0
003R`[P0003S`kP0003R`[P200000^C5^0040000i/Vi0000i/Vi0P000004iLNi0000000000000[ma
M`030000DQMUDQMU00800002DQMU00L0001`>h5`>h5`>h400026A7L000001YaOR0040000OTN3OTN3
OTN30`0000;V^JH2000000?Y_:L0003cc:L010000003m<jW0000j;^W008000000nNjY`0000000002
FR]l00@0001:8G]:8G/00002;@1100<0001>8WU>8WT010000003kHTf0000000000?;Si@200001iUK
QP030000aW9_aW9_00;6LVl00`000?ooooooo`0ooooo0`0000>U`nl200000ZG3k`030000YL?_YL?_
008000000jG3k`0000000002YL?_00<0002U`nnU`nl00P0000>U`nl300000ZG3k`@000001:G3k`00
0000000000BU`nl200000ZG3k`030000YL?_YL?_008000000jG3k`0000000002YL?_00<0002U`nnU
`nl00P0000>U`nl30000B?ooo`030000oooooooo043oool002Woool200001=>h_`040000XVbDXVbD
000018]IT@030000i]O70000008000000kB9Z00000000002f^GM00@0003=_ld000000002b;K800<0
003Aam4000000]2h`P050000flg;0000dKW3000000;KcL/010000=6j``000=c>c0800002YEYe00X0
001H6FAH6F@0003^h/<00038Xk@0003akL800002b:Fe00<0003]hL@000001P0000043Sbk00000000
bmoW0`000003_;kK0000`M7W00;1dNL2000000?1amh0000000000[jgd`060000bM3O00000000`koF
00000iZ^i@@00002fkVg00l0003UbK/0003O_kT0003Sa[X0003Ra;X0003Q`kT0003Q`kT0003P`KT0
00000^;2^0060000hl>h00000000iLRi00000^C5^08000000nK9^@000>;3^002000000?M^kH00000
00000[maM`030000DQMUDQMU00800002DQMU00<0001`>h5`>h400W0kP@030000W5n8W5n800FLGhP0
300007i7Pgi7Pgi7P`000?WHYP000>JiYP000?79Y`000>VlY`8000000o37Y`0000000002000000GX
^jL0003ecjL0003W^ZL00`000003FR]l0000BR5k009:8G/00`0002d0@@000002CR9i10000003kHTf
0000000000?;Si@200001iUKQP800003aW9_00<0003oooooool0??ooo`<00002YL?_00@0002U`nl0
00000004YL?_0`000003YL?_0000000000BU`nl3000000>U`nl0000000000P0000:U`nl300000jG3
k`800002YL?_00<0002U`nnU`nl00P0000BU`nl3000000>U`nl0000000001:G3k`<000000jG3k`00
0000000200000ZG3k`800018oooo00<0003oooooool0?oooo`00:?ooo`800005dkRo00@0002RK9@0
00000004ReVA00@0003VelL0003B^<4300000][Ug@030000cKo=000000?8]/P010000=77d@000<Zh
b08000002M_=b`000=6i`m6i``000=_=b`000=6j``000002g<k<0P0000:UFWD00`0005PII0000002
000000C8Xk@0003akL800003b:Fe0P000003cZbh00000000008000000hfim00000000004000000>l
_]/0000000000/7Ai`800002];OK00L0002n]m>n]m>n]m<00039d=l000000l>oePH00002VZWR00H0
003K^KL00000003O_kT00002hlJj00@0003Ra;X000000002hL>i0P000006hL:i00000000hl>h0000
h/:h0P0000;TaKP020000>K9^@0000000>;3^0000>G7^@0000;M^kH010000;maMkmaM`00009B5fD2
00000U8GI@030000L3^1L3^1009`>h400`0009aOR9aOR005W5n800<0001nAh=nAh<00`0000;V^JH2
000000GY_:L0003cc:L0003`ajL00P000003m<jW0000j;^W008000001nNjY`000?79Yo79Y`0005X[
O0000003BR5k00<0000]044000000ThRN@H00004bhnD0P0000NIFhH200000lIbK`030000oooooooo
03Woool400000jG3k`<00002YL?_10000004YL?_0000000000001:G3k`8000001:G3k`0000000000
00BU`nl200000ZG3k`040000YL?_000000001:G3k`<00002YL?_10000004YL?_0000000000001:G3
k`8000001:G3k`000000000000BU`nl2000000>U`nl000000000B?ooo`030000oooooooo03koool0
02Soool00`000=>h_m>h_`04dkRo00@0002RK9@000000003ReVA00H0003VelL0003B^<40003J`/84
000000?=_ld00038]/P00/Rfb0030000dLOA000000;:^<P00`000=?:d@000002dKW300D0003KcL/0
003A^/<000000]c>c00>0000d[_400000000YEYe0000F1UT0000k^;30000b:>d0000lNg200000/RU
]@8000000lj/^0000>OD``0;00000/7Ai`800002];OK0P000006^;WJ000000000000bM3O00000/>o
eP8000000lG:gP0000000005VZWR0P00000AiLVk0000gkni0000hlJj0000h/Bj0000hL>i0000hL>i
0000h<6i0000hL:i0000h/>j00<000001>G8^@000>C5^>C5^08000000nK9^@000>;3^00200000]fk
]P800002_g5g00<0001B5fD000000P00009B5fD00`00070kPG0kP@02L3^100<0002LGhRLGhP01IaO
R00;0000OTN3OTN30000nMRV0000i[VV0000lLVW0000jKbW008000001O37Y`000>o6Y`000?C>Y`02
000000GecjL0003W^ZL0003abJL00P000003FR]l0000BR5k009:8G/00`0002d0@@000002CR9i00H0
003]SB@00000003^S3T00003bhnD00<0002hO94000001iUKQP800003aW9_00<0003oooooool0=_oo
o`@00002YL?_10000003YL?_0000000000800003YL?_0P0000:U`nl00`000:G3k`000002000000>U
`nl0000000000ZG3k`030000YL?_000000800003YL?_0`0000:U`nl4000000>U`nl0000000000P00
00>U`nl200000ZG3k`030000YL?_0000008000000jG3k`0000000002YL?_00<0002U`nl000000P00
00>U`nl20000B?ooo`030000oooooooo03koool002Soool200001M>h_`8000002IAZWP0008]ITH]I
T@000>KGa`000=:h`@000002f/;20P000003>WcT0000000000?8]/P00`000=77d@000002b[S800@0
003Cb]40003=_<T2000000cKcL/0003A^/?A^/<0003Lc/`0003B^l@0003OeLh0002UFWD4000000C8
Xk@0003akL800002b:Fe00@0003]hL@0003>[;P2000000?F^K`0001kXn`00W^Sk0P00003];OK00H0
002h^MZh^MZh^MX00039d=l200000/>oeP060000aL[N00000000a<?I00000YZYhP<000001IG2mP00
00000=no^@000002hlJj00P0003Ra;X00000003Q`kT0003P`KT00002hL:i00@0003R`kX0003R`[P2
00000^C5^0080000i/Vi00000000h/>h0000iLNi00000]fk]P800002_g5g00<0001B5fD000000P00
009B5fD00`00070kPG0kP@02L3^100<0002LGhRLGhP01IaOR0030000OTN3000000800002i[VV0P00
00;Y_:L2000000S`ajL00000003dcZL0003X^jL0003ecjL200000_79Y`040000k<6W000000000dXQ
N`030000;@11000000=>8WT500000l^?U0030000^7bA000000NIFhH200000lIbK`030000oooooooo
03?oool4000000>U`nl0000000000P0000>U`nl200000ZG3k`030000YL?_000000800003YL?_0`00
0004YL?_0000000000000jG3k`<00002YL?_10000003YL?_0000000000800003YL?_0P0000:U`nl0
0`000:G3k`00000200000jG3k`<000001:G3k`000000000000>U`nl300000ZG3k`@000000jG3k`00
00000018oooo00<0003oooooool0?Oooo`00:?ooo`030000oooo000000800002dkRo0P000004U6ZN
0000ReVAReVA0P0000;B^<4010000=[2`P000=No`PD000001<Rfb0000=77d@0000;:^<P00`000=?:
d@000002cKc900P0003KcL_KcL/0003A^/<0003Lc/`00002d[_40`000008YEYe000000000000b:>d
0000lNg200000/RU]@070000kN740000cZbh0000imC3000000;F^K`3000000>8[Nh0000000000`00
0003YHnn0000];OK00800002^;WJ0P000004^L?Q0000`koF`koF0P000003aL[N0000a<?I00?4`mT2
000000BE`_H0000000000002VKG[0P00000GhlJj0000h/Bj0000hL>i0000hL>i0000h<6i0000hL:i
0000h/>j0000hL:i0000iLRi0000i<Fh0000i/Vi0000i/Vi008000002NG7^@000=fk]]fk]P000>K8
^@000;maM`000002DQMU0`00009B5fD00`00070kPG0kP@02L3^100<0002LGhRLGhP01IaOR0030000
OTN3000000800002i[VV0P000005jKbW0000llbW0000l<NW008000000oC>Y`000>RkY`02000000GW
^ZL0003abJL0003/`JL00`0000A:8G/200000dhRN@D00003bhnD00<0002hO94000001iUKQP800004
aW9_00<0003oooooool0;_ooo`@00003YL?_0P0000:U`nl00`000:G3k`00000200000jG3k`<00002
YL?_10000004YL?_0000000000001:G3k`8000000jG3k`000000000200000jG3k`800002YL?_00<0
002U`nl000000P0000>U`nl300000ZG3k`@000001:G3k`000000000000BU`nl2000000>U`nl00000
00000P0000>U`nl2000000>U`nl000000000B?ooo`030000oooooooo03coool002Soool010000?oo
ooooooooo`@00002U6ZN00T0002;FI40003VelL0003B^<40003J`/8000000]No`P030000flC20000
00<000001m77d@000<Zhb<Zhb0000=?:d@000002cKc900P0003DcM800000003A^/<0003Lc/`00002
d[_40P000003c;2n0000YEYe008000001L>Q]`0000000?7]`P000002b:Fe0P000004cZbh0000imC3
00000]Ji_0030000e[Rk000000800003UK3Z1@0000:h^MX2000000Bi`n400000002f[]42000000?5
b]h0000000000lC3f@8000000l;6gP0000000003VKG[0`0000;Sa[X2000000SQ`kT0003Q`kT0003P
`KT0003Q`[T00002h/>j0P000004i<Rk0000i<Fhi<Fh0P000009i/Vi0000h/>h0000iLNi0000gK^f
0000i/Ri008000001KmaM`00058GI@000;9jU`02000000=B5fD0001`>h40170kP@030000W5n8W5n8
00FLGhP0100007i7P`000?WIZ0<000000o79Y`000>VlY`02000000?`ajL0003_aZL00P000009j;^W
0000mLnW0000ikZW0000lLVW0000k<6W00<00004BR5k0P0000=>8WT400000l^?U0040000^7bA^7bA
00001iUKQP800004aW9_00<0003oooooool0;?ooo`<000001:G3k`000:G3kjG3k`800003YL?_0`00
00:U`nl4000000>U`nl0000000000P0000>U`nl200000ZG3k`030000YL?_0000008000000jG3k`00
00000002YL?_00<0002U`nl000000P0000>U`nl300000ZG3k`@000000jG3k`000000000200000jG3
k`800002YL?_00<0002U`nl000000P000003YL?_0000000000:U`nl00`000:G3k`00000200000jG3
k`800018oooo00<0003oooooool0??ooo`00:?ooo`050000oooooooooooo000000FDJYh2000000CV
elL0003B^<400002f/;200<0003G_l8000000]_4`P8000000c5agP0000000002b[S800H0003Cb]7C
b]40003=_<T00002e<gB00D0003<^lT0003Lc/`000000]:ka0030000gmG>000000;</;h200000/>Q
]`<00002b:Fe0P000004cZbh0000imC300000]Ji_0040000e[Rk0000kN;5300000:i`n400`000;J^
dKJ^d@02000000?6g>T00034`mT00/C3f@8000001<;6gP0000000;jie0@00002UkW`0`000003h/Bj
0000000000;Q`kT020000>31^@000>72^@000>;3^P000>72^@8000001>?5^P0000000>K9^@800000
1>;3^0000>G7^@0000;M^kH2000000OK]k@0002oLGL0001B5fD0002bNYL00P000003DQMU0000L3^1
00A`>h400`0009aOR9aOR005W5n8100000;U^JP2000000GY_:L0003cc:L0003`ajL00P000003m<jW
0000j;^W008000001nNjY`000?79Y`000>c1Y`000>_0Y`02000014XQN`800003CR9i00@0003]SB@0
00000003bhnD00@0002hO96hO9400007VE^600<0001V<W`000000lIbK`030000oooooooo02[oool2
00001:G3k`<000000jG3k`000000000200000ZG3k`<00003YL?_0P0000:U`nl00`000:G3k`000002
00000jG3k`<000001:G3k`000000000000>U`nl300000ZG3k`@000000jG3k`000000000200000jG3
k`800002YL?_00<0002U`nl000000P0000>U`nl3000000BU`nl0000000000003YL?_0`0000:U`nl4
000000>U`nl000000000B?ooo`030000oooooooo03_oool002Soool200000_ooo`<00003U6ZN0`00
0005d[S10000f/;2f/;2000000;G_l8010000=_4`P000=g;a`<000000c5agP0000000002dl[A00<0
003=_<T000000]C=dP050000c;_90000e]3D000000;B^l@00`000=oEcP000002c;2n0P0000;3XKL0
30000>Gid00000000<RU]@000>gQa0000<j/^0000>OD``0000;F^K`2000000G]h/D00032W;80001o
WNH00P0000:`b>`3000000F[V/D000000000002f[]400P000004a]cY00000000]J_?0`0000;2a]h0
1@000;jie;jie0000<WGi00500000YVll@8000007N73^@000>73^@000>31^@000>72^@000>;3^P00
0>72^@000>C8^`000>?5^P000>G:^`000>K9^@000>;3^0000>G7^@000=fk]P000>K8^@000=^g]004
00000[9jU`040000NT5n000000001G0kP@030000W5n8W5n800FLGhP2000000CifJP0003U^JSU^JP2
000000SY_:L00000003`ajL0003_aZL0003dcZL2000000OecjL0003W^ZL0003abJL0003/`JL00P00
0003lLVW0000BR5k00=:8G/200000dhRN@040000kHdT000000000l^?U0040000^7bA^7bA00001iUK
QP030000IS9l000000?6LVl20000:?ooo`<00004YL?_0P000004YL?_0000000000001:G3k`800002
YL?_00@0002U`nl000000003YL?_0`0000:U`nl4000000BU`nl0000000000004YL?_0P000003YL?_
0000000000800003YL?_0P0000:U`nl00`000:G3k`00000200000jG3k`<00002YL?_10000004YL?_
0000000000001:G3k`8000000jG3k`000000000200000jG3k`800002YL?_00<0003oooooool0A_oo
o`030000oooooooo03[oool002Ooool200001?ooo`030000Dg_L000000@00002d[S100<0003J`/80
00000]No`P060000flC20000gL_70000eKk3100000;Cb]4010000<flb@000=C=dP8000001lbkb@00
0=K@e0000<flbP000=:ka00200000/b`_P070000i^cC0000`j6g0000iOW@000000;4XkP3000000C>
[;P0003We<<00002e[Vl00@0003F^;/000000002`Ybb0P0000F`b>`4000000>f[]40000000000/KL
j@050000]J_?]J_?]J_?000000;2a]h200000[jie0070000bMOT00000000]j[<0000VKca00<00000
1IRjk`0000000>73^@000002h<6i00@0003Q`[T0003R`kX2000000CTb;/0003SaK[SaKX2000000KU
bK/0003R`kP0003UakT00002gK^f0P000003fkNd0000j<fj00<00002/WZG00@0001j@Gh000000005
L3^100<0002LGhRLGhP01IaOR0<00002iKVX00T0003`bZT00000003cc:L0003`ajL0003_aZL00P00
0003j;^W0000mLnW008000001O79Y`000>c1Y`000>_0Y`03000014XQN`800003CR9i00<0003]SB@0
00000l^?U0050000^7bA^7bA^7bA000000NIFhH00`0006HbO0000003aW9_0P0002Goool300000ZG3
k`030000YL?_0000008000000jG3k`0000000002YL?_00<0002U`nl000000P0000>U`nl3000000>U
`nl0000000000P0000:U`nl300000jG3k`800002YL?_00<0002U`nnU`nl00P000003YL?_00000000
00:U`nl00`000:G3kjG3k`0200000jG3k`<00002YL?_10000003YL?_0000000000800003YL?_0P00
00:U`nl00`000:G3k`000002000000>U`nl0000000000ZG3k`030000YL?_000000800003YL?_0P00
04Koool30000??ooo`009oooo`030000oooooooo00Coool400000UZfo08000002M[2`P000=No`]No
`P000=_4`P000=g;a`000002eKk300<0003Odl`000000`000004cKc90000e<gB00000/bkb@030000
e]3D000000?=_<X200000/b`_P030000i^cC000000;3XKL200000lBS^08000001<j/^0000>OD``00
00;F^K`020000=Jh^`000>gRa@000<:L/P000>gh_@L0000014U</P000000000000;6g>T200000[F[
c`8000000lWLi`0000000002_[WD100000>gZ/`2000000BH^^l0000000000002V;C[0P00000=h<6i
0000hL:i0000h/>j0000hL:i0000i<Rk0000hlFj0000iLZk008000002^73^P0000000>G7^@000=fk
]P000>K8^@000=^g]0D00002/WZG00@0001j@Gh000000005L3^100<0002LGhRLGhP01IaOR0030000
nMVX000000;U^JP2000000?X_JP0000000000_37Y`8000000oC>Y`000>RkY`02000000OW^ZL0003a
bJL0003/`JL0003[`:L00`0000E:8G/0100004hRNDhRNDhRN@<00003bhnD00D0002hO96hO96hO940
00001iUKQP030000IS9l000000?6LVl300008Oooo`@00003YL?_0`000004YL?_0000000000000jG3
k`<00002YL?_10000004YL?_0000000000001:G3k`800002YL?_00@0002U`nl000000004YL?_0`00
0003YL?_0000000000BU`nl3000000>U`nl0000000000P000003YL?_0000000000800003YL?_0P00
00:U`nl00`000:G3k`00000200000jG3k`<000001:G3k`000000000000>U`nl300000ZG3k`@00000
0jG3k`0000000018oooo00<0003oooooool0>Oooo`009oooo`030000oooooooo00Koool00`0005nB
jP00000200000][2`P050000eko20000flC2000000;MblL00`000=Fn``000002gm?<1@000007e<gB
0000c;_9c;_90000e]3D000000?=_<X2000000G9]<D00000003Vk=<000000/>Q]`800003a:>h0P00
000;b:^l00000000imC30000e[Vl0000e[Rk0000kN;5000000;2W;8010000>gh_@000;jI/@800003
^=Sa00<00019C;8000000`0000>eZll00`000<WLilWLi`02000000>i/]<0000000000P0000>gZ/`2
000000?@i^L0000000000iRdj`<00002h<6i0P0000;R`kX20000017Tb;/0003SaKX0003Ub[/0003U
bK/0003Q`kX0003UakT0003M^kH0003Vb;T0003K]k@00P000004f[Jd0000000000000[9jU`040000
NT5n000000001G0kP@030000W5n8W5n800FLGhP020000?WIZ0000>FiZ0000?3:Z@000>RmZ0800000
0o37Y`000>o6Y`02000000OX^jL0003ecjL0003W^ZL0003abJL00P000003jl2W0000lLVW00800005
BR5k00<0001>8WU>8WT00ThRN@800003bhnD00D0002hO96hO96hO94000001iUKQP030000IS9l0000
00;6LVl0100007H`JGH`J@0001koool400000ZG3k`@000001:G3k`000000000000:U`nl4000000>U
`nl0000000000P0000>U`nl200000ZG3k`030000YL?_000000800003YL?_0`0000:U`nl4000000BU
`nl0000000000002YL?_10000004YL?_0000000000000jG3k`800002YL?_00<0002U`nnU`nl00P00
00>U`nl300000ZG3k`@000001:G3k`000000000000:U`nl4000000>U`nl0000000000P0000>U`nl2
00000ZG3k`030000oooooooo04Koool00`000?ooooooo`0hoooo000Woooo00<0003oooooool01_oo
o`L00002eko200L0003Ka<80003MblL0003E_/<000000]oCc0030000c;C2000000@00002c;_900<0
003Fd=@000000lflbP800002bKC50`0000;3XKL200000lBS^0800002b:^l0`0000;F^K`2000000[]
h/D00032W;;2W;80003]n;d0002nVK40003^j/H8000000>nd^T0000000000P000003bMcW00000000
00>i/]<200000kNZc08000001=3Vi`0000000;NXb`@00002VK__0`000009hL:i0000h/>j0000hL:i
0000i<Rk0000hlFj008000001NG9^`000>73^P000>C8^`02000000?M^kH0000000000]^g]0800000
1=Zf]0000000000000:bNYL0100007Y1OP00000000E`>h400`0009aOR9aOR004W5n800<0003ifJP0
00000^FiZ08000000nRmZ0000?;=Z@04000000GdcZL0003X^jL0003ecjL00P000005lLVW0000k<6W
0000jl2W008000000nVmY`0000000004BR5k00<0001>8WU>8WT00ThRN@800002bhnD00<0002hO96h
O9400[QlT@030000VE^6VE^600FIFhH00`0006HbO0000002aW9_00<0001f<6Uf<6T00P0001[oool4
00000ZG3k`<00003YL?_0P000003YL?_0000000000800003YL?_0P0000:U`nl00`000:G3k`000002
00000jG3k`<00002YL?_10000003YL?_0000000000800003YL?_0P000003YL?_0000000000800003
YL?_0P0000:U`nl010000:G3k`00000000BU`nl3000000>U`nl0000000000P0000:U`nl300000jG3
k`8000000jG3k`000000000200000jG3k`800002YL?_00<0002U`nl000000P0000>U`nl20000B?oo
o`030000oooooooo03Soool002Ooool010000?ooooooo`0000Soool3000000T/Ynd00000003Ka<80
003MblL0003E_/<000000]oCc0040000c;C20000gmC=1P000004e]3D0000cKc:cKc:0`0000;9]<D0
1@000=cWg00000000<>Q]`0200000lBS^0800002b:^l00@0003Qfll0003A^L82000000?F^;/00000
00000/:L/P030000kORm000000:nVK42000000?6XK@00027XnH00P0000:]g?L4000000?9g>L00000
00000kVbd`<000001;bieP000000000000;@i^L01@000;NXbkNXb`000<oSiP0500000YRbj@800000
2N;3^P000>72^@000>C8^`000>?5^P000>G:^`0200000^73^P080000i<Rk0000g;^g0000i/Ri0000
fkNd0P0000;J][@01`000>_A^`0000000;9jU`0007Y1OP0200001G0kP@030000W5n8W5n800BLGhP0
20000?WIZ0000>FiZ0000?3:Z@000>RmZ0800002klRY0`000009j;^W0000mLnW0000ikZW0000lLVW
0000k<6W008000000o79Y`000>VmY`02000014XQN`800003CR9i00D0003;SiC;SiC;Si@000001;Ql
T@030000VE^6VE^600FIFhH00`0006HbO0000002aW9_00@0001f<6Uf<6Uf<6T200005_ooo`<00004
YL?_0P0000:U`nl01@000:G3k`0000000:G3k`0200000ZG3k`030000YL?_YL?_00800003YL?_0`00
00:U`nl4000000>U`nl0000000000P0000>U`nl200000ZG3k`030000YL?_0000008000000jG3k`00
00000002YL?_00<0002U`nl000000P0000>U`nl300000ZG3k`@000001:G3k`000000000000BU`nl2
00000ZG3k`050000YL?_00000000YL?_00800002YL?_00<0002U`nnU`nl00P0000>U`nl300000ZG3
k`@000000jG3k`0000000018oooo00<0003oooooool0=oooo`009oooo`<00009oooo1@000004flC2
0000gL_700000]Fn``050000gm?<0000c;C2000000;Oe<d00`000<be``00000400000/flbP080000
em?Eem?E0000bKC50000g>OL00000/6U_@800003a:>h00L0003Vjm800038Zk`0003Qfll000000]6i
`P050000e[Rk0000kN;5000000;2W;8200000[jI/@040000k^[60000aZ6d2`0000Bi/]<200000kbi
eP030000d>KWd>KW00800002]jS;00L0003?hnH00000002j/M00002H/^T00`0000:I^^l300000^C8
^`080000hlFj00000000iLVk0000hL>j00000^C8^`8000001nG8^`000=^g]0000>S=^P000=Zf]003
000000GJ][@0002bNYL0001j@Gh00P0000E`>h400`0009aOR9aOR003W5n80`0000;U^JP2000000OX
_JP0003bcJT0003_b:T0003^aZT00P000005j;^W0000mLnW0000ikZW008000000nc1Y`000>_0Y`02
000000CY_JL0003bbZL00004BR5k0P0000=>8WT01@000<^?U<^?U<^?U0000004^7bA00<0002IFhJI
FhH01IUKQP060000IS9lIS9l0000aW9_00000gH`J@80000Doooo0P0000:U`nl00`000:G3k`000002
00000jG3k`<000000jG3k`0000000004YL?_0`000003YL?_0000000000800002YL?_0`0000>U`nl2
00000ZG3k`030000YL?_000000800003YL?_0`000004YL?_0000000000000jG3k`<00002YL?_1000
0003YL?_0000000000800003YL?_0P0000:U`nl00`000:G3k`00000200000jG3k`<000000jG3k`00
00000004YL?_0`000003YL?_00000000008000000jG3k`000000000200000jG3k`800002YL?_00<0
003oooooool0A_ooo`030000oooooooo03Koool002Koool200003?ooo`D00002gL_700<0003E_/<0
00000]oCc0800002gmC=00@0003<]L<0003LcL/3000000<WTNh0000000000]OCe@050000bKC50000
g>OL000000?1YKd200000/BS^0070000i^_B0000b:^l0000hM_?000000;A^L800`000=2g`P000002
00000/:L/P0>0000kORm0000_YVa0000k^[60000aZ6d0000j][40000cjfg0000Sj;Q0P000003Xm_k
00000000008000001;Vbd`000000000000:l^MH2000000>ncnP0000000000[NXb`8000000loSiP00
0;Zad002^[7@0P0000>I^^l3000000OQ`[T0003Tb;/0003SaKX0003Ub[/00P0000;Q`kX010000>C8
^`000=bk]`8000001=Zg]P000000000000;J][@020000>_A^`000=Zf]0000;9jU`0007Y1OP800005
L3^100<0002LGhRLGhP00iaOR0080000nMVX0000iKVX0000l<ZY0000j;fX0P0000;_b:T2000000cc
cjT00000003ecjL0003W^ZL0003abJL0003/`JL0003[`:L2000000CY_JL0003bbZL00004BR5k00<0
001_?H<000000ThRN@040000bhnDbhnD00001[QlT@030000VE^6VE^600BIFhH01P0006HbO6HbO000
0<IbK`0000Af<6T200004?ooo`<00003YL?_0`0000:U`nl4000000BU`nl0000000000004YL?_0P00
0004YL?_0000000000001:G3k`800002YL?_00@0002U`nl000000003YL?_0`0000:U`nl4000000BU
`nl0000000000004YL?_0P000003YL?_0000000000800003YL?_0P0000:U`nl00`000:G3k`000002
00000jG3k`<00002YL?_10000004YL?_0000000000001:G3k`8000001:G3k`000000000000>U`nl2
00000ZG3k`030000YL?_YL?_00800003YL?_0`0004Ooool00`000?ooooooo`0foooo000Voooo00<0
003oooooool03Oooo`030000IXcR0000008000003]Fn``000=oCc=oCc0000<bd`P000=oDc@000<be
``000=c=b`000=2ia0@00002em?E00D00039]<D0003Lim`000000l6U_@030000`ZJm`ZJm00800000
1>K[dP000<R[_<R[_0800002dKW200@0003@]l80003Vj]82000000S2W;80003]n;d0002nVK40003^
j/H00002aZ6d00@0003Zf/@0003?[KL200000j?Kn`H00003_;WF00<0002ncnRncnP00P000003_KWF
0000000000;?hnH00`000;Zad;Zad002000000?;fnH0000000000P000004VK[_0000000000000^C8
^`8000005NG:^`000>G9^`000>73^P000>C8^`000=bk]`000>G8^`000=Zg]P000>S=^P000=Zf]000
0>_A^`000=Zf]002000000FbNYL0001j@Gij@Gh000001G0kP@030000W5n8W5n800>LGhP200000^Fi
Z0800002j;fX0P000003klRY0000k/JY008000001NNkZ000000000000>NjY`02000000G/`JL0003[
`:L0003abJL00P000004l/ZW0000jKfW00000dXQN`030000Kcf30000009>8WT010000<^?U<^?U000
00JhO9400`0009UKQYUKQP04VE^600H0001V<WaV<W`00036LVl00004MS1Y0`0000coool300000ZG3
k`@000000jG3k`000000000200000jG3k`800002YL?_00<0002U`nl000000P000003YL?_00000000
00:U`nl00`000:G3k`00000200000jG3k`<000000jG3k`000000000200000ZG3k`<00003YL?_0P00
00:U`nl00`000:G3kjG3k`02000000>U`nl0000000000ZG3k`030000YL?_000000800003YL?_0`00
00:U`nl4000000>U`nl0000000000P0000>U`nl200000ZG3k`030000YL?_0000008000000jG3k`00
00000002YL?_00@0002U`nl000000004YL?_0`000003YL?_00000000008000000jG3k`0000000018
oooo00<0003oooooool0=Oooo`006?ooo`030000oooooooo00;oool00`000?ooooooo`06oooo00<0
003oooooool03Oooo`H00002gm?<00D0003<]<80003Oe<d000000/be``800003d;W41@000004bKC5
0000g>OL00000l6U_@040000`ZJm`ZJm`ZJm0`0000;8Zk`02@000>7Kc`000=6i`P000=2g`P000>KZ
dP000002_9Na0`0000:nVK402P000>kZaP000<JQ]0000>[Ja0000<n]]`000>K@`@L000000d97/000
09Uo]P0300000[k?j0060000_KWF_KWF_KWF0000cn?V0P0000:j/M001@000<_KiP0000000;Zcd`04
00000YG3m`<000001N?5^P0000000>G9^`000002hL>j00X0003Tb;/00000003Ub;/0003J]kH0003W
cK`00002f[Jd0P0000;J][@300000gY1OP030000L3^1L3^100=`>h400`0009aOR9aOR002W5n800`0
003ifJP0003U^JP0003`bZT0003X_JP0003bcJT0003_b:T2000000GccjT0003W^jP0003dd:T00P00
0005lLVW0000k<6W0000jl2W008000001^VmY`000?;:Y`000>VmY`0000=:8G/01P0006lmPflmP`00
04hRN@0000;;Si@00`000;QlTKQlT@04^7bA00<0002IFhJIFhH019UKQP060000IS9lIS9l0000aW9_
00001GH`J@800008oooo100000:U`nl300000jG3k`800002YL?_00<0002U`nnU`nl00P0000>U`nl3
000000BU`nl0000000000003YL?_0`0000:U`nl4000000BU`nl0000000000004YL?_0P0000:U`nl0
10000:G3k`00000000BU`nl3000000>U`nl0000000000jG3k`<00002YL?_10000003YL?_00000000
00800003YL?_0P0000:U`nl00`000:G3k`00000200000jG3k`<000001:G3k`000000000000>U`nl3
00000ZG3k`@000001:G3k`000000000000>U`nl200000ZG3k`030000oooooooo04Koool00`000?oo
ooooo`0doooo000Goooo00<0003oool000000_ooo`030000oooo000000Ooool00`000?ooooooo`0?
oooo00<0001bUnL000000`000004c;C20000gmC=00000/be``030000g<g;000000;@^L@2000000?D
_L<0000000000P000004g>OL0000`JFm`JFm0`0000;2Y[d010000=gXg0000<J^`P8000001^7Kc`00
0=6i`]6i`P000=2g`P800003_9Na0P0000:nVK401`000>kZaP000<JQ]0000>[Ja0000002cjfg0P00
0003e[Bh0000000000>Qf?/500000[k?j0800002_KWF0P000004_<cV0000^[7@^[7@0P000006bm_V
0000^[?C^[?C0000aLOL1@0000:E`_H2000000?Ub[/0000000000^73^P040000i<Rk0000g;^g0P00
00;J]kH2000000KI]KD00000003[dK/0003J][@400000gY1OP030000L3^1L3^100=`>h400`0009aO
R9aOR002W5n800@0003ifJP0003U^JP200000^RmZ08000000no8Z@000>k6Z@02000000GW^jP0003d
d:T0003V^ZP00P000004k<6W0000jl2Wjl2W0P000006jKfW0000l/ZW0000jKfW00000dXQN`060000
Kcf3Kcf3Kcf30000CR9i0P0000NhO9400`0009UKQYUKQP04VE^600H0001V<WaV<W`00036LVl00005
MS1Y100000?oool400000jG3k`800002YL?_00@0002U`nl000000004YL?_0`000003YL?_00000000
008000001:G3k`000000000000:U`nl4000000>U`nl0000000000P0000>U`nl200000ZG3k`030000
YL?_000000800003YL?_0`0000:U`nl4000000FU`nl000000000002U`nl0100000:U`nl300000jG3
k`800002YL?_00<0002U`nl000000P0000>U`nl300000ZG3k`@000001:G3k`000000000000:U`nl4
000000>U`nl0000000000P0000>U`nl200000ZG3k`040000YL?_000000000jG3k`<00017oooo00<0
003oooooool0=?ooo`006Oooo`060000oooooooo0000oooo00001oooo`030000oooooooo00ooool7
000000OOe<d0003<]L?<]L<0003LcL/000000]2ia0800002e;g30P000003H87L0000000000;1YKd0
0`000=cfg@000002`ZJm00<0003Mj=`000000/J^`P030000hM_?000000;A^L8010000=2g`P000000
00>lUk43000000BnVK40003^j/H00002aZ6d0P0000;?[KL01@000>K@`@0000000>C>`@0400000Y>N
f`8000000cU6]00000000003_KWF00D0002lc>H00000002o`=/00P000003bm_V0000000000:j/m<0
1`000<G7g00000000<K7f`0009G2mP03000000FD_?800000003UbK/000000^73^P0:0000i<Rk0000
0000iLRk0000f[Nf0000ilfl00000]Ve]@8000000mZf]0000>cB^`0300000gY1OP030000L3^1L3^1
00=`>h40400009aOR9aOR9aOR0000?WIZ0000>FiZ0000?3:Z@000>RmZ0000?;=Z@000>o8Z@800000
1o??Z@000>NkZ0000?C@Z@000>JjZ002000000G/`JL0003[`:L0003abJL00P000003l/ZW0000jKfW
00800003BR5k00H0001_?H=_?H=_?H<0001>8WT200001kQlT@030000VE^6VE^600BIFhH00`0006Hb
O6HbO00200001gH`J@L000000jG3k`000:G3k`0300000jG3k`<00002YL?_10000004YL?_00000000
00000jG3k`800002YL?_0`0000>U`nl200000ZG3k`030000YL?_YL?_00800003YL?_0`0000:U`nl4
000000>U`nl0000000000P0000>U`nl2000000BU`nl0000000000004YL?_0P0000:U`nl010000:G3
k`00000000>U`nl300000ZG3k`@000000jG3k`000000000200000jG3k`8000000jG3k`0000000002
00000jG3k`800002YL?_00<0002U`nl000000P0000>U`nl3000000>U`nl0000000000P000004YL?_
000000000000Aoooo`030000oooooooo03?oool001Ooool200000oooo`030000oooo000000Ooool2
00004Oooo`L00002c;G300<0003LcL/000000]2ia0060000f<O90000e;g30000elO:0`000005H87L
00000000g?KM000000;2Y[d00`000=gXg0000002aZk200<0003HemL000000]6i`P050000d;O20000
i^[B000000:lUk4200000[N@[@8000004NkZaP000<JQ]0000>[Ja0000<n]]`000>K@`@000=Jd^000
0>C>`@000=Jf^@0009>Nf`0200000Z?GnP8000001YZ3^P00000000000;c<iP0000:o`=/2000000Bm
c>D0002j/m>j/m<2000000?5am`00036am/00/K7f`8000001IBllP000000000009O3m@0200000^73
^P040000i<Rk0000g;^g0P0000;J]kH200000]Ve]@8000001MVf]P00000000000=^g]00200000gY1
OP030000L3^1L3^100=`>h40200009aOR9aOR9aOR0000?WIZ0000>FiZ0800002j;fX0P000005klRY
0000k/JY0000llnY008000001OC@Z@000>JjZ0000?7:Z@0200000^_0Y`8000001NVmY`000?;:Y`00
0>VmY`0200000dXQN`030000Kcf3Kcf3009_?H<300001kQlT@030000VE^6VE^600BIFhH01@0006Hb
O6HbO6HbO0000007MS1Y100000>U`nl300000ZG3k`@000000jG3k`000000000200000jG3k`800002
YL?_00@0002U`nl000000002YL?_0P0000:U`nl010000:G3k`00000000BU`nl3000000>U`nl00000
00000P000003YL?_0000000000800003YL?_0P0000:U`nl00`000:G3k`000002000000>U`nl00000
00000ZG3k`030000YL?_000000800003YL?_0`000003YL?_0000000000800002YL?_0`0000>U`nl2
00000ZG3k`030000YL?_0000008000000jG3k`0000000002YL?_00<0002U`nl000000P0000>U`nl3
00000ZG3k`@000001:G3k`000000000000>U`nl200000ZG3k`030000oooooooo04Koool00`000?oo
ooooo`0boooo000Goooo00<0003oooooool00_ooo`030000oooo000000Ooool00`000?ooooooo`0B
oooo0`00009`W^d010000<be``00000000;@^L@01@000=S7b@000=Bm``000002elO:00<0003F_l<0
0000100000;2Y[d00`000=gXg0000002aZk200@0003HemL0003<^LP2000000C@]l80003Vj]800002
_9Na0P0000>gT:d3000000[6XK@0003Zf/@0003?[KL0003Vd<40003F];P00002i<k100<0003F][T0
00002@000004_<cV00000000_l3K0P000004_LcU00000000`<OP0P0000;5am`00`000<K7flK7f`02
000000Bn/<`00000002G`oD300000Y^dj@0<0000hL>j00000000g;^g0000iLRk0000f[Nf0000ilfl
00000]Ve]@8000001MVf]P000>cB^`000=^g]002000017Y1OP030000L3^1L3^1009`>h40100009aO
R9aOR9aOR08000002NFiZ0000?3:Z@000>RmZ0000?;=Z@000>o8Z@02000000OccjT0003W^jP0003d
d:T0003V^ZP00P000007jl6Y0000jl2W0000lLVW0000jKfW00800002jKfW0`00009:8G/00`0006lm
PflmP`02Kcf30P0000RhO9400`0009UKQYUKQP04VE^600D0001V<WaV<WaV<W`000001GH`J@@00000
0jG3k`000000000200000ZG3k`<00003YL?_0P0000:U`nl00`000:G3k`00000200000jG3k`<00000
1:G3k`000000000000>U`nl300000ZG3k`@000001:G3k`000000000000>U`nl200000ZG3k`030000
YL?_YL?_00800003YL?_0`000004YL?_0000000000000jG3k`<00002YL?_10000004YL?_00000000
00001:G3k`800002YL?_00@0002U`nl000000003YL?_0`000004YL?_0000000000000jG3k`<00002
YL?_10000003YL?_0000000000800003YL?_0P0000:U`nl010000:G3k`00000000BU`nl20000AOoo
o`<0000doooo000Goooo0`0000?oool00`000?ooooooo`05oooo00<0003oooooool05?ooo`H00000
1]c=b`000=2ia0000=S7b@0000;D_L<00`000=O7bP000002e[o30`00009RP]`2000000OMj=`00036
[/;6[/80003HemL000000/bib0030000bkO7000000800002_9Na00<0003?nk@000000[N@[@040000
h_g20000_i^c0`0000;?[KL020000>K@`@000=Jd^0000>C>`@000=Jf^@8000000mFd^@0009:Rg`03
000000FQd_T000000000002o`=/00P0000:mc>D01P000<37h<37h<37h0000<G7g0800002a/OK00D0
002n/<bn/<`0003Eln@00P0000BK]>T3000000GTb;/00000003Ub;/000000]Zg]P800002fKFe0P00
0005fKJf0000jm>m0000fkNd00<00004NT5n00<0001`>h5`>h400W0kP@030000W5n8W5n800<00000
0nFiZ00000000002j;fX0P000007klRY0000k/JY0000llnY0000ik^X008000001NJjZ0000?7:Z@00
0>_1Z@04000000OY_JL0003bbZL0003Y_JL0003`ajL00P00009:8G/00`0006lmPflmP`03Kcf300<0
002hO96hO9401[QlT@030000VE^6VE^600BIFhH01@0006HbO6HbO6HbO0000002MS1Y1000009N<h@2
00001:G3k`800002YL?_00@0002U`nl000000003YL?_0`0000:U`nl4000000BU`nl0000000000002
YL?_10000003YL?_0000000000800003YL?_0P0000:U`nl010000:G3k`00000000BU`nl3000000>U
`nl0000000000P000004YL?_0000000000000ZG3k`@000000jG3k`000000000200000jG3k`800002
YL?_00<0002U`nl000000P0000>U`nl3000000>U`nl0000000000P000004YL?_0000000000000ZG3
k`@000000jG3k`000000000200000jG3k`800002YL?_00<0002U`nl000000P0000>U`nl300000ZG3
k`@000000jG3k`0000000017oooo00<0003oooooool0<Oooo`009Oooo`030000oooooooo01Koool0
0`0006bNkP000002000000C@^L@0003HalT00002e;g300<0003GalX000000]Jo``8000000mJn``00
0000000400000/J^`P030000f=OG000000;<^LP00`000<^gal^ga`0200000kbG/@800002]i2]00<0
003RoL8000000[nK/`0@0000j][40000cjfg0000i]310000e[Bh0000i<k10000e[Ji0000i];20000
eKBi0P0000>Qd_T500000[g<i@800002`<OP0P000004^/KT0000a/OKa/OK0P0000:n/<`3000000>e
X<<0000000000`000005WKg_000000000000g;^g00800002f[Nf00@0003WcK`0003I]KD200000]Vf
]P8000001MZg]P0000000>W?^P000005NT5n00D0001`>h5`>h5`>h4000000YaOR0060000n=^[0000
0000l<ZY00000^RmZ08000000no8Z@000>k6Z@02000000GW^jP0003dd:T0003V^ZP00P000004jl6Y
0000jl6Yjl6Y0P000003jKfW0000000000;Y_JL2000000GY_JL0001:8G]:8G/000001FlmP`030000
^7bA^7bA00JhO9400`0009UKQYUKQP04VE^600@0001V<WaV<WaV<W`400001UhcQ0030000YL?_0000
00800003YL?_0`000003YL?_0000000000800002YL?_0`0000>U`nl2000000>U`nl0000000000P00
00>U`nl200000ZG3k`030000YL?_000000800003YL?_0`0000:U`nl4000000BU`nl0000000000003
YL?_0P0000:U`nl300000jG3k`800002YL?_00<0002U`nl000000P0000>U`nl300000ZG3k`@00000
1:G3k`000000000000>U`nl200000ZG3k`<00003YL?_0P0000:U`nl00`000:G3k`00000200000jG3
k`<00002YL?_10000003YL?_0000000000800003YL?_0P000003YL?_0000000004Koool00`000?oo
ooooo`0aoooo000Uoooo00<0003oooooool05_ooo`H00002f<O900D0003D_L<0003GalX000000]Jo
``800003e[k30`00009GQ^@2000000?HemL0003<^LP00P0000;;]lL300000[bG/@800003]i2]0P00
00:oVk<02`000>OYd@000<n]]`000>K@`@000=Jd^0000>C>`@000002e[Ji0P000003eKBi0000j=C2
00@000000hjWiP000000000400000/37h08000001;[6i00000000;cHkP800002_[3<0`0000>eX<<0
0`000<kng000000300000Z2bi@8000001>G8^`000=Zg]]Zg]P800002fKFe0P000005fKJf0000jm>m
0000f[Nf00@00005NT5n00X0001`>h5`>h5`>h40002LGhP0003hfj/0003T^JT200000^RmZ0090000
l/fY00000000k/JY0000llnY0000ik^X00800002i[ZX0P000005jl6Y0000jl6Y0000lLZY00800000
1?;:Y`000>VmYnVmY`8000001NVmY`0004XQNdXQN`000005Kcf300<0002hO96hO9401[QlT@030000
VE^6VE^600BIFhH00`0006HbO000000200000VHbO0030000GS>4GS>400=N<h@300000ZG3k`@00000
1:G3k`000000000000BU`nl200000ZG3k`050000YL?_00000000YL?_00800002YL?_00<0002U`nnU
`nl00P0000>U`nl300000ZG3k`@000000jG3k`000000000200000jG3k`800002YL?_00@0002U`nl0
00000002YL?_0P0000:U`nl010000:G3k`00000000>U`nl300000ZG3k`@000000jG3k`0000000002
00000jG3k`800002YL?_00@0002U`nl000000002YL?_0P0000:U`nl010000:G3k`00000000>U`nl3
00000ZG3k`@000000jG3k`000000000200000jG3k`800002YL?_00<0002U`nl000000P000004YL?_
00000000YL?_0P0004Koool00`000?ooooooo`0`oooo000Uoooo00<0003oooooool05oooo`L00000
2MBm``000=O7b]O7bP000=Jo``000=K4b0000002e[k30P000003eko200000000008000001=SGe`00
0<bib00000?;]lL200000[bK]`<00003]i2]0P0000:oVk<010000>OYd@000<R[_08000001nK@`@00
0=Jd^0000>C>`@000=Jf^@0200000]Fd^@8000000mBc^@000000000200000ig4l`D000000k[6i000
00000002_=S^0P000003[jgF0000000000800003]J330`000003/j750000X;;U00<000000ibol000
00000002f[Nf00@0003WcK`0003I]KD2000000[I][H0003[dkd0003J]kH0003Xd;`0003K^KL00005
NT5n0P00009`>h401P0009aOR0000?SKZ`000>BiZ@800002j;fX0P000003klRY0000k/JY00800000
1nNkZ0000?C@Z@000>JjZ0000?7:Z@0200000^_1Z@8000000nRmZ@0000000002jKfW00P0003`ajL0
0000003^a:L0001:8G/00005Kcf300<0002hO96hO9401[QlT@030000VE^6VE^600>IFhH300001FHb
O0030000GS>4000000<00002YL?_0`0000>U`nl200000ZG3k`030000YL?_000000800003YL?_0`00
0003YL?_0000000000BU`nl3000000>U`nl0000000000P0000:U`nl300000jG3k`800002YL?_00<0
002U`nl000000P0000>U`nl3000000BU`nl0000000000003YL?_0`000003YL?_0000000000800000
0jG3k`000000000200000jG3k`800002YL?_00<0002U`nl000000P0000>U`nl3000000BU`nl00000
00000003YL?_0`000003YL?_00000000008000000jG3k`000000000200000jG3k`800002YL?_00<0
002U`nl000000P0000>U`nl3000000BU`nl0000000000003YL?_0P0004Ooool00`000?ooooooo`0_
oooo000Uoooo0P0001Woool400000VRLkP8000001]O7bP000=Jo``000=K4b00000;F_/<200000]No
`PD000000lbib0000<^ga`02bkO70P0000>lVkL300000[N@[@800002_i^c00<0003WjM4000000/R[
_0<000001MJd^0000>C>`@000=Jf^@0200000]Fd^@060000j=C20000e;>i0000jm_32`0000:lf>h2
00000jn]eP800003]J330`0000>cXLD2000000BL_o00000000000002WjWN00@0003J]kH000000002
fKFe0P00000:fKJf0000jm>m0000f[Nf0000j=2l0000fkVg00001GY1OP060000LSYl0000L3^10000
W5n80P000003i;VY0000l<^/00<000003?;=Z@0000000>k6Z@000???Z@000>NkZ0000?C@Z@000>Jj
Z08000001n_1Z@000>_1Z@000?7:Z@000>RmZ@0200000^VmY`8000001^VmY`000000000004XQN`00
00E_?H<00`000;QlTKQlT@06^7bA00<0002IFhJIFhH00`000003VE^60000IS9l00AV<W`300001:G3
k`800002YL?_00@0002U`nl000000003YL?_0`0000:U`nl4000000BU`nl0000000000002YL?_1000
0004YL?_0000000000001:G3k`800002YL?_00@0002U`nl000000003YL?_0`0000:U`nl4000000BU
`nl0000000000002YL?_10000004YL?_0000000000000jG3k`800002YL?_00<0002U`nnU`nl00P00
00>U`nl300000ZG3k`@000001:G3k`000000000000:U`nl4000000BU`nl0000000000003YL?_0P00
00:U`nl00`000:G3kjG3k`0200000jG3k`<00002YL?_10000004YL?_0000000000000ZG3k`@00000
0jG3k`0000000016oooo00<0003oooooool0;oooo`009Oooo`030000oooooooo01[oool5000000KG
alX0003F_l<0003Fa<P00002e[k300H0003E`<D0003G_l80003C^;l500000l^ga`800003_9^g0P00
00:iU[<300000[nK/`030000inWA000000;8Zk`010000=oFcP000<jc`0<000001=Jf^@000>KB`P00
00;E];T200000]Bc^@8000000lfY]P0008FXj`04000000<?A/<0000000000`0000>_[MH400000[FP
``<00003/j7500@0003@lNP000000005WjWN0P000003ilfl0000fKFe008000002MVf]P000>_C_@00
0=Zg]P000>S@_0000=^i]`0200001GY1OP040000LSYl0000L3^10P000003n=^[0000i;VY00800002
ikfZ0P000005klRY0000k/JY0000llnY008000002OC@Z@000>JjZ0000?7:Z@000>_1Z@000>_1Z@02
000000?X_JT0003abjT00`000003l<NW0000jKfW00<000000dXQN`0006lmP`04Kcf300<0002hO96h
O9401[QlT@<00004VE^600@0001V<WaV<WaV<W`200000ZG3k`030000YL?_000000800003YL?_0`00
0003YL?_0000000000800002YL?_0`000003YL?_00000000008000000jG3k`000000000200000jG3
k`800002YL?_00<0002U`nl000000P0000>U`nl3000000>U`nl0000000000P000003YL?_00000000
008000000jG3k`0000000002000000>U`nl0000000000P0000>U`nl200000ZG3k`040000YL?_0000
00001:G3k`<000000jG3k`0000000002000000>U`nl0000000000P000003YL?_0000000000800000
0jG3k`000000000200000jG3k`800002YL?_00@0002U`nl000000004YL?_0`000003YL?_00000000
008000000jG3k`0000000002000000>U`nl0000000000P000003YL?_0000000000800003YL?_0P00
0003YL?_0000000004Koool00`000?ooooooo`0^oooo000Toooo00<0003oooooool07?ooo`D00000
1=Jo``000=K4b00000;F_/<020000=G0a@000=No`P000=>h_`000=k:a@D000000l^ga`0000000003
_9^g0P0000>iU[<200000knK/`070000inWA0000b:^l0000gmK>000000;>/l0010000>C>`@000=Jf
^@800002eKBi0P0000;D/kT200000/fY]P800004X<;a1P000004[jgF0000000000000jjTc@<00004
/j750`000004^[?B0000WjWNWjWN0`000004VL_i00000000fKFe0P0000;I][H010000>_C_@000=Zg
]P800002fkVg0`0000Aj@Gh00`00078jO78jO004000000CT^JT0003`bj`00002ikfZ0`000009k/JY
0000llnY0000ik^X0000m=2Y0000i[ZX008000001n_1Z@000>_1Z@000?7:Z@000>RmZ@0200000^Rm
Z@8000000nVmY`000>k4Y`02000000=:8G/0001_?H<01FlmP`030000^7bA^7bA00:hO94400001YUK
QP040000IS9l000000000jG3k`<00002YL?_10000004YL?_0000000000001:G3k`8000001:G3k`00
0000000000>U`nl200000ZG3k`030000YL?_YL?_00800003YL?_0`0000:U`nl4000000BU`nl00000
00000003YL?_0P0000:U`nl300000jG3k`800002YL?_00<0002U`nl000000P0000>U`nl300000ZG3
k`@000001:G3k`000000000000>U`nl200000ZG3k`<00003YL?_0P0000:U`nl00`000:G3k`000002
00000jG3k`<00002YL?_10000004YL?_0000000000000jG3k`8000000jG3k`000000000200000jG3
k`800002YL?_00<0002U`nl000000P0000>U`nl20000Aoooo`030000oooooooo02goool002Coool0
0`000?ooooooo`0Moooo1@0000;Fa<P01@000=Jn``000=G0a@000002eko200P0003C^;l0003Nb/D0
003A/k/0001INmX300000kbK]`030000c?o>000000>iU[<200000[nK/`070000inWA0000b:^l0000
gmK>000000;>/l0010000=kBc@000=Jf^@800002eKBi00X0003Xe<80003D/kT0003[fl<0003=ZKH0
003ak/8=00001:jTc@@00002/j750`0000Bj/m82000000BIboT0000000000002Wk3T0`00000;fKJf
0000jm>m0000f[Nf0000j=2l0000fkVg0000iLZk00800004NT5n00<0001b>Wab>W`00P000003n=^[
0000i;VY00800002ikfZ00T0003bcZ`00000003^aZT0003ccjT0003W^jP00P0000;V^ZP2000000G[
`JT0003[`JT0003abZT00P000004lL^Y0000j;fYj;fY0P000007jKfW00000000jKfW0000BR5k0000
00I_?H<00`000;QlTKQlT@0200000kQlT@030000VE^6VE^600>IFhH3000000>U`nl0000000000P00
00:U`nl300000jG3k`800002YL?_00<0002U`nl000000P000003YL?_0000000000:U`nl010000:G3
k`00000000BU`nl3000000>U`nl0000000000P000003YL?_0000000000800003YL?_0P0000:U`nl0
10000:G3k`00000000:U`nl200000ZG3k`040000YL?_000000000jG3k`<00002YL?_10000003YL?_
0000000000800003YL?_0P0000:U`nl010000:G3k`00000000:U`nl200000ZG3k`040000YL?_0000
00000jG3k`<00002YL?_10000003YL?_0000000000800003YL?_0P0000:U`nl01@000:G3k`000000
0:G3k`0200000ZG3k`030000YL?_000000800003YL?_0`0000:U`nl4000000>U`nl000000000A_oo
o`030000oooooooo02goool002Coool00`000?ooooooo`0Ooooo00<0001NV_0000000P000004e[k3
0000eL3500000]No`P050000dkRo0000g/[5000000;A/k/200000UUkfP060000_9^g_9^g0000c?o>
00000kVF/`030000_Z2j_Z2j008000001>OYd@000<R[_<R[_0800002c[?000L0003Nd/d0003>]L40
003Vd/8000000]Fd^@8000001=Bc^@000>_K``0000;=ZKH2000000?4Wk800000000019o5l`H00000
0jjTc@000000000200000kRgf@@00003^[?B0P000003a=GW0000000000>O/>@4000000KI][H0003[
dkg[dkd0003J]kH2000000GK^KL0003Ub[/0003O`;T00P0000=j@Gh01000078jO78jO78jO0800000
1>BiZ@000?3;[00000;W_JX2000000c_b:`00000003ccjT0003W^jP0003dd:T0003V^ZP0003abZT2
000000G[`JT0003abZT0003X_JT00P0000;X_JT01`000>o7Z@0000000>k4Y`000>VmY`0300001Vlm
P`<00005^7bA00<0002IFhH000000`000004YL?_0000000000001:G3k`800002YL?_00@0002U`nl0
00000003YL?_0`0000:U`nl200000jG3k`<00002YL?_10000004YL?_0000000000000jG3k`800002
YL?_00<0002U`nnU`nl00P0000>U`nl3000000BU`nl0000000000003YL?_0`000003YL?_00000000
00800002YL?_0`0000>U`nl200000ZG3k`030000YL?_000000800003YL?_0`000004YL?_00000000
00000jG3k`<000000jG3k`0000000002000000>U`nl0000000000P0000>U`nl200000ZG3k`030000
YL?_000000800003YL?_0`000003YL?_0000000000>U`nl300000ZG3k`@000000jG3k`0000000002
00000jG3k`8000000jG3k`0000000016oooo00<0003oooooool0;?ooo`009?ooo`030000oooooooo
01ooool600000]G0a@070000eko20000dkRo0000g/[5000000;A/k/2000000CA/[/00000001INmX2
000000?<olh0002iU[<00[VF/`040000_Z2j_Z2j_Z2j0`0000;8Zk`02`000=oFcP000<jc`0000=kB
c@000<je`@000>3Hc`000002eKBi0P0000;D/kT200000/fY]P8000000lBO/P000?7_`@0<000000>]
jOT0000000000kRgf@<00003^[?B0P000004a=GW00000000^kKD1P0000:L]>T2000000O[dkd0003J
]kH0003Xd;`0003K^KL00P000004gl2i0000hlJj00000gY1OP0=0000LSYlLSYl0000n=^[0000i;VY
0000l<^/0000ikfZ0000l/j/008000001Nk7[000000000000>NkZ00200000^JjZ08000001n_1Z@00
0>_1Z@000?7:Z@000>RmZ@0200000^RmZ@8000001^RmZ@0000000>VmY`000>o5Y`800003Kcf31000
00JhO94300000jG3k`800002YL?_00<0002U`nl000000P0000>U`nl3000000>U`nl0000000000P00
00:U`nl3000000>U`nl0000000000P000003YL?_0000000000800003YL?_0P0000:U`nl010000:G3
k`00000000BU`nl3000000>U`nl0000000000P000004YL?_0000000000000ZG3k`@000001:G3k`00
0000000000BU`nl200000ZG3k`040000YL?_000000000jG3k`<00002YL?_10000004YL?_00000000
00000ZG3k`@000001:G3k`000000000000>U`nl200000ZG3k`030000YL?_000000800003YL?_0`00
00:U`nl4000000FU`nl000000000002U`nl0100000:U`nl300000jG3k`800002YL?_00<0002U`nl0
00000P0000>U`nl20000Aoooo`030000oooooooo02_oool002Coool300008?ooo`<00002CJ;f0P00
0004eko20000dkRodkRo0P0000;A/k/00`000>;Cb0000002dK:k1@0000>iU[<020000;jP^[jP^[jP
^P000=cZg@000<B/`P8000003MoFcP000<jc`0000=kBc@000<je`@000>3Hc`000<fc`0000=Fd^@02
000000?D/kT0000000000/fY]P080000lNk20000a9nb0000lNo10000bJJf0`0000:A_?@600000[Rg
f@D000001K[<i`00000000000<CEi`02000000Bk]]@000000033c>8200000ibdj@<00002jm>m00/0
003J]kH00000003K^KL0003Ub[/0003O`;T0003Sa[X00P00009j@Gh00`00078jO78jO002000000CT
^JT0003`bj`00002ikfZ0P000005klR/0000k/N/0000lm2/008000001?C@Z@000>JjZ>JjZ0<00002
jl6Y0P000009j;fY0000lL^Y0000j;fY0000klNY0000j;fY008000000nVmY`000>o5Y`0500000flm
P`030000^7bA^7bA00:hO94200000ZG3k`040000YL?_000000000jG3k`<00002YL?_10000004YL?_
0000000000000ZG3k`@000001:G3k`000000000000>U`nl200000ZG3k`030000YL?_YL?_00800003
YL?_0`0000:U`nl4000000FU`nl000000000002U`nl010000003YL?_0000000000800003YL?_0P00
00:U`nl00`000:G3k`00000200000jG3k`<000000jG3k`0000000002000000>U`nl0000000000P00
0003YL?_00000000008000000jG3k`000000000200000jG3k`800002YL?_00@0002U`nl000000003
YL?_0`0000:U`nl4000000>U`nl0000000000P000003YL?_00000000008000001:G3k`0000000000
00BU`nl200000ZG3k`040000YL?_000000000jG3k`<00002YL?_10000003YL?_0000000004Koool2
0000;?ooo`009?ooo`030000oooooooo027oool500000]No`P090000dkRo0000g/[50000dK>k0000
h]?8000000;A/[/4000000EUN=40002iU[>iU[<000000kjP^P030000g>[M000000;4[<801@000=oF
cP000<jc`0000002g];=00@0003>]L4000000003cK?00P000004e;>i0000jm_300000/fY]P800000
1lBO/P000?7_`@000<VV]P000>_J``09000000B/WlX00000002ado8200000[[<i`D00002^kKD00D0
0033c>800000002m]M80100000:<`_T3000000?J]kH0000000000]^i]`8000001]o0^@000>?6^P00
0>73^@00009j@Gh03000078jO0000?SKZ`000>BiZ@000?3;[0000>NmZP000?;>[08000001Nk7[000
0??@[0000>JkZP0200000^JjZ0090000lLZY00000000jl6Y0000lLZY0000j;fY00800002j;fY0P00
0003j;fY0000k/FY008000001>o5Y`000000000000I_?H<00`000;QlT@00000200000jG3k`<00000
0jG3k`000000000200000ZG3k`<000000jG3k`0000000002000000>U`nl0000000000P0000>U`nl2
00000ZG3k`040000YL?_000000001:G3k`<000000jG3k`0000000002000000>U`nl0000000000P00
0003YL?_00000000008000001:G3k`000000000000>U`nl200000ZG3k`030000YL?_YL?_00800003
YL?_0`0000:U`nl4000000FU`nl000000000002U`nl0100000:U`nl300000jG3k`800002YL?_00<0
002U`nl000000P0000>U`nl3000000>U`nl0000000000P0000:U`nl3000000>U`nl0000000000P00
0003YL?_0000000000800003YL?_0P0000:U`nl00`000:G3k`00000200000jG3k`<000000jG3k`00
00000002000000>U`nl0000000000P000003YL?_00000000008000000jG3k`0000000014oooo0`00
02coool002?oool00`000?ooooooo`0Soooo1P000008dkRo0000g/[50000dK>k0000h]?800000]6b
^`800002ekZm1@0000>nX;X00`000=cZg@000002a:c200D0003FdmH0003>/l0000000]kBc@040000
c[G1000000000lfc`08000001<fb_`000000000000;=ZKH200000/BO/P800002bJJf0P000003d[:j
0000000000H000001JbObP00000000000;[<i`03000000B_^N400000002ibnP3000000K3c>80002m
]M:m]M800039d^4500000i^]i0<000002M^i]`000>G:^`000=o0^@000>?6^P000>73^@02000000=j
@Gh0001b>W`00P000004i;VY0000l<^/00000^NmZP8000001no8[0000>k7[0000??@[0000>JkZP02
00000^JjZ08000001N_1Z@000>_1Z@000?7:Z@02000000OabjT0003X_JT0003_ajT0003X_JT01P00
0003kL>W0000Kcf300A_?H<300000ZG3k`@000001:G3k`000000000000BU`nl2000000BU`nl00000
00000003YL?_0P0000:U`nl00`000:G3kjG3k`0200000jG3k`<00002YL?_10000004YL?_00000000
00000jG3k`8000000jG3k`000000000200000jG3k`800002YL?_00@0002U`nl000000004YL?_0`00
0003YL?_00000000008000000jG3k`000000000200000jG3k`8000001:G3k`000000000000BU`nl2
00000ZG3k`040000YL?_000000000jG3k`<00002YL?_10000004YL?_0000000000001:G3k`800000
1:G3k`000000000000>U`nl200000ZG3k`030000YL?_000000800003YL?_0`0000:U`nl4000000BU
`nl0000000000003YL?_0P000003YL?_0000000000800003YL?_0P000003YL?_0000000004Koool0
0`000?ooooooo`0Yoooo000Soooo00<0003oooooool09Oooo`<0000015ZIl0000000000000;A/k/0
0`000>;Cb0000002dK:k0P000003ekZm0000f;o100@00002_Z2j00<0003Lj]d000000/B/`P050000
e]?F0000bKC6000000;Nd/d01@000<je`@000>3Hc`000002cK?00P0000;=/[l200000/fY]P800002
a9nb0P0000;9Y[H01@000>_J``0000000>;:`00<00000jnih@060000^L_X^L_X^L_X0000`lcR0P00
00:m]M801P000<WBhLWBh@000<2id`0000>K[N@4000000oK^KL0003Ub[/0003O`;T0003Sa[X0003Q
`kT0003Q`kX0001j@Gh0001b>W`00P000009i;VY0000l<^/0000ikfZ0000l/j/0000klR/00800000
1O?@[0000>JkZP000?CB[003000000SabZT00000003[`JT0003abZT0003X_JT200000^RmZ@030000
klNY000000<000000nRmZ@0000000003000000=_?H<0000000000P000003lLVW0000000000800003
YL?_0P0000:U`nl00`000:G3k`000002000000>U`nl0000000000ZG3k`040000YL?_000000001:G3
k`<000000jG3k`0000000002000000>U`nl0000000000P0000>U`nl200000ZG3k`050000YL?_0000
0000YL?_00800002YL?_00<0002U`nnU`nl00P0000>U`nl300000ZG3k`@000001:G3k`0000000000
00>U`nl200000ZG3k`030000YL?_YL?_008000000jG3k`0000000002YL?_00<0002U`nl000000P00
00>U`nl3000000>U`nl0000000000P000003YL?_0000000000800003YL?_0P0000:U`nl00`000:G3
k`000002000000>U`nl0000000000ZG3k`040000YL?_000000000jG3k`<00002YL?_10000003YL?_
0000000000800003YL?_0P0000:U`nl01@000:G3k`0000000:G3k`0200000ZG3k`030000YL?_0000
00800003YL?_0P0004Koool00`000?ooooooo`0Yoooo000Soooo00<0003oooooool09Oooo`H00002
dK>k00<0003RdlP000000]6b^`800002ekZm0P000003gL>n0000000000<000002]cZg@000<B/`/B/
`P000=KCeP000<VdaP000=G?d`8000001<je`@000>3Hc`0000;=/l0200000/fb_`8000000lJW^P00
0<fY]P02000000W4Wk80003akl400039Y[H0003[f/<0003B/[X00P000003fl2n0000PZO/00:2Yn`4
00000ZNA_P040000[kWQ000000000[W;j08000001:f]e`000;fed[fedP800002bM;Q00<00030^M?0
^M<01P0000:K[>8300000]o0^@800002hL>i0P000003h<6i00000000008000001>BiZ@000?3;[000
00;W_JX2000000O_b:`0003^aj`0003cd:`0003V^jX00P0000;U^jX2000000O[`JT0003[`JT0003a
bZT0003X_JT00P000003j;fY0000000000@000001>RmZ@000>k6ZNk6Z@D000001NRkY`000?79Y`00
0>JhYP03000000>U`nl0000000000jG3k`<00002YL?_0P0000>U`nl300000ZG3k`@000001:G3k`00
0000000000>U`nl200000ZG3k`030000YL?_000000800003YL?_0`000003YL?_0000000000BU`nl3
000000>U`nl0000000000P000003YL?_0000000000800003YL?_0P0000:U`nl010000:G3k`000000
00BU`nl3000000>U`nl0000000000jG3k`<00002YL?_10000004YL?_0000000000000jG3k`800002
YL?_00<0002U`nnU`nl00P0000>U`nl3000000BU`nl0000000000003YL?_0`000003YL?_00000000
008000000jG3k`000000000200000jG3k`800002YL?_00<0002U`nl000000P0000>U`nl3000000>U
`nl0000000000jG3k`<00002YL?_10000003YL?_0000000004Koool00`000?ooooooo`0Xoooo000S
oooo00<0003oooooool09_ooo`<00002KI3S0P000004h]?80000dK:kdK:k0P0000;G^[d00`000=Ro
`@000002gL>n1@0000;4[<801@000=KCeP000<VdaP000002eLoC00<0003;]lL000000P0000;=/l00
10000>7Kc`000<fb_`800003aZNj0P0000;4Wk82000000S9Y[H0003[f/<0003B/[X0003Rb/000002
fl2n0`000003QZk_0000000000D00002^L_X0P000004[JgG00000000][GH0P0000;9d^42000000C0
^M<000000038d^4200000i^/hP<000002NG:^`000=o0^@000>?6^P000>73^@000>73^P06000000WT
^JT0003`bj`0003W_JX0003bcZ`0003_b:`00P000006lm2/0000i[^Z0000m=:/00000^FkZP<00000
1>_1Z@000?7:ZO7:Z@<000001^RmZ@0000000>o7Z@000>RmZ@8000001NRmZ@000>k6Z@000>c3Z@02
000000O_aZL0003X^jL0003abJL0003V^:H010000003YL?_0000000000800002YL?_0`000003YL?_
00000000008000000jG3k`000000000200000jG3k`800002YL?_00@0002U`nl000000003YL?_0`00
00:U`nl4000000BU`nl0000000000002YL?_10000004YL?_0000000000000jG3k`800002YL?_00<0
002U`nnU`nl00P0000>U`nl300000ZG3k`@000001JG3k`00000000000:G3k`04000000>U`nl00000
00000P0000>U`nl200000ZG3k`040000YL?_000000001:G3k`<000000jG3k`0000000002000000BU
`nl0000000000002YL?_10000004YL?_0000000000000jG3k`800002YL?_00<0002U`nnU`nl00P00
00>U`nl300000ZG3k`@000001JG3k`00000000000:G3k`04000000>U`nl0000000000P0000>U`nl2
00000ZG3k`030000oooooooo04Coool00`000?ooooooo`0Woooo000Soooo0`0002Ooool500000^;C
b0040000dK:k000000000]Nj_@030000f;o1000000;M`kh2000000COb<400000000oKML2000000CF
dmH00039]<H00002eLoC00<0003;]lO;]lL00P0000;=/l0010000>7Kc`000<fb_`800003aZNj0`00
0003a9nb0000000000;9Y[H010000>_J``000=:b^P800002fl2n00<0003C];X000000P0000>F/NX2
00000ZN@_@8000000jf]e`0000000003][GH00@00039d^79d^400002`;WC00D00038d^4000000030
^]@010000004UL;f0000000000000]o0^@800002hL>i0P000003h<6i0000h<6i008000001^BiZ@00
0?3;[?3;[0000>NmZP8000001no8[0000>k7[0000??@[0000>JkZP0200000^FkZP090000l<^/0000
0000jl6Y0000lLZY0000j;fY00@000001No7Z@000>RmZ@000>k5Z@0200000^k6Z@8000001Ng4Z@00
00000>RkY`000002lLVW0`000004jKbW0000000000000ZG3k`@000001:G3k`000000000000>U`nl2
00000ZG3k`030000YL?_YL?_00800003YL?_0`000003YL?_0000000000800002YL?_0`000003YL?_
00000000008000000jG3k`000000000200000jG3k`800002YL?_00@0002U`nl000000004YL?_0`00
0003YL?_00000000008000000jG3k`0000000002000000>U`nl0000000000P000004YL?_00000000
00000jG3k`800002YL?_00<0002U`nnU`nl00P0000>U`nl300000ZG3k`@000001JG3k`0000000000
0:G3k`04000000>U`nl0000000000P0000>U`nl200000ZG3k`040000YL?_000000001:G3k`<00000
0jG3k`0000000002000000>U`nl0000000000P000003YL?_00000000008000001:G3k`0000000000
00>U`nl200000ZG3k`030000YL?_000000800003YL?_0P0004Koool00`000?ooooooo`0Woooo000S
oooo00<0003oooooool0:Oooo`030000LY7R000000800002dK:k0P0000;G^[d200000]g3_P800002
glS110000004e]?F0000bKC600000]G?d`030000bkO7bkO7008000001LVeaP0000000>7Kc`000002
cK:o0P0000;6YkX200000/2M]@800002bJJf00@0003[f/<0003B/[X200000]_0_P040000dkBj0000
k^C4300000>f]MP2000000Bh_ml000000030^M<2000000K8d^400030^]C0^]@00036d>8400000iZd
jP8000001N?6^P000>73^@000>73^P0200000^31^@8000002NBiZ@000?3;[0000>NmZP000?;>[000
0>o8[002000000Kcd:`0003V^jX0003ddZ`00002iK^Z0P000004j/6[00000000lLZY1@000005j;fY
0000klNY0000j;fY008000001nRmZ@000>k6Z@000>c3Z@000>g4Z@02000000GX^jL0003abJL0003V
^:H00P000003jKbW0000000000<00003YL?_0P0000:U`nl010000:G3k`00000000BU`nl3000000>U
`nl0000000000P000004YL?_0000000000000ZG3k`@000001:G3k`000000000000>U`nl200000ZG3
k`030000YL?_YL?_00800003YL?_0`0000:U`nl4000000FU`nl000000000002U`nl010000003YL?_
0000000000800003YL?_0P0000:U`nl010000:G3k`00000000BU`nl3000000>U`nl0000000000P00
0003YL?_00000000008000000jG3k`0000000002000000BU`nl0000000000003YL?_0P0000:U`nl0
0`000:G3k`00000200000jG3k`<00002YL?_10000005YL?_000000000000YL?_00@000000jG3k`00
0000000200000jG3k`800002YL?_00@0002U`nl000000003YL?_0`0000:U`nl4000000>U`nl00000
0000A_ooo`030000oooooooo02Koool002?oool00`000?ooooooo`0Yoooo0`00009bTN8300000]Nj
_@0:0000f;o10000gL>n0000f/710000glS10000g/g710000005bKC60000eLoCeLoC000000;;]lL2
00000/VeaP<00002cK:o0P0000;6YkX200000l2M]@8000002<VV]P000>_J``000=:b^P000>;:`000
00;K`;h2000000G^i<@00032W;80001oW^H00P000003[/O/00000000008000000k6Rb@000;Jef002
000000>h_ml0000000000[BXc0040000b=;Q000000000/2je0<000001;bcd@0009ZdjYZdjP<00000
39Vkl00000000>73^@000>73^P000>31^@000>31^@000>72^@800002l<^/0140003W_JX00000003_
b:`0003^aj`0003cd:`0003V^jX0003ddZ`0003U^jX0003`bj`01P00000>j;fY00000000j;fY0000
klNY0000j;fY0000k/FY0000j;fY0000k/JY0P000003kLBY0000k/JY00800002lLVW00<0003V^:H0
00000`0000;ab:L00`000:G3kjG3k`0200000jG3k`<00002YL?_10000004YL?_0000000000000jG3
k`8000000jG3k`000000000200000jG3k`800002YL?_00@0002U`nl000000004YL?_0`000003YL?_
00000000008000000jG3k`000000000200000jG3k`8000001:G3k`000000000000>U`nl200000ZG3
k`030000YL?_YL?_00800003YL?_0`0000:U`nl4000000BU`nl0000000000003YL?_0P000003YL?_
0000000000800003YL?_0P0000:U`nl010000:G3k`00000000>U`nl300000ZG3k`@000000jG3k`00
0000000200000jG3k`8000001:G3k`000000000000>U`nl200000ZG3k`030000YL?_000000800003
YL?_0`000003YL?_00000000008000000jG3k`000000000200000jG3k`8000000jG3k`0000000016
oooo00<0003oooooool09Oooo`008_ooo`030000oooooooo02_oool600000]Nj_@0<0000f;o10000
gL>n0000f/710000glS10000g/g70000el34100000;Ecm<00`000<^gal^ga`0200000/VeaP040000
fM_H0000bKC60`0000;6YkX00`000>Gic`000002`9fe00<00035Y;W5Y;T00P000003jm[30000d[:j
00800002fl2n00@0003C];X000000002`Ybb0P0000B^an`6000000>h_ml0000000000[BXc0800000
1<STj`000<2je<2je0<00004_;?A0P000004VK_`0000000000000YZll0<000004N31^@000>31^@00
0>72^@000>;4^P000?3;[0000>NmZP000?;>[0000>o8[0000>k7[002000000CV^jX0003ddZ`00002
iK^Z10000005j/6[000000000000j;fY008000001NRmZ@000>o7Z@000>RmZ@02000000OX_JT0003^
aZT0003/`jT0003]a:T00P000005ik^X0000lLVW0000i[RV008000001^VlY`0000000?78Y`000?79
Y`8000000jG3k`0000000002000000>U`nl0000000000P0000>U`nl200000ZG3k`050000YL?_0000
0000YL?_00800002YL?_00<0002U`nnU`nl00P0000>U`nl300000ZG3k`@000001:G3k`0000000000
00>U`nl200000ZG3k`030000YL?_0000008000000jG3k`0000000002YL?_00@0002U`nl000000004
YL?_0`000003YL?_00000000008000000jG3k`000000000200000jG3k`800002YL?_00D0002U`nl0
0000002U`nl00P0000:U`nl00`000:G3k`00000200000jG3k`<000000jG3k`000000000200000ZG3
k`<00003YL?_0P0000:U`nl00`000:G3k`000002000000>U`nl0000000000ZG3k`040000YL?_0000
00000jG3k`<00002YL?_10000004YL?_0000000000000jG3k`800002YL?_00<0002U`nl000000P00
0004YL?_00000000YL?_0P0004Goool00`000?ooooooo`0Uoooo000Roooo00<0003oooooool0;?oo
o`<00002HHgU00@0003G^[d000000002gL>n0P0000;Ob<4200000mO0a08000000c]jhP0000000002
bkO70P0000;9]LH00`000=WKf0000002bKC60P0000?6YkX200000/2M]@800002aJBi0`000003d[:j
0000000000;K`;h020000=>d^P000>kTa0000<:L/P000>of_@`00003]:S<00D00038i>/00000002d
Y/X0100000>l/m42000000?<hNL0000000000iZll0<000000n73^P0000000002h<6i00D0003Q`[T0
0000003Q`[T00P000003ikfZ0000000000;_b:`2000000Gcd:`0003V^jX0003ddZ`01P000004j/6[
0000l<^/l<^/0`000004j;fY0000klNYklNY0P000007k/FY0000j;fY0000k/JY0000k<>Y00800000
0nk6Z@000>NkZ003000000CV^:H00000003Y_:L2000000Cab:L00000003fd:L200000jG3k`800002
YL?_00<0002U`nnU`nl00P0000>U`nl3000000>U`nl0000000001:G3k`<000000jG3k`0000000002
000000>U`nl0000000000P0000>U`nl200000ZG3k`040000YL?_000000000jG3k`<00002YL?_0P00
00>U`nl300000ZG3k`@000001:G3k`000000000000>U`nl200000ZG3k`030000YL?_000000800003
YL?_0`000003YL?_0000000000>U`nl300000ZG3k`@000001:G3k`000000000000BU`nl200000ZG3
k`040000YL?_000000000jG3k`<000001:G3k`000000000000>U`nl3000000>U`nl0000000000P00
0003YL?_0000000000800003YL?_0P0000:U`nl010000:G3k`00000000>U`nl300000ZG3k`800003
YL?_0P0004Koool00`000?ooooooo`0Toooo000Roooo00@0003oool00000000/oooo1P000003f;o1
0000gL>n00800002glS100<0003NcLL000000]O0a0030000hMW>00000080000013]jhP0000000000
00;9]LH00`000=WKf0000002bKC60`0000;6YkX200000/2M]@800002aJBi00@0003Th]40003</Kl3
000000KK`;h0003C];X0003^i<@00002`Ybb0P000003`Ibb0000000000>de_86000000FdZ<`00000
0038i>/000000kBVbP800004_;?A00D0003<hNL00000002dY<P01000000=VKca000000000000h<6i
0000h<6i0000hL:i0000h/Bj0000hL:i00<000001O;>[0000>o8[0000>k7[002000000?V^jX00000
00000P00000:iK^Z00000000j/6[0000j/6[0000l<^/0000ikf[0P000005j;fY0000klNY0000j;fY
008000001nRmZ@000>k6Z@000>c3Z@000>g4Z@02000000CW^jP0003abZWabZT3000000?Y_:L00000
00000_78Y`<000000nNjY`000:G3k`0200001:G3k`<000000jG3k`0000000002000000BU`nl00000
00000002YL?_10000004YL?_0000000000000jG3k`800002YL?_00<0002U`nnU`nl00P0000>U`nl3
000000>U`nl0000000000P0000:U`nl3000000>U`nl0000000000P000003YL?_0000000000800003
YL?_0P0000:U`nl010000:G3k`00000000>U`nl300000ZG3k`@000001JG3k`00000000000:G3k`04
00000ZG3k`<00003YL?_0P0000:U`nl00`000:G3k`00000200000jG3k`<000000jG3k`0000000002
000000BU`nl0000000000002YL?_10000004YL?_0000000000000jG3k`800002YL?_00<0002U`nl0
00000P0000>U`nl3000000>U`nl0000000000P0000:U`nl3000000>U`nl0000000000P000003YL?_
0000000004Goool00`000?ooooooo`0Toooo000Roooo0P00033oool5000000SM`kh0003J`L40003O
b<40003NcLL00002el3400@0003QfLh00039/L8500000/VeaP050000fM_HfM_H0000bKC600800002
aJ_10`0000?0WKD01P000<FT^LFT^@000>CRd@0000;</Kl200000]_0_P8000001>kTa0000<:L//:L
/P8000000l6L/P000>kWa@0;000000?8i>/0000000000[BVbP<000000kN/cP000;bcd@02000000K<
hNL0002dY<RdY<P0003Ak>L4000000BH]>/0000000000002h<6i00L0003Q`[T00000003Q`[T0003U
b;/00`0000;_b:`2000000_cd:`000000000003ddZ`0003U^jX0003`bj`0003Z`J/00P0000;`bj`2
000000?ac:`0000000000^o7Z@0;0000j;fY00000000j;fY0000k/JY0000k<>Y0000kLBY00800000
1NNkZ0000?7:Z@000>FhZ002000000KY_:L00000003ab:L0003abJL2000000?W^ZL0000000000ZG3
k`@000001JG3k`00000000000:G3k`0400000ZG3k`<00003YL?_0P0000:U`nl010000:G3k`000000
00BU`nl3000000>U`nl0000000000P000004YL?_0000000000000ZG3k`@000001:G3k`0000000000
00>U`nl200000ZG3k`030000YL?_000000800003YL?_0`000003YL?_00000000008000000jG3k`00
00000002000000>U`nl0000000000P000004YL?_0000000000001:G3k`800002YL?_00@0002U`nl0
00000003YL?_0`0000:U`nl4000000FU`nl000000000002U`nl010000003YL?_0000000000800003
YL?_0P0000:U`nl010000:G3k`00000000>U`nl300000ZG3k`@000001:G3k`000000000000:U`nl4
000000BU`nl0000000000003YL?_0P0000:U`nl00`000?ooooooo`11oooo0`0002Goool002;oool0
0`000?ooooooo`0`oooo1@000006f/710000glS10000g/g700000]O0a0060000hMW>0000bK720000
hM_?0`000003<i;`0000000000;IfmP010000<VdaP00000000?5Zl4300000/2M]@060000aJBiaJBi
0000i>;A00000/ba_`8000001=G1aP0000000=>d^P800002`Ybb0P0000;1W;8010000>kWa@000<RT
]@800002ZM[h1P0000>dY/X200001;N/cP040000c>7W000000000[BTb0<000000kNWb@0000000002
00000iRikP8000001N72^@000>;4^P000>72^@02000000KRa;X00000003_b:`0003^aj`4000000Cd
dZ`0003U^j[U^jX2000000OZ`J/0003Z`J/0003`bj`0003W_J/00P000007ikf[0000klNY0000j;fY
0000k/FY008000001nk6Z@000>c3Z@000>g4Z@000>k6Z@0200000_7:Z@030000iKRX000000<00002
lLRW0P000003m]2W0000000000@000000jG3k`0000000002000000BU`nl0000000000004YL?_0P00
00:U`nl010000:G3k`00000000>U`nl300000ZG3k`@000001JG3k`00000000000:G3k`04000000>U
`nl0000000000P0000>U`nl200000ZG3k`040000YL?_000000000jG3k`<00002YL?_10000005YL?_
000000000000YL?_00@00002YL?_0`0000>U`nl200000ZG3k`030000YL?_000000800003YL?_0`00
0003YL?_00000000008000000jG3k`0000000002000000>U`nl0000000000P000004YL?_00000000
00000jG3k`800002YL?_00<0002U`nl000000P0000>U`nl3000000>U`nl0000000000P000003YL?_
00000000008000000jG3k`0000000002000000>U`nl0000000000P0000>U`nl200000ZG3k`040000
YL?_000000000jG3k`800016oooo00<0003oooooool08_ooo`008_ooo`030000oooooooo037oool0
0`00051oh000000200000]o8`@800002el3400D0003QfLh00039/L8000000^7Kc`D00002fM_H00D0
0039]<H0003KhMX000000/F[`@800002_j6j0`0000;5Y;T010000>CRd@000<ba_`800002eL7600D0
003C];X0003^i<@000000/:L/P8000001l6L/P000>kWa@000<RT]@000>WH``0=00000kN/cP800000
1<OQj`000;BTb;BTb0<00002]jO900<0003@hnD000000YRikP<00002V;7Y0`000003hL:i0000iLRk
008000000nG:^`0000000002000000ocd:`0003V^jX0003ddZ`0003U^jX0003`bj`0003Z`J/0003Z
`J/0003`bj`00P000003lLb/0000ikf[00<000002^RmZ@0000000>RmZ@000>k6Z@000>c3Z@000>g4
Z@8000001NNkZ0000?7:Z@000>FhZ002000000KX_:T00000003ab:L0003abJL2000000CW^ZL00000
003V^:H300000jG3k`800002YL?_00<0002U`nl000000P0000>U`nl3000000>U`nl0000000000P00
0003YL?_00000000008000000jG3k`0000000002000000BU`nl0000000000003YL?_0P0000:U`nl0
0`000:G3kjG3k`0200000jG3k`<000000jG3k`000000000200000ZG3k`<000000jG3k`0000000002
000000BU`nl0000000000004YL?_0P0000:U`nl010000:G3k`00000000>U`nl300000ZG3k`@00000
1JG3k`00000000000:G3k`04000000>U`nl0000000000P0000>U`nl200000ZG3k`040000YL?_0000
00000jG3k`<00002YL?_10000005YL?_000000000000YL?_00@000000jG3k`000000000200000jG3
k`800002YL?_00<0002U`nl000000P0000>U`nl3000000>U`nl0000000000P000003YL?_00000000
04Goool00`000?ooooooo`0Roooo000<oooo1@0000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01_ooo`030000oooooooo03;oool7000000CNcLL0003G`<@00002hMW>00H00039/L80003Qfll0
0038/<86000000C9]<H0003KhMX00002aJ_10P0000>oXKX200000/FT^@0:0000i>;A0000c;6o0000
g<k;0000eL760000c[?00`0000;2W;82000000C1W;80003^ilD00002b:Be0P000003dJng00000000
00>Rfo/500000kN/cP8000001<OQj`0000000;^bd@@00002]jO900@0003@hnG@hnG@hnD200000iRa
j@<000001^;4^P0000000>G8^`000>;4^P@000001N73^P0000000>JkZP000002m=:/00/0003U^jX0
0000003Z`J/0003Z`J/0003`bj`0003W_J/00P000004ikf[0000k/R/k/R/0P000003k/FY0000j;fY
00800002k<>Y0P000007k/JY0000ik^X0000lLZY0000iKRX008000000nRlZ@0000000003000000?f
d:L0003W^ZL00`000004l/^W00000000YL?_0P0000>U`nl300000ZG3k`@000001JG3k`0000000000
0:G3k`0400000ZG3k`<00003YL?_0P0000:U`nl010000:G3k`00000000BU`nl3000000>U`nl00000
00000P000004YL?_0000000000000ZG3k`@000001:G3k`000000000000>U`nl200000ZG3k`030000
YL?_000000800003YL?_0`000003YL?_00000000008000000jG3k`0000000002000000>U`nl00000
00000P000004YL?_0000000000000jG3k`800002YL?_00<0002U`nl000000P0000>U`nl3000000>U
`nl0000000000P000003YL?_00000000008000000jG3k`0000000002000000BU`nl0000000000003
YL?_0P0000:U`nl00`000:G3kjG3k`0200000jG3k`<00002YL?_10000005YL?_000000000000YL?_
00@000000jG3k`0000000015oooo00<0003oooooool08Oooo`003_ooo`070000oooooooooooo0000
oooo000000;oool00`000?ooo`000007oooo00<0003oooooool0=Oooo`030000J8[P000000800000
2MO0a0000>7Ic^7IcP000<Va`P000>7Kc`000002b;3200<0003Mdld0000010000007fn7J0000aJ_1
aJ_10000gOCM000000:oXKX2000000G3Z;h00000003Th]4000000/ba_`8000001MG1aP000<jc`000
0>O^dP02000000?2W;80000000000/6L/P800002b:Be00D0003Yf<<00000003Vd<40100000:DX=`6
00000/OQj`040000^k;A^k;A^k;A0P0000:gYlT200000]3Si@8000000kffd`0000000002000000FI
^Nh000000000003Q`[T010000005iLZk0000iLRk0000hL>j008000003NJkZP000?CB[0000>FkZP00
0?3;[0000>[1Z`000>[1Z`000?3;[002000000Oac:`0003W_J/0003^b:`0003W_J/00P000007j;fY
0000k/JY0000k<>Y0000kLBY008000001>NkZ0000?7:ZO7:Z@<000000nRlZ@0000000002l<VY0`00
0006ikZW00000000i[RV0000l/^W0`000003YL?_0000000000800002YL?_0`000003YL?_00000000
008000001:G3k`000000000000BU`nl200000ZG3k`040000YL?_000000000jG3k`<00002YL?_1000
0005YL?_000000000000YL?_00@000000jG3k`000000000200000jG3k`800002YL?_00@0002U`nl0
00000003YL?_0`0000:U`nl4000000FU`nl000000000002U`nl010000003YL?_0000000000800003
YL?_0P0000:U`nl010000:G3k`00000000>U`nl300000ZG3k`@000001JG3k`00000000000:G3k`04
00000ZG3k`<00003YL?_0P0000:U`nl010000:G3k`00000000BU`nl3000000>U`nl0000000000P00
0003YL?_00000000008000000jG3k`0000000002000000BU`nl0000000000003YL?_0P000003YL?_
0000000004Goool00`000?ooooooo`0Poooo000>oooo00L0003oooooooooool0003oool000000_oo
o`030000oooo000000Ooool00`000?ooooooo`0eoooo1P0000;QfLh01@000<Va`P000>7Kc`000002
b;3200@0003Mdld0003=]L<500000/F[`@030000gOCM000000:oXKX200000/>X_P<00002c;6o0P00
0006eL760000c[?00000inkB00000[bH/P800002`Ibb00P0003^ilD00038Y;D0003Yf<<0003A[kL2
000000?F]KT0002DX=`01`0000;7hN/200000[^bd@<000000kbedP0000000003d>?U00D0002m]]<0
00000039e^<010000003VK[_0000000000@00002iLZk0P000003hL>j0000i<Nk00800002m=:/00d0
003U^jX00000003Z`J/0003Z`J/0003`bj`0003W_J/0003ac:`00P0000;^b:`01@000>NmZ`000000
0>RmZ@0200000^c3Z@8000001nk6Z@000>NkZ0000?7:Z@000>FhZ002000000KX_:T00000003`bJT0
003`bJT2000000SW^ZL00000003V^:H0003bbjL0003[_jL200000ZG3k`@000001:G3k`0000000000
00>U`nl200000ZG3k`030000YL?_000000800003YL?_0`000003YL?_00000000008000000jG3k`00
00000002000000>U`nl0000000000P000004YL?_0000000000000jG3k`800002YL?_00<0002U`nnU
`nl00P0000>U`nl3000000>U`nl0000000000P000003YL?_00000000008000000jG3k`0000000002
000000BU`nl0000000000003YL?_0P0000:U`nl00`000:G3kjG3k`0200000jG3k`<000000jG3k`00
0000000200000ZG3k`<000000jG3k`0000000002000000BU`nl0000000000004YL?_0P0000:U`nl0
10000:G3k`00000000>U`nl300000ZG3k`@000001JG3k`00000000000:G3k`04000000>U`nl00000
00000P0000>U`nl200000ZG3k`040000YL?_000000000jG3k`800015oooo00<0003oooooool02?oo
o`D00002oooo00<0003oooooool00_ooo`030000oooooooo00Woool000koool01`000?oooooooooo
o`000?ooo`000002oooo00<0003oool000001oooo`<0000foooo1`000004bK720000hM_?00000/R`
`P040000gM?=0000cKG30P000004dk_300000000F97/0P000004gOCM0000_j6j_j6j0P0000;3Z;h0
10000=cQfP000<Vda@<00002eL7600D0003>/l00003Wk]8000000[bH/P8000003L6L/P000>kWa@00
0<RT]@000>WH``000=6_]`000>K@`@000=Je^@0500000Y>Nf`@00002^k;A0`0000>l]M800`000=3S
iM3Si@02000000>m]]<00039e^<00P000003_K_G0000000000H000001N;4^P000>G:^`000>G8^`02
000000oTak/0003L^kL0003ddZ`0003U^jX0003`bj`0003Z`J/0003Z`J/0003`bj`00P000009lLb/
0000ikf[0000k/R/0000ikf[0000kLF[008000001>k6Z@000>c3ZNc3Z@<000001^NkZ0000?7:ZO7:
Z@000>FhZ0@00002l<VY0P00000;mM6Y000000000000i[RV0000l/^W0000jknW0000k<6W00<00003
YL?_0P0000:U`nl010000:G3k`00000000>U`nl300000ZG3k`@000001JG3k`00000000000:G3k`04
00000ZG3k`<00003YL?_0P0000:U`nl010000:G3k`00000000BU`nl3000000>U`nl0000000000P00
0005YL?_000000000000YL?_00@00002YL?_0`0000>U`nl200000ZG3k`040000YL?_000000001:G3
k`<000000jG3k`0000000002000000BU`nl0000000000002YL?_10000004YL?_0000000000000jG3
k`800002YL?_00<0002U`nl000000P0000>U`nl3000000>U`nl0000000000P000003YL?_00000000
008000000jG3k`0000000002000000BU`nl0000000000003YL?_0P0000:U`nl00`000:G3k`000002
00000jG3k`<000000jG3k`0000000002000000>U`nl000000000AOooo`030000oooooooo00Woool0
1`000?ooooooooooo`000?ooo`000002oooo00<0003oool000002_ooo`003_ooo`070000oooooooo
oooo0000oooo000000;oool00`000?ooo`000007oooo00<0003oooooool0=oooo`@00002NYOS0`00
00;8/<8010000=gCc@000<fe``800002dk_31P0000:oXKX200000/>X_P030000g>7J000000;9]<D0
2@000=c>b`000=G1aP000<jc`0000>O^dP000002_9Rb00<0002jU;2jU;000`0000;8Y;D010000>WH
``000=6_]`8000001mJe^@000>K@`@000=Bc^00009>Nf`0200000ZCFn@H00002_;GB0P000004_lcT
00000000_KKC0P000003bMKS0000_K_G00L0000019G3mP000000000000;Ub[/2000000?Q`kX00000
00000]bk]`<000000nFkZP0000000002j/6[0P00000;l<^/0000ikf[0000lLb/0000ikf[0000k/R/
0000ikf[008000000nNnZ`0000000002k<>Y00T0003]a:T00000003W^jP0003abZT0003U^:P00P00
0006j;bY00000000l<VY0000l<VY0P000008i[ZX00000000i[RV0000l/^W0000jknW0P000004lLVW
00000000YL?_0P0000>U`nl3000000>U`nl0000000000P0000:U`nl300000jG3k`8000001:G3k`00
0000000000BU`nl200000ZG3k`040000YL?_000000000jG3k`<00002YL?_10000004YL?_00000000
00000jG3k`8000001:G3k`000000000000BU`nl200000ZG3k`040000YL?_000000000jG3k`<00002
YL?_10000004YL?_0000000000000jG3k`8000000jG3k`000000000200000jG3k`800002YL?_00@0
002U`nl000000003YL?_0`0000:U`nl4000000BU`nl0000000000003YL?_0P000003YL?_00000000
00800003YL?_0P0000:U`nl010000:G3k`00000000>U`nl300000ZG3k`@000001:G3k`0000000000
00>U`nl2000000>U`nl000000000AOooo`030000oooooooo00Soool00`000?ooooooo`03oooo00H0
003oooooool0003oool0000:oooo000=oooo0P0000Coool00`000?ooooooo`02oooo00<0003ooooo
ool01_ooo`030000oooooooo03Woool600000/R``P0:0000gM?=0000cKG30000f/g<0000dk_30000
f<_=10000004JhCI0000000000000/>X_P<00002bKC500T0003Dc=80003E`LH0003>/l00003Wk]80
00000[bH/P800002^YB`0P0000;8Y;D030000>WH``000=6_]`000>K@`@000=Je^@000>K@`@000=Bc
^0X00003_;GB00<0002oc>Boc>@00P000003`/CK0000bMKS008000000kfke`0000000002000000?7
b]`0000000000P0000:C^_43000000SUb;/00000003Tak/0003L^kL0003UbK/3000000O`bj`0003Z
`J/0003Z`J/0003`bj`00P00000;lLb/0000ikf[0000k/R/0000ikf[0000kLF[0000ikj[00800002
k<>Y0P000003k/JY0000000000;abZT01@000>FhZ00000000>RlZ@02000000K`bJT00000003edJT0
003V^ZP300000_;;Y`030000jknW0000008000001>^oY`0000000:G3k`@000001:G3k`0000000000
00BU`nl200000ZG3k`050000YL?_00000000YL?_00800002YL?_00<0002U`nl000000P0000>U`nl3
000000>U`nl0000000000P000003YL?_0000000000800003YL?_0P0000:U`nl01@000:G3k`000000
0:G3k`0200000ZG3k`030000YL?_000000800003YL?_0`000003YL?_00000000008000000jG3k`00
0000000200000jG3k`800002YL?_00D0002U`nl00000002U`nl00P0000:U`nl00`000:G3k`000002
00000jG3k`<000000jG3k`0000000002000000>U`nl0000000000P0000>U`nl200000ZG3k`050000
YL?_00000000YL?_00800002YL?_00<0002U`nl000000P0000>U`nl3000000>U`nl0000000000P00
0003YL?_0000000000800003YL?_0P0000:U`nl01@000:G3k`0000000:G3k`02000000>U`nl00000
0000A?ooo`030000oooooooo00Soool010000?ooooooooooo`800003oooo00<0003oool000002_oo
o`008?ooo`030000oooooooo03_oool300000WZOj@8000001=gCc@000<fe`lfe``8000001]>k``00
0=S;cMS;c@000=Boa@D00002`jRn0P0000?9]<D02@000=C<dP000<o0c0000<jc`0000>O^dP000003
_9Rb00<0002jU;2jU;000`00000=b:Be0000jMS30000dJng0000i]310000e[Fi0000i]310000e;>h
008000000m6_]`00092PgP02000000>SdoP00000000010000004_lcT00000000`/CK0P000003_lOP
0000000000800002`L7I00@00037b]`0002n/<`5000000FG`_D000000000003Q`kX00P0000;L^kL2
000000CJ]kH0000000000002j/6[00d0003Z`J/00000003W_J/0003ac:`0003W_J/0003^b:`0003W
_J/00P000003ikj[0000k/N[00<000002>g4Z@0000000>NkZ0000?7:Z@000>FhZ08000000nRlZ@00
00000002l<VY0`00000:i[ZX00000000iKRX0000l/^W0000jknW0000k<6W0`000003l/VW00000000
00>U`nl200000ZG3k`030000YL?_YL?_00800003YL?_0`000003YL?_0000000000>U`nl300000ZG3
k`@000001:G3k`000000000000>U`nl200000ZG3k`030000YL?_000000800003YL?_0`000003YL?_
0000000000>U`nl300000ZG3k`@000001:G3k`000000000000>U`nl200000ZG3k`030000YL?_0000
00800003YL?_0`000003YL?_0000000000>U`nl300000ZG3k`@000001:G3k`000000000000>U`nl2
00000ZG3k`030000YL?_000000800003YL?_0`000003YL?_0000000000>U`nl300000ZG3k`@00000
1:G3k`000000000000>U`nl200000ZG3k`030000YL?_000000800003YL?_0`000003YL?_00000000
00>U`nl20000AOooo`030000oooooooo00Ooool01@000?ooooooooooo`000004oooo00<0003oool0
00002_ooo`008?ooo`030000oooooooo03coool700000/fe``8000002=>k``000=S;cMS;c@000=Bo
a@000=?2b@<0000016V7g@000000000000?9]<D01P000=C<dP000<o0c0000<Vca@8000001NO^dP00
0;bH/[bH/P000002^YB`0P0000;2X;H2000000?Yf<<0003A[kL00P000009e[Fi0000i]310000e;>h
0000j]W20000dJng00800003Xm?h10000003_lcT0000000000;2a=/00`000;o7h000000300000/71
f@8000001/O:g0000;j`c;j`c0000=Cci@@00002VkCY0P000005i<Nk0000g;^g0000iLVk00800000
2>S>_00000000>[1Z`000>[1Z`000?3;[08000001_7<[0000>NmZ`000>k8[00000;W_J/2000000?W
_Z/0000000000^c4Z`8000001nk6Z@000>NkZ0000?7:Z@000>FhZ002000000KX_:T00000003`bJT0
003`bJT2000000CV^ZP00000003U^:P3000000C[_jL00000003abJL3000000?Y_JL0002U`nl00P00
00BU`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_00@00002YL?_0`0000>U`nl2
00000ZG3k`040000YL?_000000000jG3k`<00002YL?_10000005YL?_000000000000YL?_00@00002
YL?_0`0000>U`nl200000ZG3k`040000YL?_000000000jG3k`<00002YL?_10000005YL?_00000000
0000YL?_00@000000jG3k`000000000200000jG3k`800002YL?_00@0002U`nl000000003YL?_0`00
00:U`nl4000000FU`nl000000000002U`nl010000003YL?_0000000000800003YL?_0P0000:U`nl0
10000:G3k`00000000>U`nl300000ZG3k`@000001JG3k`00000000000:G3k`04000000>U`nl00000
0000AOooo`030000oooooooo00Goool200000oooo`<00003oooo00<0003oooooool02Oooo`008?oo
o`030000oooooooo03goool00`0007JOk7JOk003MYo/0`0000;C^l<02P000=S;c@000=Boa@000=?2
b@000=G1aP0005Z<i`<00003bKC500D0003Dc=80003?`<`000000/Vca@<00002_9Rb00D0002jU;2j
U;2jU;0000000l:P]P<000001M6_]`000>K@`@000=Je^@0200000]Bc^08000000m6_]`000>cN``04
000000>;Y>D0000000000P0000;2a=/4000000C5e>D00000002j`=h2000000?7b]`0000000000[j`
c0060000e??U0000]j?50000VkCY0`00000<W;_^00000000g;^g0000iLVk0000f[Nf0000j<jl0000
fKJf0P00000>j/6[00000000ikf[0000lLb/0000ikf[0000k/R/0000ikf[0000kLF[0P000005k/N[
0000k<B[0000k<F[008000001>NkZ0000?7:ZO7:Z@<000000nRlZ@0000000002l<VY0P000006mM6Y
000000000000iKRX00000_;;Z@8000001>c1Y`0000000>^oY`8000000nVmY`0000000002YL?_1000
0005YL?_000000000000YL?_00@000001:G3k`000000000000BU`nl200000ZG3k`040000YL?_0000
00000jG3k`<000000jG3k`000000000200000ZG3k`<000000jG3k`0000000002000000BU`nl00000
00000004YL?_0P0000:U`nl010000:G3k`00000000>U`nl3000000>U`nl0000000000P000003YL?_
00000000008000000jG3k`0000000002000000BU`nl0000000000003YL?_0P0000:U`nl00`000:G3
k`00000200000jG3k`<000000jG3k`0000000002000000>U`nl0000000000P000003YL?_00000000
008000001:G3k`000000000000>U`nl200000ZG3k`030000YL?_000000800003YL?_0`000003YL?_
00000000008000000jG3k`0000000002000000>U`nl0000000000P000004YL?_0000000000000jG3
k`800002YL?_00<0003oooooool0@Oooo`80000Noooo000Poooo0`0003koool6000000CJcL`0003C
^l<00002f<_=0P000004dl;90000eL76eL760`00009JS>L01`000<Vda@000=C<dP000<o0c0000002
bK?500D0003NjM/00000002lV;800P0000:jU;0200000/:P]P040000iNCA0000bZfm0`000009e[Fi
0000i]310000e;>h0000j]W20000dJng008000000lj[]P000000000200000j;8l`H000000lGDi@00
0;[0gP02^/3N00<00037b]`000000kj`c0030000e??U000000:gXlD2000000BL^nh0000000000002
X;?V0`000007f[Nf0000j<jl0000fKJf0000j]:m008000000o3;[00000000002lLb/0P000004k/R/
0000ikf[ikf[0P000003ikj[0000000000;/a:/02@000>c5Z`0000000>NkZ0000?7:Z@000>FhZ002
000000KX_:T00000003`bJT0003`bJT2000000SV^ZP00000003U^:P0003bbjT0003Z_jT2000000Ka
bJL00000003bbJL0003Y_JL4000000>U`nl0000000000P000004YL?_0000000000000jG3k`800002
YL?_00<0002U`nnU`nl00P0000>U`nl3000000>U`nl0000000000P000004YL?_0000000000000ZG3
k`@000001:G3k`000000000000>U`nl200000ZG3k`030000YL?_000000800003YL?_0`000003YL?_
00000000008000001JG3k`00000000000:G3k`0400000ZG3k`<00003YL?_0P0000:U`nl010000:G3
k`00000000>U`nl300000ZG3k`@000001JG3k`00000000000:G3k`04000000>U`nl0000000000P00
00>U`nl200000ZG3k`040000YL?_000000000jG3k`<00002YL?_10000005YL?_000000000000YL?_
00@000000jG3k`000000000200000jG3k`800002YL?_00@0002U`nl000000003YL?_0P00047oool2
00000_ooo`030000oooooooo01_oool0023oool00`000?ooooooo`10oooo00<0001aW^`000000P00
0006dk_30000f<_=f<_=0000e;o50P0000;E`LH010000=2ja0000=S2a0@000001=C<dP000<o0c000
00;9/lD00`000=kYf`000002_9bg0P0000:jU;0200000/:P]P030000iNCA000000;:[Kd03@000>K@
`@0000000>K@`@000=Bc^0000>[I`P000=6_]`000>cN``02000000?ak<800000000020000003aMCU
0000000000:j`=h2000000>mi_<0002n/<`00[j`c0<00002]j?500@0003>oN0000000003X;?V0`00
0003iLVk0000000000;Xc[`01@000=Vf]P0000000=Vf]P02000000gW_J/0003ac:`0003W_J/0003^
b:`0003W_J/0003]aJ/0003W_Z/00P000005k<B[0000k<F[0000k/N[00800002lLZY00<0003U^:P0
00000P000003m]>X0000l<VY008000000oGAZ@000>JjZ002000000GU^:P0003bbjT0003Z_jT00`00
0003jknW0000000000;Y_JL2000000?W^ZL0000000000jG3k`800002YL?_00@0002U`nl000000004
YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`0400000ZG3k`<00003YL?_0P00
00:U`nl010000:G3k`00000000>U`nl300000ZG3k`@000001JG3k`00000000000:G3k`04000000BU
`nl0000000000004YL?_0P0000:U`nl010000:G3k`00000000>U`nl3000000>U`nl0000000000P00
00:U`nl3000000>U`nl0000000000P000004YL?_0000000000000jG3k`800002YL?_00<0002U`nl0
00000P0000>U`nl3000000>U`nl0000000000P000003YL?_00000000008000000jG3k`0000000002
000000BU`nl0000000000003YL?_0P0000:U`nl00`000:G3k`00000200000jG3k`<000000jG3k`00
00000002000000>U`nl000000000AOooo`030000oooooooo01[oool0023oool00`000?ooooooo`10
oooo1P0000;Hbld030000=Boa@000=?2b@000=G1aP000=2ja0000=S2a0000<nc_P@000001lo0c000
0<VcaLVca@000=kYf`000003_9bg0P000003^YB`0000000000;2X;H00`000>GTd@000002bZfm00@0
003OeLh0003F]KT2000000CD/kP0003ZfL800002dJng0P000004cZ^f00000000aZ6c100000:Sa_44
00000[[0gP8000001[gVl`0000000:jZd`000;j`c0800003]j?50`000003]:C80000000000800000
3Ibol@00000000000=Zg]P000>S>_0000=Vf]P000>[B_@000=Vf]P0300000_7<[0040000ikf[0000
00000^NmZ`8000001nNnZ`000>k7Z`000>c4Z`000>c5Z`02000000GV^jX0003abZT0003U^:P00P00
0003j;bY0000000000;`bJT3000000[V^ZP00000003U^:P0003bbjT0003Z_jT0003/`ZT3000000Gb
bJL0003Y_JL0003`ajL00P000003klFW0000YL?_00800003YL?_0`0000:U`nl4000000FU`nl00000
0000002U`nl010000004YL?_0000000000001:G3k`800002YL?_00@0002U`nl000000003YL?_0`00
0003YL?_00000000008000000jG3k`0000000002000000>U`nl0000000000P000004YL?_00000000
00000jG3k`800002YL?_00<0002U`nl000000P0000>U`nl3000000>U`nl0000000000P000004YL?_
0000000000000ZG3k`@000001:G3k`000000000000>U`nl200000ZG3k`040000YL?_000000000jG3
k`<00002YL?_10000005YL?_000000000000YL?_00@000000jG3k`000000000200000jG3k`800002
YL?_00@0002U`nl000000003YL?_0`0000:U`nl4000000FU`nl000000000002U`nl010000003YL?_
0000000004Coool00`000?ooooooo`0Joooo000Poooo00<0003oooooool0@Oooo`L000003MBoa@00
0=?2b@000=G1aP000=2ja0000=S2a0000<nc_P000=o<a@0400000/Vca@030000g^WK000000>lW;L0
0`000;^J][^J]P0200000l:P]P0@0000iNCA0000bZfm0000gmG>0000c[C00000i]310000e;>h0000
j]W20000dJng0P000003cZ^f00000000008000000o3f_0000000000200000Z?6l@D000000kgVl`00
00000003[Z[C0`0000:gXlD300000[BTb0030000c^_Y000000<00002X:_O0P0000;Xc[`01@000=Vf
]P0000000=Vf]P02000000gJ^;L0003ac:`0003W_J/0003^b:`0003W_J/0003]aJ/0003W_Z/00P00
0007k<B[0000k<F[0000k/N[0000i[^Z00<000001>FhZ00000000>RlZ@8000000o39Z@000?39Z@02
000000SV^ZP00000003U^:P0003bbjT0003Z_jT2000000CabZT0000000000002jKfW0P000003ikZW
0000klFW008000000jG3k`0000000002000000>U`nl0000000000P000003YL?_0000000000800000
1:G3k`000000000000>U`nl200000ZG3k`030000YL?_000000800003YL?_0`000003YL?_00000000
008000001JG3k`00000000000:G3k`0400000ZG3k`<00003YL?_0P0000:U`nl010000:G3k`000000
00>U`nl300000ZG3k`@000001JG3k`00000000000:G3k`04000000>U`nl0000000000P0000>U`nl2
00000ZG3k`040000YL?_000000000jG3k`<000000jG3k`0000000002000000>U`nl0000000000P00
0003YL?_00000000008000001:G3k`000000000000>U`nl200000ZG3k`030000YL?_000000800003
YL?_0`000003YL?_00000000008000000jG3k`0000000002000000>U`nl0000000000P000004YL?_
0000000000000jG3k`8000000jG3k`0000000014oooo00<0003oooooool06Oooo`007oooo`030000
oooooooo04?oool7000000CC`/T0003E`LKE`LH200000]S2a0050000ck>n00000000ck2k00D00000
0mkYf`000;bL]`02_9bg00@0002kV[JkV[JkV[H200000/:P]P0B0000iNCA0000bZfm0000gmG>0000
c[C00000gmG>0000e;>h0000j]W20000dJng0000k=k310000005aZ6c0000l?Jl0000`Ybb00D00000
0dIB^P000000000200000ZjZd`D000000jfRc@000000000200000[BTb0<000001;^fe0000:2[gj2[
g`800002Ulcj0P000003fKJf0000j]:m008000000n_C_@000=Zh]`03000000?W_J/0000000000^Nm
Z`8000001nNnZ`000>k7Z`000>c4Z`000>c5Z`02000000GV^jX0003`bj`0003T^:X00P000005j;bY
0000m]>X0000l<VY00<000000nJjZ00000000002iKRX00D0003bbjT00000003/`ZT00P000003j/2Y
0000000000;Y_JL2000000CW^ZL00000003V^JL2000000>U`nl0000000000P0000:U`nl300000jG3
k`800002YL?_00@0002U`nl000000003YL?_0`0000:U`nl4000000FU`nl000000000002U`nl01000
0004YL?_0000000000001:G3k`800002YL?_00@0002U`nl000000003YL?_0`000003YL?_00000000
00800002YL?_0`000003YL?_00000000008000001:G3k`000000000000>U`nl200000ZG3k`030000
YL?_000000800003YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`0400000ZG3
k`<00003YL?_0P0000:U`nl010000:G3k`00000000>U`nl300000ZG3k`@000001JG3k`0000000000
0:G3k`04000000>U`nl0000000000P0000>U`nl200000ZG3k`040000YL?_000000000jG3k`800015
oooo00<0003oooooool06?ooo`007oooo`030000oooooooo04Goool600000]G1aP060000d;[40000
f<;40000ck>n0P0000;?/;/2000000AFOml0000000000002_9bg0P0000>kV[H00`000<6U_L6U_@02
000000CUi=40003:[Kg:[Kd2000000K>]<00003OeLh0003=/Kl00002j]W200<0003A[kL000001000
0007aZ6c0000l?Jl0000`Ybb0000l_6o00<000000ik8m@0004IB^P05000000>Yk_P0000000000jfR
c@800002]:C80`0000Bk]]@2000000BGc?X0000000000002Wk3T0`000006fKJf00000000f[Rg0000
jM2l0`000004k/R/0000ikf[ikf[0P000005ikj[00000000k<B[000000;/aJ/2000000GV^jX0003`
bj`0003T^:X00P000003j;bY0000000000;`bJT3000000SV^ZP00000003U^:P0003bbjT0003Z_jT2
000000CabZT00000003abZT3000000K`ajL00000003_aJL0003V^JL300001:G3k`800002YL?_00@0
002U`nl000000003YL?_0`000003YL?_0000000000800002YL?_0`000003YL?_0000000000800000
1:G3k`000000000000>U`nl200000ZG3k`030000YL?_000000800003YL?_0`000003YL?_00000000
008000001:G3k`000000000000:U`nl4000000BU`nl0000000000003YL?_0P0000:U`nl010000:G3
k`00000000>U`nl300000ZG3k`@000001JG3k`00000000000:G3k`04000000BU`nl0000000000004
YL?_0P0000:U`nl010000:G3k`00000000>U`nl3000000>U`nl0000000000P000003YL?_00000000
008000000jG3k`0000000002000000BU`nl0000000000003YL?_0P0000:U`nl00`000:G3k`000002
00000jG3k`<000000jG3k`0000000002000000>U`nl000000000A?ooo`030000oooooooo01Soool0
01ooool30000A_ooo`<00002I9ka0P00000;d;[40000f<;40000ck>n0000glc50000ck2k0000hmC7
00@0000015Iog`000000000000>kV[H010000<6U_L6U_L6U_@<00002bZfm00T0003OeLh00000003O
eLh0003=/Kl0003ShM401@000003cZ^f0000000000;6XK<010000?3f_0000<:L/P8000000lZX]`00
0000000900000jfRc@<000000kJhfP000000000200000k^fe08000000l?Ai@0000000003Wk3T0`00
0006j]:m00000000jm>m0000f[Rg0P000004g;Zg0000000000000^NmZ`0;0000kLF[00000000k/N[
0000k<B[0000k<F[0000k/N[008000001?3;[0000>BhZ^BhZP<000001OKCZ0000?39Z@000?39Z@04
00000^FhZ0040000l/^Y0000j[nY0`000003j/2Y0000000000;X_JT2000000?W^ZL0003_aJL00P00
0003l<NW0000000000:U`nl200000jG3k`<000000jG3k`0000000002000000BU`nl0000000000002
YL?_10000004YL?_0000000000000jG3k`800002YL?_00@0002U`nl000000003YL?_0`0000:U`nl4
000000FU`nl000000000002U`nl010000003YL?_0000000000800003YL?_0P0000:U`nl010000:G3
k`00000000>U`nl3000000>U`nl0000000000P000003YL?_00000000008000000jG3k`0000000002
000000BU`nl0000000000003YL?_0P0000:U`nl00`000:G3k`00000200000jG3k`<000000jG3k`00
00000002000000FU`nl000000000002U`nl010000003YL?_0000000000800003YL?_0P0000:U`nl0
10000:G3k`00000000>U`nl300000ZG3k`@000001JG3k`00000000000:G3k`04000000>U`nl00000
0000A?ooo`030000oooooooo01Ooool001ooool00`000?ooooooo`17oooo1@000004d;[40000f<;4
00000/nc_P8000001<n`^`000>?Da`0000;@/KX00`0005emf@00000200000k^J]P800002`JFm00@0
003Ki=`00035[/<2000000?OeLh0003>]<000P000003cK6o00000000008000001/Z]_@0000000000
0<j[]P0000;6XK<01P000?3f_0000<:L/P000?;a_`8000001NSE``000000000008blmP06000000B]
X/d0000000000002][SJ0`0000Bk]]@01@000<?Ai@0000000;bge004000000F>bO`000000000003I
][H00P000008f[Rg0000jM2l0000g;Zg0000i/^k00000^NmZ`8000001NNnZ`0000000>c4Z`000002
k<F[0P000005i[^Z0000l<^/0000i;RZ008000000nNmZ`0000000002l<VY0`00000:i[ZX00000000
iKRX0000l/^Y0000j[nY0000k<:Y0`000004lLZY0000j;fYj;fY0P000004ikZW00000000i[VW0P00
0005jknW000000000000YL?_00@000001JG3k`00000000000:G3k`0400000ZG3k`<00003YL?_0P00
00:U`nl010000:G3k`00000000>U`nl3000000>U`nl0000000000P0000:U`nl3000000>U`nl00000
00000P000004YL?_0000000000000jG3k`800002YL?_00<0002U`nl000000P0000>U`nl3000000>U
`nl0000000000P000005YL?_000000000000YL?_00@00002YL?_0`0000>U`nl200000ZG3k`040000
YL?_000000000jG3k`<00002YL?_10000005YL?_000000000000YL?_00@000001:G3k`0000000000
00>U`nl200000ZG3k`030000YL?_000000800003YL?_0`000003YL?_00000000008000000jG3k`00
00000002000000>U`nl0000000000P000004YL?_0000000000000jG3k`8000000jG3k`0000000014
oooo00<0003oooooool05_ooo`007oooo`030000oooooooo04Soool500000]S2a0040000ck>n0000
00000/n`^`040000hmC70000d;6j10000004GGgI0000^iZf^iZf0P0000;1YKd00`000=_Tg0000002
aJk300H0003OeLh0003>]<00003OeLh3000000CShM40003:[Kg:[Kd2000000O>ZkH000000036XK<0
003`m[`000000/:L/P8000001/ZX]`0000000=Bf^`0007VWl0T000000kJhfP0000000003000000>i
enl0002k]]@010000004_;OD00000000`lcQ10000005W;CY000000000000jm>m008000001nW@_000
0=bj]`000>K;^`000=no^@02000000?]aJ/0003W_Z/00P000007k<B[0000k<F[0000k/N[0000i[^Z
00800002i;RZ0P000006ikf[00000000l<VY0000l<VY0P000008i[ZX00000000iKRX0000l/^Y0000
j[nY0P000008lLZY00000000lLZY0000j;fY0000klRY0P000003klFW0000i[VW00<000001O36Y`00
000000000:G3k`04000000BU`nl0000000000004YL?_0P0000:U`nl010000:G3k`00000000>U`nl3
000000>U`nl0000000000P000004YL?_0000000000000ZG3k`@000001:G3k`000000000000>U`nl2
00000ZG3k`040000YL?_000000000jG3k`<00002YL?_10000005YL?_000000000000YL?_00@00000
1:G3k`000000000000BU`nl200000ZG3k`040000YL?_000000000jG3k`<000000jG3k`0000000002
000000>U`nl0000000000P000003YL?_00000000008000001:G3k`000000000000>U`nl200000ZG3
k`040000YL?_000000000jG3k`<00002YL?_10000005YL?_000000000000YL?_00@000000jG3k`00
0000000200000jG3k`800002YL?_00@0002U`nl000000003YL?_0P0004Coool00`000?ooooooo`0F
oooo000Ooooo00<0003oooooool0BOooo`030000H9ca000000<000000lnc_P0000000002ck2k00<0
003Se<L000000]2a^P8000000mRk_@000000000400000/6U_@030000fnCL000000;5[/<010000=KC
eP000<jd`0<000001<fa_`000>?Qd@0000;:[Kd2000000?7ZK/0000000000/JQ/`800002`Ybb0P00
0005bZRg0000j=G30000e;Jk00@000000hFdm00000000005000000>`d?00000000000kWGk`@00002
_;OD00D00033c>400000002m]=4010000005S<7i000000000000f[Rg00800002g;Zg00D0003Vbk/0
0000003Sa[X00P000003ikj[0000k/N[00800002k<F[0P000005i[^Z0000l<^/0000i;RZ00800000
0nNmZ`000?KEZ`05000000?V^ZP0000000000^FhZ08000000nZoZ@000>c2Z@02000000?Z`:T00000
00000^RmZ@8000001^JjZ00000000>JiY`000?37Y`<00002k<6W0P0000>U`nl200000ZG3k`030000
YL?_YL?_00800003YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`0400000ZG3
k`<00003YL?_0P0000:U`nl010000:G3k`00000000>U`nl3000000>U`nl0000000000P0000:U`nl3
000000>U`nl0000000000P000004YL?_0000000000000jG3k`800002YL?_00<0002U`nl000000P00
00>U`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_00@000000jG3k`0000000002
00000jG3k`800002YL?_00@0002U`nl000000003YL?_0`000003YL?_00000000008000000jG3k`00
00000002000000>U`nl0000000000P000004YL?_0000000000000jG3k`800002YL?_00<0002U`nl0
00000P0000>U`nl3000000>U`nl0000000000P000003YL?_0000000004Coool00`000?ooooooo`0E
oooo000Noooo00<0003oooooool0Boooo`<00002H9ca0`000004ck2k0000hmC700000]2a^P800000
0mRk_@000=Nk_P0400000/6U_@030000fnCL000000;5[/<00`000=KCeP000002000000COeLh0003=
/Kl00002hn7A00@0003:[Kd000000002ajVk0P000009aZ6c0000l?Jl0000`Ybb0000l_6o0000bZRg
008000000mBf^`000=g2_P0400000XRZj`H00002^MO_1@000007]mOa000000000000`lcQ0000_KCA
008000000l[Fh`000000000200000Y^/h`8000001nW@_0000=bj]`000>K;^`000=no^@02000000?Q
`[T0003W_Z/00P000007k<B[0000k<F[0000k/N[0000i[^Z00800002i;RZ0P000003ikf[00000000
00;_bJ`3000000SV^ZP00000003U^:P0003bbjT0003Z_jT2000000[abZT00000003abZT0003X_JT0
003_b:T0003V^ZP2000000CV^JL00000003[_jL2000000G/`JL0003Y_:L0002U`nl00P0000BU`nl3
000000>U`nl0000000000P000005YL?_000000000000YL?_00@000001:G3k`000000000000BU`nl2
00000ZG3k`040000YL?_000000000jG3k`<000000jG3k`0000000002000000BU`nl0000000000002
YL?_10000004YL?_0000000000000jG3k`800002YL?_00@0002U`nl000000003YL?_0`0000:U`nl4
000000FU`nl000000000002U`nl010000004YL?_0000000000000jG3k`800002YL?_00<0002U`nl0
00000P0000>U`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_00@000000jG3k`00
0000000200000jG3k`800002YL?_00@0002U`nl000000003YL?_0`0000:U`nl8000000>U`nl00000
00000P000003YL?_0000000004?oool00`000?ooooooo`0Eoooo000Noooo00<0003oooooool0C?oo
o`H000001<n`^`000>?Da`0000;@/KX200000]Rk_@040000ek^n0000h<Jn10000004fnCL0000aJk3
aJk31@000004e]7D0000cK6o00000^?Qd@040000bZfm000000000/NY^`030000`Inf`Inf00<00002
`Ybb0P000003bZRg0000000000;D][/2000000?Oa[l0000000001P0000:US;X3000000>Z/=`00000
00000[OGl@8000001/?<h@0000000;fdd@000<[Fh`8000000knfdP0009^/h`06000000CL^[L0003V
bk_Vbk/2000000KSa[X00000003Q`kX0003^aj/200000^c5Z`8000001>JkZP000?3;[00000;T^:X3
000000GfeJ/0003_bJ`0003`bZ`0100000;U^:P01@000?;;Z@0000000>c2Z@02000000GZ`:T0003a
bZT0003X_JT00P000003i[ZX0000k/JY008000001_37Y`0000000?36Y`000>c1Y`@00002YL?_1000
0005YL?_000000000000YL?_00@000001:G3k`000000000000>U`nl200000ZG3k`030000YL?_0000
00800003YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`04000000>U`nl00000
00000P0000>U`nl200000ZG3k`040000YL?_000000000jG3k`<000000jG3k`0000000002000000>U
`nl0000000000P000003YL?_00000000008000001:G3k`000000000000>U`nl200000ZG3k`040000
YL?_000000000jG3k`<00002YL?_10000005YL?_000000000000YL?_00@000001:G3k`0000000000
00>U`nl200000ZG3k`030000YL?_000000800003YL?_0`000003YL?_00000000008000000jG3k`00
00000006000000>U`nl0000000000P0000>U`nl2000000>U`nl000000000@Oooo`030000oooo0000
01Koool001koool00`000?ooo`00001=oooo0`00009^TN@2000000CSe<L0003@/K[@/KX2000000OH
^kd0003G^kh0003Pa[h0003G_;h010000003aJk300000000008000001LVea`000=KAe0000<VeaP02
000000CShM40003:[Kg:[Kd2000000?7ZK/00031WkH00/6O]P<000002/:L/P0000000<ZX]`000>SE
``000=Bf^`000=g2_P8000000m6a^@000000000200000YRaj@@000001:VA_@0000000;OGl@<00002
YZ;B00H0002m]=400000003:e^<00003_kKB1@0000>LZN02000000?Vbk/0003O_kT00P000003hL:i
0000hL>j008000001>c4Z`000>c5Znc5Z`8000000nJkZP0000000002i;RZ0P000003ikf[00000000
00;_bJ`3000000?U^ZX0000000000^FhZ08000001>ZoZ@0000000?7:Z@8000001?7:Z@000>RmZNRm
Z@8000001>JjZ00000000>FiZ08000000n^oY`0000000002k<6W1P000003YL?_0000000000800000
1:G3k`000000000000>U`nl200000ZG3k`040000YL?_000000000jG3k`<00002YL?_10000005YL?_
000000000000YL?_00@000001:G3k`000000000000>U`nl200000ZG3k`030000YL?_YL?_00800003
YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`0400000ZG3k`<00003YL?_0P00
00:U`nl010000:G3k`00000000>U`nl3000000>U`nl0000000000P000003YL?_0000000000800000
0jG3k`0000000002000000BU`nl0000000000003YL?_0P0000:U`nl010000:G3k`00000000>U`nl3
00000ZG3k`@000001JG3k`00000000000:G3k`04000000BU`nl0000000000003YL?_0P0000:U`nl0
0`000:G3k`00000200000jG3k`800014oooo00<0003oooooool04oooo`007_ooo`80001?oooo1@00
0004hmC70000d;6jd;6j0P000009f;^m0000ek^n0000h<Jn0000ekbn0000i<g100D000001]KCeP00
0<Vea`000=KAe00000;9]LH300000/Z]_@8000000lNY^`0000000002`Inf0P0000:nVk<3000000c:
Z;L00000003D][/0003M`[h0003Oa[l0003A/KT0003^h/<800000ZVA_@800003YZ;B0P000003][WL
0000b]KS00800002_kKB10000004_kOB0000W:WPW:WP0`0000;Vbk/2000000KSa[X00000003Q`kX0
003O_kT200000^c5Z`060000k/N[00000000l<^/00000^BhZP8000001^NmZ`0000000>o9[0000?3:
[08000000nFjZP0000000002000000?bbjT0003Z_jT00`000007j/2Y0000lLZY0000j;fY0000klRY
008000000nk6Z@000>FiZ003000000G`aZL0003/`JL0003Y_:L00P000004hkFV0000000000000jG3
k`800002YL?_00@0002U`nl000000003YL?_0`000003YL?_0000000000800002YL?_0`000003YL?_
00000000008000001:G3k`000000000000>U`nl200000ZG3k`040000YL?_000000001:G3k`<00000
0jG3k`0000000002000000FU`nl000000000002U`nl010000004YL?_0000000000001:G3k`800002
YL?_00@0002U`nl000000003YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`04
00000ZG3k`<00003YL?_0P0000:U`nl010000:G3k`00000000>U`nl3000000>U`nl0000000000P00
0003YL?_00000000008000000jG3k`0000000002000000BU`nl0000000000003YL?_0P0000:U`nl0
10000:G3k`00000000>U`nl300000ZG3k`@000000jG3k`0000000013oooo00<0003oooooool04ooo
o`007_ooo`030000oooooooo04ooool00`00072Bi000000200000]2a^P800002f;^m0P0000;Pa[h0
0`000=Nl_P000005000000KFdmH00039]LL0003FdM@00002bKG600@0003KgmX00037/<<300000/NY
^`030000`Inf`Inf00800003_Y^c0P000003bZRg0000000000;D][/2000000OOa[l0003A/KT0003^
h/<00033W[800`0000:[a>`6000000BVX]800000002f^M`2000000>a/]T0002o]]800[nfdP030000
bMKS000000>o]m8300000YO5m`<000001=no^@0000000>72^@8000001=no^@000>73^@0000;/aJ/2
000000?V^jX0000000000^BhZP8000000nNmZ`0000000002klV/0`000003iKZZ0000000000;S^:X2
000000?Z_jT0003/`ZT00P000003j/2Y0000000000;X_JT2000000KV^ZP00000003U^JP0003_ajT3
00000^c1Y`8000001?78Y`0000000?OBYP8000000jG3k`0000000003YL?_0`000003YL?_00000000
008000001:G3k`000000000000:U`nl4000000FU`nl000000000002U`nl0100000:U`nl010000:G3
k`00000000>U`nl300000ZG3k`@000001JG3k`00000000000:G3k`04000000FU`nl000000000002U
`nl0100000:U`nl00`000:G3k`00000200000jG3k`<000000jG3k`0000000002000000FU`nl00000
0000002U`nl010000004YL?_0000000000000ZG3k`@00002YL?_00@0002U`nl000000003YL?_0`00
0003YL?_00000000008000001JG3k`00000000000:G3k`04000000>U`nl0000000000P000003YL?_
0000000000800002YL?_00@0002U`nl000000003YL?_0`000003YL?_00000000008000000jG3k`00
00000002000000>U`nl0000000000P000003YL?_0000000004?oool00`000?ooooooo`0Boooo000N
oooo00<0003oooooool0Coooo`<00002L9;T00T0003@/KX00000003H^kd0003G^kh0003Pa[h00`00
0003i<g10000gLW500@000001<Vea`000=KAe00000;9]LH00`000=_OfP000002ak330P0000;7ZK/0
1P000<6O]/6O]P000=_n``0000:nVk<2000000O6YkX000000000003D][/0003M`[h00P0000;A/KT2
000000?3W[80003alkh020000004^J[:00000000][WL0P000004/K;I00000000/jG91@0000:o]m82
000000?8f^H0000000000P000005W;?X000000000000hlJj008000001^73^P0000000>73^@000>31
^@8000000nk7Z`000>JkZP0200000^BhZP8000001^NmZ`0000000>o9[0000?3:[08000000nFjZP00
00000002hkRZ0P000004j[nY00000000lLZY0P000007lLZY0000j;fY0000klRY0000i[ZX00800000
1>FiZ00000000>ZoZ@800002k<6W0`000003hkFV0000mm:V00<000000jG3k`0000000002000000FU
`nl000000000002U`nl0100000:U`nl3000000>U`nl0000000000P000004YL?_0000000000001JG3
k`<000000jG3k`0000000002000000>U`nl0000000000P000003YL?_00000000008000001JG3k`00
000000000:G3k`04000000BU`nl0000000000005YL?_0`0000:U`nl4000000FU`nl000000000002U
`nl010000005YL?_000000000000YL?_00@000000jG3k`000000000200001JG3k`<000000jG3k`00
00000002000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00@000000jG3k`00
0000000200001JG3k`<000000jG3k`0000000002000000FU`nl000000000002U`nl010000003YL?_
00000000008000000jG3k`0000000002000000>U`nl000000000@oooo`030000oooooooo017oool0
01goool00`000?ooooooo`1Coooo1@000003f;^m0000ek^n00<000001mNl_P000>C=`@000=g9a@00
0=c7a004000000?FdM@00039]LH00P000004fmoJ0000ak33ak330P000003a:c10000000000?1WkH2
00000[jK/`800002aZNj0P00000;e;Jk0000gL:n0000glJo0000dK6i0000k^;30000`ijb00800000
0l>O/`0008JSi`02000000F`dO8000000000003<fN<00P0000:a/]T010000;>UbK>UbK>Ub@<00003
_kOB00D00038f^H00000002hZ//010000005Vkg`000000000000hL:i008000001Mno^@000>73^@00
0>31^@03000000?V^jX0000000000^BhZP8000000nNmZ`0000000002klV/0P000004mM>[00000000
00000^>hZP050000lLb/00000000k<:Y008000001N[0Z@000?7:Z@000>RmZ@02000000?V^ZP0003^
aZT00P000004klNY00000000klNY0`000004jKbW00000000hkFV0P000005iKRW000000000000YL?_
00@000001:G3k`000000000000:U`nl4000000BU`nl0000000000003YL?_0P0000:U`nl00`000:G3
k`000003000000FU`nl000000000002U`nl0100000:U`nl3000000>U`nl0000000000P000004YL?_
0000000000000jG3k`800002YL?_00<0002U`nl000000`000003YL?_00000000008000000jG3k`00
00000002000000FU`nl000000000002U`nl010000004YL?_0000000000000jG3k`800002YL?_00<0
002U`nnU`nl010000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`04000000BU
`nl0000000000003YL?_0P0000:U`nl00`000:G3kjG3k`04000000FU`nl000000000002U`nl01000
0005YL?_000000000000YL?_00@000000jG3k`000000000200000jG3k`8000000jG3k`0000000012
oooo00<0003oooooool04Oooo`007Oooo`030000oooooooo05?oool300000Ub<iP<000001^36_P00
0=Nl_]Nl_P000>C=`@8000000mc7a0000>;Ld004000000G9]LH0003Kgm[KgmX000000/N```800002
a:c10P0000;1WkH200000[jK/`800002aZNj0P00000;ckG1000000000000glJo0000dK6i0000k^;3
0000`ijb00800002`inc0P0000:`dO85000000C3`]T0000000000002/jG910000007/j7600000000
0000b=[V0000^:[;008000000lg]jP0000000002000000FL_O0000000000003Q`kX00P000005hL>i
0000h<6i0000h/Fj008000000nJkZP0000000002i;RZ0P000006ikf[00000000klV/0000l<Z/0P00
0003iKZZ0000000000;S^:X2000000KY`:/00000003abZT0003Z`:T2000000GX_JT0003_b:T0003V
^ZP00P000004iKVX00000000j[nY0P0000;/`ZT2000000Kab:L00000003gdZH0003U^:L4000000>U
`nl0000000000P0000:U`nl300000jG3k`800002YL?_00@0002U`nl000000003YL?_0`000003YL?_
00000000008000001:G3k`000000000000:U`nl4000000BU`nl0000000000003YL?_0P0000:U`nl0
10000:G3k`00000000>U`nl3000000>U`nl0000000000P0000:U`nl3000000>U`nl0000000000P00
0004YL?_0000000000000jG3k`800002YL?_00@0002U`nl000000003YL?_10000003YL?_00000000
008000001JG3k`00000000000:G3k`04000000BU`nl0000000000003YL?_0P0000:U`nl010000:G3
k`00000000>U`nl4000000>U`nl0000000000P000005YL?_000000000000YL?_00@000001:G3k`00
0000000000>U`nl200000ZG3k`030000YL?_000000800003YL?_0P0004?oool00`000?ooooooo`0@
oooo000Moooo00@0003oool00000001Doooo10000009ek^n0000h<Jn0000ekbn0000i<g10000gLW5
00800002h]c@1@0000;KgmX00`000<N```00000200000/B/`@030000`:>l`:>l00<00003_Y^c0P00
0003aZNj0000000000;?]L4020000=g2_P0000000=6a^@000>kR``0000;3W[82000000?3Wk<0003^
i<@02P0000>cYLT00`000<WXk0000003/j7600L00038f^H00000002hZ//0003=kNX00P000003/Yo5
00000000008000002IVnl@00000000000=no^@000>73^@000>31^@02000000CQ`[T0000000000003
i;RZ0`000003m]F[0000klV/008000002_GCZ`0000000?KDZ`000>>hZP000?7<[0000>W0Z`<00000
1N[0Z@000?7:Z@000>RmZ@02000000GV^ZP0003^aZT0003U^JP00P000003j[nY0000000000;/`ZT3
000000?S]JH0003gdZH00`000004klFW0000000000001:G3k`800002YL?_00@0002U`nl000000003
YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`0400000ZG3k`<00003YL?_0P00
00:U`nl010000:G3k`00000000>U`nl3000000>U`nl0000000000P000004YL?_0000000000000ZG3
k`@000001:G3k`000000000000>U`nl200000ZG3k`040000YL?_000000000jG3k`<000000jG3k`00
00000002000000>U`nl0000000000P000003YL?_00000000008000001:G3k`000000000000>U`nl2
00000ZG3k`040000YL?_000000000jG3k`<000000jG3k`0000000002000000>U`nl0000000000P00
0003YL?_00000000008000001:G3k`000000000000>U`nl200000ZG3k`040000YL?_000000000jG3
k`<00002YL?_10000003YL?_0000000004?oool00`000?ooooooo`0?oooo000Moooo0P0005Coool7
000000gPa[h0003G_;h0003TcL40003MbLD0003Lal@0003Rg=000038/<801P000004ak330000g>OL
00000/B/`@040000`:>l`:>l`:>l0`0000:nVk<2000000?6YkX0000000000/ne`@060000e/?70000
glJo0000dK6i0P0000;3W[8200000/>O/`8000000lZV]@000000000<00000[>QaP8000000l[gjP00
0;RZb`02000000K=kNX0002bWlFbWlD0003Bl>L400000YVdjP8000001n73^@000>31^@000>;5^P00
0>72^@0300000^BhZP8000000nNmZ`0000000002klV/0`000003iKZZ0000000000;S^:X2000000?Y
`:/0003[`Z/00P000005j/2Y0000lLZY0000j;fY008000001^JjZ00000000>FiZ0000>o7Z@800000
1No7Z@000>c2Z@000>RmZ@02000000CS]JH00000003U^:L4000000CgdJH0002U`nnU`nl200000jG3
k`<000000jG3k`0000000002000000FU`nl000000000002U`nl010000004YL?_0000000000001:G3
k`800002YL?_00@0002U`nl000000003YL?_0`000003YL?_00000000008000001JG3k`0000000000
0:G3k`04000000>U`nl0000000000P0000>U`nl200000ZG3k`040000YL?_000000000jG3k`<00000
0jG3k`0000000002000000FU`nl000000000002U`nl010000003YL?_0000000000800003YL?_0P00
00:U`nl010000:G3k`00000000>U`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_
00@000000jG3k`000000000200000jG3k`800002YL?_00@0002U`nl000000003YL?_0`000003YL?_
00000000008000000jG3k`0000000002000000>U`nl000000000100004?oool00`000?ooooooo`0?
oooo000Moooo00<0003oooooool0D?ooo`<00004oooo100000;G_;h2000000KMbLD0003Lal@0003R
g=000002b;3200<0003Sh]80000010000005g>OL0000a:c1a:c1000000?0Xk`200000[jO^@<00002
aZNj0P00000;ckG10000e/?70000fLW90000dK6i0000k^;30000`ijb00800002`inc0P000006bZJe
00000000d[2h0000U:CP200000>cXLH01`000<[gjP0000000;FTa`000<g]jP0200000[:Oa@<00000
0kNVb00009VdjP0300000YNik`<000002N;5^P000>72^@000>G9^`000>73^P000>BhZP02000000KW
_J/00000003_bJ`0003`bZ`3000000Cfe:/0003S^:[S^:X2000000CY`:/00000003`bj`2000000Ga
bZT0003X_JT0003_b:T00P000003k/JY0000iKVX008000000nZoZ@0000000002k<:Y0P000006l<VY
00000000mm:V0000iKRW1@000004ikZW00000000YL?_10000005YL?_000000000000YL?_00@00000
1:G3k`000000000000>U`nl200000ZG3k`030000YL?_YL?_00800003YL?_0`000003YL?_00000000
008000001JG3k`00000000000:G3k`04000000BU`nl0000000000003YL?_0P0000:U`nl00`000:G3
kjG3k`0200000jG3k`<000000jG3k`0000000002000000FU`nl000000000002U`nl010000004YL?_
0000000000000jG3k`800002YL?_00<0002U`nl000000P0000>U`nl3000000>U`nl0000000000P00
0005YL?_000000000000YL?_00@000001:G3k`000000000000>U`nl200000ZG3k`030000YL?_0000
00800003YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`04000000>U`nl00000
00000P0000:U`nl200000ZG3k`030000oooooooo043oool200004?ooo`002?ooo`D00002oooo00<0
003oooooool00_ooo`030000oooooooo00Koool00`000?ooooooo`1=oooo0`0000Soool5000000OT
cL400000003Lal@0003Rg=0000000/R``P040000hn;B0000a:[01@0000;4[<4010000<2S_<2S_<2S
_0800003_Yni0P0000;6YkX2000000O?]L40003F`lL0003IbLT0003</;h00`0000;3W[801`000<>O
/l>O/`000>kTa0000<ZV]@02000000?B/;P0000000001`000003Z9[70000000000<000001KFTa`00
00000<O`kP000002/Yo50`0000>gY/P200000iNik`<000000n31^@0000000002hL:i0P000003hL>j
00000000008000000nNmZ`0000000002klV/0`000003iKZZ0000000000;S^:X01@000?7<[0000000
0>_2Z`02000000GY`:/000000000003X_JT00P000008i[ZX00000000iKVX0000klNY0000j[nY0P00
0003k<:Y0000j;fY008000001>:eZ00000000>FhY`8000001No5Y`00000000000>NjY`03000000>U
`nl0000000000P000004YL?_0000000000000jG3k`800002YL?_00@0002U`nl000000004YL?_0`00
0003YL?_00000000008000001JG3k`00000000000:G3k`04000000BU`nl0000000000003YL?_0P00
00:U`nl010000:G3k`00000000BU`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_
00@000001:G3k`000000000000>U`nl200000ZG3k`040000YL?_000000000jG3k`<00002YL?_1000
0005YL?_000000000000YL?_00@000001:G3k`000000000000>U`nl200000ZG3k`040000YL?_0000
00000jG3k`<00002YL?_10000005YL?_000000000000YL?_00@000001:G3k`000000000000>U`nl2
00000ZG3k`040000YL?_000000000jG3k`80000ooooo0`000003oooo0000oooo00ooool000[oool0
1`000?ooooooooooo`000?ooo`000002oooo00<0003oool000001oooo`030000oooooooo04[oool3
00003Oooo`@000001Mg9a@0000000>;Ld0000002b;3200H0003Sh]800034Z/00003Qg=03000000=9
XOH0000000000l2S_0800003_Yni0P000004aJZo0000000000000/ne`@8000001MW9b@000<b`_P00
0>K/dP02000000?3W[80000000000/>O/`8000001<ZV]@0000000=:`^08000000mNg^@0009JRg@03
000000>Neo`0000000000`0000:eY<L01@000<O`kP0000000;RXb@0400000[NVb08000000m3Pi000
00000002000000VH[nL000000000003RaKX0003Q`[T0003UbK/00P000005iLZk000000000000ikf[
008000000no9[0000?3:[002000000?U^ZX0000000000^>hZP8000002>W0Z`0000000?3;[0000>W0
Z`000?3;[08000000no8Z@000>JjZ002000000SU^JP00000003Z_jT0003_ajT0003/`ZT2000000?`
bJT0003R]JP00P000003iKRW00000000008000000oOAYP000>NjY`0400000jG3k`800002YL?_00@0
002U`nl000000003YL?_0`0000:U`nl4000000FU`nl000000000002U`nl010000004YL?_00000000
00000jG3k`800002YL?_00@0002U`nl000000003YL?_0`0000:U`nl4000000FU`nl000000000002U
`nl010000004YL?_0000000000000jG3k`800002YL?_00@0002U`nl000000003YL?_0`000003YL?_
0000000000800002YL?_0`000003YL?_00000000008000001:G3k`000000000000>U`nl200000ZG3
k`040000YL?_000000000jG3k`<000000jG3k`0000000002000000>U`nl0000000000P000003YL?_
00000000008000001:G3k`000000000000>U`nl200000ZG3k`040000YL?_000000000jG3k`<00000
0jG3k`0000000002000000>U`nl000000000>_ooo`@00004oooo00<0003oooooool03_ooo`002_oo
o`030000oooooooo00?oool01P000?ooooooo`000?ooo`0000Koool00`000?ooooooo`18oooo0`00
013oool5000000?Lal@0000000000lR``P8000001LBZ`0000>7Ld0000<V_`@0500000/2S_0800003
_Yni0P0000;5Z[l200000/ne`@040000e/?7000000000/b`_P800002_i^d0P0000;3Wk<2000000?:
Y[D0000000000]:`^08000000mNg^@000000000;000000?7l>h0002hZ<T00[RXb@800003]jK800D0
003@h>C@h>@00030^mD010000004VKS^0000000000000^72^@8000001>73^P0000000>C7^`@00002
klV/0P000004mM>[0000000000000^>hZP050000lLb/00000000jl:[008000001NW0Z`000?3;[000
0>NmZ`02000000?V^ZP0003^aZT00P000003klNY0000j[nY00800002k<:Y0`000003h[FX0000mm>X
00<000001>o5Y`000000000000;W^ZL4000000>U`nl0000000000jG3k`<000000jG3k`0000000002
00000ZG3k`<000000jG3k`0000000002000000BU`nl0000000000003YL?_0P0000:U`nl010000:G3
k`00000000>U`nl3000000>U`nl0000000000P000003YL?_00000000008000000jG3k`0000000002
000000BU`nl0000000000003YL?_0P0000:U`nl010000:G3k`00000000>U`nl3000000>U`nl00000
00000P000004YL?_0000000000000ZG3k`@000001:G3k`000000000000>U`nl200000ZG3k`040000
YL?_000000000jG3k`<000000jG3k`0000000002000000FU`nl000000000002U`nl010000003YL?_
0000000000800003YL?_0P0000:U`nl010000:G3k`00000000>U`nl3000000>U`nl0000000000P00
0005YL?_000000000000YL?_00@000000jG3k`000000000foooo0`0000Soool00`000?ooooooo`0>
oooo000:oooo00@0003oooooooooool200000oooo`030000oooo000000Koool00`000?ooo`000015
oooo0`0001Coool600000lR``P8000001LBZ`0000>7Ld0000<V_`@02000000C@^/@00000001XUNT3
00000kjO^@800002aJZo0P000008c;S700000000e/?70000fLW90000c;2n0P0000>oVk@2000000?3
Wk<0000000000/ZV]@8000002]:`^00000000=Ng^@000>KA`@000=>a]`0009>Nf`8000001JCEn@00
000000000<O`kP0200000[RXb@<000001KZ[b`00000000000=3Pi002000000C0^mD000000038dn<3
00000YZjkP<000001>G9^`0000000>G:^`8000001n;3^P00000000000>o9[0000?3:[002000000?U
^ZX0000000000^>hZP8000000nW0Z`000>_2Z`02000000GY`:/0003`bj`0003W_J/00P000004i[ZX
00000000iKVX0P000007j[nY0000klNY0000k<:Y0000j;fY008000001>:eZ00000000>BhZ0@00000
0oOAYP000>NjY`02000000GS]JH000000000002U`nl010000004YL?_0000000000000ZG3k`@00000
1JG3k`00000000000:G3k`0400000ZG3k`040000YL?_000000000jG3k`<000000jG3k`0000000002
000000FU`nl000000000002U`nl0100000:U`nl3000000>U`nl0000000000P0000:U`nl010000:G3
k`00000000>U`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_00@000000jG3k`00
00000002000000>U`nl0000000000P0000:U`nl010000:G3k`00000000>U`nl3000000>U`nl00000
00000P000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`0400000ZG3k`030000
YL?_000000800003YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`04000000FU
`nl000000000002U`nl0100000:U`nl00`000?ooooooo`0`oooo0`0000coool00`000?ooooooo`0=
oooo000:oooo00D0003oooooooooool000001?ooo`030000oooo000000Koool20000A?ooo`80000H
oooo0`00009nV>4010000<R``P00000000;4Z/02000000?9[l40000000000m2ja0D00002_Yni0P00
00;5Z[l200000/bha`090000e/?70000fLW90000c;2n0000i^cB000000:oVk@00`000;fI/[fI/P03
000000c:Y[D00000003B/;P0003Uc/00003G]kT0003VdL40003C/KL200000ZCEn@D00003^:S90P00
00>jZl/010000=3Pi=3Pi00000;0^mD01@000<SCh`0000000<32g004000000FEaOL000000000003Q
`kX00P000006i<Nk00000000i<Rk0000gKbh0`000008mM>[00000000m]B[0000hkRZ0000lLb/0P00
000:jl:[00000000jL2[0000l<^/0000ikf[0000klR/0P000003k/JY0000iKVX008000000nZoZ@00
00000002k<:Y0P000006l<VY00000000mm>X0000i;RX1@0000;W^ZL2000000?S]JH0000000000P00
00:U`nl300000ZG3k`<000000jG3k`0000000002000000BU`nl0000000000005YL?_0`000003YL?_
00000000008000001JG3k`00000000000:G3k`04000000BU`nl0000000000002YL?_10000004YL?_
0000000000001JG3k`<000000jG3k`0000000002000000FU`nl000000000002U`nl010000005YL?_
000000000000YL?_00@000000jG3k`000000000200001JG3k`<000000jG3k`0000000002000000FU
`nl000000000002U`nl010000005YL?_000000000000YL?_00@000001:G3k`000000000000FU`nl3
00000ZG3k`@000001JG3k`00000000000:G3k`04000000FU`nl000000000002U`nl010000004YL?_
0000000000001JG3k`80000^oooo100000ooool00`000?ooooooo`0=oooo0009oooo0P0000?oool3
00000oooo`030000oooooooo00Goool00`000?ooooooo`10oooo0`0001_oool700000/BZ`0800000
0lV_`@0000000003d;[400<0003Ke]<000000P000004MHOG0000000000000/FZ_`800002c;S700T0
003@`lh0003IbLT0003</;h0003Vk=8000000[nK]0040000_IVb_IVb_IVb0P000003bZJe00000000
00;B/;P2000000OG]kT0003VdL40003C/KL0003^h<<01@000003Z=Kh0000000000@00002^Z_;0P00
0004a<WN00000000`;_E0P000003b=?S0000`<;L008000000kjje`0000000002000000FE`oL00000
0000003Ub[/00P000006h/>j00000000gKbh0000iLRk0`000003iKZZ0000000000;S^:X2000000?Y
`:/0003[`Z/00P000005jL2[0000l<^/0000ikf[008000002>FjZP0000000>FiZ0000>o7Z@000>Zo
Z@8000000nc2Z@000>RmZ@02000000CR]JP00000003T^:P2000000C^aJT0000000000002ikZW0`00
0003m<fW0000000000<000000jG3k`0000000002000000BU`nl0000000000003YL?_0P0000:U`nl0
0`000:G3k`000003000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00@00002
YL?_0`0000>U`nl200000ZG3k`030000YL?_000000<000001JG3k`00000000000:G3k`04000000FU
`nl000000000002U`nl010000004YL?_0000000000000jG3k`800002YL?_00<0002U`nnU`nl01000
0005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`04000000BU`nl0000000000003
YL?_0P0000:U`nl00`000:G3k`000003000000>U`nl0000000000P000003YL?_0000000000800000
1JG3k`00000000000:G3k`04000000BU`nl0000000000003YL?_0P0000:U`nl00`000:G3k`000003
000000>U`nl000000000:_ooo`<0000Coooo00<0003oooooool03Oooo`007?ooo`030000oooooooo
03goool300008?ooo`<00002PioV0`0000;9[l4200000]2ja0060000fmKC0000dL7:0000MHoN0`00
00;5Z[l200000/bha`050000d<?>0000d/K?000000;</;h200000[nK]0800002_IVb0P000005a:Bh
000000000000d[2h008000001]Ng^@000>KA`NKA`@000=>a]`8000000lbY]@0000000004Z=Kh0`00
00>jZl/00`000<C9g/C9gP02000000?5`]L00038dn<00P000003`<;L0000_[[G008000000lO<g@00
00000002000000FC^_8000000000003Tak/00P000006i<Rk00000000iLRk0000f[Rg0`000004m]B[
0000hkRZhkRZ0P000004jL2[0000000000000^W0Z`070000l<^/00000000klR/0000iKZZ00800000
2>FiZ00000000>ZoZ@000>o7Z@000>c2Z@8000000o39Z@000>:eZ002000000?T^:P0000000000P00
0003m]>X00000000008000001>>eYP0000000>VlY`D00003YL?_0P0000:U`nl010000:G3k`000000
00>U`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_00@000001:G3k`0000000000
00BU`nl200000ZG3k`040000YL?_000000000jG3k`<000000jG3k`0000000002000000FU`nl00000
0000002U`nl010000004YL?_0000000000000jG3k`800002YL?_00@0002U`nl000000003YL?_1000
0003YL?_00000000008000001JG3k`00000000000:G3k`04000000BU`nl0000000000003YL?_0P00
00:U`nl010000:G3k`00000000>U`nl3000000>U`nl0000000000P000003YL?_0000000000800000
0jG3k`0000000002000000BU`nl0000000000003YL?_0P0000:U`nl010000:G3k`00000000>U`nl3
000000>U`nl0000000000P000003YL?_0000000002Koool300005_ooo`030000oooooooo00goool0
01coool00`000?ooooooo`0joooo0`0002Coool600000/V_`@800002d;[400<0003Ke]<000000]71
bP<00002MHoN0`000008c;S700000000d<?>0000d/K?0000ak330`0000>oVk@00`000;fI/[fI/P02
00000/BT^08000002M:`^0000>G>`0000=Ng^@000>KA`@000=>a]`02000000?<ZKD0003ak/402`00
00;4bMh01`000<G2e`0000000<K7f`000<32g002000000>n^]L00037c=d00P000003_[3=00000000
008000001IK0m000000000000>;3^P02000000KM_;P00000003J^;L0003Xc[`300000^>hZP050000
lLb/00000000jl:[008000001NW0Z`000?3;[0000>NmZ`02000000?U^ZX0003^aj/00P000003klNY
0000j[nY008000000nc2Z@000>RmZ@02000000?R]JP0003gdjP00P000003n]ZV0000000000800002
i[ZY0P000005hkFV000000000000l<JW00@000000jG3k`0000000003YL?_0`000003YL?_00000000
008000001JG3k`00000000000:G3k`04000000BU`nl0000000000003YL?_0P0000:U`nl00`000:G3
kjG3k`0200000jG3k`<000000jG3k`0000000002000000FU`nl000000000002U`nl010000004YL?_
0000000000000jG3k`800002YL?_00@0002U`nl000000003YL?_0`000003YL?_0000000000800000
0jG3k`0000000002000000>U`nl0000000000P000004YL?_0000000000000jG3k`800002YL?_00@0
002U`nl000000003YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`04000000>U
`nl0000000000P0000>U`nl200000ZG3k`040000YL?_000000000jG3k`<000000jG3k`0000000002
000000FU`nl000000000002U`nl010000003YL?_00000000027oool400006Oooo`030000oooooooo
00goool001_oool00`000?ooooooo`0hoooo0`0002Soool300000WjQj@<00003d;[40P0000;A`LX2
000000?A`L/0000000000`000007c;S70000d<?>d<?>0000d/K?000000;7/<<300000[nK]0030000
_IVb_IVb00800002a:Bh0P00000=bjnn000000000000ekNi0000i]710000dk6g0000k^330000c:Ve
008000000lJR/`0000000003Ym3e0`0000;4bMh2000000?5`]L00036am/00P000003c]cS0000_[[G
008000001/O<g@000;j`cKj`c@000=?`iP@000001IZdjP00000000000>C8^`02000000?Ub;/0003J
^;L00P000003fKJf0000000000;S^:X2000000SY`:/00000003`bj`0003Y`:/0003`bj`2000000?_
b:`0003U^ZX00P000003i;VZ0000000000;Z_jT2000000K/`ZT00000003`bJT0003R]JP2000000CT
^:P00000003^aJT300000^JjZ@<000001OC=Y`00000000000?78Y`04000000>U`nl0000000000P00
0005YL?_000000000000YL?_00@000001:G3k`000000000000>U`nl200000ZG3k`040000YL?_0000
00001:G3k`<000000jG3k`0000000002000000FU`nl000000000002U`nl010000004YL?_00000000
00000jG3k`800002YL?_00@0002U`nl000000003YL?_0`000003YL?_00000000008000001JG3k`00
000000000:G3k`0400000ZG3k`<00003YL?_0P0000:U`nl010000:G3k`00000000>U`nl3000000>U
`nl0000000000P000005YL?_000000000000YL?_00@000001:G3k`000000000000>U`nl200000ZG3
k`030000YL?_000000800003YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`04
000000BU`nl0000000000003YL?_0P000003YL?_0000000001goool300007Oooo`030000oooooooo
00goool001_oool00`000?ooooooo`0eoooo0`0002coool600000m2ja0800002dL7:0P0000;A`L/6
00000]33cP030000d/K?000000;7/<<200000[jO^@800003_IVb0P000003a:Bh0000000000;;[kh0
10000>G>`000000000;VdL401@000=>a]`0000000<bY]@02000000?6X[<0003^n;P02@000006aL;G
00000000a/OK0000c]cS0P000003`/7I0000alcM00800002_[3=0`000003^:O80000000000800000
1Ibgj`00000000000=fl^002000000?J^;L0000000000]Vf]P@000001?7<[00000000>_2Z`800002
jL2[0P000008ikf[00000000iKZZ0000k/N[0000i;VZ0P000005j[nY0000klNY0000k<:Y00<00000
1N:eZ0000?OCZ0000>BhZ004000000?fdjP0003V^ZT00P000004h[FX00000000jKbW0`000003l<JW
00000000008000000jG3k`0000000002000000BU`nl0000000000003YL?_0P0000:U`nl010000:G3
k`00000000>U`nl300000ZG3k`@000001JG3k`00000000000:G3k`04000000BU`nl0000000000003
YL?_0P0000:U`nl010000:G3k`00000000>U`nl3000000>U`nl0000000000P000005YL?_00000000
0000YL?_00@000001:G3k`000000000000BU`nl200000ZG3k`040000YL?_000000000jG3k`<00000
0jG3k`0000000002000000FU`nl000000000002U`nl010000004YL?_0000000000000jG3k`800002
YL?_00@0002U`nl000000003YL?_0`0000:U`nl8000000>U`nl0000000000P000004YL?_00000000
00000jG3k`800002YL?_00@0002U`nl000000003YL?_0P0001[oool300008?ooo`030000oooooooo
00goool001_oool30000<_ooo`<0000`oooo0`00009jXN/01@000=2ja00000000=71bP0300000]71
b`8000000mC2b@0000000004000000CBa/l00037/<?7/<<200000kjO^@800002_IVb0P000003a:Bh
0000000000;;[kh020000=kCc@000=Ng^@000>KA`@000=>a]`800002c:Ve0P000004aZ:c00000000
`I^a0`0000:Uc?@4000000K6am/00000003>g><00032`MT2000000Bomnh0002n/<fn/<d300000[RW
b0030000c?cT000000<00002XKSY0P000003iLRk0000f[Rg008000001MVf]P000>[B_0000=Zg]P02
000000?Y`:/0003[`Z/00P000003jL2[0000l<^/008000000no8[0000>FjZP02000000?T^JX0003_
b:/010000003k<:Y0000j;fY008000001^:eZ00000000>BhZ0000?[JYP@00002i[ZY0P000005h[FX
000000000000l<JW00<000000o;:Y`0000000002000000>U`nl0000000000P0000:U`nl010000:G3
k`00000000>U`nl300000ZG3k`<00002YL?_0`000003YL?_00000000008000001JG3k`0000000000
0:G3k`0400000ZG3k`040000YL?_000000000jG3k`<000000jG3k`0000000002000000FU`nl00000
0000002U`nl010000005YL?_000000000000YL?_00@00002YL?_00<0002U`nl000000P0000>U`nl3
000000>U`nl0000000000P000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`04
00000ZG3k`040000YL?_000000000jG3k`<000000jG3k`0000000002000000>U`nl0000000001P00
0003YL?_00000000008000000jG3k`000000000200000ZG3k`040000YL?_000000000jG3k`<00000
0jG3k`0000000002000000>U`nl0000000005Oooo`@0000Soooo00<0003oooooool03Oooo`006ooo
o`030000oooooooo033oool20000=?ooo`L000001=71bP000=35c`0000;A`L/2000000?D`/T00038
[Kh01P0000;7/<<200000kjO^@030000_Yni_Yni00<00002a:Bh0P000006bjnn0000g]?=0000ckK2
00000^KA`@<00002c:Ve0P000006aZ:c00000000`I^a0000joVb0`0000:Uc?@4000000K>g><00000
0032`MT0002omnh2000000>aZm80000000000P0000:hYlP3000000>dY/X0002Q^>T00`000004W;c_
00000000f[Rg0P000004fKJf0000j]:l00000]Zg]P<000000n_2Z`0000000002jL2[0P000008ikf[
00000000iKZZ0000k/N[0000i;VZ0P0000;Y`:/2000000C/`ZT00000003`bJT2000000?gdjP0003T
^:P00P000005k/FY000000000000i[ZY008000000n:eZ0000??>Z@03000000Gab:L000000000003[
`:L0100000FU`nl3000000>U`nl0000000000P0000:U`nl3000000>U`nl0000000000P000005YL?_
000000000000YL?_00@000001:G3k`000000000000FU`nl3000000>U`nl0000000000P000005YL?_
000000000000YL?_00@000001JG3k`00000000000:G3k`04000000BU`nl0000000000005YL?_0`00
00:U`nl4000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00@000001:G3k`00
0000000000FU`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_00@000001JG3k`00
000000000:G3k`04000000>U`nl0000000000P0000FU`nl3000000>U`nl0000000000P000005YL?_
000000000000YL?_00@000000jG3k`000000000Aoooo0`0002Soool00`000?ooooooo`0<oooo000K
oooo00<0003oooooool0;Oooo`<0000hoooo1P000003d<G?0000dL7;00<00002e<;900@00038[Kh0
003NcLL3000000@KTNT0000000000003_Yni00@0002nWkVnWkVnWkT200000/BT^08000001<^__P00
0=kCcMkCc@8000001>3GcP0000000=>a]`8000000lbY]@0000000002aZ:c0P000004`I^a00000000
`I^b2@000003`/7I0000000000800003/J_B0P0000:hYlP300000kBVbP80000019blk`0000000000
00:QZmh3000000GI][H0003Zd[`0003J]kH00P000003fkVg0000jl:[008000001NW0Z`000?3;[000
0>NmZ`02000000[U^ZX00000003T^JX0003_b:/0003Y`:/0003^b:/2000000CX_JT00000003R]JP2
000000?T^:P0003jfZH00`000003m]>X0000i[ZY008000001>:eZ00000000>RmZ@<000001?36Y`00
00000>_0Y`8000000nJiY`000:G3k`04000000BU`nl0000000000002YL?_10000005YL?_00000000
0000YL?_00@000001:G3k`000000000000>U`nl200000ZG3k`030000YL?_000000<000001JG3k`00
000000000:G3k`04000000FU`nl000000000002U`nl010000004YL?_0000000000000jG3k`800002
YL?_00<0002U`nl000000`000003YL?_00000000008000000jG3k`0000000002000000FU`nl00000
0000002U`nl010000004YL?_0000000000000jG3k`800002YL?_00<0002U`nl000000`000005YL?_
000000000000YL?_00@000001JG3k`00000000000:G3k`04000000BU`nl0000000000003YL?_0P00
00:U`nl00`000:G3kjG3k`08000000>U`nl0000000000P000005YL?_000000000000YL?_00@00000
0jG3k`000000000=oooo0`0002_oool00`000?ooooooo`0<oooo000Koooo00<0003oooooool0:_oo
o`<0000loooo1P00000>dL7;0000b[O7b[O70000e<;90000b:fn0000g/g70000bZZj0000A8[[0`00
00>nWkT010000;jO^KjO^KjO^@8000001<>X_`000000000000;;[kh020000=kCc@000<nf`P000>3G
cP000<^__P800002c:Ve00<00036X[?6X[<00P000006`I^a00000000`I^b0000l_302`0000>aZm83
000000>ZVlP0000000000P0000>dY/X010000<g[jP00000000>QZmh4000000WI][H0003Zd[`0003J
]kH0003[dkd0003K^KL00`0000;Y`:/01@000?3;[00000000>o8[002000000?^aj/0003T^JX00P00
00;Y`:/2000000K[`Z/00000003`bJT0003R]JP2000000CT^:P00000003^aJT3000000?V^ZT0003h
eZP00P000004lljY00000000klNY0`000004l/ZW00000000klJW100000:U`nl300000ZG3k`<00000
0jG3k`0000000002000000BU`nl0000000000003YL?_0P0000:U`nl010000:G3k`00000000>U`nl3
000000>U`nl0000000000P000005YL?_000000000000YL?_00@000001:G3k`000000000000>U`nl2
00000ZG3k`040000YL?_000000000jG3k`<000000jG3k`000000000200000ZG3k`<000000jG3k`00
00000002000000BU`nl0000000000003YL?_0P0000:U`nl010000:G3k`00000000>U`nl3000000>U
`nl0000000000P000005YL?_000000000000YL?_00@000001:G3k`000000000000>U`nl200000ZG3
k`040000YL?_000000000jG3k`P000000jG3k`0000000002000000>U`nl0000000000P000004YL?_
0000000000000jG3k`8000000jG3k`0000000008oooo100002koool00`000?ooooooo`0<oooo000K
oooo00<0003oooooool09oooo`<00010oooo1P0000;:]lL00`000=C2b@000002b:fn0P000003bZZj
0000im[8008000001DB:j`000;jO^KjO^@000003_Yni0P0000;3Z;l200000/^__P080000g]?=0000
ckK20000h=O>0000bjnn0`000004c:Ve00000000aZ:c0P0000;1Vk42000000C1Vk800000003<Z[P4
000000B9^oH00000000fC[h2000000BaZm80000000000003ZY_80P0000>dY/X4000000>k^=L00000
0000100000:P/^D300000]Zg]P8000000m^i]`000000000200000^W0Z`8000001>NmZ`0000000>Fj
ZP800002i;VZ0P000005jL2[0000k/R[0000jl:[00<000000n:eZ0000?OCZ002000000OjfZH00000
0000003fdjP0003V^ZT00P000004h[FX00000000j;fY0P000005l<VY000000000000jl2W00800000
0nJiY`0000000003000000>U`nl0000000000P000004YL?_0000000000000jG3k`800002YL?_00@0
002U`nl000000003YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`04000000BU
`nl0000000000003YL?_0P0000:U`nl010000:G3k`00000000>U`nl3000000>U`nl0000000000P00
0004YL?_0000000000000ZG3k`@000001:G3k`000000000000>U`nl200000ZG3k`040000YL?_0000
00000jG3k`<000000jG3k`0000000002000000FU`nl000000000002U`nl010000004YL?_00000000
00000jG3k`800002YL?_00@0002U`nl000000003YL?_0`000003YL?_00000000008000001JG3k`00
000000000:G3k`04000000>U`nl0000000000P0000>U`nl2000000>U`nl0002U`nl00`0000>U`nl2
00001Oooo`<0000boooo00<0003oooooool03?ooo`006_ooo`030000oooooooo02Goool30000A?oo
o`<00002Ljof0P000004e<;90000b:fnb:fn0P000005bZZj0000im[80000bj^i00D00003_Yni0P00
00;3Z;l2000000[5[l@00000003Ndld0003?]/80003Pelh0003;[kh200000/FU^@800002aZ:c00<0
0031Vk71Vk400P000006`I^b00000000c:Zh0000i<k12`0000>ZVlP3000000>aZm80002dY/X00`00
00:k^=L2000000>oc>@0000000000Z2bi@<000001N[B_0000=Zg]P000>_C_@02000000?ZdK`0003L
^[L00`000006l<^/00000000klR/0000iKZZ0P000005i;VZ0000klR[0000jL2[008000000n_2Z`00
0>NmZ`02000000KR]JP00000003T^:P0003jfZH4000000GV^ZT0003heZP0003R]JP00`000004klNY
00000000klNY0`000003klJW0000i[VW008000001N:cYP00000000000:G3k`0400000ZG3k`040000
YL?_000000000jG3k`<000000jG3k`0000000002000000FU`nl000000000002U`nl010000005YL?_
000000000000YL?_00@00002YL?_00@0002U`nl000000003YL?_0`000003YL?_0000000000800000
1JG3k`00000000000:G3k`04000000>U`nl0000000000P000003YL?_0000000000800002YL?_00@0
002U`nl000000003YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`04000000FU
`nl000000000002U`nl0100000:U`nl010000:G3k`00000000>U`nl3000000>U`nl0000000000P00
0005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`0400000ZG3k`030000YL?_0000
00800002YL?_0`0000:U`nl4000000BU`nl00000003oool30000=Oooo`030000oooooooo00coool0
01[oool00`000?ooo`00000Roooo0`0004Soool500000]C2b@060000b:fn0000g/g70000bZZj0P00
0003bj^i0000h/o400@00002_Yni0P0000;3Z;l200000/F_a0030000g]?=g]?=00800002h=O>0`00
00?5YKT2000000C6X[<000000031Vk42000000G1Vk80003bl<00003<Z[P00P000003f[jn00000000
00P000001:ZKb0000000000000>aZm8300000[^he`8000001;o<i00000000;^ge@<0000018c<o@00
0000000000;J]kH2000000KK^KL00000003L^[L0003Vc;/3000000SW_J/00000003U^ZX0003^aj/0
003T^JX200000^W0Z`8000001>_2Z`0000000?3:Z`8000000oOCZ0000>BhZ002000000G^aJT00000
0000003V^ZT00P000006h[FX00000000j;fY0000klNY0`000007lL^Y000000000000i[VW0000k/>W
008000001?78Y`000000000000FU`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_
00@000001JG3k`00000000000:G3k`04000000BU`nl0000000000005YL?_0`000003YL?_00000000
008000001JG3k`00000000000:G3k`04000000FU`nl000000000002U`nl0100000:U`nl300001JG3
k`<000000jG3k`0000000002000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_
00@000001:G3k`000000000000FU`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_
00@000001JG3k`00000000000:G3k`04000000BU`nl0000000000005YL?_0`000003YL?_00000000
008000000jG3k`0000000002000000>U`nl0000000001@0003Soool00`000?ooooooo`0<oooo000J
oooo0P00023oool30000C?ooo`030000L:Ga000000<000002LR]_P000=k=a`000<ZZ^P000>OJb000
0<^[^@02000000?D]k`000000000100000;3Z;l200000/F_a0090000eM7E00000000ckK20000h=O>
0000bjnn00800002aJFi00<00031WkK1WkH00P0000;1Vk400`000<6K//6K/P02000000?<Z[P0003T
c/400P000003ekVl0000000000T00002/J_B1@000004^=S`00000000_lcT0P000004^kOE00000000
`LOO0`0000:K]^/3000000C[dkd00000003ZdK`2000000?Vc;/0003N_KP00`000003klR/0000iKZZ
00800002i;VZ0P000003jL2[0000k/R[008000001>NmZ`0000000>6eZ@8000000nBhZ0000?[JYP03
000000?fdjP0003V^ZT00P000004h[FX00000000j;fY0P000005l<VY000000000000j/2Y00800000
2^JiY`0000000>:cYP000?78Y`000>BgY`000:G3k`@000001JG3k`00000000000:G3k`04000000FU
`nl000000000002U`nl010000004YL?_0000000000000jG3k`800002YL?_00<0002U`nl000000`00
0005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`0400000ZG3k`800004YL?_0P00
00:U`nl00`000:G3k`000003000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_
00@000001:G3k`000000000000>U`nl200000ZG3k`030000YL?_000000<000001JG3k`0000000000
0:G3k`04000000FU`nl000000000002U`nl010000004YL?_0000000000000jG3k`800002YL?_00<0
002U`nl000000`000005YL?_000000000000YL?_00@000000jG3k`0000000006000000>U`nl00000
0000>?ooo`030000oooooooo00coool001[oool00`000?ooooooo`0Loooo0`0004ooool300000g2U
l@<000001LZZ^P000>OJb0000<^[^@02000000?D]k`0003G^kh0100000;3Z;l01@000=[Rf`000<F_
a0000002eM7E00H0003:]/L0003Pelh0003;[kh200000/FU^@040000`Inf`Inf`Inf0P000004`I^a
00000000`I^b0P000005c:Zh0000i<k10000f[jn008000000nC>`@0000000007000000BRR;T00000
002bg?D2000000Bhf?000000002[/=`200000[^ge@050000`LOO00000000_K;?00@000001H^nn000
000000000=^i]`02000000KL^[L00000003N_KP0003TakX3000000WU^ZX0003^aj/0003T^JX0003_
b:/0003Y`:/00P000006jl:[00000000l<Z[0000hKFY0P000003i;RX0000n]ZV00@000001>JjZ@00
00000>:eZ08000000nRmZ@000>o7Z@02000000G_ajT000000000003_ajT00P000005k/>W0000h[>V
0000lLRW00@000000jG3k`0000000002000000FU`nl000000000002U`nl010000004YL?_00000000
00000jG3k`800002YL?_00@0002U`nl000000003YL?_0`000003YL?_00000000008000001JG3k`00
000000000:G3k`04000000BU`nl0000000000004YL?_0P000004YL?_0000YL?_YL?_0P0000>U`nl3
000000>U`nl0000000000P000005YL?_000000000000YL?_00@000001:G3k`000000000000>U`nl2
00000ZG3k`040000YL?_000000000jG3k`<000000jG3k`0000000002000000FU`nl000000000002U
`nl010000004YL?_0000000000000jG3k`800002YL?_00@0002U`nl000000003YL?_0`000003YL?_
00000000008000001JG3k`00000000000:G3k`04000000BU`nl0000000000003YL?_0P0000:U`nl0
0`000?ooooooo`0eoooo00<0003oooooool03?ooo`006_ooo`030000oooooooo01[oool20000Dooo
o`L000003LZZ^P000>OJb0000<^[^@000>;?a0000=Bg_0000=Nk_P000>76_P04000000CJh]/00035
[l@00002eM7E00H0003:]/L0003Fd]@0003;[kh200000/FU^@800002`Inf00<0002mVK>mVK<00P00
0003`I^b0000000000;<Z[P2000000?J_[h0003G^K`00P000003cjjh0000000000800002V;;Y00@0
001;D[P0002RR;T2000000Bhf?000000002[/=`2000000N_jOP0000000000031aml0002m//l00P00
0003cM_T00000000008000001I^[hP00000000000>[A_002000000KVc;/00000003TakX0003O_kT2
000000?U^ZX0000000000^BiZP8000000nW0Z`000>k8Z`02000000KW_J/00000003Q]JT0003feJ/2
000000?jfZH0003^aJT00`000004i[ZY00000000h[FX0P000003j;fY0000klNY00<000001O7;Z@00
000000000>FiZ@02000000GR/jH0003ab:L0003T]jL010000003YL?_00000000008000001JG3k`00
000000000:G3k`0400000ZG3k`040000YL?_000000000jG3k`<000000jG3k`0000000002000000FU
`nl000000000002U`nl010000004YL?_0000000000000ZG3k`<00002YL?_00<0002U`nnU`nl00P00
00>U`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_00@000001JG3k`0000000000
0:G3k`0400000ZG3k`040000YL?_000000000jG3k`<000000jG3k`0000000002000000FU`nl00000
0000002U`nl010000005YL?_000000000000YL?_00@00002YL?_00@0002U`nl000000003YL?_0`00
0003YL?_00000000008000001JG3k`00000000000:G3k`04000000FU`nl000000000002U`nl01000
00:U`nl010000:G3k`00000000>U`nl20000>?ooo`030000oooooooo00_oool001[oool00`000?oo
ooooo`0Goooo0`0005Ooool300000W:GiP<00002bj^i0P000005e;Nl0000ek^n0000hLJn00H00002
aJo40`000005b[K70000e];D0000bK?500800003aJFi00@00031WkK1WkH00003_IVc00<0002nV[<0
00000P000005c:Zh0000i<k10000f[jn008000001>C>`@0000000>gM`PT000001:ZC_P0000000:^`
g08000001JoYn000000000000<77g`02000000>m//l0003=fn@00P000003_[C@0000000000800000
1I76n@00000000000=bj]`02000000KN_KP00000003O_kT0003R`kX2000000O^aj/0003T^JX0003_
b:/0003Y`:/00P000003jl:[0000ikf[008000001>6eZ@0000000>>hZPD000001?KCZ00000000?SF
Z08000001_?>Z@0000000>o7Z@000?39Z@<000001>[0Z@0000000>FiZ@8000001N:cYP000?78Y`00
0>BgY`02000000CU^:L00000002U`nl400000ZG3k`800005YL?_0`000003YL?_0000000000800000
1JG3k`00000000000:G3k`04000000BU`nl0000000000002YL?_0`0000:U`nl300001JG3k`<00000
0jG3k`0000000002000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00@00000
1:G3k`000000000000FU`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_00@00000
1JG3k`00000000000:G3k`04000000BU`nl0000000000005YL?_0`000003YL?_0000000000800000
1JG3k`00000000000:G3k`04000000FU`nl000000000002U`nl010000004YL?_0000000000001JG3
k`<000000jG3k`0000000002000000>U`nl000000000=oooo`030000oooooooo00_oool001Woool0
0`000?ooooooo`0Eoooo0`0005_oool5000000?Wf/P0003;ZkT00P000004e;Nl0000ek^n00000^76
_P8000000nO@_`000000000400000/Zfa`040000e];D0000bK?50`0000;5YKT00`000<6O]/6O]P02
00000[fI/`8000002[jJ/`0000000<bZ^0000>C>`@000=Zn_P000=Ni_08000001<n^^00000000<NS
]0@00002Y[o/2@0000:RW<l2000000Jm//l00000003=fn@0002n]=02000000?<hnP0000000000P00
00:NYm`2000000CVc;/00000003TakX2000000?R`kX0003O_kT00P0000;T^JX2000000?Y`:/0003^
b:/00P000005ikf[0000l<Z[0000hKFY008000000n>hZP000?WLZ@04000000CV^ZT00000003R]JP2
000000?X_JT0003_ajT00P000005klNY000000000000klNY008000000ng4Z@0000000002lLRW0P00
0004mLjV00000000klFW0P0000BU`nl2000000>U`nl0002U`nl010000004YL?_0000000000000ZG3
k`<000001:G3k`000000000000:U`nl300000ZG3k`<00003YL?_0P0000:U`nl00`000:G3k`000003
000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00@000001:G3k`0000000000
00>U`nl200000ZG3k`030000YL?_000000<000001JG3k`00000000000:G3k`04000000FU`nl00000
0000002U`nl010000004YL?_0000000000000jG3k`800002YL?_00<0002U`nl000000`000005YL?_
000000000000YL?_00@000001JG3k`00000000000:G3k`04000000BU`nl0000000000003YL?_0P00
00:U`nl00`000:G3k`000003000000FU`nl000000000002U`nl010000003YL?_0000000003Koool0
0`000?ooooooo`0;oooo000Ioooo00<0003oooooool04_ooo`<0001Ooooo1@000003bj^i00000000
00;D]k`200000^76_P8000000nO@_`000=Vo_`0400000/Zfa`<000000lVca@0000000002`jRo0P00
00?1WkH00`000;fI/kfI/`02000000BnV[<000000037ZK/300000]Zn_P8000001>C>`@0000000>gM
`P8000000o7X`P000000000700000[jbcP030000XYc?0000008000001;C>k@0000000<gKi0800000
0kjdd0000<cSj002000000>k[lh0002NYm`01P000004g[fh00000000gkni0P000004gkni0000hL>j
00000^BiZP8000001^W0Z`0000000>_2Z`000>NmZ`8000002>6eZ@0000000>>hZP000?WLZ@000>g6
Z`@000000oSFZ0000>:eZ003000000?_ajT0003`bJT00P000005lL^Y000000000000iKVY00800000
1N6cZ0000?78Y`000>BgY`02000000GU^:L00000003]`ZL000000ZG3k`800002YL?_0`0000:U`nl3
00000ZG3k`<000001:G3k`000000000000:U`nl300000jG3k`800002YL?_00@0002U`nl000000003
YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`04000000BU`nl0000000000003
YL?_0P0000:U`nl010000:G3k`00000000>U`nl3000000>U`nl0000000000P000005YL?_00000000
0000YL?_00@000001:G3k`000000000000>U`nl200000ZG3k`040000YL?_000000000jG3k`<00000
0jG3k`0000000002000000FU`nl000000000002U`nl010000004YL?_0000000000000jG3k`800002
YL?_00@0002U`nl000000003YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`04
000000>U`nl000000000=Oooo`030000oooooooo00_oool001Woool300003oooo`<0001Soooo0`00
000=LYKU000000000000e;Nl0000ek^n0000hLJn0000e;Jk0000im2o008000000n?>`P0000000004
00000/Vca@800003`jRo0P0000;1WkH00`000;fI/kfI/`02000000^nV[<0003To<`00037ZK/0003T
c/40003J_[h0003G^K`00P00000:cjjh00000000aj>d0000lNS20000b:Be0000SZSW0P000003[<ga
0000000000@000001;C>k@000000000000:VX]801P000;jdd00000000<cSj00000>k[lh500000Z2c
iP8000001^C7^P0000000>;3^P000=no^@8000001]o0^@0000000>o8Z`000>W0Z`8000001^_2Z`00
00000?3:Z`000>6eZ@8000000n>hZP000?WLZ@03000000Gfe:/000000000003R]JP00P000003j;fY
0000klNY008000001>o7Z@0000000>[0Z@8000001>FiZ@0000000>6cZ0<000001>BgY`0000000>Fh
Y`<000001>BfY`0000000:G3k`<00002YL?_0`000003YL?_00000000008000001JG3k`0000000000
0:G3k`0400000ZG3k`040000YL?_000000000jG3k`<000000jG3k`0000000002000000FU`nl00000
0000002U`nl010000005YL?_000000000000YL?_00@00002YL?_00@0002U`nl000000003YL?_0`00
0003YL?_00000000008000001JG3k`00000000000:G3k`04000000FU`nl000000000002U`nl01000
00:U`nl010000:G3k`00000000>U`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_
00@000001JG3k`00000000000:G3k`0400000ZG3k`040000YL?_000000000jG3k`<000000jG3k`00
00000002000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00@000000jG3k`00
0000000doooo00<0003oooooool02oooo`006Oooo`030000oooooooo00coool30000Ioooo`D00000
1=Bg_0000=Nk_P0000;Qa[h2000000GWd;l0003I_kl0003Sc/800P000003BfW@0000000000;9/lD2
00000l>X_`030000_j:l_j:l00800003_IVc00T0002nV[<0003To<`00037ZK/0003Nd/d000000]Zn
_P8000001^C>`@00000000000<NS]00000;aj<800`000<RT]@000007000000C;b=L0000000000003
YZ;B0P000003]:gB0000c>?X00800002^jo>0`000003/j;70000X;?V00<0000019jmkP0000000=no
^@8000001Mno^@000>73^P000=o0^@03000000?Y`:/0003^b:/00P000003ikf[0000000000;Q]JT3
000000?ig:T0003]aZ/00`000004iKZZ00000000h[FX0P000003j;fY0000klNY00<000001?7;Z@00
00000>o7Z@8000000ng4Z@0000000002l<RY0P000004mLjV00000000klFW0P000005i;JW00000000
0000YL?_00@000001JG3k`00000000000:G3k`04000000BU`nl0000000000005YL?_0`000003YL?_
00000000008000001JG3k`00000000000:G3k`04000000FU`nl000000000002U`nl010000004YL?_
0000000000001JG3k`<000000jG3k`0000000002000000FU`nl000000000002U`nl010000005YL?_
000000000000YL?_00@000001:G3k`000000000000FU`nl3000000>U`nl0000000000P000005YL?_
000000000000YL?_00@000001JG3k`00000000000:G3k`04000000BU`nl0000000000005YL?_0`00
0003YL?_00000000008000001JG3k`00000000000:G3k`04000000FU`nl000000000002U`nl01000
0004YL?_0000000000001JG3k`80000doooo00<0003oooooool02oooo`006Oooo`030000oooooooo
00Woool30000Joooo`<0000015n?j0000000000000;Qa[h2000000GWd;l0003I_kl0003Sc/800P00
0004d[W100000000BfW@0`0000?3Z;l010000;nR_;nR_;nR_0800002_IVc0P000003_YZc00000000
00;7ZK/2000000CD_lD00000003G^K`2000000S?[[P000000037Xk@0003aj<800038Y;D2000000?=
Z[L0002CZND00P000007YMOi000000000000_k;=0000YZ;B008000001KB]dP0000000;kAj@000002
^jo>0`0000>cX/L2000000FN_Nh000000000002O`>l00P000003h/>j0000gkni008000000mo0^@00
0>?5^P02000000CY`:/00000003[`Z/2000000?`bZ/0003Q]JT00P000003hkRZ0000nMbY00<00000
1?KDZ`0000000?OGZP<000001NRmZ@000>o7Z@000?39Z@03000000CZ`:T00000003U^JT2000000GQ
/jP0003`b:T0003S]ZP00P000004iKRW00000000kL:W0`000004hK:V00000000YL?_10000004YL?_
0000000000000jG3k`800002YL?_00<0002U`nl000000`000005YL?_000000000000YL?_00@00000
1JG3k`00000000000:G3k`04000000BU`nl0000000000003YL?_0P0000:U`nl00`000:G3k`000003
000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00@000001:G3k`0000000000
00>U`nl200000ZG3k`030000YL?_000000<000001JG3k`00000000000:G3k`04000000FU`nl00000
0000002U`nl010000004YL?_0000000000000jG3k`800002YL?_00<0002U`nl000000`000005YL?_
000000000000YL?_00@000001JG3k`00000000000:G3k`04000000BU`nl0000000000003YL?_0P00
00:U`nl00`000:G3k`000003000000>U`nl000000000<oooo`030000oooooooo00_oool001Woool0
0`000?ooooooo`07oooo0P0006ooool4000000OG^kh0003Qa[h0003D][/0003Wd;l00P000003hlk2
0000000000;B^L4500000/>X_`800003_j:l00<0002mW[VmW[T00`000003_YZc0000000000;7ZK/2
00000]Boa@040000dKW30000i<k10`000004aj>d0000lNS200000/RT]@8000000lfZ]`0000000009
00000[B]dP050000_]7Y00000000/j;700@00002/j;70P000004a_WZ00000000Wl3_0`000006VL;d
00000000gkni0000hL>j0P000003hlFj0000h<6i008000001>k8Z`0000000>NmZ`800002hKFY0P00
0004hkRZ00000000kLJ[0`000004iKZZ00000000hKFY0P000003j;fY0000klNY008000001no7Z@00
000000000>o7Z@000>FiZ@02000000GQ/jP0003`b:T0003S]ZP00P000005iKRW000000000000i;JW
008000001>6bYP000000000000>U`nl200000ZG3k`040000YL?_000000000jG3k`<000000jG3k`00
00000002000000FU`nl000000000002U`nl010000004YL?_0000000000000jG3k`800002YL?_00@0
002U`nl000000003YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`04000000BU
`nl0000000000003YL?_0P0000:U`nl010000:G3k`00000000>U`nl3000000>U`nl0000000000P00
0005YL?_000000000000YL?_00@000001:G3k`000000000000>U`nl200000ZG3k`040000YL?_0000
00000jG3k`<000000jG3k`0000000002000000FU`nl000000000002U`nl010000004YL?_00000000
00000jG3k`800002YL?_00@0002U`nl000000003YL?_0`000003YL?_00000000008000000jG3k`00
0000000coooo00<0003oooooool02_ooo`006?ooo`030000oooooooo00Goool30000L_ooo`@00002
hLJn0P000003im2o0000fKno008000001N3Bb@000=:i`@000>COd003000000AHPn40000000000003
_j:l00@0002mW[VmW[VmW[T4000000?To<`00037ZK/00P0000;D_lD01P000=6i``000=kBc@000<n^
^08000001LNS]0000?7X`P000<RT]@02000000K=Z[L00000003E]KT0002GY]l;000000FcX/L00000
002nn^X000000k>Ra`050000a_WZ00000000[Y[20080000019W2m0000000000000:I]n`3000000KO
`;T00000003P`KT0003UbK/2000000?[`Z/0003W_J/00P000003hKFY0000m]F[008000001OWLZ@00
000000000?KDZ`02000000?gejX0003Q]JT00`0000;_ajT3000000OabjT000000000003U^JT0003]
a:T00P000005l<RY0000hkJX0000m=2X008000001>o5Y`0000000>BfY`@000000nNkY`000:G3k`02
00000jG3k`<000000jG3k`0000000002000000FU`nl000000000002U`nl010000005YL?_00000000
0000YL?_00@00002YL?_00@0002U`nl000000003YL?_0`000003YL?_00000000008000001JG3k`00
000000000:G3k`04000000FU`nl000000000002U`nl0100000:U`nl010000:G3k`00000000>U`nl3
000000>U`nl0000000000P000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`04
00000ZG3k`040000YL?_000000000jG3k`<000000jG3k`0000000002000000FU`nl000000000002U
`nl010000005YL?_000000000000YL?_00@00002YL?_00@0002U`nl000000003YL?_0`000003YL?_
00000000008000001JG3k`00000000000:G3k`060000<oooo`030000oooooooo00[oool001Soool0
0`000?ooooooo`02oooo0`0007Ooool4000000KD][/00000003I_kl0003Sc/82000000GB^L40003T
gm000036Z[d01@0000:oX[`300000[fN^@8000003kfM^000000000000<NY^`000=kBc@000=Boa@00
0=6i``000=kBc@000<V/_@02000000G7Xk@0003aj<800038Y;D00P0000;=Z[L2000000?E]KT00000
00000P0000:GX]`500000[>Ra`050000__[Z00000000/Ig300D000001:jJ`P0000000=3`j0800003
VKO/0`000004hL>j00000000hlFj0P000003iLVk0000hL:i008000001NNmZ`000?3:Z`000>6eZ@02
000000CS^:X00000003]aZ/3000000CU^ZX00000003Q]JT2000000GW_J/0003_ajT0003`bJT00`00
0004j/2Y00000000iKVY0P000005hK>X0000l<RY0000hkJX008000001>BhZ00000000>g2Y`<00000
1>6bYP0000000>NkY`8000000jG3k`0000000002000000FU`nl000000000002U`nl010000005YL?_
000000000000YL?_00@000001:G3k`000000000000FU`nl3000000>U`nl0000000000P000005YL?_
000000000000YL?_00@000001JG3k`00000000000:G3k`04000000BU`nl0000000000005YL?_0`00
0003YL?_00000000008000001JG3k`00000000000:G3k`04000000FU`nl000000000002U`nl01000
0004YL?_0000000000001JG3k`<000000jG3k`0000000002000000FU`nl000000000002U`nl01000
0005YL?_000000000000YL?_00@000001:G3k`000000000000FU`nl3000000>U`nl0000000001P00
0003YL?_0000000000X000000jG3k`000000000boooo00<0003oooooool02_ooo`006?ooo`030000
oooo00000080001koooo10000004im2o00000000hlk20P000007d[W10000i=o@0000aZZm0000i^??
00<000001EVIl00000000=7oe0000002_Iji0P000005_Ifh0000gOOL0000aZg100<00002e;o50P00
0003g];=0000bJbm00<000000lNS]00000000002b:Be0P000004cJZg00000000eKFi0P000003f;Rj
0000Uj;L00800002VmOl1`0000>aWL<300000ZjJ`P050000d?3X00000000]jK800@000001IJhk`00
000000000=o0^@02000000CP`KT00000003Q`[T3000000?W_J/0000000000^6eZ@8000000n>hZP00
00000002000000Kfe:/00000003gejX0003Q]JT2000000?W_J/0000000000P000005klNY00000000
0000klNY008000001Ng4Z@000>6cZ0000?38Z@02000000?dd:P0003T^:P00`000004i;JW00000000
hK:V1P000003YL?_00000000008000001JG3k`00000000000:G3k`04000000BU`nl0000000000003
YL?_0P0000:U`nl00`000:G3k`000003000000FU`nl000000000002U`nl010000005YL?_00000000
0000YL?_00@000001:G3k`000000000000>U`nl200000ZG3k`030000YL?_000000<000001JG3k`00
000000000:G3k`04000000FU`nl000000000002U`nl010000004YL?_0000000000000jG3k`800002
YL?_00<0002U`nl000000`000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`04
000000BU`nl0000000000003YL?_0P000004YL?_0000YL?_YL?_30000003YL?_0000000000H00000
1:G3k`000000000000>U`nl2000000>U`nl000000000<Oooo`030000oooooooo00[oool001Soool2
0000Ooooo`@000001=Vo_`000000000000;B^L4200000/JZ_@8000000lN[_0000000000400000[fN
^@060000_Ifh_Ifh0000gOOL00000/J]`@800002e;o500D0003A^L<000000039[;d00P0000;2XKL0
10000?7X`P000<RT]@8000000lfZ]`0000000002eKFi0P000003f;Rj0000000000T00003/Ig30`00
0003/Ic20000000000<00002]jK800<0003Agn<000000`000005VJcT000000000000hlFj00800000
1>G9^`0000000>G9^`<000000o3:Z`000>6eZ@02000000?S^:X0003ig:T010000003iKZZ0000mmNZ
00<000001>NmZ`000>k8Znk8Z`<000001O7;Z@00000000000>FiZ@02000000GQ/jP0003`b:T0003S
]ZP00P000003i;RX0000k/JY008000000nBfY`0000000002000000?W^jL0000000000`000003YL?_
00000000008000001JG3k`00000000000:G3k`0400000ZG3k`040000YL?_000000000jG3k`<00000
0jG3k`0000000002000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00@00002
YL?_00@0002U`nl000000003YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`04
000000FU`nl000000000002U`nl0100000:U`nl010000:G3k`00000000>U`nl3000000>U`nl00000
00000P000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`04000000>U`nl0002U
`nl00`0000:U`nl8000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00@00002
YL?_00@0002U`nl000000003YL?_0P00037oool00`000?ooooooo`0:oooo000Ioooo00<0003ooooo
ool0O_ooo`D000000n3Bb@000=:i`@0200000/JZ_@8000000lN[_0000>KTc`04000000=YU>P00000
00000[fM^0030000gOOL000000;6[L42000000C@`/d00000003A^L<2000000?9[;d0000000000l:Q
]`8000000lRT]@0000000002cJZg0P000004eKFi00000000f;Rj0P000003d[2g0000U9gJ00800000
0j?Fn@000000000600000k6L`P<00002]jK80P000003dMoS0000a<CJ00@000001IZfk00000000000
0>31^@02000000CQ`[T00000003Sa[X300000^6eZ@8000001>>hZP0000000>g6Z`@000000oOGZP00
0>6eZ@02000000GW_J/0003^b:/0003`bZ/00`000004j/2Y00000000iKVY0P000005hK>X0000l<RY
0000hkJX008000001>BhZ00000000>c3Z@<000001>6bYP0000000>NkY`H000000jG3k`0000000002
00000ZG3k`800005YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`04000000FU
`nl000000000002U`nl010000004YL?_0000000000001JG3k`<000000jG3k`0000000002000000FU
`nl000000000002U`nl010000005YL?_000000000000YL?_00@000001:G3k`000000000000FU`nl3
000000>U`nl0000000000P000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`08
00001:G3k`<000000jG3k`0000000002000000FU`nl000000000002U`nl010000005YL?_00000000
0000YL?_00@000001:G3k`000000000000FU`nl3000000>U`nl0000000000P000003YL?_00000000
033oool00`000?ooooooo`0:oooo0004oooo0`0000?oool00`000?ooooooo`02oooo00<0003ooooo
ool02?ooo`80001ooooo1@000003d[W10000000000;6Z[d200000/N[_0040000i^C?0000c[K21@00
00:mWKP200000/J]`@800002d<;=00@0003A^L<000000002bJbm0P0000;2XKL2000000G2X;L00000
0000003=Z[L00P000003eKFi0000000000;H^;X2000000?B/;L0000000002@0000BaW<83000000Bd
X<@00000003Agn<2000000?4a=X00034c>4010000005WKKY000000000000iLVk008000001>G9^`00
00000>;4^P800002hKFY0`000005nMbY000000000000m]B[008000000oOGZP000>6eZ@0300000^k8
Z`8000001Nk8Z`00000000000>o7Z@02000000K]a:T00000003`b:T0003S]ZP2000000?T^:P0003^
aZT00P000004h[JX00000000hK:V10000003lLRW0000000000<00004YL?_0P000003YL?_0000YL?_
00@000001JG3k`00000000000:G3k`04000000FU`nl000000000002U`nl010000004YL?_00000000
00000jG3k`800002YL?_00<0002U`nl000000`000005YL?_000000000000YL?_00@000001JG3k`00
000000000:G3k`04000000BU`nl0000000000003YL?_0P0000:U`nl00`000:G3k`000003000000FU
`nl000000000002U`nl010000005YL?_000000000000YL?_00P00002YL?_0P0000:U`nl00`000:G3
k`000003000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00@000001:G3k`00
0000000000>U`nl200000ZG3k`030000YL?_000000<000001JG3k`00000000000:G3k`04000000>U
`nl000000000;oooo`030000oooooooo00[oool000Coool00`000?ooooooo`02oooo00<0003oool0
00000_ooo`030000oooo000000_oool00`000?ooooooo`1moooo1P0000;6Z[d02P000>KSc`000<N[
_0000>KTc`000<jf`P000>;Te@<0000017N;fP000000000000;6[L4200000]32c@040000cK_:0000
00000/V/_@800002`Z6g0P0000;2X;L2000000?=Z[L0000000000]Fe^@8000001=Rh^P0000000=:`
]`8000000lVU]00008fJf`02000000>]f?H0000000000P0000:aW<8300000kBPa0040000dMoS0000
a<CJ0P000003a<cQ0000`]3U00@000001IS8n000000000000>72^@02000000CSa[X00000003Tak/4
000000CS^:X00000003]aZ/3000000?U^ZX0003gejX00`000005ikf[0000k/R[0000l<Z[00800000
1O7<Z`00000000000>FiZ@02000000GQ/jP0003`b:T0003S]ZP00P000006i;RX00000000k<>Y0000
h[JX10000005ik^W000000000000klJW00@00002YL?_0P0000:U`nl3000000>U`nl0000000000P00
0005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`0400000ZG3k`040000YL?_0000
00000jG3k`<000000jG3k`0000000002000000FU`nl000000000002U`nl010000005YL?_00000000
0000YL?_00@00002YL?_00@0002U`nl000000003YL?_0`000003YL?_00000000008000001JG3k`00
000000000:G3k`04000000FU`nl000000000002U`nl00`0000:U`nl010000:G3k`00000000>U`nl3
000000>U`nl0000000000P000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`04
00000ZG3k`040000YL?_000000000jG3k`<000000jG3k`0000000002000000FU`nl000000000002U
`nl010000003YL?_0000000002koool00`000?ooooooo`0:oooo0005oooo00L0003oooooooooool0
003oool000000_ooo`030000oooo000000coool00`000?ooooooo`1moooo0`00009oVN803`000<JZ
_@0000000<N[_0000>KTc`000<jf`P000>;Te@000<o0c00007VDh@0300000/J]`@800002d<;=00D0
003=^lX000000035[<400`0000;2XKL200000/:P]`8000001LNX^`00000000000=Fe^@02000000?H
^;X0000000000]:`]`030000bJFdbJFd00@00002[MSf1`0000:dX<@2000000G6bmh00034a=X00034
c>4010000003]k;D00000000008000001IO8n000000000000>G9^`02000000CRa;X00000003N_[P3
000000?S^:X0000000000P000006m]B[00000000mmNZ0000hKFY0P000003ikf[0000k/R[00800000
1>k8Z`0000000>W1Z`8000001>FiZ@0000000>6cZ08000001^>fZ00000000>BhZ0000>k6Z@800000
1>:fZ00000000=nbZ08000000nNkY`0000000003000000?T]jL0000000000P000005YL?_00000000
0000YL?_00<00002YL?_0`000005YL?_000000000000YL?_00@00002YL?_0P0000FU`nl3000000>U
`nl0000000000P000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`04000000BU
`nl0000000000005YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`04000000FU
`nl000000000002U`nl010000004YL?_0000000000001:G3k`<000000jG3k`0000000002000000FU
`nl000000000002U`nl010000005YL?_000000000000YL?_00@000001:G3k`000000000000FU`nl3
000000>U`nl0000000000P000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`04
000000>U`nl000000000;_ooo`030000oooooooo00Woool000Goool01`000?ooooooooooo`000?oo
o`000002oooo00<0003oool000003Oooo`030000oooooooo07goool7000000S7Zk`0003Vi<l0003>
]/80003Ri=D00002cl3<0`00009iU>43000000C@`/d00000003=^lX200000/F/`@800003`Z6g00<0
0032X;O2X;L00P0000;7Z;/2000000?E]KT0000000000]Rh^P8000001=:`]`0000000<VU]0800000
0l6K/@00086Kh`03000000AGF[T0000000000003]:3400L00036bmh000000031/ld00034c>400`00
00:g/]@00`000<G<h0000003000000FD^_4000000000003Sa[X00P000006i<Nk00000000iLVk0000
f[Rg0P000009kLJ[000000000000iKZZ0000mmNZ0000hKFY00<000000nk8Z`000?3:Z`02000000Ca
c:/00000003^aj/2000000K]a:T00000003`b:T0003S]ZP2000000KT^:P00000003/`jT0003R]ZP2
000000?O/ZP0000000000P000005lLRW000000000000i;NW00D000001:G3k`000000000000:U`nl3
000000FU`nl000000000002U`nl00`0000BU`nl2000000>U`nl0002U`nl010000005YL?_00000000
0000YL?_00@000001JG3k`00000000000:G3k`04000000BU`nl0000000000003YL?_0P0000:U`nl0
0`000:G3k`000003000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00@00000
1:G3k`000000000000>U`nl2000000>U`nl0002U`nl010000005YL?_000000000000YL?_00@00000
1JG3k`00000000000:G3k`04000000BU`nl0000000000003YL?_0P0000:U`nl00`000:G3k`000003
000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00@000001:G3k`0000000000
00>U`nl2000000>U`nl000000000;Oooo`030000oooooooo00Woool000Coool00`000?ooo`000002
oooo00<0003oool000000_ooo`030000oooo000000koool20000O_ooo`@00002OYcU0`0000;>]/82
00000/o0c0030000e=?G000000D000000m32c@000<fkbP0300000/F/`@<00002`Z6g00<00032X;O2
X;L00P0000;7Z;/2000000G>]<4000000000003H^;X00P000003d[2g0000000000;9YK@00`000<6K
/L6K/@04000000>[eoH0001GF[T01@000006a/_N0000`K?=`K?=0000clkI0P0000:g/]@2000000?5
c>00002m/m0010000005U/?f000000000000h/Bj008000001=jn^00000000=Zh]`D000001_KDZ`00
00000?OGZP000>6eZ@8000000nNmZ`000>k8Z`02000000C^b:/00000003Y`J/2000000KT^JX00000
003Q/jP0003`b:T2000000Kdd:P00000003^aZT0003/`jT2000000GfdjP000000000003V^jT00`00
0003klJW00000000008000000nJiY`0000000002000000>U`nl0000000000P000005YL?_00000000
0000YL?_00<00002YL?_00<0002U`nnU`nl00P0000:U`nl3000000>U`nl0000000000P000005YL?_
000000000000YL?_00@000001JG3k`00000000000:G3k`0400000ZG3k`040000YL?_000000000jG3
k`<000000jG3k`0000000002000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_
00@00002YL?_00@0002U`nl000000002YL?_0`000003YL?_00000000008000001JG3k`0000000000
0:G3k`04000000FU`nl000000000002U`nl0100000:U`nl010000:G3k`00000000>U`nl3000000>U
`nl0000000000P000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`0400000ZG3
k`040000YL?_000000000jG3k`80000]oooo00<0003oooooool02Oooo`001Oooo`030000oooooooo
00;oool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo07goool600000/jf
`P800002cl3<00@0003DdmL00038_<l6000000C=^lX0003Dc]<00002aJc10P0000;1Y;`200000l:P
]`8000000lNX^`0000000002c[C10P000003f;Rj0000000000;B/;L00`000<VU]<VU]002000000C1
Vk400000002mU[08000000?6bmh0000000000/6cc@@000001<o=f00000000<G<h08000001;fcd000
00000<oTiP<000001IVdjP00000000000>C7^`02000000KUbK/00000003Xc[`0003H][H3000000GU
^ZX0003gejX0003Q]JT00P000004ikf[00000000l<Z[0P000006lLb[00000000k/N[0000i;VZ0P00
0004hK>X00000000hkJX0P000006i;RX00000000k<>Y0000h[JX0P000004gk:X00000000i[^Y1@00
0004i;NW00000000i[VW1@000003YL?_00000000008000001:G3k`000000000000FU`nl3000000FU
`nl000000000002U`nl00`000003YL?_00000000008000001JG3k`00000000000:G3k`04000000BU
`nl0000000000005YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`04000000FU
`nl000000000002U`nl010000004YL?_0000000000001JG3k`<000001JG3k`00000000000:G3k`03
000000>U`nl0000000000P000005YL?_000000000000YL?_00@000001:G3k`000000000000FU`nl3
000000>U`nl0000000000P000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`04
000000BU`nl0000000000005YL?_0`000003YL?_0000000000@0000]oooo00<0003oooooool02Ooo
o`008_ooo`030000oooooooo07goool300000W^PjP<000002<o0c00000000=CCe`000<Rlc`000<c0
c`H000001=C>d`000<F/`LF/`@800003`JBl0P0000;2X;L2000000?7Z;/0000000000/jd`@800000
1]2h`P00000000000=:`]`0000;9YK@200000/6K/@040000_IJ`0000i?RX0`000003YM;g00000000
00800002`K?=0`000007cL_G0000clgHclgH0000aLcP000000:m/m001@000<oTiP0000000;b_c@03
000000FM/NH000000000003N_[P00P000006f[Rg00000000f;Jf0000j]:l0`0000;gejX3000000?W
_J/0003^b:/00P000004k/R[00000000jL6[0P000003i;VZ0000k<B[008000000o38Z@000>>fZ002
000000KT^:P00000003/`jT0003R]ZP2000000?O/ZP0000000000P000005l<VY000000000000i;NW
00<000000oK@YP0000000003000000>U`nl0000000000P0000:U`nl00`000:G3k`000003000000FU
`nl000000000002U`nl00`000004YL?_0000000000000ZG3k`<000001JG3k`00000000000:G3k`04
00000ZG3k`030000YL?_000000<000001JG3k`00000000000:G3k`04000000FU`nl000000000002U
`nl010000005YL?_000000000000YL?_00@00002YL?_00<0002U`nl000000`000003YL?_00000000
00D000001JG3k`00000000000:G3k`04000000FU`nl000000000002U`nl0100000:U`nl00`000:G3
k`000003000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00@000001JG3k`00
000000000:G3k`0400000ZG3k`030000YL?_000000/000000jG3k`000000000/oooo00<0003ooooo
ool02Oooo`008oooo`030000oooooooo07goool6000000??`<`0003DdmL00P000003b;c?0000c<3?
008000000lJ_``000000000300000/F/`@800003`JBl00<00032Ykk2Ykh00`0000;7Z;/2000000?>
]<40000000000]2h`P8000000m:`]`0000000002bJFd00<00031Vk71Vk400P000004_IJ`00000000
`Yfc3@000006clgH00000000cnoY0000_K?@0P000003cnCV0000_:o=008000001L[ji`0000000000
0::nk@03000000CUbK/00000003Xc[`2000000?Zd[`0003I]kH00P000003mmNZ0000hKFY00800000
0nNmZ`000>k8Z`03000000Kac:/00000003^aj/0003T^JX2000000CO/jT00000003S]ZP2000000GT
^:P0003^aZT0003/`jT00P000005m]>X000000000000i[^Y00<000000no7Z@0000000002000000CV
^JL00000003_aJL500001JG3k`<000000jG3k`0000000002000000FU`nl000000000002U`nl00`00
00:U`nl3000000BU`nl0000000000002YL?_0P0000FU`nl3000000>U`nl0000000000P000005YL?_
000000000000YL?_00@000001JG3k`00000000000:G3k`04000000BU`nl0000000000005YL?_0`00
0003YL?_0000000000D000000jG3k`0000000002000000FU`nl000000000002U`nl010000004YL?_
0000000000001JG3k`<000000jG3k`0000000002000000FU`nl000000000002U`nl010000005YL?_
000000000000YL?_00@000001:G3k`000000000000FU`nl7000000FU`nl000000000002U`nl01000
0003YL?_0000000002_oool00`000?ooooooo`09oooo000Toooo00<0003oooooool0OOooo`H00000
0mCCe`000<Rlc`02000000K<`<l000000036[l<0003GbL`3000000AFY?H0000000000003`JBl00@0
0032Ykk2Ykk2Ykh200000/NX^`8000000ljd`@0000000002d;S20P000003bZjn0000000000;9YK@0
0`000<6K/L6K/@02000000JmU[0000000032WK<0003ak<48000000K=bmL0003?cMS?cMP0003?knT2
000000>m]]<0003?i>H00P000003_:o=0000b_[W008000001K>Wc0000000000009ndi`03000000CJ
^;L00000003H][H2000000?I]kH0003[e;d00`000007hKFY000000000000k/R[0000l<Z[00<00000
0nW1Z`000>k7Z`02000000?/a:/0003O/jT00P000004hkJX00000000i;RX0P000003k<>Y0000h[JX
008000000mnbZ00000000002000000G`bJT000000000003S]jP00P000003i[VW0000000000800000
1O78Y`00000000000:G3k`04000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_
00@000001:G3k`000000000000>U`nl2000000>U`nl0002U`nl010000005YL?_000000000000YL?_
00@000001JG3k`00000000000:G3k`04000000BU`nl0000000000003YL?_0P0000:U`nl00`000:G3
k`000003000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00@000001:G3k`00
0000000000>U`nl200000ZG3k`030000YL?_000000<000001JG3k`00000000000:G3k`04000000FU
`nl000000000002U`nl010000004YL?_0000000000000jG3k`8000001:G3k`000:G3kjG3k`L00000
0jG3k`0000000002000000FU`nl000000000002U`nl010000003YL?_0000000002[oool00`000?oo
ooooo`09oooo000Uoooo0P0007koool6000000?8_<l0003<`<l00`000005aZo30000elW<0000aJNk
00D00002`JBl0`0000;2Ykh2000000W5[/<000000000003>]<40003Lcl/0003@^<800P0000;:[[h2
000000?9YK@0000000000/6K/@030000_IJ`_IJ`008000001<:M/`0000000<n_^PP000000lo=f000
00000002000000>m]]<0000000000P000003_:o=00000000008000001;>Wc00000000<S_kP<00002
Y:[K0P000004j<jl00000000j]:l0P000003jmBm0000fkVg00@000000nNmZ`000>k8Z`02000000O^
b:/000000000003^aj/0003T^JX00P000003gk>Y0000klV[00<000001nBhZ0000>k6Z@000>c3Z@00
0>:fZ002000000?O/ZP0000000000`000004klNY00000000hkNX0`000003m]2V0000000000<00000
1>^oY`0000000:G3k`@000001JG3k`00000000000:G3k`04000000FU`nl000000000002U`nl01000
00:U`nl010000:G3k`00000000:U`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_
00@000001JG3k`00000000000:G3k`0400000ZG3k`040000YL?_000000000jG3k`<000000jG3k`00
00000002000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00@00002YL?_00@0
002U`nl000000003YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`04000000FU
`nl000000000002U`nl0100000:U`nl010000:G3k`00000000:U`nl8000000FU`nl000000000002U
`nl010000005YL?_000000000000YL?_00@000000jG3k`000000000Yoooo00<0003oooooool02Ooo
o`009oooo`030000oooooooo07coool6000000_<`<l00039^ld00036[l<0003GbL`00035Yk/0003V
gL/00`000005>9Ob00000000gO;M000000;2Ykh200000/F^``8000001Ljd`@000=c?b`000=2h`P02
00000/Z^_P030000`Ijf`Ijf00800002`I^a00<0002mU[2mU[000P000006`Yfc00000000cjnj0000
g/Bo2P0000:m]]<300000ZjMa`<00002/jO<00L00038knh00000002h_Mh0002TZ]/01@000004f;Jf
00000000fKNf0P000004fkVg00000000g;^h0P000004ikf[00000000l<Z[0P000006lLb[00000000
k/N[0000i;VZ0P000004gk>Y00000000h[JZ0P000006i;RX00000000k<>Y0000h[JX0P000004gk:X
00000000i[^Y1@000004hkNX00000000iKVY0P000003klFW00000000008000001N^oY`0000000000
0:G3k`04000000FU`nl000000000002U`nl010000004YL?_0000000000001JG3k`<000001JG3k`00
000000000:G3k`03000000>U`nl0000000000P000005YL?_000000000000YL?_00@000001:G3k`00
0000000000FU`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_00@000001JG3k`00
000000000:G3k`03000000BU`nl0000000000005YL?_0`000003YL?_00000000008000001JG3k`00
000000000:G3k`04000000FU`nl000000000002U`nl010000004YL?_0000000000001JG3k`L00000
1JG3k`00000000000:G3k`04000000FU`nl000000000002U`nl010000004YL?_0000000000001JG3
k`80000Zoooo00<0003oooooool02?ooo`00:?ooo`030000oooooooo07coool6000000K9^ld00036
[l<0003GbL`00002aJNk0P000003aZNj0000000000@00002`ZNn0P0000;5[/<2000000[7/lL0003L
cl/0003@^<80003Pelh0003:[[h00003`Ijf0P000004`I^a00000000_IJ`0P000003`Yfc0000lNc1
008000000mk4_`000>38`00;00000jjMa`<000000jnNaP000000000300000[RmgPD00002Y:cM0P00
0004j]:l00000000jmBm0P000003jm>l0000g;^h00<000001>k8Z`0000000>k8Z`8000000nW1Z`00
0>k7Z`02000000K/a:/00000003_bJ/0003R]ZX3000000G^aZT0003/`jT0003R]ZP00P000003gk:X
00000000008000001O39Z@00000000000>>gZ002000000?U^JT0000000000P000005lLRW00000000
0000k/BW00<000000jG3k`0000000002000000FU`nl000000000002U`nl0100000:U`nl00`000:G3
k`000003000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00@000001JG3k`00
000000000:G3k`0400000ZG3k`030000YL?_000000<000001JG3k`00000000000:G3k`04000000FU
`nl000000000002U`nl010000005YL?_000000000000YL?_00<00002YL?_00<0002U`nl000000`00
0005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`04000000FU`nl000000000002U
`nl0100000:U`nl00`000:G3k`000006000000>U`nl0000000000P000005YL?_000000000000YL?_
00@000001JG3k`00000000000:G3k`0400000ZG3k`030000YL?_000000<000000jG3k`000000000Y
oooo00<0003oooooool02?ooo`00:Oooo`030000oooooooo07coool6000000K6[l<0003GbLcGbL`0
0035Yk/2000000?6YkX0003Xg/T010000004;Xo_0000000000000/F^``8000002LNca`000=C@e@00
0=2h`P000>3GcP000<Z^_P0200000/6N]P8000000kbG/P0000000002_IJ`00<00032WK?2WK<00P00
0006cjnj00000000h<S00000d[:j0`0000:A[^X3000000>NPkH0002^WLL00`0000>_W/H3000000>h
_Mh0000000000`000003^L3O0000Y:cM00D000001=Vg]P0000000=^i]`8000001=bk^00000000=fl
^08000001?3:Z`0000000?7<Z`8000000nk7Z`000>BiZP02000000CO/jT00000003R]ZX2000000?S
^:X0000000000^c3Z@8000001OKCZ000000000000>JkZ@03000000G_ajT000000000003edJP00P00
0003mM6X0000000000<000001>^oY`0000000>RlY`<000000jG3k`0000000002000000BU`nl00000
00000005YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`03000000FU`nl00000
0000002U`nl0100000:U`nl200001JG3k`<000000jG3k`0000000002000000FU`nl000000000002U
`nl010000005YL?_000000000000YL?_00@000001:G3k`000000000000BU`nl3000000>U`nl00000
00000P000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`04000000BU`nl00000
00000005YL?_1`000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`04000000BU
`nl0000000000005YL?_0`000003YL?_00000000008000000jG3k`000000000Xoooo00<0003ooooo
ool02?ooo`00:_ooo`80001moooo1P0000;GbL`010000<FW^`00000000;6YkX2000000?;[[`0003K
a<<0100000;5[/<2000000W7/lL0003Dd=D00037/lL0003Pelh0003:[[h00P0000;1W[H200000[bG
/P8000001;fF/00000000<:M/`8000000ln_^P000=k4_`02000000?B/[X0003Xdl402`0000>_W/H3
000000Bl`]l00000002ea>H200000[W0g`D000001Ic1lP00000000000>_D_@02000000K[dk`00000
003Wc;/0003M_;P3000000S^b:/00000003Y`J/0003^aj/0003T^JX2000000CO/jT00000003R]ZX2
000000KS^:X00000003/`jT0003R]ZP2000000CO/ZP00000003V^jT5000000CS]jP00000003U^JT2
000000?^aZT0000000000P000005jknW000000000000iKRW00<00003YL?_0P0000:U`nl00`000:G3
k`000003000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00<000001:G3k`00
0000000000BU`nl2000000>U`nl0002U`nl010000005YL?_000000000000YL?_00@000001JG3k`00
000000000:G3k`04000000BU`nl0000000000003YL?_0P000003YL?_0000YL?_00@000001JG3k`00
000000000:G3k`04000000FU`nl000000000002U`nl010000004YL?_0000000000000jG3k`800002
YL?_00<0002U`nl000001P000003YL?_00000000008000001JG3k`00000000000:G3k`04000000BU
`nl0000000000003YL?_0P0000:U`nl00`000:G3k`000003000000FU`nl000000000002U`nl01P00
02Soool00`000?ooooooo`08oooo000/oooo00<0003oooooool0Noooo`L000001lFW^`000>KMb`00
0<JW^P000>SNb@02000000?Ka<<0003G_;l01P000009ak?70000e=3E0000ak?70000e<oD0000bZjn
00800002`Ijf0P0000:lUk800`000;ZE/KZE/@02000000[2WK<00000003?[kX0003Na;l0003Pb<00
003B/[X2000000C>[KP0000000000002V;7Y0P0000:OQ[P00`000:nNaP000002000000Bl`]l00000
002mbN@2000000>i`=l0000000000`000005^:_<000000000000Rkcg00<000001=^i]`0000000=bk
^08000000mfl^0000>C7^P03000000Sac:/00000003^aj/0003T^JX0003/a:/2000000O_bJ/00000
0000003S^:X0003^aZ/00`000004h[JX00000000gk:X10000005l<VY000000000000hkNX00<00000
1OGAZ000000000000?39Z@03000000C^a:L00000003U^:L3000000>U`nl0000000000jG3k`<00000
0jG3k`0000000002000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00<00002
YL?_00<0002U`nnU`nl00P0000:U`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_
00@000001JG3k`00000000000:G3k`0400000ZG3k`040000YL?_000000000ZG3k`<000000jG3k`00
00000002000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00@00002YL?_00@0
002U`nl000000003YL?_0`000005YL?_000000000000YL?_00<000000jG3k`0000000002000000FU
`nl000000000002U`nl0100000:U`nl010000:G3k`00000000>U`nl3000000>U`nl0000000000P00
0003YL?_0000000000D000000jG3k`000000000Woooo00<0003oooooool02?ooo`00;Oooo`030000
oooooooo07_oool300000gfOj@<000001LJW^P000>SNb@000<^^_002000000?G_;l0003C][d01000
00;7/lL2000000G7/lL0003Dcm@00038//D00P0000?1W[H010000;bG/[bG/P0000>jUK400`000;jK
]0000003000000GNa;l0003Pb<00003B/[X00P000003cZfh0000j]O100/000001;c2g`0000000;g9
i08000000k_Ym00000000002/kKK00D0002hZl`00000003>h>D00`000005VkCY000000000000jm>l
008000001^O<^`0000000>C7^P000=fm^0<000001NW1Z`000>k7Z`000>BiZP02000000CO/jT00000
003R]ZX2000000?S^:X0000000000^_3Z`8000001OKCZ000000000000>JkZ@03000000G_ajT00000
0000003edJP00`000003k/JY00000000008000001>[0Z@0000000>RlY`8000001Nk3Y`0000000000
0:G3k`04000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00@000001:G3k`00
0000000000FU`nl3000000FU`nl000000000002U`nl00`000003YL?_00000000008000001JG3k`00
000000000:G3k`04000000BU`nl0000000000005YL?_0`000005YL?_000000000000YL?_00<00000
0jG3k`0000000002000000FU`nl000000000002U`nl010000004YL?_0000000000001JG3k`<00000
0jG3k`0000000002000000>U`nl0000000001@000005YL?_000000000000YL?_00@000001:G3k`00
0000000000FU`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_00L000000jG3k`00
00000002000000>U`nl0000000009_ooo`030000oooooooo00Soool002koool00`000?ooooooo`1k
oooo1`0000;6YkX2000000?;[[`0003Ka<<00P000003dkJm0000h/Ro00H000001LNca`000=C?e000
0<Rba@0300000/6N]P8000000kbG/P0000000002^YFa00<0002nVkBnVk@00P00000:cjnj00000000
h<S00000d[:j0000j=?10000cZfh0P000005c:Zg000000000000X[_[00@000001:RE`P0000000;g9
i08000001;_Ym00000000:f/eP<000000kR[c0000<kPi@02000000FjZLT000000000002B^_800`00
0004g;^h00000000gKbh0P000003gKfh0000h/Bj00<00002k/N[0P000003k<B[0000gk>Y00800000
2N:fZP00000000000>k6Z`000>_3Z`000>6eZP02000000?O/ZP0000000000P000005l<VY00000000
0000hkNX008000000nFiZ@0000000002000000C`bJT00000003Z`:T3000000CU^:L00000003P/ZH3
000000>U`nl0000000000P000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`04
00000ZG3k`030000YL?_000000<000001JG3k`00000000000:G3k`03000000FU`nl000000000002U
`nl010000005YL?_000000000000YL?_00@00002YL?_00<0002U`nl000000`000005YL?_00000000
0000YL?_00<000001JG3k`00000000000:G3k`04000000FU`nl000000000002U`nl0100000:U`nl0
0`000:G3k`000003000000FU`nl000000000002U`nl01`000003YL?_00000000008000001JG3k`00
000000000:G3k`0400000ZG3k`030000YL?_000000<000001JG3k`00000000000:G3k`04000000>U
`nl0000000001@000005YL?_000000000000YL?_00@000000jG3k`000000000Uoooo00<0003ooooo
ool02?ooo`00;oooo`80001moooo0P00009kWNL02`000<JW^P0000000<^^_0000=_4``000=Nl_`00
0=>f_@0700000/Nca`8000000lRba@0000000002`JFl0`0000:lUk8010000;ZE/KZE/@0000:nVk@2
000000?:[Kd0003Na;l00P0000;B/[X2000000K>[KP00000003<Z[L0003/fl8;000000>kjO@00000
00000Zf/eP8000001[R[c00000000<kPi@000;ZYb@8000001LkiiP000000000009nTf003000000CW
c;/00000003TakX2000000?Ra;X0003N_[P00P000003k/N[0000i;VZ008000000mncZ@000>o9Z`03
000000?S^:X0000000000^_3Z`050000hKFZ00000000gk:X00D000001>o7Z@0000000>>gZ0<00000
0oGAZ00000000002000000Cbc:T00000003]a:T2000000CU^:L00000003P/ZH400000ZG3k`<00000
1JG3k`00000000000:G3k`04000000BU`nl0000000000005YL?_0`000003YL?_0000000000800000
1JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl010000004YL?_0000000000001JG3
k`<000000jG3k`0000000002000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_
00@000001:G3k`000000000000FU`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_
00<000001JG3k`00000000000:G3k`04000000BU`nl0000000000005YL?_0`000003YL?_00000000
008000001JG3k`00000000000:G3k`07000000>U`nl0000000000P000004YL?_0000000000001JG3
k`80000Voooo00<0003oooooool01oooo`00<Oooo`030000oooooooo07_oool3000000=kWNL00000
00000P000005flC30000ekbo0000dkJm008000000mJi_@000>C;_`06000000?8//D0000000000l6U
_0<000001;bG/P000;ZE/KZE/@800002_Y^d0`000005f<K80000h<S00000d[:j008000001Lj]^000
0>[G`@000<bZ]`02000000?=[;L0000000000ZK9lP<000001KjnfP00000000000:f/eP03000000Bc
gOD00000003>h>D2000000>jZLT0003>nNH00P000005]jW;000000000000W/gh00<000001=fl^000
00000=fm^08000000mjn^0000>73^P03000000CT^JX00000003O/jT2000000CR]ZX00000003S^:X2
000000G[`j/0003Q]JX0003fe:X00`000003i[^Y0000000000<000001>>gZ00000000>FiZ@800000
0nk6Z@0000000002000000CZ`:T00000003W_:T2000000C^`jL00000003gdZD5000000FU`nl00000
0000002U`nl00`000003YL?_0000000000800002YL?_00<0002U`nl000000`000005YL?_00000000
0000YL?_00@000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl0100000:U`nl0
0`000:G3k`000003000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00<00000
1JG3k`00000000000:G3k`0400000ZG3k`030000YL?_000000<000001JG3k`00000000000:G3k`04
000000>U`nl0000000001@000005YL?_000000000000YL?_00@00002YL?_00<0002U`nl000000`00
0005YL?_000000000000YL?_00@000000jG3k`0000000005000000FU`nl000000000002U`nl01000
00:U`nl00`000:G3k`000003000000>U`nl0000000009Oooo`030000oooooooo00Ooool003;oool0
0`000?ooooooo`1koooo1@000008bjjl00000000ekbo0000dkJm0000h/Ro0P000003i<^o00000000
00@00002b;;50P0000;1YK`2000000BjV[L0000000000002^YFa00<0002nVkBnVk@00P000006bZfm
00000000f/_:0000d[:j0P0000;>[KP2000000K<Z[L00000003=[;L0003Zf<85000000>Se_X00031
^M<00`000005/mge000000000000XZ;E008000000kZYb@0000000002000000BgZL/000000030mnh3
00000Z>XfP8000001>C7^P0000000>;4^P8000000n73^P000=o0^@03000000K/a:/00000003_bJ/0
003R]ZX3000000G^aZ/0003[`j/0003Q]JX00P000003g[6Y00000000008000001O39Z@0000000000
0>>gZ002000000?U^JT0000000000P000005l<VY000000000000kLBY008000001>BhZ@0000000>2b
YP8000001>2bYP0000000>BgY`8000001JG3k`00000000000:G3k`0300001JG3k`<000000jG3k`00
00000002000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00<000001:G3k`00
0000000000FU`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_00@000000jG3k`00
00000005000000BU`nl0000000000005YL?_0`000003YL?_00000000008000001JG3k`0000000000
0:G3k`07000000>U`nl0000000000P000004YL?_0000000000001JG3k`<000000jG3k`0000000002
000000FU`nl000000000002U`nl01`000003YL?_00000000008000001:G3k`000000000000FU`nl3
000000>U`nl0000000000P000003YL?_0000000002Coool00`000?ooooooo`07oooo000coooo00<0
003oooooool0Noooo`D000000m_4``0000000002dkJm0P000006e[Vm00000000g<K30000g<6o1P00
00;1YK`200000[ZJ]`030000^YVg^YVg00800002_Y^d0P000003bZfm0000f<K8008000001Lb`_`00
000000000<j]^002000000G<Z[L0003/fl80003=[;L02`000004^Zc;00000000XZ;E0`000003];cP
0000000000800002]jW;00L00030mnh00000002aX/P0002SZ=X00P000004Y/7]00000000gKfh0P00
0006g[jh00000000gl2i0000hlJj0`000004gk>Y00000000h[JZ0P00000:hkRZ00000000jl>[0000
hKFZ0000m]BZ0000g[6Y1@000005klNY000000000000mM6X008000000oGAZ00000000002000000Ob
c:T000000000003W_:T0003T^:T00P000004h;:V00000000h;:V0`000004jl2W00000000YL?_0`00
00:U`nl00`000:G3k`000003000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_
00@000001JG3k`00000000000:G3k`0300000ZG3k`030000YL?_000000<000001JG3k`0000000000
0:G3k`04000000FU`nl000000000002U`nl01`000003YL?_0000000000800002YL?_00<0002U`nl0
00000`000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`03000000FU`nl00000
0000002U`nl0100000:U`nl00`000:G3k`000003000000FU`nl000000000002U`nl010000003YL?_
0000000000D000001JG3k`00000000000:G3k`0400000ZG3k`030000YL?_000000<000001JG3k`00
000000000:G3k`04000000>U`nl0000000008oooo`030000oooooooo00Ooool003Coool20000O?oo
o`D000000mNl_`000=>f_@02000000?F^Kd0003Tbkl00P000003g<6o0000hmK:00@00002`JFl00D0
002jV[NjV[NjV[L000000kZI]`8000002[jK]00000000<Z]_@000=S6b0000=[;bP000<b`_`800000
0lj]^00000000002c:Zg0P000003cJbg00000000008000000mVk^`0009^Yh009000000>d_>000000
00000`000003/jO<0000000000<00003/J;80P000004Y/7]00000000Z;[W0P000004h/Bj00000000
hL>j0P000003hlJj0000gl2i008000001=ncZ@0000000>:fZP8000001^>hZP0000000>_3Z`000>6e
ZP8000001=jaZ@0000000>FkZ`D000001>>gZ00000000>FiZ@8000000nk6Z@0000000002000000CZ
`:T00000003W_:T2000000C]a:T00000003gdZD3000000CT]jL00000003^a:L200001:G3k`<00000
0jG3k`0000000002000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00@00000
1:G3k`000000000000BU`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_00@00000
1JG3k`00000000000:G3k`03000000BU`nl0000000000005YL?_0`000003YL?_0000000000800000
1JG3k`00000000000:G3k`04000000FU`nl000000000002U`nl00`000004YL?_0000000000001JG3
k`<000000jG3k`0000000002000000FU`nl000000000002U`nl01`000003YL?_0000000000800000
1:G3k`000000000000FU`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_00H0000S
oooo00<0003oooooool01oooo`00=_ooo`030000oooooooo07[oool5000000KC][d00000003F^Kd0
003Tbkl2000000GL`Kl0003Se/X0003?/K`01@0000>jV[L01@000;ZI]kZI]kZI]`000002_9fi1000
0005f<K80000f/_:0000c;2o008000001LR[_000000000000<bZ]`02000000?=[;L0003Zf<800`00
0003fK^k0000000000<000000iZUg@0000000004000000>[^^@0000000000k>Wc0<00003/J;81@00
0003Z;[W0000000000<000001=jn^00000000=o0^@8000000mo0^@000>G9^`02000000O_bJ/00000
0000003S^:X0003^aZ/00P000005hKFZ0000m]BZ0000g[6Y00@000001O3:Z`00000000000>>gZ003
000000GedJP000000000003`bJT00`000004kLBY00000000i;RY0P000004gk6X00000000h;:V0P00
0007i;NW000000000000h[>W0000YL?_00<000001JG3k`00000000000:G3k`04000000FU`nl00000
0000002U`nl010000005YL?_000000000000YL?_00@00002YL?_00<0002U`nl000000P000005YL?_
000000000000YL?_00@000001JG3k`00000000000:G3k`04000000FU`nl000000000002U`nl00`00
00:U`nl00`000:G3k`000003000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_
00@000000jG3k`000000000500000ZG3k`030000YL?_000000<000001JG3k`00000000000:G3k`04
000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00@00002YL?_00<0002U`nl0
00000`000005YL?_000000000000YL?_00@000000jG3k`0000000005000000>U`nl0000000008_oo
o`030000oooooooo00Ooool003Ooool00`000?ooooooo`1joooo0`00000508?C000000000000e[Vm
008000000mc6``000=c1_`02000000??/K`0003Vg</0100000:jV[L01@000;ZI]kZI]kZI]`000003
_9fi0P00000:bZfm00000000f/_:0000c;2o0000hM[?0000b:^l0P000003c:Zg0000000000;=[;L4
000000CI^k/00000003L_[/400000YKCo@D00003/jO<0`000003/Z770000/J;800@00002ZIS51000
0005W/Kd000000000000hL>j008000001>?6^P0000000>G9^`@000001>:fZP0000000>>hZP800000
0n_3Z`000>6eZP02000000CN/JT00000003U^j/3000000G^aj/000000000003edJP00`000003k/JY
00000000008000001>[0Z@0000000>NlZ@8000000ng4Z@000=naZ002000000GP/ZH000000000003[
`:L01@000005YL?_000000000000YL?_00<000000jG3k`0000000002000000FU`nl000000000002U
`nl010000004YL?_0000000000001JG3k`<000001JG3k`00000000000:G3k`03000000>U`nl00000
00000P000005YL?_000000000000YL?_00@000001:G3k`000000000000BU`nl3000000>U`nl00000
00000P000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`0700001JG3k`<00000
0jG3k`0000000002000000FU`nl000000000002U`nl010000003YL?_0000000000D000001:G3k`00
0000000000FU`nl3000000>U`nl0000000000P000005YL?_000000000000YL?_00L000000jG3k`00
00000002000000>U`nl0000000008Oooo`030000oooooooo00Ooool003Soool00`000?ooooooo`1k
oooo10000006e[Vm00000000g<K30000g<6o0P000005ck6l0000i]c;0000c:fj00D00002^YVg0P00
00>lWKT2000000?7[l<0003Ha/P00P000005c;2o0000hM[?0000b:^l008000001LJX^P0000000000
0<f/]`02000000C@[kP00000003I^k/3000000?Tc/400000000020000004/jO<0000000000000k:Q
a`<00003ZIS50P000003/9o700000000008000001IJol`00000000000=o0^@02000000GO`;T00000
0000003UbK/00P000007h[JZ000000000000k/J[0000jl>[008000000oKDZP000=jaZ@04000000G`
bZ/000000000003R]jX00P000003iKVY00000000008000001?39Z@0000000>[0Z@8000001nNlZ@00
000000000=naZ0000?ODY`03000000CT]jL00000003^a:L5000000FU`nl000000000002U`nl00`00
00:U`nl3000000FU`nl000000000002U`nl0100000:U`nl00`000:G3k`000003000000FU`nl00000
0000002U`nl00`000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`0400000ZG3
k`030000YL?_0000008000001JG3k`00000000000:G3k`04000000FU`nl000000000002U`nl01000
0005YL?_000000000000YL?_00<00002YL?_00<0002U`nl000000`000005YL?_000000000000YL?_
00@000001JG3k`00000000000:G3k`07000000>U`nl0000000000P0000:U`nl00`000:G3k`000003
000000FU`nl000000000002U`nl010000003YL?_0000000000D000001JG3k`00000000000:G3k`04
000000>U`nl0000000008?ooo`030000oooooooo00Ooool003Woool00`000?ooooooo`1joooo2000
0005g<6o0000hmK:0000ck6l008000000lb]^P000>SPbP03000000A_S=l0000000000003_9fi0P00
0007ajo30000d/O?0000f/_:0000c;2o008000001LR[_0000>?Pd0000<JX^P02000000C=[;L00000
003@[kP2000000CI^k/00000003L_[/2000000CB/;P0000000000003X]Gi1@0000>bXLL3000000>b
W/@0002YV<D00P0000:`WlL00`000<_Dh0000003000000FH/nX000000000003Sa[X00P000005iLVk
000000000000hlJj00<000001^>hZP0000000>_3Z`000>6eZP8000001=jaZ@0000000>FkZ`<00000
1>k7Z`0000000>:gZP<000000oGAZ00000000002000000Cbc:T00000003]a:T2000000CT^:T00000
003O/JP2000000CO/JP00000003T]jL3000000?R/jL0000000000`000004YL?_0000000000000ZG3
k`<000001JG3k`00000000000:G3k`0300001JG3k`<000000jG3k`0000000002000000FU`nl00000
0000002U`nl00`000005YL?_000000000000YL?_00@000001:G3k`000000000000FU`nl3000000FU
`nl000000000002U`nl00`000003YL?_00000000008000001JG3k`00000000000:G3k`04000000BU
`nl0000000000004YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`04000000FU
`nl000000000002U`nl00`000004YL?_0000000000001JG3k`<000000jG3k`0000000002000000FU
`nl000000000002U`nl01`000003YL?_00000000008000001:G3k`000000000000FU`nl200008Ooo
o`030000oooooooo00Koool003[oool20000O?ooo`@000001]c6``0000000>?FbP000<na_0800000
1Lb]^P000>SPbP000=2e_P0500000[bM^@<000001lN_``000=;7c`000=G=d@000<b`_`02000000G8
Zk`0003Sh=000036Z;X00P000005b:Zl000000000000d:nh00<000001=o6_P0000000>C>`@800000
0o;a_P0000000008000000BbXLL0000000000003/Yk40P0000:`WlL2000000?;e>000035aMX01000
0005Uk?[000000000000gl2i00<000001>G9^`0000000>?5^P8000001^>hZP0000000>_3Z`000>6e
ZP8000001=jaZ@0000000>FkZ`D000000n:gZP000?GBZ`03000000?^aZT0000000000P000004j/2Y
00000000ikbY0P000006kLBY00000000mmBW0000gk6X0`000005jl2W000000000000mm:U00D00000
0jG3k`0000000002000000FU`nl000000000002U`nl00`0000:U`nl00`000:G3k`000003000000FU
`nl000000000002U`nl010000005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`04
00000ZG3k`030000YL?_000000<000001JG3k`00000000000:G3k`03000000FU`nl000000000002U
`nl010000005YL?_000000000000YL?_00@00002YL?_00<0002U`nl000000P000005YL?_00000000
0000YL?_00@000001JG3k`00000000000:G3k`04000000>U`nl0000000001@0000:U`nl00`000:G3
k`000003000000FU`nl000000000002U`nl010000003YL?_0000000000D000001JG3k`0000000000
0:G3k`0400000ZG3k`030000YL?_000000<000000jG3k`000000000Poooo00<0003oooooool01_oo
o`00??ooo`030000oooooooo07Woool5000000SL`Kl00000003?/K`0003Vg</0003<[KX2000000?@
]Kh0003Ug/d00`000004L8_M0000000000000/N_``0:0000d/O?0000eLgA0000bkO70000hM[?0000
b:^l0P0000;6Z;X2000000C8Z[`00000003@[kP2000000CI^k/00000003L_[/2000000CB/;P00000
0036X[@300000[7LmPH00003/Yk40`000004/j;600000000bmCP0P000003aLGJ0000a<KK00@00000
1IfZh000000000000>G9^`03000000OSa[X000000000003N_[P0003^aZ/00P000004hKFZ00000000
g[6Y0P000004iK^[00000000l<Z[0`000004h[NZ00000000i;V[10000005l<VY000000000000kLBY
008000001>BhZ@0000000=naZ08000001=naZ00000000>>gZ@8000001Nk4Y`00000000000>>fY`05
000000>U`nl0000000000P000004YL?_0000000000001:G3k`<000000jG3k`0000000002000000FU
`nl000000000002U`nl010000005YL?_000000000000YL?_00<000001:G3k`000000000000FU`nl3
000000>U`nl0000000000P000003YL?_0000000000D000001JG3k`00000000000:G3k`04000000BU
`nl0000000000005YL?_1`000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`07
00001JG3k`<000000jG3k`0000000002000000FU`nl000000000002U`nl01`000003YL?_00000000
008000001:G3k`000000000000FU`nl3000000>U`nl0000000001000023oool00`000?ooooooo`06
oooo000moooo00<0003oooooool0N_ooo`D000001Lna_0000>KLb`000<b]^P02000000G@]Kh0003U
g/d0003D`<L01@0000;7[l<02P000=;7c`000=G=d@000<^ga`000=KEe`000<R[_0800002aZRj0P00
0004b:Zl00000000bZfm10000004glJn00000000i<k10P000003l_6n0000aZ:d00@00002/Mcf1@00
0004/Yk40000000000000k>RaP040000bmCP0000aLGJ0P000003a<KK0000anS]00@000000i_9m`00
00000002000000CUbK/00000003SaKX2000000KN_[P00000003[`j/0003Q]JX2000000CN/JT00000
003U^j/3000000G^aj/000000000003edZ/00P000003mM:[00000000008000001o;<Z@0000000000
0>NlZ@000>BhZ@02000000CO/JP00000003O/JP2000000GS]jT000000000003R/jL010000003jKfW
0000k/BW008000000jG3k`000000000200000ZG3k`030000YL?_0000008000001JG3k`0000000000
0:G3k`04000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00<00002YL?_00<0
002U`nl000000`000005YL?_000000000000YL?_00L000000jG3k`0000000002000000FU`nl00000
0000002U`nl0100000:U`nl00`000:G3k`000006000000>U`nl0000000000P000005YL?_00000000
0000YL?_00@000001JG3k`00000000000:G3k`0300000ZG3k`030000YL?_000000<000001JG3k`00
000000000:G3k`04000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00@00002
YL?_00<0002U`nl000000`000005YL?_000000000000YL?_00<000000jG3k`000000000Ooooo00<0
003oooooool01_ooo`00?_ooo`030000oooooooo07Woool300000WFAh0<000000lb]^P000>SPbP02
000000GUg/d0003D`<L0003Le=000`000004J93U00000000d/O?0`000009bkO70000e]GG0000aJg2
0000hn3@0000aZRj008000001LRZ_0000>CPd0000<Z]_@02000000CI^k/00000003L_[/2000000CB
/;P000000036X[@2000000>lU[00000000000`000003Iejd0000000000@00002/j;60P000005`<WQ
0000aLGJ0000a<KK00@000000k:^d`0000000002000000>M`?40000000000P000005hlJj00000000
0000g[jh00@000000n6eZP0000000002g[6Y00<0003U^j_U^j/01@000004h[NZ00000000i;V[0P00
0003kLJ[00000000008000001>[0Z@0000000>NlZ@8000001>g4Z@0000000?ODY`<000000n>gZ@00
0>[0Z@02000000?R/jL0000000000P000004jKfW00000000kL:W0P0000>U`nl5000000FU`nl00000
0000002U`nl00`000003YL?_00000000008000001JG3k`00000000000:G3k`04000000BU`nl00000
00000002YL?_1@000003YL?_00000000008000001JG3k`00000000000:G3k`03000000FU`nl00000
0000002U`nl010000004YL?_0000000000000jG3k`D000001JG3k`00000000000:G3k`03000000>U
`nl0000000000P000005YL?_000000000000YL?_00@000001:G3k`000000000000>U`nl4000000>U
`nl0000000000P000005YL?_000000000000YL?_00@000000jG3k`0000000005000000BU`nl00000
00000003YL?_1@000003YL?_00000000008000000jG3k`0000000005000000>U`nl0000000007_oo
o`030000oooooooo00Koool003ooool20000Noooo`D000001Lb]^P000>SPbP000=2e_P02000000CD
`<L0003Le=3Le=05000000?Ball0000000000/^ga`080000e]GG0000aJg20000fM_H0000aZRj0P00
0005b:Zl0000i>3@0000bZfm008000000m:ka0000=o6_P02000000CTc/40000000000002aZ:d0`00
0006b>b=000000000000/=cf00000VMN]0800003/j;600L00030bN400000002j[/h00034a]/00`00
00:b[]<00`000<?Fj0000003000000>H`oD0000000000P000004hlFj00000000g[jh0P000003f[Rg
0000hKFZ008000001=jaZ@0000000>FkZ`8000001O3:Z`00000000000>:gZP03000000GedZ/00000
0000003`bZ/00`000004kLBY00000000i;RY0P000004gk6X00000000gk6X0P000004hkNY00000000
k/FY0`000003hkJW0000000000@000000o37Y`000000000200000jG3k`<000001JG3k`0000000000
0:G3k`03000000>U`nl0000000000P000005YL?_000000000000YL?_00T00003YL?_0`000003YL?_
00000000008000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl010000003YL?_
0000000000<00003YL?_0`000005YL?_000000000000YL?_00<000000jG3k`0000000002000000FU
`nl000000000002U`nl010000003YL?_0000000000<00002YL?_0`000003YL?_0000000000800000
1JG3k`00000000000:G3k`07000000>U`nl0000000000P000003YL?_0000000000<00003YL?_0`00
0003YL?_0000000000D000000jG3k`0000000002000000>U`nl0000000007Oooo`030000oooooooo
00Koool0047oool00`000?ooooooo`1hoooo0`00009eUN@3000000G@]Kh00000003D`<L000000]cD
d08000000mC8cP000000000300000/^ga`<000001LF]`P000=WKf0000<:X_`03000000C8Z[`00000
003:[Kd2000000GB^l@0003Ib<T0003L_[/00P000004d[2h00000000aZ:d0P000004_9J`00000000
^Y>_1P000003Iejd0000000000@000001;Z^cP0000000<S:f`800002/ZkC10000003]k3A00000000
008000000i;>o00000000003000000CN_[P00000003J^;L400000]jaZ@030000iK^[iK^[00<00000
1Nk7Z`00000000000?GBZ`03000000G]aZ/000000000003bcJ/00`000006ikbY00000000kLBY0000
gk6X0P000005gk6X000000000000j/2Y008000001>6cZ00000000>>fY`<000001nk4Y`0000000000
0>VmY`000:G3k`04000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00@00000
1JG3k`00000000000:G3k`0300000ZG3k`030000YL?_000000<000001JG3k`00000000000:G3k`04
000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00@00002YL?_00<0002U`nl0
00000`000005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`04000000FU`nl00000
0000002U`nl010000003YL?_0000YL?_00@000001JG3k`00000000000:G3k`04000000FU`nl00000
0000002U`nl00`000005YL?_000000000000YL?_00@00002YL?_00<0002U`nl000000`000003YL?_
0000000000D000001JG3k`00000000000:G3k`04000000>U`nl0000000007?ooo`030000oooooooo
00Koool004;oool00`000?ooooooo`1ioooo1@000005d;Fn00000000e<37000000;Le=0200000]C8
cP<00002Li;R0`0000;5[L800`000=WKf0000002`ZRo0P000004b:Zl00000000bZfm0P000007d[_4
0000fLS90000e;o50000i<k100<000001/JR]00000000;bF/0000<S/S@<000000l:M/`0006nNk@07
00000[Z^cP030000b<[K0000008000000lo?f@000000000200000[N`d@030000am3Q000000<00000
0iV/i00000000002000000KN_[P00000003J^;L0003I][H2000000CN/JT00000003U^j/2000000G`
bZ/000000000003R]jX00P000003i;V[00000000008000001?3:Z`0000000>W0Z`8000001nNlZ@00
000000000=naZ0000?ODY`03000000KS]jT00000003^aJT0003Q/jP4000000CY_JL00000003]`ZL5
000000>U`nl0000000000P000005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`04
000000BU`nl0000000000004YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`04
000000FU`nl000000000002U`nl00`000004YL?_0000000000001JG3k`<000000jG3k`0000000002
000000>U`nl0000000001@000005YL?_000000000000YL?_00@000001:G3k`000000000000BU`nl3
000000>U`nl0000000000P000005YL?_000000000000YL?_00@000000jG3k`0000000005000000BU
`nl0000000000005YL?_0`000003YL?_0000000000D000000jG3k`0000000002000000FU`nl00000
0000002U`nl010000003YL?_0000000001_oool00`000?ooooooo`06oooo0013oooo00<0003ooooo
ool0NOooo`H000001=C0a`000=cDd=cDd0800002e<S>0P000003ck_80000000000<00002aJg20`00
00;2Z;l2000000?4[<40003Th=000P00000:g];<00000000fLS90000e;o50000g];=0000d[2h0P00
0004aZ:d0000_9J`_9J`0P000004^Y>_0000`Yfc`Yfc1P000003He^c00000000008000001<S:f`00
0<BoeP0000;?cmT200000[N`d@@000000l>neP000000000400000YfgjP8000001=Zh]`0000000=Vf
]P8000001=jaZ@000>FkZnFkZ`<000001>k7Z`0000000>:gZP<000000oGBZ`0000000002000000Cb
cJ/00000003/aJ/2000000CT^:T00000003O/JP2000000CO/JP00000003S]jT3000000CQ/jP00000
003R]JP6000000?`ajL0000000000`000003YL?_00000000008000001JG3k`00000000000:G3k`03
000000FU`nl000000000002U`nl0100000:U`nl00`000:G3k`000002000000FU`nl000000000002U
`nl010000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`0300000ZG3k`030000
YL?_000000<000001JG3k`00000000000:G3k`07000000>U`nl0000000000P000005YL?_00000000
0000YL?_00@00002YL?_00<0002U`nl000000P000005YL?_000000000000YL?_00@000001JG3k`00
000000000:G3k`07000000>U`nl0000000000P0000:U`nl00`000:G3k`000003000000FU`nl00000
0000002U`nl00`000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`04000000>U
`nl0003oool06oooo`030000oooooooo00Goool004Coool20000N_ooo`H00002g=C@00@0003>_/`0
003Db<h2000000??^lP0003B`l`00`000004K9OY0000000000000l:X_`8000000lB/`@000=[Lf@02
000000?Nd/`0003B^l@00P000005e;o50000g];=0000bjjn008000001<JR]00000000;bF/0800000
1;ZC[`0000000<:M/`8000000m2`^P0000000003000000=SFk<00038b]/010000005cloI00000000
0000aL7F00@000001<>neP0000000<WIi@800003WKOZ10000003f[Rg0000fKJf008000000mZh]`00
00000002iK^[1@000004h[NZ00000000i;V[0P000003kLJ[00000000008000001>W0Z`0000000>Jl
Z`8000001^g4Z@0000000?ODY`000=naZ0<000001>[0Z@0000000>6cZ08000001N:eZ00000000000
0>k4Y`03000000?Y_JL0000000000`000003YL?_00000000008000001JG3k`00000000000:G3k`03
000000BU`nl0000000000005YL?_0`000005YL?_000000000000YL?_00<000000jG3k`0000000002
000000FU`nl000000000002U`nl010000004YL?_0000000000001:G3k`<000000jG3k`0000000002
000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00@000001:G3k`0000000000
00FU`nl7000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00<000001:G3k`00
0000000000FU`nl3000000>U`nl0000000000P000003YL?_0000000000D000001JG3k`0000000000
0:G3k`04000000BU`nl0000000000004YL?_0P0001coool00`000?ooooooo`05oooo0016oooo00<0
003oooooool0N?ooo`L000000ljnc0000=C8cP02000000G?^lP0003B`l`00038[Kl01@0000;2Z;l3
000000?4[<40003Jg=T00P000005g];<0000d[_40000fLS9008000000mkBc@000<^^_P02000000>m
VK<0000000000[bF/0050000^Y>_00000000`Yfc008000000m2`^P000=^o_@05000000ASFk<00034
_mH00002cloI0P0000?5`MH2000000C3_]H000000039fND2000000>l/m4000000000100000:S]NH2
000000CI][H00000003J^;L5000000G`bZ/000000000003R]jX00P000003i;V[0000000000800000
1o3:Z`00000000000>c5Z`000>JlZ`03000000CO/JP00000003O/JP2000000CS]jT00000003^aJT3
000000CR]JP00000003X_JT2000000G]`ZL000000000003dcJH01@000003YL?_0000000000800000
1JG3k`00000000000:G3k`0300000ZG3k`030000YL?_000000<000001JG3k`00000000000:G3k`03
000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00@00002YL?_00<0002U`nl0
00000P000005YL?_000000000000YL?_00@000001JG3k`00000000000:G3k`03000000FU`nl00000
0000002U`nl0100000:U`nl00`000:G3k`000006000000>U`nl0000000000P000005YL?_00000000
0000YL?_00@000000jG3k`000000000500000ZG3k`030000YL?_000000<000001JG3k`0000000000
0:G3k`07000000>U`nl0000000000P000005YL?_000000000000YL?_00@000000jG3k`000:G3k`04
000000>U`nl0000000006oooo`030000oooooooo00Goool004Ooool00`000?ooooooo`1hoooo1`00
0003e<S>0000b[[;008000001M;3c0000<R]_`000>3Fc@03000000A5V?80000000000002a:c100/0
003Jg=T00000003Dcm@0003B^l@0003Ib<T0003D_lD00P000003bjjn0000000000:mVK<2000000Fl
U[000000002jTjl000000/:M/`8000001=2`^P0000000>G@`@L000001<o?f@000000000000;5`MH3
000000>cYl`00039fND00P000004_;?A00000000c>SZ0P0000>S]NH3000000CI][H00000003J^;L2
000000?L^[L0000000000P000005k/N[000000000000mM:[008000000oGBZ`0000000002000000Ob
cJ/000000000003V_:/0003S^:X00P000004gk6X00000000gk6X0P000005hkNY000000000000hK>X
008000000n:eZ00000000004000000G`ajL000000000003^`jL01@000003YL?_0000000000800000
1:G3k`000000000000>U`nl4000000>U`nl0000000000P000005YL?_000000000000YL?_00<00000
1JG3k`00000000000:G3k`04000000BU`nl0000000000003YL?_2@000005YL?_000000000000YL?_
00@000001JG3k`00000000000:G3k`03000000BU`nl0000000000003YL?_1@000005YL?_00000000
0000YL?_00<000000jG3k`0000000002000000FU`nl000000000002U`nl01`0000>U`nl5000000>U
`nl0000000000P000005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`04000000BU
`nl0000000000003YL?_10000003YL?_00000000008000000jG3k`000000000Joooo00<0003ooooo
ool01Oooo`00B?ooo`030000oooooooo07Soool7000000?:^//0003?^lP00P0000;8[Kl3000000?U
fl/0000000000P0000;4[<44000000ODcm@0003>_l`0003Ib<T0003D_lD00P000003bjjn00000000
00:mVK<00`000;N@[[N@[P02000000BjTjl00032WK?2WK<2000000?@/;X0003K_kd01P000003O[kk
0000000000800002aL7F0`000006/jO<00000000]O[X0000_;?A0P000004c>SZ00000000^[OG1@00
00:SYML3000000GJ^;L000000000003/eK`01@000004h[NZ00000000i;V[0P000003kLJ[00000000
008000001>W0Z`0000000>JlZ`8000001>c4Z`0000000?ODY`<000000n>gZ@000>[0Z@02000000?Q
/jP0000000000P000003j;fY0000kLFY00<000000nVmY`0000000002000000?`ajL0000000000P00
0003YL?_00000000008000000jG3k`000000000300000ZG3k`<000000jG3k`0000000002000000FU
`nl000000000002U`nl00`000005YL?_000000000000YL?_00@000000jG3k`000000000300000ZG3
k`<000000jG3k`0000000002000000FU`nl000000000002U`nl010000003YL?_0000000000D00000
0jG3k`000000000300000jG3k`<000001JG3k`00000000000:G3k`03000000>U`nl0000000000P00
0005YL?_000000000000YL?_00<000000jG3k`000000000300000jG3k`<000000jG3k`0000000002
000000>U`nl0000000001@000005YL?_000000000000YL?_00@000000jG3k`000000000300000ZG3
k`<000000jG3k`0000000002000000>U`nl0000000006Oooo`030000oooooooo00Goool004Woool2
0000NOooo`L000001Lnkb0000=;3c0000<R]_`0300000^GKb`L000002LRca@000=C?e0000<joc000
0=?>e0000=Boa@0200000/^^_P040000_IVc_IVc00000kN@[P@000001/:M/`0000000=2`^P000=^o
_@@000000l:K/0000869dP0800000[>Wc0070000]O[X00000000/J?90000c>SZ008000001;Zge`00
00000<;Ej0800002XjGG10000004f[Rg00000000g;Zg0`000005ilbk000000000000h[NZ00<00000
1OGBZ`00000000000?3:Z`03000000C/aJ/00000003S^:X2000000CN/JT00000003O/JP2000000CS
]jT00000003^aJT3000000CR]JP00000003X_JT2000000G/`jT000000000003dcJH01@000005j[nW
000000000000YL?_00@00002YL?_00<0002U`nl000000P000005YL?_000000000000YL?_00@00000
1JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl0100000:U`nl00`000:G3k`000002
000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00L000000jG3k`0000000002
00000ZG3k`030000YL?_000000<000001JG3k`00000000000:G3k`03000000FU`nl000000000002U
`nl010000005YL?_000000000000YL?_00<00002YL?_00<0002U`nl000000`000005YL?_00000000
0000YL?_00L000000jG3k`0000000002000000FU`nl000000000002U`nl010000003YL?_0000YL?_
00@000001JG3k`00000000000:G3k`04000000>U`nl0000000006?ooo`030000oooooooo00Goool0
04_oool00`000?ooooooo`1goooo1`000003d/?<0000b:fo008000000lNZ_@000>GKb`02000000?N
c<L0000000000P0000;8/lD2000000G>_l`0003Cc]@0003;^l/00P0000;;[[h00`000;fI/kfI/`02
00000[N@[P050000^9:_00000000`Yfc00800002d;2j0P000005iM31000000000000`Y^`00800003
Zl?/2@000003/J?900000000008000001;Zge`0000000<;Ej0P00002X[o^10000005k=Fl00000000
0000g;^h00@000001>BiZ`0000000>g6Z`@000001>W0Z`0000000>JlZ`8000000nc4Z`000=jaZ@02
000000GO/JP000000000003Z`:T00P000004hK>X00000000h[FX1P000005l<RY000000000000k/>W
00D000001?C<YP000000000000>U`nl5000000FU`nl000000000002U`nl00`000003YL?_00000000
008000001JG3k`00000000000:G3k`03000000BU`nl0000000000003YL?_1@000005YL?_00000000
0000YL?_00<000000jG3k`0000000002000000FU`nl000000000002U`nl00`000004YL?_00000000
00000jG3k`D000000jG3k`0000000002000000>U`nl0000000001@000005YL?_000000000000YL?_
00@000001:G3k`000000000000:U`nl5000000>U`nl0000000000P000005YL?_000000000000YL?_
00<000001JG3k`00000000000:G3k`04000000BU`nl0000000000003YL?_10000003YL?_00000000
008000001JG3k`00000000000:G3k`0600006?ooo`030000oooooooo00Goool004coool00`000?oo
ooooo`1goooo1`000003b:fo0000h=K=008000001^GKb`0000000=k<a`000=6g_`H000001Ljoc000
0=?>e0000<^kb`02000000?6[l<0000000000kfI/`040000]i2^]i2^00000[RB[`030000_ibd0000
008000000m2`^P000=^o_@04000000?2Vk00002ohg`00`0000:[`n`600000[6Sb@<000001;Zhe`00
00000<;Ej0@00002[kCL0P0000:R_nh4000000GL^[L000000000003Wc;/00P000005hlJj00000000
0000i;V[00@000001?3:Z`0000000>W0Z`8000001nJlZ`00000000000=jaZ@000?OEZP03000000KS
]jT00000003^aJT0003Q/jP4000000?X_JT0003]aJT00`000003j;fY00000000008000000o37Y`00
00000002000000?V^ZL0000000000`0000>U`nl3000000FU`nl000000000002U`nl00`000003YL?_
00000000008000001JG3k`00000000000:G3k`03000000>U`nl0000000000`0000>U`nl3000000FU
`nl000000000002U`nl00`000003YL?_00000000008000001JG3k`00000000000:G3k`03000000>U
`nl0000000000`0000>U`nl3000000>U`nl0000000001@000003YL?_00000000008000001JG3k`00
000000000:G3k`0900000jG3k`<000000jG3k`0000000002000000>U`nl0000000001@000005YL?_
000000000000YL?_00@000000jG3k`000000000300000ZG3k`<000000jG3k`0000000002000000FU
`nl000000000002U`nl00`000003YL?_0000000001Soool00`000?ooooooo`04oooo001=oooo00<0
003oooooool0Moooo`<00003Nj;/10000005iM_;0000bZjn0000g/c700<000002M_2`00000000000
0<joc0000=?>e0000<^kb`0200000/J_``800002_IVc00@0002gT:jgT:h00002^9:_00<0002oW;Bo
W;@00P000003d;2j0000fknm008000001<n^^00000000<:K/08000000k^E[`0000000003000000=W
GkD0000000001@000004^[SG00000000`=W/0`0000>_]=`2000000>f[m80000000000P000005VKob
000000000000k=Fl00<000001=bk^00000000=fl^0<000000oGBZ`0000000002000000CbcJ/00000
003/aJ/2000000CS^:X00000003N/JT2000000CN/JT00000003S]jT3000000CQ/jP00000003R]JP2
000000CX_JT00000003/`jT3000000?ccZP0000000000`000005j[nW000000000000k/>W00800000
0jG3k`0000000002000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00@00000
1JG3k`00000000000:G3k`0300000ZG3k`030000YL?_000000<000001JG3k`00000000000:G3k`03
000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00<00002YL?_00<0002U`nl0
00000`000005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`04000000FU`nl00000
0000002U`nl00`0000:U`nl00`000:G3k`000003000000FU`nl000000000002U`nl01`000003YL?_
00000000008000001JG3k`00000000000:G3k`04000000>U`nl0002U`nl010000005YL?_00000000
0000YL?_00@000000jG3k`0000000005000000>U`nl0000000005oooo`030000oooooooo00Coool0
04koool20000N?ooo`P00002iM_;0P000006g/c700000000e[_00000fl;010000003dlkD0000bk_;
00800002aZo300<0002mW[VmW[T00P0000>gT:h00`000;RB[`000002_ibd0P000003bjnn00000000
008000001/n^^00000000<:K/0000;oSO0<000000kN@[@0000000002000000=WGkD0000000000P00
0004^[SG00000000`=W/0`000003^;_K0000[kCL008000001KJ_dP00000000000;JQ``03000000><
__L0000000000P000004ilbk00000000hlJj0P000005h/Fj000000000000kLJ[00@000001>W0Z`00
00000>JlZ`8000001^c4Z`0000000?OEZP000=jaZ@<000001>[0Z@0000000>6cZ08000000n:eZ000
00000004000000G`b:T000000000003]a:T01@000005m<bV000000000000jknW008000000jG3k`00
00000002000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00@000001:G3k`00
0000000000>U`nl4000000>U`nl0000000000P000005YL?_000000000000YL?_00<000001JG3k`00
000000000:G3k`04000000BU`nl0000000000003YL?_10000003YL?_00000000008000001JG3k`00
000000000:G3k`03000000FU`nl000000000002U`nl010000004YL?_0000000000000jG3k`@00000
0jG3k`0000000002000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00@00000
1:G3k`000000000000>U`nl4000000>U`nl0000000000P000005YL?_000000000000YL?_00L00000
0jG3k`0000000002000000>U`nl0000000005_ooo`030000oooooooo00Coool0053oool00`000?oo
ooooo`1foooo0`00009lX>T2000000KUfl/00000003Nc<L0003A]kl2000000CK`/000000003Pa[l3
000000K;^l/0003Cc=<00036[l<00003_Iji0P0000:gT:h010000;RB[`00000000:oW;@2000000?;
[kh0003K_kd00P000004cjjh00000000`Y^`0P000004^iF_00000000]i2]20000003^lKR0000`=W/
00<00002^;_K0`000004]ZoB0000000000000[JQ``030000c_kN0000008000000if/hP0000000002
000000CL^kP00000003M_;P2000000?N_[P0000000000P000005l<Z[000000000000k<F[00800000
1>>hZP0000000=jaZ@8000001=jaZ@0000000>:gZP8000001Nk5Z@00000000000>:eZ002000000?X
_JT0003]aJT00`000003j;fY00000000008000000o38Z@0000000002000000?V^ZL0000000001000
0003YL?_00000000008000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl01000
0003YL?_0000000000<00002YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`03
000000FU`nl000000000002U`nl010000003YL?_0000000000<00002YL?_0`000003YL?_00000000
008000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl010000003YL?_00000000
00<00002YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`03000000FU`nl00000
0000002U`nl010000003YL?_0000000000<00002YL?_0`000003YL?_00000000008000000jG3k`00
00000005000000FU`nl000000000002U`nl010000003YL?_0000000001Goool00`000?ooooooo`04
oooo001Aoooo00<0003oooooool0Moooo`L000000mk<a`000=6g_`02000000GK`/00003G^kh0003P
a[l010000003dlcC0000aZo300800002_Iji00<0002hU[>hU[<00P0000:hTZl00`000;nL];nL]002
000000?;[kh0003D`<H00P000004cjjh00000000`Y^`0P000004^iF_00000000]i2]0P000003^I:^
0000000000D000000kV_d00000000002^;_K0P000003^]S_0000000000<00002]Z731`000003Ul7d
00000000008000001>?6^P0000000>;5^P8000000n;4^P0000000003000000KY`:/00000003V_:/0
003S^:X2000000CN/JT00000003N/JT2000000GR]jX000000000003Q/jP00P000003h[FX00000000
00<000001Nc3Z@00000000000??>Z005000000CY_jT00000003V^ZL7000000>U`nl0000000000P00
0005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`0400000ZG3k`030000YL?_0000
008000001JG3k`00000000000:G3k`04000000>U`nl0000000001@000005YL?_000000000000YL?_
00@000000jG3k`000:G3k`04000000FU`nl000000000002U`nl010000003YL?_0000000000D00000
1JG3k`00000000000:G3k`04000000>U`nl0002U`nl010000005YL?_000000000000YL?_00@00000
0jG3k`0000000005000000FU`nl000000000002U`nl010000003YL?_0000YL?_00@000001JG3k`00
000000000:G3k`07000000>U`nl0000000000P000005YL?_000000000000YL?_00H0000Eoooo00<0
003oooooool01?ooo`00D_ooo`030000oooooooo07Koool300000WVMj08000001]k<a`0000000=Jk
`0000=_2`08000001>36_`0000000=Zn_P<000000lJ_``0000000002_Iji00H0002hU[>hU[>hU[<0
002iUk@200000[nL]08000000l^__P000=C0aP02000000K9[;d0000000000032Vk000002^iF_00<0
002gT:fgT:d00P000003^I:^0000000000L000001;2Ma00000000;[Hk`8000000j^^fP0000000002
]Z730`000003]9bo0000]O[800@000000inVf`0000000002000000CM_;P00000003N_[P2000000?O
_kT0000000000P000004jL2[00000000i[b[0P000004k<B[00000000mmFZ0`000003h[NZ0000jL2[
008000000n6cZ00000000002000000?X_JT0000000000P000003l<RY0000000000<000001O38Z@00
000000000??=Z002000000C^`jL00000003ecZH4000000>U`nl0000000000P000005YL?_00000000
0000YL?_00<000001:G3k`000000000000>U`nl9000000FU`nl000000000002U`nl01`000003YL?_
00000000008000001:G3k`000000000000>U`nl4000000>U`nl0000000000P000005YL?_00000000
0000YL?_00L000000jG3k`0000000002000000BU`nl0000000000003YL?_10000003YL?_00000000
008000001JG3k`00000000000:G3k`07000000>U`nl0000000000P000004YL?_0000000000000jG3
k`@000000jG3k`0000000002000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_
00@000001:G3k`000000000000>U`nl300005Oooo`030000oooooooo00Coool005?oool00`000?oo
ooooo`1goooo1`000003e[_00000fl;0008000000n36_`0000000002f[jn1@0000:mW[T01@000;RF
/kRF/kRF/`000002^INd0P00000:_ibd00000000bjnn0000e<360000gmG=0000bJbm0P000005`Y^`
00000000^iF_000000:gT:d2000000JiTZh0002_Q:N_Q:L0001_IkX3000000=RG;D0000000000`00
0003ZjkJ0000000000:d^]h300000[BL_`<000000k>N`P0000000002000000>O`o80000000000P00
0007h/Fj000000000000gkni0000i<Nj00@000001>c5Z`0000000>>hZP8000001=jaZ@0000000=ja
Z@8000001>:gZP0000000>g5Z`<000001>:eZ00000000>RmZ@D000000nRmZ@0000000004000000CY
_jT00000003U^ZT2000000C[_jL00000003Q/jL4000000>U`nl0000000000P000003YL?_00000000
00D000000jG3k`000000000300000ZG3k`<000000jG3k`0000000002000000FU`nl000000000002U
`nl00`000005YL?_000000000000YL?_00@000000jG3k`000000000300000ZG3k`<000000jG3k`00
00000002000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00@000000jG3k`00
0000000300000ZG3k`<000000jG3k`0000000002000000FU`nl000000000002U`nl00`000005YL?_
000000000000YL?_00@000000jG3k`000000000300000ZG3k`<000000jG3k`0000000002000000>U
`nl0000000001@000005YL?_000000000000YL?_00@000000jG3k`000000000300000ZG3k`80000D
oooo00<0003oooooool01?ooo`00E?ooo`80001hoooo0`000007JICX000000000000fl;00000ek^n
008000000mg6``000=Zn_P02000000C@/[/00000001VLl/200000kRF/`040000^INd^INd00000[fO
^P<000001/^__P0000000=oEc@000<V/_@8000000kbH/P0000000002^iF_00@0002gT:fgT:d00002
^I:^00<0002_Q:N_Q:L00P0000;oool2000000ARG;D00000002UQ[<200000[BjgP@00002]9bo0P00
00:cW/800`000;OlfP000003000000>Q[Ml0000000000P000007g[jh000000000000i<Nj0000fkZg
00@000001^JlZ`0000000>c4Z`000=jaZ@8000001MjaZ@00000000000>W0Z`02000000CO/jX00000
003R]JP4000000?]aJT0000000000P000003lljX0000000000@000000o?=Z0000>FjZ@05000000?Q
/jL0000000000`000003YL?_0000000000D000000jG3k`000000000200000ZG3k`030000YL?_0000
008000001JG3k`00000000000:G3k`04000000FU`nl000000000002U`nl00`000005YL?_00000000
0000YL?_00@00002YL?_00<0002U`nl000000P000005YL?_000000000000YL?_00@000001JG3k`00
000000000:G3k`03000000FU`nl000000000002U`nl0100000:U`nl00`000:G3k`000002000000FU
`nl000000000002U`nl010000003YL?_0000000000D000001JG3k`00000000000:G3k`04000000>U
`nl0002U`nl010000005YL?_000000000000YL?_00L000000jG3k`0000000002000000FU`nl00000
0000002U`nl010000003YL?_0000YL?_00@000000jG3k`000000000Coooo00<0003oooooool01?oo
o`00E_ooo`030000oooooooo07Koool4000000KF^l000000003G^kh0003Pa[l2000000?J_[h00000
00000]2b^`D00002^9Jc00@0002iUkBiUk@00003_Inj0P000003bjnn0000e<36008000000lV/_@00
00000002_9Rb0P000005^iF_0000]i2]]i2]000000:iTZh010000:n4Yjn4Y`0000Goool3000000=R
G;D0002UQ[<0100000>aYL`200000[>N`P@000000k:Qa`0000000002000000>NaO@0000000000`00
0004gkni00000000fkZg1P000004hkRZ00000000g[6Y0P000004g[6Y00000000h[NZ0P000003kLF[
0000gk>Z00@000001NRmZ@00000000000>c3Z@06000000?`b:T0000000000P000003iKZY0000kLBY
008000001OG>YP00000000000>BfY`04000000FU`nl000000000002U`nl00`0000>U`nl5000000FU
`nl000000000002U`nl00`000003YL?_00000000008000001JG3k`00000000000:G3k`03000000BU
`nl0000000000003YL?_1@000005YL?_000000000000YL?_00<000000jG3k`0000000002000000FU
`nl000000000002U`nl00`000004YL?_0000000000000jG3k`D000001JG3k`00000000000:G3k`03
000000>U`nl0000000001@000003YL?_00000000008000001:G3k`000000000000>U`nl4000000>U
`nl0000000000P000005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`04000000BU
`nl0000000000003YL?_10000003YL?_00000000008000000jG3k`000000000Coooo00<0003ooooo
ool00oooo`00Eoooo`030000oooooooo07Koool4000000CK`/000000003Pa[l2000000?J_[h00000
00000]2b^`030000cZnjcZnj008000000g=mc`0000000002^INd0P0000:mWkX2000000?7/<<0003D
`<H00P000003bJbm0000000000:lV;800`000;>;Zk>;Z`0200000[N@[@030000^I:^000000>_Q:L0
0`000?ooooooo`04oooo1@000003Wgb/0000/JG<00>aYL`2000000>aX/T0000000000P0000:bXLL0
0`000<O`kP000003000000>N_Nh0000000000`000003i<Nj00000000008000001N?6^P0000000000
0>>hZP02000000CN/JT00000003N/JT2000000GR]jX000000000003O/jX00P000004hKFZ00000000
j;fY10000003l<RY0000000000D000001>VoZ@0000000>FjZ@8000001>[0Z@0000000>6cY`800000
0nBfY`0000000003000000FU`nl000000000002U`nl01@000003YL?_0000000000<000001JG3k`00
000000000:G3k`03000000>U`nl0000000000P000005YL?_000000000000YL?_00<000000jG3k`00
00000003000000>U`nl0000000000`000005YL?_000000000000YL?_00<000000jG3k`0000000002
000000>U`nl0000000001@000003YL?_0000000000<000000jG3k`0000000007000000FU`nl00000
0000002U`nl00`000005YL?_000000000000YL?_00@000000jG3k`0000000003000000>U`nl00000
00000P000003YL?_00000000008000001JG3k`00000000000:G3k`03000000FU`nl000000000002U
`nl010000003YL?_0000000000P000000jG3k`0000000002000000>U`nl0000000004_ooo`030000
oooooooo00?oool005Soool00`000?ooooooo`1foooo10000004ek^n0000000000000]Zn_P800000
1=2b^`0000000<j_^PH00002^INd00<0002mWkZmWkX00P000007ak330000cl3<0000gmG=0000bJbm
00800002_9Rb00D0002cRj^cRj/0002^Q:L00P0000:iTZh010000:n4Yjn4Y`0000Soool3000000Eb
GJ`0002OO:`0002aYL`00P0000>aX/T200000[:Qa`@000000kBUbP0000000005000000CO_kT00000
003K^[L4000000GWc;/000000000003/a:/00P000004mmFZ00000000n=NY0P000004jL2[00000000
gk>Z0P000003hKFZ00000000008000001Ng5Z@00000000000>RmZ@07000000CccJP00000003]a:T4
000000?Q/jL0000000000P000003j;bW00000000008000001JG3k`00000000000:G3k`0500000jG3
k`<000001JG3k`00000000000:G3k`03000000>U`nl0000000000P000005YL?_000000000000YL?_
00<000000jG3k`000000000300000jG3k`<000001JG3k`00000000000:G3k`03000000>U`nl00000
00001@000003YL?_00000000008000000jG3k`000000000300000ZG3k`<000000jG3k`0000000002
000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00@000000jG3k`0000000003
00000ZG3k`<000000jG3k`0000000002000000>U`nl0000000001@000005YL?_000000000000YL?_
00T00003YL?_0`000003YL?_0000000000@0000Boooo00<0003oooooool00oooo`00FOooo`80001h
oooo10000003gLK30000f[jn008000001=2b^`0000000<j_^P800002dkNn1@0000:mWkX2000000O7
/<<0003?`<`0003He=@00039[;d00P0000:lV;8010000;>;Zk>;Z`0000:^Q:L2000000FiTZh0002_
Q:N_Q:L000002_ooo`L00003/J;90`000003/JC:0000000000800002]:G:00<00038d>0000000P00
0005UkS^000000000000i<Nj00@000001>?6^P0000000=jn^0<000001=jaZ@0000000=jaZ@800000
1>:gZP0000000>g5Z`<000001>6eZP0000000>NmZ`<000001Nc3Z@00000000000??>Z002000000?`
b:T0000000000P000006iKZY00000000j/2Y0000m<nX0`000004i;JW00000000j;bW1@000004YL?_
0000000000000ZG3k`030000YL?_000000<000001JG3k`00000000000:G3k`03000000FU`nl00000
0000002U`nl010000005YL?_000000000000YL?_00<00002YL?_00<0002U`nl000000`000003YL?_
0000000000D000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl0100000:U`nl0
0`000:G3k`000002000000FU`nl000000000002U`nl010000005YL?_000000000000YL?_00<00000
1JG3k`00000000000:G3k`04000000>U`nl0002U`nl010000005YL?_000000000000YL?_00L00000
0jG3k`0000000002000000FU`nl000000000002U`nl00`0000:U`nl00`000:G3k`000003000000>U
`nl0000000001@000003YL?_00000000017oool00`000?ooooooo`03oooo001Koooo00<0003ooooo
ool0MOooo`D000000mZn_P0000000002d;:k00<0003>[k[>[kX00P000004dkNn00000000e[o40P00
000;K8KK000000000000ak330000cl3<0000f=CD0000aZk200800002_9Rb00@0002cRj^cRj/00003
[XBW0`0000>_Q:L00`000?ooooooo`09oooo00<00020GZ8000000`000004/J;90000000000000k6T
bP800002]:G:10000005a<CJ000000000000U;S`00<000000m^j]`0000000002000000CWc;/00000
003WcK/2000000CN/JT00000003N/JT3000000CY`:/00000003O/jX2000000CQ]JX00000003W_J/4
000000?`b:T0000000001@000004jKnY00000000iKZY1@000004h;>X00000000i;JW0`000003ikZW
0000000000<00003YL?_10000003YL?_00000000008000001JG3k`00000000000:G3k`03000000FU
`nl000000000002U`nl010000004YL?_0000000000000jG3k`@000000jG3k`0000000005000000>U
`nl0000000000P000005YL?_000000000000YL?_00<000001:G3k`000000000000>U`nl5000000FU
`nl000000000002U`nl00`000003YL?_00000000008000000jG3k`0000000005000000BU`nl00000
00000003YL?_10000003YL?_00000000008000001JG3k`00000000000:G3k`03000000FU`nl00000
0000002U`nl010000004YL?_0000000000000ZG3k`D000000jG3k`0000000005000000>U`nl00000
00000P000003YL?_00000000013oool00`000?ooooooo`03oooo001Loooo00<0003oooooool0M_oo
o`D00002d;:k00<0003>[k[>[kX00P000003dkNn0000000000;F_l@5000000O7/<<0003?`<`0003H
e=@00036[/800`000005_9Rb0000/h^[/h^[000000>^Q:L010000:f2YP00000000:_Q:L00`000?oo
ooooo`0;oooo00@00020GZ800020GZ8300000k6TbP<000000k>Wc00000000002000000C4a=X00000
0031^m@3000000>H]N`0000000000`000004hlJj00000000g[jh0P000005g;^h000000000000g[6Y
008000000n:gZP000>W0Z`02000000?O/jX0000000000P000004ikf[00000000kLF[0`000005j;fY
000000000000l<RY00<000001??=Z00000000>g4Z@@000001N2cZ000000000000?37Y`03000000?a
b:L0000000001@000003YL?_00000000008000000jG3k`0000000002000000FU`nl000000000002U
`nl00`000005YL?_000000000000YL?_00@000000jG3k`0000000008000000FU`nl000000000002U
`nl00`000003YL?_00000000008000001JG3k`00000000000:G3k`03000000>U`nl0000000000`00
0003YL?_0000000000L000001JG3k`00000000000:G3k`07000000>U`nl0000000000P000003YL?_
0000000000<000000jG3k`0000000002000000>U`nl0000000000P000003YL?_0000000000D00000
1JG3k`00000000000:G3k`09000000>U`nl0000000000`000005YL?_000000000000YL?_00<00000
0jG3k`0000000002000000>U`nl0000000003oooo`030000oooooooo00?oool005goool00`000?oo
ooooo`1eoooo0`00009hSm`3000000C>[kX00000003C]kh200000]Joa0L000001Lo0c0000=SDe000
0<J^`P0200000/6S^`800002/h^[00@0002^Q:N^Q:L00002[H:V00@0002UMj000000000?oooo0P00
0005P5jR0000UVjS0000/JC:00<00003/jO<0P000004a<CJ00000000`K_D0P000003bmKR00000000
00L000001>O<^`0000000>O=^`D000001=jaZ@0000000>:gZP8000001Ng5Z`00000000000>6eZP02
000000GW_J/000000000003[`j/00`000003lljX00000000008000001>VoZ@0000000>FjZ@800000
0n[0Z@000?C?Z003000000CS]ZT00000003X_:L3000000?V^JL0000000001@000003YL?_00000000
008000000jG3k`0000000002000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_
00T000000jG3k`0000000003000000FU`nl000000000002U`nl00`000003YL?_0000000000800000
1JG3k`00000000000:G3k`03000000>U`nl0000000000`000003YL?_00000000008000000jG3k`00
00000002000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00@000000jG3k`00
00000008000000>U`nl0000000001@000003YL?_00000000008000001JG3k`00000000000:G3k`03
000000>U`nl0000000000`000003YL?_0000000000L000001JG3k`00000000000:G3k`0600003ooo
o`030000oooooooo00?oool005koool20000Moooo`D000000lj_^P0000000002dkNn0P000004e[o4
00000000d/391P000003f=CD0000000000800003`J>k0P000003/h^[0000[XBW00:^Q:L00`000:f2
YP000002YGNP0P00017oool600000k>Wc08000001;N_d@0000000<6ke08000000l_FhP0000000002
000000F@X^4000000000002U]N@00`000003g[jh0000000000800002ek>e0P000004n=NY00000000
jL2[0P000004gk>Z00000000hKFZ10000004kLF[00000000klV[20000004llfX00000000kLBY1000
0004h;>X00000000hkJY0`000005ikZW000000000000n=>T008000000nc1Y`000000000200000ZG3
k`<000000jG3k`0000000002000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_
00<000000jG3k`000000000300000jG3k`<000001JG3k`00000000000:G3k`03000000>U`nl00000
00000P000003YL?_0000000000D000000jG3k`000000000300000ZG3k`<000000jG3k`0000000002
000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00T00003YL?_0`000005YL?_
000000000000YL?_00<000000jG3k`0000000002000000>U`nl0000000001@000003YL?_00000000
00<00002YL?_0`000003YL?_00000000008000001JG3k`00000000000:G3k`03000000>U`nl00000
00003_ooo`030000oooooooo00?oool0063oool00`000?ooooooo`1eoooo0`000005M9CT00000000
0000dkNn008000001]Joa00000000=;0b@000=C2b0L000000mgUfP000<6S^`02`J>k00@0002bSJl0
00000003[XBW00@0002]PZJ]PZH00002YGNP00<0003oooooool04Oooo`060000oooooooooooo0000
/jO<0P0000:g[m401@000<;6g@0000000<_FhP02000000>hYlP0000000000P000003YKGT00000000
00D000001nO=^`00000000000=Nc]@000?ooo`02000000KR]jX00000003]aJ/0003O/jX4000000GW
_J/000000000003[`j/00P000005ikf[000000000000l<RY00@000001>FjZ@0000000>[0Z@<00000
1N2cZ000000000000?38Z@03000000?ab:L0000000001P000005YL?_000000000000YL?_00<00000
0jG3k`0000000002000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00<00002
YL?_00<0002U`nl000000`000005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`07
000000>U`nl0000000000P0000:U`nl00`000:G3k`000002000000FU`nl000000000002U`nl01000
0003YL?_0000000000D000001JG3k`00000000000:G3k`0300000ZG3k`030000YL?_000000<00000
1JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl01`000003YL?_0000000000800002
YL?_00<0002U`nl000000P000005YL?_000000000000YL?_00@000000jG3k`0000000005000000>U
`nl0000000003_ooo`030000oooooooo00;oool0067oool00`000?ooooooo`1eoooo1@000004dkNn
00000000e[o40P000003d/390000e<;8008000000mW5aP0000000002000000?MiMX00031Xk/00/6S
^`030000/Xf_/Xf_00800002[XBW00@0002]PZJ]PZH00002YGNP00<0003oooooool05_ooo`800002
]joA0P000003`/KM0000`LcR008000001;RWb0000000000000:ZVLD5000000>Q^^X0000000001000
0003ek>e0000000000;oool2000000CY`:/00000003O/jX2000000CQ]JX00000003W_J/4000000C_
bJ/00000003ccj/4000000CY_jT00000003U^ZT2000000?Z`:T0003dcjP00`000004hkJY00000000
ikbY0`000004i[VW00000000n=>T1@000005YL?_000000000000YL?_00<000000jG3k`0000000002
000000>U`nl0000000001@000004YL?_0000000000000jG3k`@000000jG3k`0000000002000000FU
`nl000000000002U`nl00`000005YL?_000000000000YL?_00<000001:G3k`000000000000>U`nl5
000000FU`nl000000000002U`nl00`000003YL?_0000000000D000000jG3k`0000000002000000BU
`nl0000000000003YL?_10000003YL?_00000000008000000jG3k`0000000005000000FU`nl00000
0000002U`nl00`000004YL?_0000000000000jG3k`D000001JG3k`00000000000:G3k`03000000>U
`nl0000000001@000003YL?_00000000008000000jG3k`000000000=oooo00<0003oooooool00_oo
o`00H_ooo`030000oooooooo07Koool5000000?F_l@0003NdL/00P000005e<;80000d;c70000fLG6
008000000g]ia@0000000002`J>k0P0000:bSJl00`000:n6ZZn6ZP0200000Zf2YP050000YGNPYGNP
YGNP000001[oool2000000?2a]d0000000000P000004a=3T0000000000000ZZIa@<000000jR=^000
0000000300000YVNf0<000000mNc]@000?ooo`03oooo00D0003Y`:/00000003O/jX00P000003hKFZ
00000000008000001Ng5Z`00000000000>NmZ`07000000CccJP00000003]a:T4000000CP/jP00000
003S]ZT3000000CV^ZT00000003V^JL3000000?/`JL0000000000`000005YL?_000000000000YL?_
00<000000jG3k`0000000005000000>U`nl0000000000P000003YL?_0000000000<000000jG3k`00
00000002000000>U`nl0000000000P000003YL?_0000000000D000001JG3k`00000000000:G3k`03
000000>U`nl0000000000`000003YL?_0000000000<000001JG3k`00000000000:G3k`03000000FU
`nl000000000002U`nl00`000003YL?_00000000008000000jG3k`0000000008000000>U`nl00000
00001@000003YL?_00000000008000001JG3k`00000000000:G3k`03000000>U`nl0000000000`00
0003YL?_0000000000L000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl01P00
00goool00`000?ooooooo`02oooo001Soooo0P0007Ooool5000000?NdL/0003B`<T00P000003d;c7
0000fLG6008000001<6T_@00000007]ia@800003/Xf_00@0002_QZZ_QZZ_QZX200000Zf2YP040000
YGNPYGNP00006oooo`030000`/KM000000800002a=3T0P000003^j;00000000000800002Z8fh0P00
0003/IFj0000000000D000000mNc]@0000000004oooo0P000005kLF[000000000000hKFZ00800000
1NNmZ`00000000000>_3Z`03000000Cccj/00000003_bJ/4000000CU^ZT00000003Z`:T3000000GP
/jP000000000003`b:T00`000003l<VY0000000000D000000ng2Y`0000000002000000FU`nl00000
0000002U`nl00`000005YL?_000000000000YL?_00<000000jG3k`0000000002000000>U`nl00000
00000`000003YL?_00000000008000000jG3k`0000000005000000>U`nl0000000000P000005YL?_
000000000000YL?_00<000000jG3k`0000000003000000>U`nl0000000001`000005YL?_00000000
0000YL?_00<000001JG3k`00000000000:G3k`09000000>U`nl0000000000`000005YL?_00000000
0000YL?_00<000000jG3k`0000000002000000>U`nl0000000001@000003YL?_0000000000<00000
0jG3k`0000000002000000>U`nl0000000000P000003YL?_0000000000D000001JG3k`0000000000
0:G3k`03000000>U`nl0000000003?ooo`030000oooooooo00;oool006Goool00`000?ooooooo`1e
oooo1@000003d/390000e<;8008000000mW5aP0000000002`JBm1@0000:bSJl00`000:n6ZZn6ZP02
[hJZ00@0002^QZX000000003YGNP00<0003oooooool06_ooo`800002a=3T0`0000:kX/0200000ZR=
^0<000000k6E^P000000000300000ibDb`800006oooo0P000004gk>Z00000000hKFZ10000004kLF[
00000000klV[1`000005j;n[000000000000kLBY008000000n>gZ@0000000002000000GS]ZT00000
0000003V^ZT00P000004i;VY00000000n=>T10000003k<6W00000000008000001JG3k`0000000000
0:G3k`03000000FU`nl000000000002U`nl00`000003YL?_00000000008000000jG3k`0000000003
00000ZG3k`<000001JG3k`00000000000:G3k`03000000>U`nl0000000000P000005YL?_00000000
0000YL?_00<000000jG3k`000000000300000ZG3k`<000000jG3k`0000000002000000FU`nl00000
0000002U`nl00`000005YL?_000000000000YL?_00<000000jG3k`000000000300000jG3k`<00000
1JG3k`00000000000:G3k`03000000>U`nl0000000001@000003YL?_00000000008000000jG3k`00
0000000300000ZG3k`<000000jG3k`0000000005000000>U`nl0000000000P000003YL?_00000000
00D000000jG3k`000000000;oooo00<0003oooooool00_ooo`00I_ooo`030000oooooooo07Goool5
000000CD`/P00000003IaLH200000/6T_@8000001;nN^000000008j>cP800004[hJZ00<0002^QZZ^
QZX00`000003YGNP0000oooo01koool300000k^R`08000001;RO_`000000000000:aUKX3000000BZ
S;H0002LU<^LU</400001oooo`030000gk>Z000000<000001NNmZ`00000000000>_3Z`02000000?W
_J/0000000001@000005llj[000000000000j/2Y008000001OC?Z000000000000>>fZ@04000000?`
bJT0003T^JT00`000003k<6W00000000008000000no6Y`0000000002000000FU`nl000000000002U
`nl00`000005YL?_000000000000YL?_00<000000jG3k`000000000200000ZG3k`030000YL?_0000
008000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl010000003YL?_00000000
00D00002YL?_00<0002U`nl000000P000005YL?_000000000000YL?_00@000000jG3k`0000000005
000000FU`nl000000000002U`nl00`0000:U`nl00`000:G3k`000003000000>U`nl0000000001@00
0005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`04000000>U`nl0002U`nl01000
0005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`07000000>U`nl0000000000P00
0003YL?_0000000000[oool00`000?ooooooo`02oooo001Woooo00<0003oooooool0M_ooo`@00000
0m2la`000=W5aP02000000?1Y;d0000000000[nN^0030000RXG8000000800003[hJZ00T0002^QZZ^
QZZ^QZX0002WNj<0002UMj0000008?ooo`030000^j;0^j;000800003^9no0P0000:aUKX200000jZ<
]P@0000;oooo0P000004hKFZ00000000ikf[10000004klV[00000000lln[0P000003klV[00000000
008000001>BjZ`0000000>[0Z@<000001N2cZ000000000000?38Z@04000000?T^JT0000000000`00
0003l<NW00000000008000000no5Y`0000000002000000FU`nl000000000002U`nl00`000005YL?_
000000000000YL?_00<00003YL?_2@000005YL?_000000000000YL?_00<000001JG3k`0000000000
0:G3k`0700000jG3k`D000001JG3k`00000000000:G3k`03000000>U`nl0000000001@000003YL?_
00000000008000001:G3k`000000000000>U`nl4000000>U`nl0000000001@000003YL?_00000000
008000001JG3k`00000000000:G3k`03000000BU`nl0000000000003YL?_10000003YL?_00000000
008000000jG3k`0000000005000000FU`nl000000000002U`nl00`000004YL?_0000000000000jG3
k`@0000:oooo00<0003oooooool00_ooo`00J?ooo`030000oooooooo07Goool5000000CIaLH00000
0031Y;d200000[nN^0@00002RXG800<0002_QZX000000jj6ZP030000Yg^SYg^S0080000Roooo0`00
00:hWkl3000000>`V/00000000000jZ<]P80000?oooo0P000003hKFZ00000000008000001Ng5Z`00
000000000>NmZ`06000000GX_j/000000000003/a:/00P000004hkNY00000000h;>X1@000004i[ZY
00000000i;VY0P000005n=FV000000000000kL:W00@000000o?<YP0000000006000000FU`nl00000
0000002U`nl00`000003YL?_0000000000<000000jG3k`0000000002000000>U`nl0000000000P00
0005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`03000000>U`nl0000000000`00
0003YL?_0000000000<000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl00`00
0003YL?_00000000008000000jG3k`0000000008000000FU`nl000000000002U`nl00`000003YL?_
00000000008000000jG3k`0000000005000000>U`nl0000000000`000003YL?_0000000000800000
0jG3k`0000000005000000>U`nl0000000000P000005YL?_000000000000YL?_00<000000jG3k`00
00000003000000BU`nl000000000000;oooo00<0003oooooool00Oooo`00JOooo`80001foooo1P00
00;1Y;d2000000>oW[P0000000000/:P]`D00003[XJZ00@0002WNj>WNj>WNj<200008_ooo`040000
^9no^9no^9no0P0000>`V/001@000:Z<]ZZ<]ZZ<]P00000Coooo0P000005ikf[000000000000jl>[
00<000000o??Z`0000000005000000CT^Z/00000003Y`:/2000000GdcjP000000000003S]ZT01000
0003l<VY0000000000<000001N_1Z@00000000000>c1Y`08000000>U`nl0000000000P000005YL?_
000000000000YL?_00<000000jG3k`0000000003000000>U`nl0000000000P000003YL?_00000000
008000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl00`000003YL?_00000000
00<000000jG3k`0000000007000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_
00T000000jG3k`0000000003000000FU`nl000000000002U`nl00`000003YL?_0000000000D00000
0jG3k`0000000002000000>U`nl00000000020000005YL?_000000000000YL?_00<000000jG3k`00
00000002000000>U`nl0000000001@000003YL?_0000000000<000001:G3k`000000000000[oool0
0`000?ooooooo`01oooo001[oooo00<0003oooooool0M?ooo`<00002TYOE0`000003_ijh00000000
00;2X;L00`000;fH/@000002000000B5O/@0002^QZX00004Yg^S00<0003oooooool08_ooo`<00003
/9[00P000004[8nh0000000000005?ooo`@000001>g5Z`0000000>o9Z`D000000no9Z`0000000003
000000?/a:/0003Y`:/00`000004h;>X00000000hkJY1@000003i;VY0000000000<000001O38Z@00
000000000>o6Y`04000000GZ_jL000000000002U`nl010000005YL?_000000000000YL?_00<00000
0jG3k`0000000003000000>U`nl0000000000P000003YL?_00000000008000000jG3k`0000000005
000000FU`nl000000000002U`nl00`000003YL?_0000000000<000000jG3k`0000000002000000>U
`nl0000000000P000005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`03000000>U
`nl0000000000`000003YL?_0000000000L000001JG3k`00000000000:G3k`03000000FU`nl00000
0000002U`nl02@000003YL?_0000000000<000001JG3k`00000000000:G3k`03000000>U`nl00000
00001@000003YL?_00000000008000000jG3k`000000000700002Oooo`030000oooooooo007oool0
06coool00`000?ooooooo`1doooo1P0000:oW[P010000<:P]l:P]`0000>mV;4600000jMkX`030000
oooooooo02?oool010000?ooo`000;2J`0800003[8nh00<0003oooooool05_ooo`<000001>_3Z`00
00000>NmZ`H000000nRoZ`0000000002000000?Y`:/0003R]j/00P000003h;>X0000000000<00000
1>JjZ@0000000>BiZ@8000001OSEYP00000000000>c3Z@04000000Gcc:H000000000003aajL00`00
0003YL?_00000000008000001JG3k`00000000000:G3k`03000000>U`nl0000000000`000003YL?_
00000000008000000jG3k`0000000005000000>U`nl0000000000P000005YL?_000000000000YL?_
00<000000jG3k`0000000003000000>U`nl0000000000P000003YL?_00000000008000000jG3k`00
00000005000000FU`nl000000000002U`nl00`000003YL?_0000000000<000000jG3k`0000000002
000000>U`nl0000000000P000005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`03
000000>U`nl0000000000`000003YL?_0000000000L000001JG3k`00000000000:G3k`03000000FU
`nl000000000002U`nl02@000003YL?_0000000000800008oooo00<0003oooooool00Oooo`00KOoo
o`030000oooooooo07Coool300000Y6Bd@<000000l:P]`000;fH/@02_IRa00<0003oool000000P00
0003SgFb0000Yg^S0080000Xoooo0P0000>/SkP200006oooo`8000001>o9Z`0000000???Z`L00000
1>BjZ`0000000>W0Z`8000001OCAZP00000000000>>fZ@04000000?`bJT0000000000`000005jl6Y
000000000000jl6Y00P000001NBfY`00000000000:G3k`04000000>U`nl0000000001@000003YL?_
0000000000<000000jG3k`0000000002000000FU`nl000000000002U`nl00`000003YL?_00000000
008000001JG3k`00000000000:G3k`03000000>U`nl0000000000`000003YL?_0000000000800000
0jG3k`0000000005000000>U`nl0000000000P000005YL?_000000000000YL?_00<000000jG3k`00
00000003000000>U`nl0000000000P000003YL?_00000000008000000jG3k`0000000005000000FU
`nl000000000002U`nl00`000003YL?_0000000000<000000jG3k`0000000002000000>U`nl00000
00000P000003YL?_0000000000D000001JG3k`00000000000:G3k`03000000>U`nl0000000000`00
0004YL?_0000000000002?ooo`030000oooooooo007oool006koool20000M_ooo`D00002`Z2g00@0
002mV;6mV;400004oooo100002coool300007_ooo`8000000nNmZ`0000000002000000?_bJ/00000
00000`000004k<B[00000000h[N[0P000004gk>Z00000000hkJY0P000004i[ZY00000000i;VY1@00
0005l<RY000000000000klNY00@000001^ZoY`0000000>BfY`000?78Y`8000000jG3k`0000000005
000000>U`nl0000000000P000003YL?_0000000000<00002YL?_0`000005YL?_000000000000YL?_
00<000000jG3k`0000000002000000>U`nl0000000001@000003YL?_0000000000<00002YL?_0`00
0005YL?_000000000000YL?_00<000000jG3k`0000000002000000>U`nl0000000001@000003YL?_
0000000000<00002YL?_0`000003YL?_0000000000D000000jG3k`0000000002000000>U`nl00000
00001@000003YL?_0000000000<00002YL?_0`000003YL?_0000000000D000000jG3k`0000000002
000000>U`nl0000000001@000003YL?_0000000000<00002YL?_0P0000Ooool00`000?ooooooo`01
oooo001`oooo00<0003oooooool0Loooo`<00002RhoB0P0000:mV;400`000?ooooooo`05oooo00<0
003oooooool0:oooo`030000oooooooo01ooool2000000?ccj/0000000000`000003j;n[0000i;Z[
008000001^W0Z`0000000?CAZP000=ncZPH000000o39Z@000>BiZ@02000000GheJH000000000003/
`jT010000005llfX000000000000lLNW00L000001JG3k`00000000000:G3k`03000000>U`nl00000
00000P0000:U`nl00`000:G3k`000002000000FU`nl000000000002U`nl00`000005YL?_00000000
0000YL?_00L000000jG3k`000000000200000ZG3k`030000YL?_0000008000001JG3k`0000000000
0:G3k`03000000FU`nl000000000002U`nl01`000003YL?_0000000000800002YL?_00<0002U`nl0
00000P000005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`07000000>U`nl00000
00000P0000:U`nl00`000:G3k`000002000000FU`nl000000000002U`nl00`000005YL?_00000000
0000YL?_00L000000jG3k`000000000200000ZG3k`030000YL?_0000008000000jG3k`0000000006
oooo00<0003oooooool00Oooo`00LOooo`030000oooooooo07?oool00`0008Z7bP000003000000>m
V;40003oool0F?ooo`8000000nc4Z`0000000002000000?X_j/0003T^Z/00P000005jL2[00000000
0000gk>Z008000000n6fZP0000000003000000?T^JT0000000000P000005jl6Y000000000000jl6Y
00P000001NBfY`00000000000>c2Y`03000000FU`nl000000000002U`nl00`0000>U`nl5000000FU
`nl000000000002U`nl00`000005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`03
00000jG3k`T000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl00`000004YL?_
0000000000000jG3k`T000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl00`00
0004YL?_0000000000000jG3k`T000001JG3k`00000000000:G3k`03000000FU`nl000000000002U
`nl00`000004YL?_0000000000000jG3k`T000000jG3k`0000000005oooo00<0003oooooool00Ooo
o`00L_ooo`030000oooooooo07;oool300000XZ7bP80001Koooo0`000003klV[0000000000<00000
1>c4Z`0000000>:gZ`8000001=ncZP0000000>6fZP8000001>JjZ@0000000>BiZ@D000000o38Z@00
00000003000000CccJP00000003Y_jT2000000?T]ZL0003ab:L00P000005ikZX000000000000YL?_
00<000000jG3k`0000000003000000>U`nl0000000001`000005YL?_000000000000YL?_00<00000
1JG3k`00000000000:G3k`03000000>U`nl0000000000`000003YL?_00000000008000000jG3k`00
00000002000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00<000000jG3k`00
00000003000000>U`nl0000000000P000003YL?_00000000008000000jG3k`0000000005000000FU
`nl000000000002U`nl00`000003YL?_0000000000<000000jG3k`0000000002000000>U`nl00000
00000P000003YL?_0000000000D000000jG3k`0000000005000000>U`nl0000000000`000003YL?_
00000000008000000jG3k`000000000400001_ooo`400001oooo0Oooo`00Loooo`80001boooo00<0
003oooooool00`0005goool4000000?X_j/0003T^Z/00P000004jL2[00000000m=6Z0`000003hKJZ
00000000008000001O39Z@00000000000>NlZ@04000000?/`jT0000000001P000003l<RY00000000
00@000000nNjZ00000000002000000FU`nl000000000002U`nl01@000003YL?_0000000000800000
0jG3k`0000000002000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00<00000
0jG3k`0000000003000000>U`nl0000000000P000003YL?_00000000008000000jG3k`0000000005
000000FU`nl000000000002U`nl00`000003YL?_0000000000<000000jG3k`0000000002000000>U
`nl0000000001@000003YL?_00000000008000000jG3k`0000000005000000>U`nl0000000000`00
0003YL?_00000000008000000jG3k`0000000005000000>U`nl0000000001@000003YL?_00000000
008000000jG3k`0000000008000000FU`nl000000000002U`nl00P0000Goool100000Oooo`7oool0
07Goool00`000?ooooooo`1_oooo00<0003oooooool0H_ooo`8000001>RoZ`0000000>c4Z`800000
1>:gZ`0000000=ncZP8000000n6fZP0000000003000000?T^JT0000000000P000005jl6Y00000000
0000jl6Y00P000001N:fZ@00000000000>c2Y`02000000?]`ZL0000000000P000005YL?_00000000
0000YL?_00D000000jG3k`0000000002000000>U`nl0000000000P000003YL?_0000000000D00000
1JG3k`00000000000:G3k`03000000>U`nl0000000000`000003YL?_00000000008000000jG3k`00
00000005000000>U`nl0000000000P000003YL?_0000000000D000000jG3k`0000000003000000>U
`nl0000000000P000005YL?_000000000000YL?_00<000000jG3k`0000000005000000>U`nl00000
00000P000003YL?_0000000000P000001JG3k`00000000000:G3k`03000000FU`nl000000000002U
`nl00`000003YL?_0000000000L000000jG3k`0000000003000000FU`nl000000000002U`nl00P00
00Coool100000Oooo`7oool007Koool00`000?ooooooo`1^oooo00<0003oooooool0Hoooo`800000
1>BjZ`0000000>W0Z`8000000oCAZP000=ncZP05000000CU^Z/00000003T^JT5000000?`b:T00000
00000`000004llfX00000000jKnY0P000003h[JY0000l<VY008000001>NjZ00000000>VnZ0@00000
1JG3k`00000000000:G3k`05000000>U`nl0000000000P000003YL?_0000000000D000000jG3k`00
00000002000000>U`nl0000000001@000003YL?_0000000000<000000jG3k`0000000002000000FU
`nl000000000002U`nl00`000003YL?_0000000000D000000jG3k`0000000002000000>U`nl00000
000020000005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`03000000>U`nl00000
00001`000003YL?_0000000000<000001JG3k`00000000000:G3k`03000000FU`nl000000000002U
`nl00`000005YL?_000000000000YL?_00D000000jG3k`0000000007000000>U`nl0000000000ooo
o`400001oooo0Oooo`00Moooo`030000oooooooo06goool00`000?ooooooo`1Toooo00D0003T^Z/0
0000003Y`:/00`000004gk>Z00000000hKJZ10000005l<V[000000000000ikbY00@000000nc3Z@00
00000006000000?`b:T00000000010000005ikZX000000000000jknW00@000001JG3k`0000000000
0:G3k`05000000>U`nl0000000000P000005YL?_000000000000YL?_00<000000jG3k`0000000005
000000>U`nl0000000000P000003YL?_0000000000<000000jG3k`0000000002000000FU`nl00000
0000002U`nl00`000005YL?_000000000000YL?_00<000000jG3k`0000000007000000>U`nl00000
00000`000005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`03000000FU`nl00000
0000002U`nl01@000003YL?_0000000000L000000jG3k`0000000005000000FU`nl000000000002U
`nl00`000003YL?_0000000000<000000jG3k`0000000002000000>U`nl000000000100000?oool1
00000Oooo`7oool007Soool20000KOooo`030000oooooooo06Coool2000000C/a:/00000003R]j/2
000000CO/jX00000003Q]ZX5000000?S^J/0000000000P000007jl6Y000000000000jl6Y0000k/JY
00H000001N:fZ@000?39Z@000>c2Z@02000000O]`ZL000000000003`aZL0003oool00P000005YL?_
000000000000YL?_00D000000jG3k`0000000002000000FU`nl000000000002U`nl00`000005YL?_
000000000000YL?_00<000000jG3k`0000000002000000>U`nl00000000020000005YL?_00000000
0000YL?_00<000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl01@000003YL?_
0000000000L000000jG3k`0000000005000000FU`nl000000000002U`nl00`000003YL?_00000000
00<000000jG3k`0000000002000000>U`nl0000000001@000003YL?_00000000008000000jG3k`00
00000005000000>U`nl00000000020000005YL?_000000000000YL?_00800002oooo0@00007oool1
oooo001joooo00<0003oooooool0J_ooo`030000oooooooo06Goool2000000CY`:/00000003ddJX3
000000GQ]ZX000000000003U^Z/00P000003hkV[0000000000<000000o38Z@0000000003000000Cc
cJP00000003Y_jT2000000?R]ZT0000000000P000004i[ZY00000000jKjX0`0000?oool6000000>U
`nl0000000000`000003YL?_00000000008000001JG3k`00000000000:G3k`03000000FU`nl00000
0000002U`nl00`000003YL?_0000000000L000000jG3k`0000000003000000FU`nl000000000002U
`nl00`000005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`05000000>U`nl00000
00000P000003YL?_0000000000D000000jG3k`0000000002000000>U`nl0000000001@000003YL?_
0000000000<000000jG3k`0000000002000000FU`nl000000000002U`nl00`000003YL?_00000000
00D000000jG3k`0000000007000000>U`nl0000000000`000005YL?_000000000000YL?_00800000
0oooo`000?ooo`01oooo001koooo00<0003oooooool0JOooo`030000oooooooo06Koool2000000CR
]j/00000003O/jX2000000?Q]ZX0000000000P000005l<V[000000000000i[b[00@000000nc3Z@00
00000006000000?`b:T00000000010000005i[ZY000000000000jknW00800003oooo0P000003YL?_
00000000008000000jG3k`0000000003000000>U`nl0000000000P000005YL?_000000000000YL?_
00<000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl01@000003YL?_00000000
00L000000jG3k`0000000005000000FU`nl000000000002U`nl00`000003YL?_0000000000<00000
0jG3k`0000000002000000FU`nl000000000002U`nl00`000003YL?_0000000000D000000jG3k`00
00000002000000>U`nl00000000020000005YL?_000000000000YL?_00<000001JG3k`0000000000
0:G3k`03000000FU`nl000000000002U`nl01@000003YL?_0000000000L000001:G3k`0000000000
00;oool007coool00`000?ooooooo`1Xoooo00<0003oooooool0Ioooo`8000000oCAZP000=ncZP03
000000?_bJ/0000000000P000003hkV[00000000008000001N[1Z`00000000000>_1Z@02000000?c
cJP0000000000`000005h[JY0000l<VY0000k<:Y008000001^c2Z@00000000000?36Y`0000Coool2
000000>U`nl0000000000P000003YL?_0000000000P000001JG3k`00000000000:G3k`03000000FU
`nl000000000002U`nl00`000005YL?_000000000000YL?_00D000000jG3k`0000000002000000>U
`nl0000000001@000003YL?_00000000008000000jG3k`0000000005000000>U`nl0000000000`00
0003YL?_00000000008000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl00`00
0003YL?_0000000000L000000jG3k`0000000007000000>U`nl0000000001@000005YL?_00000000
0000YL?_00<000000jG3k`0000000003000000>U`nl0000000000P000003YL?_0000000000@00001
oooo0@00007oool007goool00`000?ooooooo`1Woooo00<0003oooooool0J?ooo`8000001=ncZP00
00000>6fZP<000001>FjZ`0000000>>iZ`D000000no8Z`0000000005000000GfdZL000000000003R
]ZT010000004i[ZY00000000jKjY0`0000Koool2000000>U`nl0000000001`000003YL?_00000000
00<000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl00`000005YL?_00000000
0000YL?_00D000000jG3k`0000000002000000FU`nl000000000002U`nl00`000003YL?_00000000
00D000000jG3k`0000000002000000>U`nl00000000020000005YL?_000000000000YL?_00<00000
1JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl01@000003YL?_0000000000800000
0jG3k`0000000005000000>U`nl0000000000P000003YL?_0000000000D000000jG3k`0000000008
000000FU`nl000000000002U`nl00`00007oool007koool20000Ioooo`030000oooooooo06Woool0
1@000=ncZP0000000>6fZP04000000O`bJ/000000000003V_:/0003Z`J/00P000004jl>[00000000
k/JY10000003jKnY0000000000D000001NJjZ@00000000000>[0Z@0200001oooo`8000001JG3k`00
000000000:G3k`05000000>U`nl0000000001`000005YL?_000000000000YL?_00<000001JG3k`00
000000000:G3k`03000000>U`nl0000000000`000003YL?_00000000008000001JG3k`0000000000
0:G3k`03000000FU`nl000000000002U`nl00`000003YL?_0000000000L000000jG3k`0000000007
000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00<000000jG3k`0000000003
000000>U`nl0000000000P000005YL?_000000000000YL?_00<000000jG3k`0000000005000000>U
`nl0000000001`000003YL?_0000000000L000000jG3k`0000000001oooo0020oooo00<0003ooooo
ool0I?ooo`030000oooooooo06Woool3000000CQ]ZX00000003V_:/3000000?S^J/0000000000`00
0004klR[00000000j/6[0P000003llfX00000000008000001_38Z@0000000?39Z@000>c2Z@800000
1^c2Z@00000000000>o7Z@0000Soool2000000FU`nl000000000002U`nl01@000003YL?_00000000
008000000jG3k`0000000002000000>U`nl0000000001@000003YL?_0000000000D000000jG3k`00
00000003000000>U`nl0000000000P000005YL?_000000000000YL?_00<000001JG3k`0000000000
0:G3k`03000000FU`nl000000000002U`nl01@000003YL?_00000000008000000jG3k`0000000002
000000>U`nl0000000001@000003YL?_0000000000D000000jG3k`0000000008000000FU`nl00000
0000002U`nl00`000005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`05000000>U
`nl0000000000P000003YL?_0000000000@00001oooo0021oooo00<0003oooooool0Hoooo`030000
oooooooo06[oool2000000GQ]ZX000000000003U^Z/00P000003hkV[0000000000@000000n_3Z`00
00000004000000GfdZL000000000003R]ZT010000004i[ZY00000000jKjY0`0000[oool2000000FU
`nl000000000002U`nl01@000003YL?_00000000008000000jG3k`0000000005000000>U`nl00000
00001@000003YL?_00000000008000000jG3k`0000000008000000FU`nl000000000002U`nl00`00
0005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`05000000>U`nl0000000000P00
0003YL?_0000000000D000000jG3k`0000000005000000>U`nl0000000001`000003YL?_00000000
00L000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl00`000003YL?_00000000
00<000000jG3k`0000000002000000BU`nl0000000000003oooo0022oooo00<0003oooooool0H_oo
o`030000oooooooo06_oool2000000G_bJ/000000000003`bJ/00`000003i[b[0000j/6[00<00000
0n[1Z`000>k7Z`04000000GY_jT000000000003`bJT00`000005i[ZY000000000000j/2Y0080000;
oooo0P000005YL?_000000000000YL?_00D000000jG3k`0000000002000000FU`nl000000000002U
`nl00`000005YL?_000000000000YL?_00<000000jG3k`0000000007000000>U`nl0000000001`00
0005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`03000000>U`nl0000000000`00
0003YL?_00000000008000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl00`00
0005YL?_000000000000YL?_00D000000jG3k`0000000002000000>U`nl0000000000P000003YL?_
0000000000D000000jG3k`0000000005000000>U`nl000000000200000Koool008?oool20000H_oo
o`030000oooooooo06coool2000000GV_:/000000000003S^J/01@000003klR[0000000000<00000
0o;>Z`0000000002000000G`b:T000000000003X_ZT00`000003k<:Y000000000080000=oooo0P00
0005YL?_000000000000YL?_00D000000jG3k`0000000002000000>U`nl0000000001@000005YL?_
000000000000YL?_00<000001JG3k`00000000000:G3k`05000000>U`nl0000000000P000003YL?_
0000000000X000000jG3k`0000000005000000>U`nl00000000020000003YL?_0000000000D00000
1JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl01@000003YL?_0000000000800000
0jG3k`0000000005000000>U`nl0000000001@000003YL?_0000000000L0000;oooo0025oooo00<0
003oooooool0Goooo`030000oooooooo06goool2000000CU^Z/00000003S^J/3000000CZ`J/00000
003[`j/6000000GfdjT000000000003R]ZT00`000005k<:Y000000000000jKjY00<0000>oooo0P00
0005YL?_000000000000YL?_00D000000jG3k`0000000005000000>U`nl0000000000P000005YL?_
000000000000YL?_00<000001JG3k`00000000000:G3k`05000000>U`nl0000000001@000003YL?_
00000000008000000jG3k`0000000005000000>U`nl0000000001`000003YL?_0000000000D00000
0jG3k`0000000007000000>U`nl0000000001@000003YL?_0000000000<000000jG3k`0000000005
000000>U`nl0000000000P000005YL?_000000000000YL?_00<000000jG3k`000000000200003ooo
o`00Q_ooo`030000oooooooo05koool00`000?ooooooo`1^oooo0P000005l<V[000000000000i[b[
008000001^o8Z`0000000>[1Z`000>k7Z`@000001NRoZ`00000000000?39Z@03000000GV^ZT00000
0000003Z`:T00P0000ooool6000000>U`nl0000000001@000003YL?_0000000000<000000jG3k`00
00000002000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00L000000jG3k`00
00000003000000>U`nl0000000000P000005YL?_000000000000YL?_00<000001JG3k`0000000000
0:G3k`07000000>U`nl0000000000`000003YL?_00000000008000000jG3k`0000000005000000>U
`nl0000000000P000003YL?_0000000000D000000jG3k`0000000008000000FU`nl000000000002U
`nl00`0001?oool008Ooool00`000?ooooooo`1Moooo00<0003oooooool0Koooo`8000000n>iZ`00
00000004000000?[`j/0000000000P000003l/j[00000000008000001No9Z`00000000000>RnZ@03
000000?/`ZT0000000000P00013oool2000000>U`nl0000000000P000003YL?_0000000000D00000
0jG3k`0000000008000000FU`nl000000000002U`nl00`000005YL?_000000000000YL?_00<00000
1JG3k`00000000000:G3k`05000000>U`nl0000000000P000005YL?_000000000000YL?_00<00000
1JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl01@000003YL?_0000000000800000
1JG3k`00000000000:G3k`03000000>U`nl0000000001@000003YL?_0000000000L000000jG3k`00
0000000700005_ooo`00R?ooo`80001Moooo00<0003oooooool0L?ooo`030000hkV[000000800000
1N[1Z`00000000000>[1Z`05000000GfdjT000000000003Q]Z/00`000005k<:Y000000000000jKjY
00<0000Aoooo0P000003YL?_0000000000D000000jG3k`0000000007000000>U`nl0000000001`00
0003YL?_0000000000D000000jG3k`0000000005000000>U`nl00000000020000005YL?_00000000
0000YL?_00<000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl01@000003YL?_
00000000008000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl00`000005YL?_
000000000000YL?_00D000000jG3k`000000000200006_ooo`00R_ooo`030000oooooooo05[oool0
0`000?ooooooo`1`oooo0`000004i[b[00000000klR[10000003k/N[0000000000<000001>o9Z`00
00000?3:Z`<000001>JjZ@0000000>VnZ@80000Coooo0P000005YL?_000000000000YL?_00<00000
1JG3k`00000000000:G3k`05000000>U`nl0000000000P000003YL?_0000000000D000000jG3k`00
00000005000000>U`nl0000000001`000003YL?_0000000000L000000jG3k`0000000005000000>U
`nl0000000001@000003YL?_0000000000P000001JG3k`00000000000:G3k`03000000FU`nl00000
0000002U`nl00`000005YL?_000000000000YL?_00D0000Noooo002;oooo00<0003oooooool0FOoo
o`030000oooooooo077oool3000000CZ`J/00000003[`j/5000000?_b:/0000000000P000004hKJ[
00000000ikj[0`000005k<:Y00000000j/2Y000001Coool2000000FU`nl000000000002U`nl00`00
0005YL?_000000000000YL?_00D000000jG3k`0000000002000000FU`nl000000000002U`nl00`00
0005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`05000000>U`nl0000000000P00
0003YL?_0000000000D000000jG3k`0000000005000000>U`nl0000000001`000003YL?_00000000
00L000000jG3k`0000000005000000>U`nl0000000001P0002;oool008coool00`000?ooooooo`1H
oooo00<0003oooooool0Loooo`8000001>o8Z`0000000>[1Z`D000000oKCZ@0000000005000000G[
`j/000000000003Y_ZT00`0001Goool2000000FU`nl000000000002U`nl00`000005YL?_00000000
0000YL?_00D000000jG3k`0000000002000000FU`nl000000000002U`nl00`000005YL?_00000000
0000YL?_00<000001JG3k`00000000000:G3k`05000000>U`nl0000000000P000005YL?_00000000
0000YL?_00<000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl01@000003YL?_
00000000008000000jG3k`0000000005000000>U`nl0000000001P0002Koool008goool20000F?oo
o`030000oooooooo07Coool2000000G[`j/000000000003^aj/01P000003hKJ[0000l<Z[00<00000
1>FkZ`0000000>VnZ@80000Goooo0P000005YL?_000000000000YL?_00<000001JG3k`0000000000
0:G3k`05000000>U`nl0000000000P000003YL?_0000000000D000001JG3k`00000000000:G3k`03
000000FU`nl000000000002U`nl01@000003YL?_00000000008000000jG3k`0000000005000000FU
`nl000000000002U`nl00`000005YL?_000000000000YL?_00D000000jG3k`0000000002000000>U
`nl0000000001@000004YL?_000000000000:_ooo`00Soooo`030000oooooooo05Goool00`000?oo
ooooo`1eoooo0P000003j/6[00000000008000000no8Z`0000000002000000CQ]Z/00000003W_Z/3
000000G[`j/00000003Z`:T000006?ooo`8000001JG3k`00000000000:G3k`03000000FU`nl00000
0000002U`nl01@000003YL?_0000000000D000000jG3k`0000000002000000FU`nl000000000002U
`nl00`000005YL?_000000000000YL?_00D000000jG3k`0000000005000000>U`nl0000000000P00
0005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`05000000>U`nl0000000002P00
02goool0093oool00`000?ooooooo`1Coooo00<0003oooooool0Moooo`8000000nk7Z`0000000002
000000?fdjT0003_bJ/01@000005jl>[000000000000j;j[0080000Joooo0P000005YL?_00000000
0000YL?_00<000001JG3k`00000000000:G3k`07000000>U`nl00000000020000005YL?_00000000
0000YL?_00L000000jG3k`0000000005000000>U`nl00000000030000003YL?_0000000000D00000
0jG3k`000000000;0000<Oooo`00TOooo`030000oooooooo05;oool00`000?ooooooo`1hoooo0P00
0003k/N[0000000000@000000n6fZ`000?3:Z`03000000CU^j/00000003X_Z/200006oooo`H00000
0jG3k`0000000008000000>U`nl0000000001`000003YL?_0000000000X000000jG3k`0000000005
000000>U`nl0000000001`000003YL?_00000000008000000jG3k`0000000005000000>U`nl00000
00001@000003YL?_0000000000<0000eoooo002Boooo0P0005;oool00`000?ooooooo`1ioooo0`00
0003klR[0000000000D000000nNnZ`0000000002000000CX_Z/0003Y`:/0000Koooo0P000003YL?_
0000000000D000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl01@000003YL?_
00000000008000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl00`000005YL?_
000000000000YL?_00D000000jG3k`0000000002000000FU`nl000000000002U`nl00`000005YL?_
000000000000YL?_00@0000ioooo002Doooo00<0003oooooool0Coooo`030000oooooooo07[oool3
000000CfdjT00000003Q]Z/4000000G[`j/000000000003X_Z/00P0001goool2000000>U`nl00000
00001@000005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`05000000>U`nl00000
00000P000003YL?_0000000000D000001JG3k`00000000000:G3k`03000000FU`nl000000000002U
`nl01@000003YL?_00000000008000000jG3k`0000000005000000BU`nl000000000000moooo002E
oooo00<0003oooooool0C_ooo`030000oooooooo07coool4000000?Q]Z/0003`bZ/00`000006iK^[
000000000000jL2[00007_ooo`D000000jG3k`0000000002000000FU`nl000000000002U`nl00`00
0005YL?_000000000000YL?_00D000000jG3k`0000000005000000>U`nl0000000000P000005YL?_
000000000000YL?_00<000001JG3k`00000000000:G3k`05000000>U`nl0000000002P00043oool0
09Koool00`000?ooooooo`1=oooo00<0003oooooool0O?ooo`<000001N6fZ`00000000000>NnZ`04
000000CX_Z/000000000000Poooo10000003YL?_00000000008000001JG3k`00000000000:G3k`03
000000FU`nl000000000002U`nl01`000003YL?_0000000000P000001JG3k`00000000000:G3k`07
000000>U`nl0000000002`0004Coool009Ooool00`000?ooooooo`1<oooo00<0003oooooool0OOoo
o`8000000n6fZ`0000000002000000?[`j/0000000000P000003jL2[0000oooo027oool4000000>U
`nl0000000000P000005YL?_000000000000YL?_00<000001JG3k`00000000000:G3k`0<000000>U
`nl0000000002P000003YL?_0000000000D000000jG3k`00000000030000B?ooo`00V?ooo`80001<
oooo00<0003oooooool0O_ooo`<000001o3:Z`00000000000>FkZ`000>RnZ`0300008oooo`T00000
0jG3k`000000000<000000FU`nl000000000002U`nl01@000003YL?_00000000008000000jG3k`00
00000005000000FU`nl000000000002U`nl0100004coool009[oool00`000?ooooooo`19oooo00<0
003oooooool0Ooooo`<000000nNnZ`0000000002000000CX_Z/000000000000Soooo10000003YL?_
0000000000D000000jG3k`0000000002000000FU`nl000000000002U`nl00`000005YL?_00000000
0000YL?_00D000000jG3k`0000000005000000>U`nl0000000000P000004YL?_000000000000D?oo
o`00Voooo`030000oooooooo04Soool00`000?ooooooo`21oooo0P000003jl>[0000000000800000
0nW0Z`000?ooo`0Toooo1P000003YL?_0000000000<000000jG3k`0000000002000000FU`nl00000
0000002U`nl00`000005YL?_000000000000YL?_00L000000jG3k`0000000003000000>U`nl00000
00000P0005?oool009coool00`000?ooooooo`17oooo00<0003oooooool0P_ooo`8000000nFkZ`00
0>RnZ`0300009_ooo`8000001JG3k`00000000000:G3k`05000000>U`nl0000000000P000005YL?_
000000000000YL?_00<000001JG3k`00000000000:G3k`03000000FU`nl000000000002U`nl01@00
05Ooool009goool20000Aoooo`030000oooooooo08?oool4000000?Y`:/0000000009oooo`800000
1JG3k`00000000000:G3k`05000000>U`nl0000000000P000003YL?_0000000000D000001JG3k`00
000000000:G3k`080000Foooo`00Woooo`030000oooooooo04Coool00`000?ooooooo`23oooo0P00
0004j;j[000000000000:Oooo`8000001JG3k`00000000000:G3k`05000000>U`nl0000000004P00
05ooool00:3oool00`000?ooooooo`13oooo00<0003oooooool0Q?ooo`8000000nW0Z`000000000Z
oooo0P000005YL?_000000000000YL?_00`000000jG3k`0000000002000000BU`nl000000000001S
oooo002Qoooo00<0003oooooool0@_ooo`030000oooooooo08Goool2000000?_b:/0003oool0:_oo
o`T000001JG3k`00000000000:G3k`05000000>U`nl0000000000P0006Koool00:;oool20000@_oo
o`030000oooooooo08Koool20000;?ooo`8000001JG3k`00000000000:G3k`03000000FU`nl00000
0000002U`nl01@0006[oool00:Coool00`000?ooooooo`0ooooo00<0003oooooool0Qoooo`030000
oooooooo02_oool2000000>U`nl0000000001@000003YL?_000000000080001^oooo002Uoooo00<0
003oooooool0?_ooo`030000oooooooo0;Koool5000000>U`nl0000000000P0007;oool00:Koool0
0`000?ooooooo`0moooo00<0003oooooool0^?ooo`@0001foooo002Woooo0P0003goool00`000?oo
ooooo`2eoooo0`0007[oool00:Woool00`000?ooooooo`0joooo00<0003oooooool0/Oooo`@0001m
oooo002Zoooo00<0003oooooool0>Oooo`030000oooooooo0:goool40000POooo`00Zoooo`030000
oooooooo03Soool00`000?ooooooo`2Yoooo100008Goool00:coool00`000?ooooooo`0goooo00<0
003oooooool0YOooo`@00029oooo002]oooo0P0003Ooool00`000?ooooooo`2Qoooo100008goool0
0:ooool00`000?ooooooo`0doooo00<0003oooooool0W_ooo`<0002Aoooo002`oooo00<0003ooooo
ool0<oooo`030000oooooooo09[oool40000U?ooo`00/Oooo`030000oooooooo03;oool00`000?oo
ooooo`2Foooo100009Soool00;;oool20000<Oooo`030000oooooooo09?oool40000W?ooo`00]?oo
o`030000oooooooo02koool00`000?ooooooo`2?oooo10000:3oool00;Goool00`000?ooooooo`0]
oooo00<0003oooooool0S?ooo`<0002Toooo002foooo00<0003oooooool0;?ooo`030000oooooooo
08Soool40000Yoooo`00]oooo`80000/oooo00<0003oooooool0Q?ooo`@0002[oooo002ioooo00<0
003oooooool0:Oooo`030000oooooooo083oool40000[oooo`00^_ooo`030000oooooooo02Soool0
0`000?ooooooo`1loooo10000;?oool00;_oool00`000?ooooooo`0Woooo00<0003oooooool0N?oo
o`@0002goooo002loooo0P0002Ooool00`000?ooooooo`1eoooo0`000;_oool00;koool00`000?oo
ooooo`0Toooo00<0003oooooool0LOooo`@0002noooo002ooooo00<0003oooooool08oooo`030000
oooooooo06goool40000`_ooo`00`?ooo`030000oooooooo02;oool00`000?ooooooo`1Yoooo1000
0<Koool00<7oool00`000?ooooooo`0Qoooo00<0003oooooool0IOooo`@0003:oooo0032oooo0P00
027oool00`000?ooooooo`1Roooo0`000<koool00<Coool00`000?ooooooo`0Noooo00<0003ooooo
ool0G_ooo`@0003Aoooo0035oooo00<0003oooooool07Oooo`030000oooooooo05[oool40000eOoo
o`00a_ooo`030000oooooooo01coool00`000?ooooooo`1Foooo10000=Woool00<Ooool200007?oo
o`030000oooooooo05;oool40000gOooo`00bOooo`030000oooooooo01Woool00`000?ooooooo`1?
oooo0`000>7oool00<[oool00`000?ooooooo`0Hoooo00<0003oooooool0Boooo`@0003Toooo003;
oooo00<0003oooooool05oooo`030000oooooooo04Ooool40000j?ooo`00c?ooo`80000Goooo00<0
003oooooool0@oooo`@0003/oooo003>oooo00<0003oooooool05?ooo`030000oooooooo03ooool4
0000l?ooo`00coooo`030000oooooooo01?oool00`000?ooooooo`0koooo10000?Coool00=3oool0
0`000?ooooooo`0Boooo00<0003oooooool0>?ooo`<0003hoooo003Aoooo0P0001;oool00`000?oo
ooooo`0doooo10000?_oool00=?oool00`000?ooooooo`0?oooo00<0003oooooool0<?ooo`@0003o
oooo003Doooo00<0003oooooool03Oooo`030000oooooooo02goool40000ooooo`Coool00=Goool0
0`000?ooooooo`0<oooo00<0003oooooool0:Oooo`@0003ooooo2?ooo`00e_ooo`80000<oooo00<0
003oooooool09_ooo`<0003ooooo3?ooo`00f?ooo`030000oooooooo00Woool00`000?ooooooo`0R
oooo10000?ooool?oooo003Ioooo00<0003oooooool02?ooo`030000oooooooo01koool40000oooo
oa?oool00=[oool00`000?ooooooo`07oooo00<0003oooooool06_ooo`@0003ooooo5oooo`00fooo
o`030000oooooooo00Koool00`000?ooooooo`0Foooo10000?oooolKoooo003Loooo0P0000Koool0
0`000?ooooooo`0Boooo10000?oooolOoooo003Noooo00<0003oooooool00oooo`030000oooooooo
00ooool30000ooooob?oool00=ooool00`000?ooooooo`02oooo00<0003oooooool02oooo`@0003o
oooo9_ooo`00h?ooo`050000oooooooooooo000000Woool40000ooooob[oool00>7oool2000000?o
ool0003oool01?ooo`@0003ooooo;_ooo`00hoooo`8000000oooo`00000000020000oooooc;oool0
0>Coool20000ooooocKoool00?oooooooooo7Oooo`00oooooooooolMoooo003ooooooooooagoool0
0?oooooooooo7Oooo`00oooooooooolMoooo003ooooooooooagoool00?oooooooooo7Oooo`00oooo
oooooolMoooo003ooooooooooagoool00001\
\>"],
  ImageRangeCache->{{{0, 538}, {436.063, 0}} -> {-0.0452004, 0.0467096, 
  0.00185464, 0.00185464}}]
}, Open  ]],

Cell[TextData["Obliczenie b\[LSlash]\:0119du sumarycznego E"], "MathCaption"],

Cell[BoxData[
    \(\(ES = e1 + W\ e2; \)\)], "Input",
  CellLabel->"In[31]:="],

Cell["Detekcja minim\[OAcute]w i konwersja na Hz", "MathCaption"],

Cell[BoxData[
    \(\(FS = DetMinK[ES]; \)\)], "Input",
  CellLabel->"In[32]:="],

Cell["Wykres wyniku detekcji", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[FS, PlotRange -> All, PlotJoined -> True, 
      PlotStyle -> RGBColor[0, 0, 1]]; \)\)], "Input",
  CellLabel->"In[33]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0181406 0.00566893 -4.7917 0.035074 [
[.15986 .10616 -6 -9 ]
[.15986 .10616 6 0 ]
[.30159 .10616 -6 -9 ]
[.30159 .10616 6 0 ]
[.44331 .10616 -6 -9 ]
[.44331 .10616 6 0 ]
[.58503 .10616 -9 -9 ]
[.58503 .10616 9 0 ]
[.72676 .10616 -9 -9 ]
[.72676 .10616 9 0 ]
[.86848 .10616 -9 -9 ]
[.86848 .10616 9 0 ]
[.00564 .03097 -30 -4.5 ]
[.00564 .03097 0 4.5 ]
[.00564 .20634 -30 -4.5 ]
[.00564 .20634 0 4.5 ]
[.00564 .29403 -18 -4.5 ]
[.00564 .29403 0 4.5 ]
[.00564 .38171 -30 -4.5 ]
[.00564 .38171 0 4.5 ]
[.00564 .4694 -18 -4.5 ]
[.00564 .4694 0 4.5 ]
[.00564 .55708 -30 -4.5 ]
[.00564 .55708 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.15986 .11866 m
.15986 .12491 L
s
[(25)] .15986 .10616 0 1 Mshowa
.30159 .11866 m
.30159 .12491 L
s
[(50)] .30159 .10616 0 1 Mshowa
.44331 .11866 m
.44331 .12491 L
s
[(75)] .44331 .10616 0 1 Mshowa
.58503 .11866 m
.58503 .12491 L
s
[(100)] .58503 .10616 0 1 Mshowa
.72676 .11866 m
.72676 .12491 L
s
[(125)] .72676 .10616 0 1 Mshowa
.86848 .11866 m
.86848 .12491 L
s
[(150)] .86848 .10616 0 1 Mshowa
.125 Mabswid
.04649 .11866 m
.04649 .12241 L
s
.07483 .11866 m
.07483 .12241 L
s
.10317 .11866 m
.10317 .12241 L
s
.13152 .11866 m
.13152 .12241 L
s
.18821 .11866 m
.18821 .12241 L
s
.21655 .11866 m
.21655 .12241 L
s
.2449 .11866 m
.2449 .12241 L
s
.27324 .11866 m
.27324 .12241 L
s
.32993 .11866 m
.32993 .12241 L
s
.35828 .11866 m
.35828 .12241 L
s
.38662 .11866 m
.38662 .12241 L
s
.41497 .11866 m
.41497 .12241 L
s
.47166 .11866 m
.47166 .12241 L
s
.5 .11866 m
.5 .12241 L
s
.52834 .11866 m
.52834 .12241 L
s
.55669 .11866 m
.55669 .12241 L
s
.61338 .11866 m
.61338 .12241 L
s
.64172 .11866 m
.64172 .12241 L
s
.67007 .11866 m
.67007 .12241 L
s
.69841 .11866 m
.69841 .12241 L
s
.7551 .11866 m
.7551 .12241 L
s
.78345 .11866 m
.78345 .12241 L
s
.81179 .11866 m
.81179 .12241 L
s
.84014 .11866 m
.84014 .12241 L
s
.89683 .11866 m
.89683 .12241 L
s
.92517 .11866 m
.92517 .12241 L
s
.95351 .11866 m
.95351 .12241 L
s
.98186 .11866 m
.98186 .12241 L
s
.25 Mabswid
0 .11866 m
1 .11866 L
s
.01814 .03097 m
.02439 .03097 L
s
[(137.5)] .00564 .03097 1 0 Mshowa
.01814 .20634 m
.02439 .20634 L
s
[(142.5)] .00564 .20634 1 0 Mshowa
.01814 .29403 m
.02439 .29403 L
s
[(145)] .00564 .29403 1 0 Mshowa
.01814 .38171 m
.02439 .38171 L
s
[(147.5)] .00564 .38171 1 0 Mshowa
.01814 .4694 m
.02439 .4694 L
s
[(150)] .00564 .4694 1 0 Mshowa
.01814 .55708 m
.02439 .55708 L
s
[(152.5)] .00564 .55708 1 0 Mshowa
.125 Mabswid
.01814 .04851 m
.02189 .04851 L
s
.01814 .06605 m
.02189 .06605 L
s
.01814 .08358 m
.02189 .08358 L
s
.01814 .10112 m
.02189 .10112 L
s
.01814 .1362 m
.02189 .1362 L
s
.01814 .15373 m
.02189 .15373 L
s
.01814 .17127 m
.02189 .17127 L
s
.01814 .18881 m
.02189 .18881 L
s
.01814 .22388 m
.02189 .22388 L
s
.01814 .24142 m
.02189 .24142 L
s
.01814 .25895 m
.02189 .25895 L
s
.01814 .27649 m
.02189 .27649 L
s
.01814 .31157 m
.02189 .31157 L
s
.01814 .3291 m
.02189 .3291 L
s
.01814 .34664 m
.02189 .34664 L
s
.01814 .36418 m
.02189 .36418 L
s
.01814 .39925 m
.02189 .39925 L
s
.01814 .41679 m
.02189 .41679 L
s
.01814 .43432 m
.02189 .43432 L
s
.01814 .45186 m
.02189 .45186 L
s
.01814 .48694 m
.02189 .48694 L
s
.01814 .50447 m
.02189 .50447 L
s
.01814 .52201 m
.02189 .52201 L
s
.01814 .53955 m
.02189 .53955 L
s
.01814 .01344 m
.02189 .01344 L
s
.01814 .57462 m
.02189 .57462 L
s
.01814 .59216 m
.02189 .59216 L
s
.01814 .60969 m
.02189 .60969 L
s
.25 Mabswid
.01814 0 m
.01814 .61803 L
s
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02948 .30052 L
.03515 .30052 L
.04082 .30052 L
.04649 .30052 L
.05215 .30052 L
.05782 .30052 L
.06349 .30052 L
.06916 .30052 L
.07483 .30052 L
.0805 .30052 L
.08617 .30052 L
.09184 .30052 L
.09751 .30052 L
.10317 .30052 L
.10884 .30052 L
.11451 .30052 L
.12018 .30052 L
.12585 .30052 L
.13152 .30052 L
.13719 .30052 L
.14286 .30052 L
.14853 .30052 L
.1542 .30052 L
.15986 .30052 L
.16553 .30052 L
.1712 .30052 L
.17687 .60332 L
.18254 .30052 L
.18821 .60332 L
.19388 .30052 L
.19955 .60332 L
.20522 .30052 L
.21088 .60332 L
.21655 .30052 L
.22222 .30052 L
.22789 .30052 L
.23356 .30052 L
.23923 .30052 L
.2449 .30052 L
.25057 .30052 L
.25624 .30052 L
.2619 .30052 L
.26757 .30052 L
.27324 .30052 L
.27891 .30052 L
.28458 .30052 L
.29025 .30052 L
.29592 .30052 L
.30159 .30052 L
Mistroke
.30726 .30052 L
.31293 .30052 L
.31859 .30052 L
.32426 .30052 L
.32993 .60332 L
.3356 .30052 L
.34127 .60332 L
.34694 .30052 L
.35261 .60332 L
.35828 .30052 L
.36395 .60332 L
.36961 .30052 L
.37528 .30052 L
.38095 .30052 L
.38662 .60332 L
.39229 .30052 L
.39796 .30052 L
.40363 .30052 L
.4093 .30052 L
.41497 .30052 L
.42063 .30052 L
.4263 .30052 L
.43197 .30052 L
.43764 .30052 L
.44331 .30052 L
.44898 .30052 L
.45465 .30052 L
.46032 .30052 L
.46599 .30052 L
.47166 .30052 L
.47732 .30052 L
.48299 .60332 L
.48866 .30052 L
.49433 .60332 L
.5 .30052 L
.50567 .60332 L
.51134 .30052 L
.51701 .30052 L
.52268 .30052 L
.52834 .30052 L
.53401 .30052 L
.53968 .60332 L
.54535 .30052 L
.55102 .60332 L
.55669 .30052 L
.56236 .60332 L
.56803 .30052 L
.5737 .30052 L
.57937 .30052 L
.58503 .30052 L
Mistroke
.5907 .30052 L
.59637 .30052 L
.60204 .30052 L
.60771 .30052 L
.61338 .30052 L
.61905 .30052 L
.62472 .30052 L
.63039 .30052 L
.63605 .30052 L
.64172 .30052 L
.64739 .60332 L
.65306 .30052 L
.65873 .60332 L
.6644 .30052 L
.67007 .30052 L
.67574 .30052 L
.68141 .30052 L
.68707 .30052 L
.69274 .60332 L
.69841 .30052 L
.70408 .60332 L
.70975 .30052 L
.71542 .60332 L
.72109 .30052 L
.72676 .60332 L
.73243 .30052 L
.7381 .30052 L
.74376 .30052 L
.74943 .30052 L
.7551 .30052 L
.76077 .30052 L
.76644 .30052 L
.77211 .30052 L
.77778 .30052 L
.78345 .30052 L
.78912 .30052 L
.79478 .30052 L
.80045 .30052 L
.80612 .30052 L
.81179 .60332 L
.81746 .30052 L
.82313 .30052 L
.8288 .30052 L
.83447 .30052 L
.84014 .30052 L
.8458 .60332 L
.85147 .30052 L
.85714 .60332 L
.86281 .30052 L
.86848 .60332 L
Mistroke
.87415 .30052 L
.87982 .60332 L
.88549 .30052 L
.89116 .30052 L
.89683 .30052 L
.90249 .30052 L
.90816 .30052 L
.91383 .30052 L
.9195 .30052 L
.92517 .30052 L
.93084 .60332 L
.93651 .30052 L
.94218 .60332 L
.94785 .30052 L
.95351 .60332 L
.95918 .30052 L
.96485 .60332 L
.97052 .30052 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[33]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo000Qoooo00<0003oooooool0o?ooo`008Oooo`030000oooooooo0?coool0027oool0
0`000?ooooooo`3loooo000Qoooo00<0003oooooool0o?ooo`008Oooo`030000003ooooo0?coool0
027oool00`000000ooooo`3loooo0005oooo1@000003oooo0000000000Coool00`000?ooooooo`02
oooo00<0003oooooool00_ooo`030000oooooooo00?oool00`000000ooooo`3loooo0007oooo00<0
003oooooool00oooo`050000oooooooooooo000000Soool00`000?ooo`000004oooo00<000000?oo
ool0o?ooo`001oooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0003oooooool02?oo
o`030000oooooooo00;oool00`000000ooooo`3loooo0007oooo00<0003oooooool00oooo`030000
oooooooo00;oool00`000?ooooooo`05oooo0P0000Goool00`000000ooooo`3loooo0007oooo00L0
003oooooooooool0003oool000000_ooo`030000oooo000000Ooool00`000?ooooooo`04oooo00<0
00000?ooool0o?ooo`001_ooo`800004oooo00@0003oooooooooool300001oooo`<00004oooo00<0
00000?ooool0o?ooo`008Oooo`030000003ooooo0?coool0027oool00`000000ooooo`3loooo000Q
oooo00<000000?ooool0o?ooo`008Oooo`030000003ooooo0?coool0027oool00`000000ooooo`3l
oooo000Qoooo00<000000?ooool0o?ooo`008Oooo`030000003ooooo0?coool0027oool00`000000
ooooo`3loooo000Qoooo00<000000?ooool07Oooo`<00003oooo00<0003oooooool07Oooo`030000
oooooooo00;oool00`000?ooooooo`0Moooo00<0003oooooool00_ooo`030000oooooooo01Soool5
00000_ooo`030000oooooooo00;oool00`000?ooooooo`0Eoooo1@000004oooo0000000000000ooo
o`030000oooooooo01Koool500000_ooo`030000oooooooo00;oool00`000?ooooooo`0Loooo000Q
oooo00<000000?ooool07Oooo`030000oooooooo00;oool00`000?ooo`00000Moooo00<0003oool0
00000_ooo`030000oooo000001koool01`000?ooooooooooo`000?ooo`00000Koooo00L0003ooooo
ooooool0003oool000000_ooo`030000oooo000001Soool01@000?ooooooooooo`000004oooo00<0
003oool000006Oooo`070000oooooooooooo0000oooo000000;oool00`000?ooo`00000Moooo000Q
oooo00<000000?ooool07_ooo`030000oooooooo00?oool00`000?ooooooo`0Moooo00H0003ooooo
ool0003oool0000Noooo00<0003oooooool00oooo`030000oooooooo01Woool01`000?oooooooooo
o`000?ooo`000002oooo00<0003oool000006?ooo`030000oooooooo00;oool00`000?ooooooo`03
oooo00<0003oooooool05oooo`030000oooooooo00?oool01P000?ooooooo`000?ooo`0001goool0
027oool00`000?ooo`00o`0Noooo00@0003oooooooooool200007_ooo`800003oooo00<0003oool0
00007oooo`030000oooooooo0080000Loooo00L0003oooooooooool0003oool000000_ooo`030000
oooo000001Soool00`000?ooooooo`02oooo00@0003oooooooooool200006_ooo`040000oooooooo
oooo0P0000?oool00`000?ooo`00000Moooo000Qoooo00<0003oool00?l07Oooo`030000oooo0000
00;oool00`000?ooooooo`0Moooo00<0003oooooool00_ooo`030000oooo000001goool00`000?oo
o`000002oooo00<0003oooooool06oooo`070000oooooooooooo0000oooo000000;oool00`000?oo
o`00000Hoooo00L0003oooooooooool0003oool000000_ooo`030000oooooooo01Woool01@000?oo
ooooooooo`000004oooo00<0003oool000007Oooo`008Oooo`030000oooo003o01koool010000?oo
ooooooooo`<0000Moooo0`0000?oool00`000?ooooooo`0Loooo0`0000;oool300006_ooo`800004
oooo00<0003oooooool00_ooo`030000oooooooo01Koool200001?ooo`040000oooooooooooo0`00
01Soool200000oooo`<00003oooo00<0003oooooool07?ooo`008Oooo`8000000`00ooooooooo`3j
oooo000Qoooo00<0003oool00?l0o?ooo`008Oooo`030000oooo003o0?coool0027oool00`000?oo
o`00o`3loooo000Qoooo00<0003oool00?l0o?ooo`007?ooo`L000000`00o`000000003j0000000Q
oooo00<0003oool00?l01?ooo`030000oooooooo00Coool00`000?ooooooo`05oooo00<0003ooooo
ool01?ooo`030000oooooooo00Coool00`000?ooooooo`05oooo00<0003oooooool01?ooo`030000
oooooooo00Coool00`000?ooooooo`05oooo00<0003oooooool01?ooo`030000oooooooo00Coool0
0`000?ooooooo`05oooo00<0003oooooool01?ooo`030000oooooooo00Coool00`000?ooooooo`05
oooo00<0003oooooool01?ooo`030000oooooooo00Coool00`000?ooooooo`05oooo00<0003ooooo
ool01?ooo`030000oooooooo00Coool00`000?ooooooo`05oooo00<0003oooooool01?ooo`030000
oooooooo00Coool00`000?ooooooo`05oooo00<0003oooooool01?ooo`030000oooooooo00Coool0
0`000?ooooooo`05oooo00<0003oooooool01?ooo`030000oooooooo00Coool00`000?ooooooo`05
oooo00<0003oooooool01?ooo`030000oooooooo00Coool00`000?ooooooo`04oooo00<0003ooooo
ool01Oooo`030000oooooooo00?oool0027oool00`000?ooo`00o`3loooo000Qoooo00<0003oool0
0?l0o?ooo`008Oooo`8000000`00ooooooooo`3joooo000Qoooo00<0003oool00?l0o?ooo`008Ooo
o`030000oooo003o0?coool0027oool00`000?ooo`00o`3loooo000Qoooo00<0003oool00?l0o?oo
o`008Oooo`8000000`00ooooooooo`3joooo000Qoooo00<0003oool00?l0o?ooo`008Oooo`030000
oooo003o0?coool0027oool00`000?ooo`00o`3loooo000Qoooo0P000003003ooooooooo0?[oool0
027oool00`000?ooo`00o`3loooo000Qoooo00<0003oool00?l0o?ooo`008Oooo`030000oooo003o
0?coool0027oool00`000?ooo`00o`3loooo000Qoooo0P000003003ooooooooo0?[oool0027oool0
0`000?ooo`00o`3loooo0005oooo1@0000;oool3000000Coool0000000000003oooo00<0003ooooo
ool00_ooo`030000oooooooo00?oool00`000?ooo`00o`3loooo0007oooo00<0003oooooool00ooo
o`040000oooooooo00002Oooo`030000oooo000000Coool00`000?ooo`00o`3loooo0007oooo00@0
003oooooooooool400000_ooo`030000oooooooo00Soool00`000?ooooooo`02oooo0P000003003o
oooooooo0?[oool000Ooool01`000?ooooooooooo`000?ooo`000003oooo00<0003oooooool01_oo
o`800005oooo00<0003oool00?l0o?ooo`001oooo`030000oooooooo00;oool200000_ooo`030000
oooo000000Ooool00`000?ooooooo`04oooo00<0003oool00?l0o?ooo`001_ooo`800005oooo00D0
003oooooooooool000002?ooo`<00004oooo00<0003oool00?l0o?ooo`008Oooo`030000oooo003o
0?coool0027oool2000000<00?ooooooool0n_ooo`008Oooo`030000oooo003o0?coool0027oool0
10000?ooooooo`00oo_oool0027oool010000?ooooooo`00oo_oool0027oool010000?ooooooo`00
oo_oool0027oool2000000?oool00?ooool0n_ooo`008Oooo`040000oooooooo003onoooo`008Ooo
o`040000oooooooo003onoooo`008Oooo`040000oooooooo003onoooo`008Oooo`8000000oooo`00
ooooo`3joooo000Qoooo00@0003oooooool00?okoooo000Qoooo00@0003oooooool00?okoooo000Q
oooo00@0003oooooool00?okoooo000Qoooo00@0003oooooool00?okoooo000Qoooo0P000003oooo
003ooooo0?[oool0027oool010000?ooooooo`00oo_oool000ooool500000_ooo`<00002oooo00<0
003oooooool00oooo`040000oooooooo003onoooo`004Oooo`030000oooooooo00?oool01P000?oo
ooooo`000?ooo`0000Coool010000?ooooooo`00oo_oool0017oool010000?ooooooooooo`@00003
oooo00<0003oooooool00_ooo`8000000oooo`00ooooo`3joooo000Aoooo00L0003oooooooooool0
003oool000000_ooo`800005oooo00@0003oooooool00?okoooo000Aoooo00<0003oooooool00_oo
o`800002oooo00<0003oooooool01?ooo`030000oooooooo02D00?l2oooo00@00?ooooooool00?l2
oooo00<00?ooooooool07@00o`;oool01000ooooooooo`00o`;oool00`00ooooooooo`04003o00?o
ool00?l00?l05@00o`;oool01000ooooooooo`00o`;oool7003o0_ooo`04003ooooooooo003o0_oo
oa@00?l2oooo00<00?ooooooool01`00o`;oool00`00ooooo`00o`02oooo00<00?ooooooool05000
o`;oool7003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00/00?l2oooo00@00?oooooo
ool00?l2oooo00@00?ooooooool00?l8oooo000@oooo0P0000Goool00`000?ooooooo`0300001?oo
o`030000oooooooo02Coool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool00`00oooo
ooooo`0Ioooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?oo
ool00?lEoooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l5oooo00@00?ooooooool00?l2
oooo00@00?ooooooool00?lBoooo00@00?ooooooool00?l2oooo00<00?ooooooool00oooo`06003o
oooooooo003ooooo003o0_ooo`04003ooooooooo003o4_ooo`04003ooooooooo003o1Oooo`04003o
oooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00Ooool01000ooooooooo`00
o`;oool01000ooooooooo`00o`;oool00`00ooooooooo`06oooo000Qoooo00<0003oooooool09?oo
o`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo01Woool01000oooo
ooooo`00o`;oool01000ooooooooo`00o`;oool01P00ooooooooo`00ooooo`00oaGoool01000oooo
ooooo`00o`;oool01000ooooooooo`00o`Goool01000ooooooooo`00o`;oool01000ooooooooo`00
oa;oool01000ooooooooo`00o`;oool00`00ooooooooo`03oooo00H00?ooooooool00?ooool00?l2
oooo00@00?ooooooool00?lBoooo00@00?ooooooool00?l5oooo00@00?ooooooool00?l2oooo00@0
0?ooooooool00?l2oooo00<00?ooooooool01oooo`04003ooooooooo003o0_ooo`04003ooooooooo
003o0_ooo`03003ooooooooo00Koool0027oool200009Oooo`04003ooooooooo003o0_ooo`04003o
oooooooo003o0_ooo`03003ooooooooo01Woool01000ooooooooo`00o`;oool01000ooooooooo`00
o`;oool01P00ooooooooo`00ooooo`00oaGoool01000ooooooooo`00o`;oool01000ooooooooo`00
o`Goool01000ooooooooo`00o`;oool01000ooooooooo`00oa;oool01000ooooooooo`00o`;oool0
0`00ooooooooo`03oooo00H00?ooooooool00?ooool00?l2oooo00@00?ooooooool00?lBoooo00@0
0?ooooooool00?l5oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<00?oooooo
ool01oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00Koool0
027oool00`000?ooooooo`0Toooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<0
0?ooooooool06Oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`06003ooooooooo
003ooooo003o5Oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o1Oooo`04003ooooooooo
003o0_ooo`04003ooooooooo003o4_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00?oool0
1P00ooooooooo`00ooooo`00o`;oool01000ooooooooo`00oa;oool01000ooooooooo`00o`Goool0
1000ooooooooo`00o`;oool01000ooooooooo`00o`;oool00`00ooooooooo`07oooo00@00?oooooo
ool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool01_ooo`008Oooo`030000oooooooo
02Coool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool00`00ooooooooo`0Ioooo00@0
0?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?lEoooo00@0
0?ooooooool00?l2oooo00@00?ooooooool00?l5oooo00@00?ooooooool00?l2oooo00@00?oooooo
ool00?lBoooo00@00?ooooooool00?l2oooo00<00?ooooooool00oooo`06003ooooooooo003ooooo
003o0_ooo`04003ooooooooo003o4_ooo`04003ooooooooo003o1Oooo`04003ooooooooo003o0_oo
o`04003ooooooooo003o0_ooo`03003ooooooooo00Ooool01000ooooooooo`00o`;oool01000oooo
ooooo`00o`;oool00`00ooooooooo`06oooo000Qoooo00<0003oooooool09?ooo`04003ooooooooo
003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo01Woool01000ooooooooo`00o`;oool0
1000ooooooooo`00o`;oool01P00ooooooooo`00ooooo`00oaGoool01000ooooooooo`00o`;oool0
1000ooooooooo`00o`Goool01000ooooooooo`00o`;oool01000ooooooooo`00oa;oool01000oooo
ooooo`00o`;oool00`00ooooooooo`03oooo00H00?ooooooool00?ooool00?l2oooo00@00?oooooo
ool00?lBoooo00@00?ooooooool00?l5oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2
oooo00<00?ooooooool01oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003o
oooooooo00Koool0027oool200009Oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_oo
o`03003ooooooooo01Woool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool01P00oooo
ooooo`00ooooo`00oaGoool01000ooooooooo`00o`;oool01000ooooooooo`00o`Goool01000oooo
ooooo`00o`;oool01000ooooooooo`00oa;oool01000ooooooooo`00o`;oool00`00ooooooooo`03
oooo00H00?ooooooool00?ooool00?l2oooo00@00?ooooooool00?lBoooo00@00?ooooooool00?l5
oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool01oooo`04003o
oooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00Koool0027oool00`000?oo
ooooo`0Toooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool06Ooo
o`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo003o5Ooo
o`04003ooooooooo003o0_ooo`04003ooooooooo003o1Oooo`04003ooooooooo003o0_ooo`04003o
oooooooo003o4_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00?oool01P00ooooooooo`00
ooooo`00o`;oool01000ooooooooo`00oa;oool01000ooooooooo`00o`Goool01000ooooooooo`00
o`;oool01000ooooooooo`00o`;oool00`00ooooooooo`07oooo00@00?ooooooool00?l2oooo00@0
0?ooooooool00?l2oooo00<00?ooooooool01_ooo`008Oooo`030000oooooooo02Coool01000oooo
ooooo`00o`;oool01000ooooooooo`00o`;oool00`00ooooooooo`0Ioooo00@00?ooooooool00?l2
oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?lEoooo00@00?ooooooool00?l2
oooo00@00?ooooooool00?l5oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?lBoooo00@0
0?ooooooool00?l2oooo00<00?ooooooool00oooo`06003ooooooooo003ooooo003o0_ooo`04003o
oooooooo003o4_ooo`04003ooooooooo003o1Oooo`04003ooooooooo003o0_ooo`04003ooooooooo
003o0_ooo`03003ooooooooo00Ooool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool0
0`00ooooooooo`06oooo000Qoooo00<0003oooooool09?ooo`04003ooooooooo003o0_ooo`04003o
oooooooo003o0_ooo`03003ooooooooo01Woool01000ooooooooo`00o`;oool01000ooooooooo`00
o`;oool01P00ooooooooo`00ooooo`00oaGoool01000ooooooooo`00o`;oool01000ooooooooo`00
o`Goool01000ooooooooo`00o`;oool01000ooooooooo`00oa;oool01000ooooooooo`00o`;oool0
0`00ooooooooo`03oooo00H00?ooooooool00?ooool00?l2oooo00@00?ooooooool00?lBoooo00@0
0?ooooooool00?l5oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<00?oooooo
ool01oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00Koool0
027oool00`000?ooooooo`0Toooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<0
0?ooooooool06Oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`06003ooooooooo
003ooooo003o5Oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o1Oooo`04003ooooooooo
003o0_ooo`04003ooooooooo003o4_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00?oool0
1P00ooooooooo`00ooooo`00o`;oool01000ooooooooo`00oa;oool01000ooooooooo`00o`Goool0
1000ooooooooo`00o`;oool01000ooooooooo`00o`;oool00`00ooooooooo`07oooo00@00?oooooo
ool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool01_ooo`008Oooo`80000Uoooo00@0
0?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool06Oooo`04003ooooooooo
003o0_ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo003o5Oooo`04003ooooooooo
003o0_ooo`04003ooooooooo003o1Oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o4_oo
o`04003ooooooooo003o0_ooo`03003ooooooooo00?oool01P00ooooooooo`00ooooo`00o`;oool0
1000ooooooooo`00oa;oool01000ooooooooo`00o`Goool01000ooooooooo`00o`;oool01000oooo
ooooo`00o`;oool00`00ooooooooo`07oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2
oooo00<00?ooooooool01_ooo`008Oooo`030000oooooooo02Coool01000ooooooooo`00o`;oool0
1000ooooooooo`00o`;oool00`00ooooooooo`0Ioooo00@00?ooooooool00?l2oooo00@00?oooooo
ool00?l2oooo00H00?ooooooool00?ooool00?lEoooo00@00?ooooooool00?l2oooo00@00?oooooo
ool00?l5oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?lBoooo00@00?ooooooool00?l2
oooo00<00?ooooooool00oooo`06003ooooooooo003ooooo003o0_ooo`04003ooooooooo003o4_oo
o`04003ooooooooo003o1Oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003o
oooooooo00Ooool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool00`00ooooooooo`06
oooo000Qoooo00<0003oooooool09?ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_oo
o`03003ooooooooo01Woool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool01P00oooo
ooooo`00ooooo`00oaGoool01000ooooooooo`00o`;oool01000ooooooooo`00o`Goool01000oooo
ooooo`00o`;oool01000ooooooooo`00oa;oool01000ooooooooo`00o`;oool00`00ooooooooo`03
oooo00H00?ooooooool00?ooool00?l2oooo00@00?ooooooool00?lBoooo00@00?ooooooool00?l5
oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool01oooo`04003o
oooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00Koool0027oool00`000?oo
ooooo`0Toooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool06Ooo
o`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo003o5Ooo
o`04003ooooooooo003o0_ooo`04003ooooooooo003o1Oooo`04003ooooooooo003o0_ooo`04003o
oooooooo003o4_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00?oool01P00ooooooooo`00
ooooo`00o`;oool01000ooooooooo`00oa;oool01000ooooooooo`00o`Goool01000ooooooooo`00
o`;oool01000ooooooooo`00o`;oool00`00ooooooooo`07oooo00@00?ooooooool00?l2oooo00@0
0?ooooooool00?l2oooo00<00?ooooooool01_ooo`008Oooo`80000Uoooo00@00?ooooooool00?l2
oooo00@00?ooooooool00?l2oooo00<00?ooooooool06Oooo`04003ooooooooo003o0_ooo`04003o
oooooooo003o0_ooo`06003ooooooooo003ooooo003o5Oooo`04003ooooooooo003o0_ooo`04003o
oooooooo003o1Oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o4_ooo`04003ooooooooo
003o0_ooo`03003ooooooooo00?oool01P00ooooooooo`00ooooo`00o`;oool01000ooooooooo`00
oa;oool01000ooooooooo`00o`Goool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool0
0`00ooooooooo`07oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<00?oooooo
ool01_ooo`008Oooo`030000oooooooo02Coool01000ooooooooo`00o`;oool01000ooooooooo`00
o`;oool00`00ooooooooo`0Ioooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00H0
0?ooooooool00?ooool00?lEoooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l5oooo00@0
0?ooooooool00?l2oooo00@00?ooooooool00?lBoooo00@00?ooooooool00?l2oooo00<00?oooooo
ool00oooo`06003ooooooooo003ooooo003o0_ooo`04003ooooooooo003o4_ooo`04003ooooooooo
003o1Oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00Ooool0
1000ooooooooo`00o`;oool01000ooooooooo`00o`;oool00`00ooooooooo`06oooo000Qoooo00<0
003oooooool09?ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo
01Woool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool01P00ooooooooo`00ooooo`00
oaGoool01000ooooooooo`00o`;oool01000ooooooooo`00o`Goool01000ooooooooo`00o`;oool0
1000ooooooooo`00oa;oool01000ooooooooo`00o`;oool00`00ooooooooo`03oooo00H00?oooooo
ool00?ooool00?l2oooo00@00?ooooooool00?lBoooo00@00?ooooooool00?l5oooo00@00?oooooo
ool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool01oooo`04003ooooooooo003o0_oo
o`04003ooooooooo003o0_ooo`03003ooooooooo00Koool000Goool500000_ooo`<00002oooo00<0
003oooooool00_ooo`030000oooooooo00;oool00`000?ooooooo`03oooo00<0003oooooool09?oo
o`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo01Woool01000oooo
ooooo`00o`;oool01000ooooooooo`00o`;oool01P00ooooooooo`00ooooo`00oaGoool01000oooo
ooooo`00o`;oool01000ooooooooo`00o`Goool01000ooooooooo`00o`;oool01000ooooooooo`00
oa;oool01000ooooooooo`00o`;oool00`00ooooooooo`03oooo00H00?ooooooool00?ooool00?l2
oooo00@00?ooooooool00?lBoooo00@00?ooooooool00?l5oooo00@00?ooooooool00?l2oooo00@0
0?ooooooool00?l2oooo00<00?ooooooool01oooo`04003ooooooooo003o0_ooo`04003ooooooooo
003o0_ooo`03003ooooooooo00Koool000Ooool00`000?ooooooo`03oooo00D0003oooooooooool0
00002?ooo`030000oooo000000Coool00`000?ooooooo`0Uoooo00D00?ooool00?l00?ooool00P00
o`05oooo003o003ooooo003o01_oool01@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool0
0?l00oooo`03003ooooo003o01Koool01@00ooooo`00o`00ooooo`02003o00?oool00?ooool01Ooo
o`04003ooooo003ooooo0P00o`03oooo003ooooo01;oool01P00ooooo`00o`00ooooo`00o`Koool0
1@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool00?l04oooo`03003ooooo003o00Koool0
1@00ooooo`00o`00ooooo`02003o00Coool00?ooool00?l;oooo00L00?ooool00?l00?ooool00?oo
ool00P00o`03oooo003o003o00Soool000Ooool010000?ooooooooooo`@00002oooo00<0003ooooo
ool02?ooo`030000oooooooo00;oool200009_ooo`05003ooooo003o003ooooo00800?l01Oooo`00
o`00ooooo`00o`0Koooo00D00?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o00?oool0
0`00ooooo`00o`0Foooo00D00?ooool00?l00?ooool00P00o`03oooo003ooooo00Goool01000oooo
o`00ooooo`800?l00oooo`00ooooo`0Boooo00H00?ooool00?l00?ooool00?l6oooo00D00?ooool0
0?l00?ooool00P00o`05oooo003o003ooooo003o01?oool00`00ooooo`00o`06oooo00D00?ooool0
0?l00?ooool00P00o`04oooo003ooooo003o2oooo`07003ooooo003o003ooooo003ooooo00800?l0
0oooo`00o`00o`08oooo0007oooo00L0003oooooooooool0003oool000001?ooo`030000oooooooo
00Goool200001Oooo`030000oooooooo02Goool01@00ooooo`00o`00ooooo`02003o00Goool00?l0
0?ooool00?l06oooo`05003ooooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`03oooo00<0
0?ooool00?l05_ooo`05003ooooo003o003ooooo00800?l00oooo`00ooooo`05oooo00@00?ooool0
0?ooool2003o00?oool00?ooool04_ooo`06003ooooo003o003ooooo003o1_ooo`05003ooooo003o
003ooooo00800?l01Oooo`00o`00ooooo`00o`0Coooo00<00?ooool00?l01_ooo`05003ooooo003o
003ooooo00800?l01?ooo`00ooooo`00o`_oool01`00ooooo`00o`00ooooo`00ooooo`02003o00?o
ool00?l00?l02?ooo`001oooo`030000oooooooo00;oool200000_ooo`030000oooo000000Ooool0
0`000?ooooooo`04oooo00<0003oooooool09Oooo`05003ooooo003o003ooooo00800?l01Oooo`00
o`00ooooo`00o`0Koooo00D00?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o00?oool0
0`00ooooo`00o`0Foooo00D00?ooool00?l00?ooool00P00o`03oooo003ooooo00Goool01000oooo
o`00ooooo`800?l00oooo`00ooooo`0Boooo00H00?ooool00?l00?ooool00?l6oooo00D00?ooool0
0?l00?ooool00P00o`05oooo003o003ooooo003o01?oool00`00ooooo`00o`06oooo00D00?ooool0
0?l00?ooool00P00o`04oooo003ooooo003o2oooo`07003ooooo003o003ooooo003ooooo00800?l0
0oooo`00o`00o`08oooo0006oooo0P0000Goool00`000?ooooooo`0300001oooo`<00004oooo00<0
003oooooool09Oooo`05003ooooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`0Koooo00D0
0?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o00?oool00`00ooooo`00o`0Foooo00D0
0?ooool00?l00?ooool00P00o`03oooo003ooooo00Goool01000ooooo`00ooooo`800?l00oooo`00
ooooo`0Boooo00H00?ooool00?l00?ooool00?l6oooo00D00?ooool00?l00?ooool00P00o`05oooo
003o003ooooo003o01?oool00`00ooooo`00o`06oooo00D00?ooool00?l00?ooool00P00o`04oooo
003ooooo003o2oooo`07003ooooo003o003ooooo003ooooo00800?l00oooo`00o`00o`08oooo000Q
oooo0P0002Koool01@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool00?l06oooo`05003o
oooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`03oooo00<00?ooool00?l05_ooo`05003o
oooo003o003ooooo00800?l00oooo`00ooooo`05oooo00@00?ooool00?ooool2003o00?oool00?oo
ool04_ooo`06003ooooo003o003ooooo003o1_ooo`05003ooooo003o003ooooo00800?l01Oooo`00
o`00ooooo`00o`0Coooo00<00?ooool00?l01_ooo`05003ooooo003o003ooooo00800?l01?ooo`00
ooooo`00o`_oool01`00ooooo`00o`00ooooo`00ooooo`02003o00?oool00?l00?l02?ooo`008Ooo
o`030000oooooooo02Goool01@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool00?l06ooo
o`05003ooooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`03oooo00<00?ooool00?l05_oo
o`05003ooooo003o003ooooo00800?l00oooo`00ooooo`05oooo00@00?ooool00?ooool2003o00?o
ool00?ooool04_ooo`06003ooooo003o003ooooo003o1_ooo`05003ooooo003o003ooooo00800?l0
1Oooo`00o`00ooooo`00o`0Coooo00<00?ooool00?l01_ooo`05003ooooo003o003ooooo00800?l0
1?ooo`00ooooo`00o`_oool01`00ooooo`00o`00ooooo`00ooooo`02003o00?oool00?l00?l02?oo
o`008Oooo`030000oooooooo02Goool01@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool0
0?l06oooo`05003ooooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`03oooo00<00?ooool0
0?l05_ooo`05003ooooo003o003ooooo00800?l00oooo`00ooooo`05oooo00@00?ooool00?ooool2
003o00?oool00?ooool04_ooo`06003ooooo003o003ooooo003o1_ooo`05003ooooo003o003ooooo
00800?l01Oooo`00o`00ooooo`00o`0Coooo00<00?ooool00?l01_ooo`05003ooooo003o003ooooo
00800?l01?ooo`00ooooo`00o`_oool01`00ooooo`00o`00ooooo`00ooooo`02003o00?oool00?l0
0?l02?ooo`008Oooo`030000oooooooo02Goool01@00ooooo`00o`00ooooo`02003o00Goool00?l0
0?ooool00?l06oooo`05003ooooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`03oooo00<0
0?ooool00?l05_ooo`05003ooooo003o003ooooo00800?l00oooo`00ooooo`05oooo00@00?ooool0
0?ooool2003o00?oool00?ooool04_ooo`06003ooooo003o003ooooo003o1_ooo`05003ooooo003o
003ooooo00800?l01Oooo`00o`00ooooo`00o`0Coooo00<00?ooool00?l01_ooo`05003ooooo003o
003ooooo00800?l01?ooo`00ooooo`00o`_oool01`00ooooo`00o`00ooooo`00ooooo`02003o00?o
ool00?l00?l02?ooo`008Oooo`030000oooooooo02Goool01@00ooooo`00o`00ooooo`02003o00Go
ool00?l00?ooool00?l06oooo`05003ooooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`03
oooo00<00?ooool00?l05_ooo`05003ooooo003o003ooooo00800?l00oooo`00ooooo`05oooo00@0
0?ooool00?ooool2003o00?oool00?ooool04_ooo`06003ooooo003o003ooooo003o1_ooo`05003o
oooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`0Coooo00<00?ooool00?l01_ooo`05003o
oooo003o003ooooo00800?l01?ooo`00ooooo`00o`_oool01`00ooooo`00o`00ooooo`00ooooo`02
003o00?oool00?l00?l02?ooo`008Oooo`80000Voooo00D00?ooool00?l00?ooool00P00o`05oooo
003o003ooooo003o01_oool01@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool00?l00ooo
o`03003ooooo003o01Koool01@00ooooo`00o`00ooooo`02003o00?oool00?ooool01Oooo`04003o
oooo003ooooo0P00o`03oooo003ooooo01;oool01P00ooooo`00o`00ooooo`00o`Koool01@00oooo
o`00o`00ooooo`02003o00Goool00?l00?ooool00?l04oooo`03003ooooo003o00Koool01@00oooo
o`00o`00ooooo`02003o00Coool00?ooool00?l;oooo00L00?ooool00?l00?ooool00?ooool00P00
o`03oooo003o003o00Soool0027oool00`000?ooooooo`0Uoooo00D00?ooool00?l00?ooool00P00
o`05oooo003o003ooooo003o01_oool01@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool0
0?l00oooo`03003ooooo003o01Koool01@00ooooo`00o`00ooooo`02003o00?oool00?ooool01Ooo
o`04003ooooo003ooooo0P00o`03oooo003ooooo01;oool01P00ooooo`00o`00ooooo`00o`Koool0
1@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool00?l04oooo`03003ooooo003o00Koool0
1@00ooooo`00o`00ooooo`02003o00Coool00?ooool00?l;oooo00L00?ooool00?l00?ooool00?oo
ool00P00o`03oooo003o003o00Soool0027oool00`000?ooooooo`0Uoooo00D00?ooool00?l00?oo
ool00P00o`05oooo003o003ooooo003o01_oool01@00ooooo`00o`00ooooo`02003o00Goool00?l0
0?ooool00?l00oooo`03003ooooo003o01Koool01@00ooooo`00o`00ooooo`02003o00?oool00?oo
ool01Oooo`04003ooooo003ooooo0P00o`03oooo003ooooo01;oool01P00ooooo`00o`00ooooo`00
o`Koool01@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool00?l04oooo`03003ooooo003o
00Koool01@00ooooo`00o`00ooooo`02003o00Coool00?ooool00?l;oooo00L00?ooool00?l00?oo
ool00?ooool00P00o`03oooo003o003o00Soool0027oool00`000?ooooooo`0Uoooo00D00?ooool0
0?l00?ooool00P00o`05oooo003o003ooooo003o01_oool01@00ooooo`00o`00ooooo`02003o00Go
ool00?l00?ooool00?l00oooo`03003ooooo003o01Koool01@00ooooo`00o`00ooooo`02003o00?o
ool00?ooool01Oooo`04003ooooo003ooooo0P00o`03oooo003ooooo01;oool01P00ooooo`00o`00
ooooo`00o`Koool01@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool00?l04oooo`03003o
oooo003o00Koool01@00ooooo`00o`00ooooo`02003o00Coool00?ooool00?l;oooo00L00?ooool0
0?l00?ooool00?ooool00P00o`03oooo003o003o00Soool0027oool200009_ooo`05003ooooo003o
003ooooo00800?l01Oooo`00o`00ooooo`00o`0Koooo00D00?ooool00?l00?ooool00P00o`05oooo
003o003ooooo003o00?oool00`00ooooo`00o`0Foooo00D00?ooool00?l00?ooool00P00o`03oooo
003ooooo00Goool01000ooooo`00ooooo`800?l00oooo`00ooooo`0Boooo00H00?ooool00?l00?oo
ool00?l6oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o01?oool00`00oooo
o`00o`06oooo00D00?ooool00?l00?ooool00P00o`04oooo003ooooo003o2oooo`07003ooooo003o
003ooooo003ooooo00800?l00oooo`00o`00o`08oooo000Qoooo00<0003oooooool09Oooo`05003o
oooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`0Koooo00D00?ooool00?l00?ooool00P00
o`05oooo003o003ooooo003o00?oool00`00ooooo`00o`0Foooo00D00?ooool00?l00?ooool00P00
o`03oooo003ooooo00Goool01000ooooo`00ooooo`800?l00oooo`00ooooo`0Boooo00H00?ooool0
0?l00?ooool00?l6oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o01?oool0
0`00ooooo`00o`06oooo00D00?ooool00?l00?ooool00P00o`04oooo003ooooo003o2oooo`07003o
oooo003o003ooooo003ooooo00800?l00oooo`00o`00o`08oooo000Qoooo00<0003oooooool09Ooo
o`05003ooooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`0Koooo00D00?ooool00?l00?oo
ool00P00o`05oooo003o003ooooo003o00?oool00`00ooooo`00o`0Foooo00D00?ooool00?l00?oo
ool00P00o`03oooo003ooooo00Goool01000ooooo`00ooooo`800?l00oooo`00ooooo`0Boooo00H0
0?ooool00?l00?ooool00?l6oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o
01?oool00`00ooooo`00o`06oooo00D00?ooool00?l00?ooool00P00o`04oooo003ooooo003o2ooo
o`07003ooooo003o003ooooo003ooooo00800?l00oooo`00o`00o`08oooo000Qoooo00<0003ooooo
ool09Oooo`05003ooooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`0Koooo00D00?ooool0
0?l00?ooool00P00o`05oooo003o003ooooo003o00?oool00`00ooooo`00o`0Foooo00D00?ooool0
0?l00?ooool00P00o`03oooo003ooooo00Goool01000ooooo`00ooooo`800?l00oooo`00ooooo`0B
oooo00H00?ooool00?l00?ooool00?l6oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003o
oooo003o01?oool00`00ooooo`00o`06oooo00D00?ooool00?l00?ooool00P00o`04oooo003ooooo
003o2oooo`07003ooooo003o003ooooo003ooooo00800?l00oooo`00o`00o`08oooo000Qoooo00<0
003oooooool09Oooo`05003ooooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`0Koooo00D0
0?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o00?oool00`00ooooo`00o`0Foooo00D0
0?ooool00?l00?ooool00P00o`03oooo003ooooo00Goool01000ooooo`00ooooo`800?l00oooo`00
ooooo`0Boooo00H00?ooool00?l00?ooool00?l6oooo00D00?ooool00?l00?ooool00P00o`05oooo
003o003ooooo003o01?oool00`00ooooo`00o`06oooo00D00?ooool00?l00?ooool00P00o`04oooo
003ooooo003o2oooo`07003ooooo003o003ooooo003ooooo00800?l00oooo`00o`00o`08oooo000Q
oooo0P0002Koool2003o00Coool00?l00?ooool2003o00?oool00?l00?l07Oooo`800?l01?ooo`00
o`00ooooo`800?l00oooo`00o`00o`04oooo00<00?ooooooool05Oooo`800?l01?ooo`00o`00oooo
o`800?l7oooo0P00o`04oooo003o003ooooo0P00oaCoool2003o00?oool00?l00?l01oooo`800?l0
0oooo`00ooooo`02003o00?oool00?l00?l05?ooo`800?l7oooo0P00o`04oooo003o003ooooo0P00
o`03oooo003o003o00_oool2003o00Coool00?l00?ooool2003o00Goool00?l00?ooool00?l01ooo
o`008Oooo`030000oooooooo02Goool2003o00Coool00?l00?ooool2003o00?oool00?l00?l07Ooo
o`800?l01?ooo`00o`00ooooo`800?l00oooo`00o`00o`04oooo00<00?ooooooool05Oooo`800?l0
1?ooo`00o`00ooooo`800?l7oooo0P00o`04oooo003o003ooooo0P00oaCoool2003o00?oool00?l0
0?l01oooo`800?l00oooo`00ooooo`02003o00?oool00?l00?l05?ooo`800?l7oooo0P00o`04oooo
003o003ooooo0P00o`03oooo003o003o00_oool2003o00Coool00?l00?ooool2003o00Goool00?l0
0?ooool00?l01oooo`003oooo`D00002oooo00<0003oooooool00_ooo`030000oooooooo00?oool0
0`000?ooooooo`0Uoooo0P00o`04oooo003o003ooooo0P00o`03oooo003o003o01goool2003o00Co
ool00?l00?ooool2003o00?oool00?l00?l01?ooo`03003ooooooooo01Goool2003o00Coool00?l0
0?ooool2003o1oooo`800?l01?ooo`00o`00ooooo`800?lDoooo0P00o`03oooo003o003o00Ooool2
003o00?oool00?ooool00P00o`03oooo003o003o01Coool2003o1oooo`800?l01?ooo`00o`00oooo
o`800?l00oooo`00o`00o`0;oooo0P00o`04oooo003o003ooooo0P00o`05oooo003o003ooooo003o
00Ooool0017oool01`000?ooooooooooo`000?ooo`000002oooo00<0003oool000001?ooo`030000
oooooooo02Goool2003o00Coool00?l00?ooool2003o00?oool00?l00?l07Oooo`800?l01?ooo`00
o`00ooooo`800?l00oooo`00o`00o`04oooo00<00?ooooooool05Oooo`800?l01?ooo`00o`00oooo
o`800?l7oooo0P00o`04oooo003o003ooooo0P00oaCoool2003o00?oool00?l00?l01oooo`800?l0
0oooo`00ooooo`02003o00?oool00?l00?l05?ooo`800?l7oooo0P00o`04oooo003o003ooooo0P00
o`03oooo003o003o00_oool2003o00Coool00?l00?ooool2003o00Goool00?l00?ooool00?l01ooo
o`004Oooo`030000oooooooo00?oool01P000?ooooooo`000?ooo`0000Coool200009_ooo`800?l0
1?ooo`00o`00ooooo`800?l00oooo`00o`00o`0Moooo0P00o`04oooo003o003ooooo0P00o`03oooo
003o003o00Coool00`00ooooooooo`0Eoooo0P00o`04oooo003o003ooooo0P00o`Ooool2003o00Co
ool00?l00?ooool2003o5?ooo`800?l00oooo`00o`00o`07oooo0P00o`03oooo003ooooo00800?l0
0oooo`00o`00o`0Doooo0P00o`Ooool2003o00Coool00?l00?ooool2003o00?oool00?l00?l02ooo
o`800?l01?ooo`00o`00ooooo`800?l01Oooo`00o`00ooooo`00o`07oooo000Aoooo00@0003ooooo
ooooool200000oooo`030000oooo000000Coool00`000?ooooooo`0Uoooo0P00o`04oooo003o003o
oooo0P00o`03oooo003o003o01goool2003o00Coool00?l00?ooool2003o00?oool00?l00?l01?oo
o`03003ooooooooo01Goool2003o00Coool00?l00?ooool2003o1oooo`800?l01?ooo`00o`00oooo
o`800?lDoooo0P00o`03oooo003o003o00Ooool2003o00?oool00?ooool00P00o`03oooo003o003o
01Coool2003o1oooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00o`00o`0;oooo0P00o`04oooo
003o003ooooo0P00o`05oooo003o003ooooo003o00Ooool0017oool01@000?ooooooooooo`000004
oooo00<0003oool000001?ooo`030000oooooooo02Goool2003o00Coool00?l00?ooool2003o00?o
ool00?l00?l07Oooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00o`00o`04oooo00<00?oooooo
ool05Oooo`800?l01?ooo`00o`00ooooo`800?l7oooo0P00o`04oooo003o003ooooo0P00oaCoool2
003o00?oool00?l00?l01oooo`800?l00oooo`00ooooo`02003o00?oool00?l00?l05?ooo`800?l7
oooo0P00o`04oooo003o003ooooo0P00o`03oooo003o003o00_oool2003o00Coool00?l00?ooool2
003o00Goool00?l00?ooool00?l01oooo`004?ooo`800003oooo0`0000?oool00`000?ooooooo`03
oooo00<0003oooooool09Oooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00o`00o`0Moooo0P00
o`04oooo003o003ooooo0P00o`03oooo003o003o00Coool00`00ooooooooo`0Eoooo0P00o`04oooo
003o003ooooo0P00o`Ooool2003o00Coool00?l00?ooool2003o5?ooo`800?l00oooo`00o`00o`07
oooo0P00o`03oooo003ooooo00800?l00oooo`00o`00o`0Doooo0P00o`Ooool2003o00Coool00?l0
0?ooool2003o00?oool00?l00?l02oooo`800?l01?ooo`00o`00ooooo`800?l01Oooo`00o`00oooo
o`00o`07oooo000Qoooo00<0003oooooool09Oooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00
o`00o`0Moooo0P00o`04oooo003o003ooooo0P00o`03oooo003o003o00Coool00`00ooooooooo`0E
oooo0P00o`04oooo003o003ooooo0P00o`Ooool2003o00Coool00?l00?ooool2003o5?ooo`800?l0
0oooo`00o`00o`07oooo0P00o`03oooo003ooooo00800?l00oooo`00o`00o`0Doooo0P00o`Ooool2
003o00Coool00?l00?ooool2003o00?oool00?l00?l02oooo`800?l01?ooo`00o`00ooooo`800?l0
1Oooo`00o`00ooooo`00o`07oooo000Qoooo0P0002Koool2003o00Coool00?l00?ooool2003o00?o
ool00?l00?l07Oooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00o`00o`04oooo00<00?oooooo
ool05Oooo`800?l01?ooo`00o`00ooooo`800?l7oooo0P00o`04oooo003o003ooooo0P00oaCoool2
003o00?oool00?l00?l01oooo`800?l00oooo`00ooooo`02003o00?oool00?l00?l05?ooo`800?l7
oooo0P00o`04oooo003o003ooooo0P00o`03oooo003o003o00_oool2003o00Coool00?l00?ooool2
003o00Goool00?l00?ooool00?l01oooo`008Oooo`030000oooooooo02Goool2003o00Coool00?l0
0?ooool2003o00?oool00?l00?l07Oooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00o`00o`04
oooo00<00?ooooooool05Oooo`800?l01?ooo`00o`00ooooo`800?l7oooo0P00o`04oooo003o003o
oooo0P00oaCoool2003o00?oool00?l00?l01oooo`800?l00oooo`00ooooo`02003o00?oool00?l0
0?l05?ooo`800?l7oooo0P00o`04oooo003o003ooooo0P00o`03oooo003o003o00_oool2003o00Co
ool00?l00?ooool2003o00Goool00?l00?ooool00?l01oooo`008Oooo`030000oooooooo02Goool2
003o00Coool00?l00?ooool2003o00?oool00?l00?l07Oooo`800?l01?ooo`00o`00ooooo`800?l0
0oooo`00o`00o`04oooo00<00?ooooooool05Oooo`800?l01?ooo`00o`00ooooo`800?l7oooo0P00
o`04oooo003o003ooooo0P00oaCoool2003o00?oool00?l00?l01oooo`800?l00oooo`00ooooo`02
003o00?oool00?l00?l05?ooo`800?l7oooo0P00o`04oooo003o003ooooo0P00o`03oooo003o003o
00_oool2003o00Coool00?l00?ooool2003o00Goool00?l00?ooool00?l01oooo`008Oooo`030000
oooooooo02Goool2003o00Coool00?l00?ooool2003o00?oool00?l00?l07Oooo`800?l01?ooo`00
o`00ooooo`800?l00oooo`00o`00o`04oooo00<00?ooooooool05Oooo`800?l01?ooo`00o`00oooo
o`800?l7oooo0P00o`04oooo003o003ooooo0P00oaCoool2003o00?oool00?l00?l01oooo`800?l0
0oooo`00ooooo`02003o00?oool00?l00?l05?ooo`800?l7oooo0P00o`04oooo003o003ooooo0P00
o`03oooo003o003o00_oool2003o00Coool00?l00?ooool2003o00Goool00?l00?ooool00?l01ooo
o`008Oooo`030000oooooooo02Goool2003o00Coool00?l00?ooool2003o00?oool00?l00?l07Ooo
o`800?l01?ooo`00o`00ooooo`800?l00oooo`00o`00o`04oooo00<00?ooooooool05Oooo`800?l0
1?ooo`00o`00ooooo`800?l7oooo0P00o`04oooo003o003ooooo0P00oaCoool2003o00?oool00?l0
0?l01oooo`800?l00oooo`00ooooo`02003o00?oool00?l00?l05?ooo`800?l7oooo0P00o`04oooo
003o003ooooo0P00o`03oooo003o003o00_oool2003o00Coool00?l00?ooool2003o00Goool00?l0
0?ooool00?l01oooo`008Oooo`80000Voooo0P00o`04oooo003o003ooooo0P00o`03oooo003o003o
01goool2003o00Coool00?l00?ooool2003o00?oool00?l00?l01?ooo`03003ooooooooo01Goool2
003o00Coool00?l00?ooool2003o1oooo`800?l01?ooo`00o`00ooooo`800?lDoooo0P00o`03oooo
003o003o00Ooool2003o00?oool00?ooool00P00o`03oooo003o003o01Coool2003o1oooo`800?l0
1?ooo`00o`00ooooo`800?l00oooo`00o`00o`0;oooo0P00o`04oooo003o003ooooo0P00o`05oooo
003o003ooooo003o00Ooool0027oool00`000?ooooooo`0Uoooo0P00o`04oooo003o003ooooo0P00
o`03oooo003o003o01goool2003o00Coool00?l00?ooool2003o00?oool00?l00?l01?ooo`03003o
oooooooo01Goool2003o00Coool00?l00?ooool2003o1oooo`800?l01?ooo`00o`00ooooo`800?lD
oooo0P00o`03oooo003o003o00Ooool2003o00?oool00?ooool00P00o`03oooo003o003o01Coool2
003o1oooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00o`00o`0;oooo0P00o`04oooo003o003o
oooo0P00o`05oooo003o003ooooo003o00Ooool0027oool00`000?ooooooo`0Uoooo0P00o`04oooo
003o003ooooo0P00o`03oooo003o003o01goool2003o00Coool00?l00?ooool2003o00?oool00?l0
0?l01?ooo`03003ooooooooo01Goool2003o00Coool00?l00?ooool2003o1oooo`800?l01?ooo`00
o`00ooooo`800?lDoooo0P00o`03oooo003o003o00Ooool2003o00?oool00?ooool00P00o`03oooo
003o003o01Coool2003o1oooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00o`00o`0;oooo0P00
o`04oooo003o003ooooo0P00o`05oooo003o003ooooo003o00Ooool0027oool00`000?ooooooo`0U
oooo0P00o`04oooo003o003ooooo0P00o`03oooo003o003o01goool2003o00Coool00?l00?ooool2
003o00?oool00?l00?l01?ooo`03003ooooooooo01Goool2003o00Coool00?l00?ooool2003o1ooo
o`800?l01?ooo`00o`00ooooo`800?lDoooo0P00o`03oooo003o003o00Ooool2003o00?oool00?oo
ool00P00o`03oooo003o003o01Coool2003o1oooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00
o`00o`0;oooo0P00o`04oooo003o003ooooo0P00o`05oooo003o003ooooo003o00Ooool0027oool2
00009_ooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00o`00o`0Moooo0P00o`04oooo003o003o
oooo0P00o`03oooo003o003o00Coool00`00ooooooooo`0Eoooo0P00o`04oooo003o003ooooo0P00
o`Ooool2003o00Coool00?l00?ooool2003o5?ooo`800?l00oooo`00o`00o`07oooo0P00o`03oooo
003ooooo00800?l00oooo`00o`00o`0Doooo0P00o`Ooool2003o00Coool00?l00?ooool2003o00?o
ool00?l00?l02oooo`800?l01?ooo`00o`00ooooo`800?l01Oooo`00o`00ooooo`00o`07oooo000Q
oooo00<0003oooooool09Oooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00o`00o`0Moooo0P00
o`04oooo003o003ooooo0P00o`03oooo003o003o00Coool00`00ooooooooo`0Eoooo0P00o`04oooo
003o003ooooo0P00o`Ooool2003o00Coool00?l00?ooool2003o5?ooo`800?l00oooo`00o`00o`07
oooo0P00o`03oooo003ooooo00800?l00oooo`00o`00o`0Doooo0P00o`Ooool2003o00Coool00?l0
0?ooool2003o00?oool00?l00?l02oooo`800?l01?ooo`00o`00ooooo`800?l01Oooo`00o`00oooo
o`00o`07oooo000Qoooo00<0003oooooool09_ooo`04003ooooooooo003o0_ooo`04003ooooooooo
003o7Oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o1Oooo`03003ooooooooo01Koool0
1000ooooooooo`00o`;oool00`00ooooooooo`06oooo00<00?ooool00?l00_ooo`03003ooooooooo
01?oool01000ooooooooo`00o`Soool01000ooooooooo`00o`;oool01000ooooooooo`00oaGoool0
0`00ooooooooo`06oooo00@00?ooooooool00?l2oooo00<00?ooool00?l03Oooo`06003ooooooooo
003ooooo003o0_ooo`04003ooooooooo003o1oooo`008Oooo`030000oooooooo02Koool01000oooo
ooooo`00o`;oool01000ooooooooo`00oagoool01000ooooooooo`00o`;oool01000ooooooooo`00
o`Goool00`00ooooooooo`0Foooo00@00?ooooooool00?l2oooo00<00?ooooooool01_ooo`03003o
oooo003o00;oool00`00ooooooooo`0Coooo00@00?ooooooool00?l8oooo00@00?ooooooool00?l2
oooo00@00?ooooooool00?lEoooo00<00?ooooooool01_ooo`04003ooooooooo003o0_ooo`03003o
oooo003o00goool01P00ooooooooo`00ooooo`00o`;oool01000ooooooooo`00o`Ooool0027oool0
0`000?ooooooo`0Voooo00@00?ooooooool00?l2oooo00@00?ooooooool00?lMoooo00@00?oooooo
ool00?l2oooo00@00?ooooooool00?l5oooo00<00?ooooooool05_ooo`04003ooooooooo003o0_oo
o`03003ooooooooo00Koool00`00ooooo`00o`02oooo00<00?ooooooool04oooo`04003ooooooooo
003o2?ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o5Oooo`03003ooooooooo00Koool0
1000ooooooooo`00o`;oool00`00ooooo`00o`0=oooo00H00?ooooooool00?ooool00?l2oooo00@0
0?ooooooool00?l7oooo000Qoooo0P0002Ooool01000ooooooooo`00o`;oool01000ooooooooo`00
oagoool01000ooooooooo`00o`;oool01000ooooooooo`00o`Goool00`00ooooooooo`0Foooo00@0
0?ooooooool00?l2oooo00<00?ooooooool01_ooo`03003ooooo003o00;oool00`00ooooooooo`0C
oooo00@00?ooooooool00?l8oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?lEoooo00<0
0?ooooooool01_ooo`04003ooooooooo003o0_ooo`03003ooooo003o00goool01P00ooooooooo`00
ooooo`00o`;oool01000ooooooooo`00o`Ooool0027oool00`000?ooooooo`0Voooo00@00?oooooo
ool00?l2oooo00@00?ooooooool00?lMoooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l5
oooo00<00?ooooooool05_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00Koool00`00oooo
o`00o`02oooo00<00?ooooooool04oooo`04003ooooooooo003o2?ooo`04003ooooooooo003o0_oo
o`04003ooooooooo003o5Oooo`03003ooooooooo00Koool01000ooooooooo`00o`;oool00`00oooo
o`00o`0=oooo00H00?ooooooool00?ooool00?l2oooo00@00?ooooooool00?l7oooo0005oooo1@00
00;oool010000?ooooooooooo`<00003oooo00<0003oooooool00_ooo`030000oooooooo00?oool0
0`000?ooooooo`0Voooo00@00?ooooooool00?l2oooo00@00?ooooooool00?lMoooo00@00?oooooo
ool00?l2oooo00@00?ooooooool00?l5oooo00<00?ooooooool05_ooo`04003ooooooooo003o0_oo
o`03003ooooooooo00Koool00`00ooooo`00o`02oooo00<00?ooooooool04oooo`04003ooooooooo
003o2?ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o5Oooo`03003ooooooooo00Koool0
1000ooooooooo`00o`;oool00`00ooooo`00o`0=oooo00H00?ooooooool00?ooool00?l2oooo00@0
0?ooooooool00?l7oooo0007oooo00L0003oooooooooool0003oool000000_ooo`030000oooooooo
00Ooool00`000?ooo`000004oooo00<0003oooooool09_ooo`04003ooooooooo003o0_ooo`04003o
oooooooo003o7Oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o1Oooo`03003ooooooooo
01Koool01000ooooooooo`00o`;oool00`00ooooooooo`06oooo00<00?ooool00?l00_ooo`03003o
oooooooo01?oool01000ooooooooo`00o`Soool01000ooooooooo`00o`;oool01000ooooooooo`00
oaGoool00`00ooooooooo`06oooo00@00?ooooooool00?l2oooo00<00?ooool00?l03Oooo`06003o
oooooooo003ooooo003o0_ooo`04003ooooooooo003o1oooo`001oooo`030000oooooooo00?oool0
1@000?ooooooooooo`00000:oooo00<0003oooooool00_ooo`80000Woooo00@00?ooooooool00?l2
oooo00@00?ooooooool00?lMoooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l5oooo00<0
0?ooooooool05_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00Koool00`00ooooo`00o`02
oooo00<00?ooooooool04oooo`04003ooooooooo003o2?ooo`04003ooooooooo003o0_ooo`04003o
oooooooo003o5Oooo`03003ooooooooo00Koool01000ooooooooo`00o`;oool00`00ooooo`00o`0=
oooo00H00?ooooooool00?ooool00?l2oooo00@00?ooooooool00?l7oooo0007oooo00@0003ooooo
ooooool200001?ooo`030000oooooooo00Koool200001Oooo`030000oooooooo02Koool01000oooo
ooooo`00o`;oool01000ooooooooo`00oagoool01000ooooooooo`00o`;oool01000ooooooooo`00
o`Goool00`00ooooooooo`0Foooo00@00?ooooooool00?l2oooo00<00?ooooooool01_ooo`03003o
oooo003o00;oool00`00ooooooooo`0Coooo00@00?ooooooool00?l8oooo00@00?ooooooool00?l2
oooo00@00?ooooooool00?lEoooo00<00?ooooooool01_ooo`04003ooooooooo003o0_ooo`03003o
oooo003o00goool01P00ooooooooo`00ooooo`00o`;oool01000ooooooooo`00o`Ooool000Ooool0
1@000?ooooooooooo`000004oooo00<0003oool000001oooo`030000oooooooo00Coool00`000?oo
ooooo`0Voooo00@00?ooooooool00?l2oooo00@00?ooooooool00?lMoooo00@00?ooooooool00?l2
oooo00@00?ooooooool00?l5oooo00<00?ooooooool05_ooo`04003ooooooooo003o0_ooo`03003o
oooooooo00Koool00`00ooooo`00o`02oooo00<00?ooooooool04oooo`04003ooooooooo003o2?oo
o`04003ooooooooo003o0_ooo`04003ooooooooo003o5Oooo`03003ooooooooo00Koool01000oooo
ooooo`00o`;oool00`00ooooo`00o`0=oooo00H00?ooooooool00?ooool00?l2oooo00@00?oooooo
ool00?l7oooo0006oooo0P0000?oool300000oooo`030000oooooooo00Koool300001?ooo`030000
oooooooo02Koool01000ooooooooo`00o`;oool01000ooooooooo`00oagoool01000ooooooooo`00
o`;oool01000ooooooooo`00o`Goool00`00ooooooooo`0Foooo00@00?ooooooool00?l2oooo00<0
0?ooooooool01_ooo`03003ooooo003o00;oool00`00ooooooooo`0Coooo00@00?ooooooool00?l8
oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?lEoooo00<00?ooooooool01_ooo`04003o
oooooooo003o0_ooo`03003ooooo003o00goool01P00ooooooooo`00ooooo`00o`;oool01000oooo
ooooo`00o`Ooool0027oool00`000?ooooooo`0Voooo00@00?ooooooool00?l2oooo00@00?oooooo
ool00?lMoooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l5oooo00<00?ooooooool05_oo
o`04003ooooooooo003o0_ooo`03003ooooooooo00Koool00`00ooooo`00o`02oooo00<00?oooooo
ool04oooo`04003ooooooooo003o2?ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o5Ooo
o`03003ooooooooo00Koool01000ooooooooo`00o`;oool00`00ooooo`00o`0=oooo00H00?oooooo
ool00?ooool00?l2oooo00@00?ooooooool00?l7oooo000Qoooo0P0002Ooool01000ooooooooo`00
o`;oool01000ooooooooo`00oagoool01000ooooooooo`00o`;oool01000ooooooooo`00o`Goool0
0`00ooooooooo`0Foooo00@00?ooooooool00?l2oooo00<00?ooooooool01_ooo`03003ooooo003o
00;oool00`00ooooooooo`0Coooo00@00?ooooooool00?l8oooo00@00?ooooooool00?l2oooo00@0
0?ooooooool00?lEoooo00<00?ooooooool01_ooo`04003ooooooooo003o0_ooo`03003ooooo003o
00goool01P00ooooooooo`00ooooo`00o`;oool01000ooooooooo`00o`Ooool0027oool00`000?oo
ooooo`0Voooo00@00?ooooooool00?l2oooo00@00?ooooooool00?lMoooo00@00?ooooooool00?l2
oooo00@00?ooooooool00?l5oooo00<00?ooooooool05_ooo`04003ooooooooo003o0_ooo`03003o
oooooooo00Koool00`00ooooo`00o`02oooo00<00?ooooooool04oooo`04003ooooooooo003o2?oo
o`04003ooooooooo003o0_ooo`04003ooooooooo003o5Oooo`03003ooooooooo00Koool01000oooo
ooooo`00o`;oool00`00ooooo`00o`0=oooo00H00?ooooooool00?ooool00?l2oooo00@00?oooooo
ool00?l7oooo000Qoooo00<0003oooooool09_ooo`04003ooooooooo003o0_ooo`04003ooooooooo
003o7Oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o1Oooo`03003ooooooooo01Koool0
1000ooooooooo`00o`;oool00`00ooooooooo`06oooo00<00?ooool00?l00_ooo`03003ooooooooo
01?oool01000ooooooooo`00o`Soool01000ooooooooo`00o`;oool01000ooooooooo`00oaGoool0
0`00ooooooooo`06oooo00@00?ooooooool00?l2oooo00<00?ooool00?l03Oooo`06003ooooooooo
003ooooo003o0_ooo`04003ooooooooo003o1oooo`008Oooo`030000oooooooo02Koool01000oooo
ooooo`00o`;oool01000ooooooooo`00oagoool01000ooooooooo`00o`;oool01000ooooooooo`00
o`Goool00`00ooooooooo`0Foooo00@00?ooooooool00?l2oooo00<00?ooooooool01_ooo`03003o
oooo003o00;oool00`00ooooooooo`0Coooo00@00?ooooooool00?l8oooo00@00?ooooooool00?l2
oooo00@00?ooooooool00?lEoooo00<00?ooooooool01_ooo`04003ooooooooo003o0_ooo`03003o
oooo003o00goool01P00ooooooooo`00ooooo`00o`;oool01000ooooooooo`00o`Ooool0027oool2
00009oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o7Oooo`04003ooooooooo003o0_oo
o`04003ooooooooo003o1Oooo`03003ooooooooo01Koool01000ooooooooo`00o`;oool00`00oooo
ooooo`06oooo00<00?ooool00?l00_ooo`03003ooooooooo01?oool01000ooooooooo`00o`Soool0
1000ooooooooo`00o`;oool01000ooooooooo`00oaGoool00`00ooooooooo`06oooo00@00?oooooo
ool00?l2oooo00<00?ooool00?l03Oooo`06003ooooooooo003ooooo003o0_ooo`04003ooooooooo
003o1oooo`008Oooo`030000oooooooo02Koool01000ooooooooo`00o`;oool01000ooooooooo`00
oagoool01000ooooooooo`00o`;oool01000ooooooooo`00o`Goool00`00ooooooooo`0Foooo00@0
0?ooooooool00?l2oooo00<00?ooooooool01_ooo`03003ooooo003o00;oool00`00ooooooooo`0C
oooo00@00?ooooooool00?l8oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?lEoooo00<0
0?ooooooool01_ooo`04003ooooooooo003o0_ooo`03003ooooo003o00goool01P00ooooooooo`00
ooooo`00o`;oool01000ooooooooo`00o`Ooool0027oool00`000?ooooooo`0Voooo00@00?oooooo
ool00?l2oooo00@00?ooooooool00?lMoooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l5
oooo00<00?ooooooool05_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00Koool00`00oooo
o`00o`02oooo00<00?ooooooool04oooo`04003ooooooooo003o2?ooo`04003ooooooooo003o0_oo
o`04003ooooooooo003o5Oooo`03003ooooooooo00Koool01000ooooooooo`00o`;oool00`00oooo
o`00o`0=oooo00H00?ooooooool00?ooool00?l2oooo00@00?ooooooool00?l7oooo000Qoooo00<0
003oooooool09_ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o7Oooo`04003ooooooooo
003o0_ooo`04003ooooooooo003o1Oooo`03003ooooooooo01Koool01000ooooooooo`00o`;oool0
0`00ooooooooo`06oooo00<00?ooool00?l00_ooo`03003ooooooooo01?oool01000ooooooooo`00
o`Soool01000ooooooooo`00o`;oool01000ooooooooo`00oaGoool00`00ooooooooo`06oooo00@0
0?ooooooool00?l2oooo00<00?ooool00?l03Oooo`06003ooooooooo003ooooo003o0_ooo`04003o
oooooooo003o1oooo`008Oooo`030000oooooooo0?coool0027oool20000oOooo`008Oooo`030000
oooooooo0?coool0027oool00`000?ooooooo`3loooo003ooooo8Oooo`00ooooob7oool00?oooolQ
oooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-22.6815, 135.668, 0.682517, 
  0.110314}}]
}, Open  ]],

Cell[TextData["Obliczenie b\[LSlash]\:0119du detekcji"], "MathCaption"],

Cell[BoxData[
    \(\(B\[LSlash]\[SHacek]d = FB\[LSlash]\:0119du[FS, RzCzPodst]; \)\)], 
  "Input",
  CellLabel->"In[41]:="],

Cell[TextData["Wykres b\[LSlash]\:0119du"], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[B\[LSlash]\[SHacek]d, PlotJoined -> True, 
      PlotStyle -> RGBColor[0, 0, 1]]; \)\)], "Input",
  CellLabel->"In[42]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00563539 4.38455 0.035074 [
[.16469 -0.0122 -6 -9 ]
[.16469 -0.0122 6 0 ]
[.30558 -0.0122 -6 -9 ]
[.30558 -0.0122 6 0 ]
[.44646 -0.0122 -6 -9 ]
[.44646 -0.0122 6 0 ]
[.58735 -0.0122 -9 -9 ]
[.58735 -0.0122 9 0 ]
[.72823 -0.0122 -9 -9 ]
[.72823 -0.0122 9 0 ]
[.86912 -0.0122 -9 -9 ]
[.86912 -0.0122 9 0 ]
[.01131 .08799 -36 -4.5 ]
[.01131 .08799 0 4.5 ]
[.01131 .17567 -24 -4.5 ]
[.01131 .17567 0 4.5 ]
[.01131 .26336 -36 -4.5 ]
[.01131 .26336 0 4.5 ]
[.01131 .35104 -24 -4.5 ]
[.01131 .35104 0 4.5 ]
[.01131 .43873 -36 -4.5 ]
[.01131 .43873 0 4.5 ]
[.01131 .52641 -24 -4.5 ]
[.01131 .52641 0 4.5 ]
[.01131 .6141 -36 -4.5 ]
[.01131 .6141 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.16469 .0003 m
.16469 .00655 L
s
[(25)] .16469 -0.0122 0 1 Mshowa
.30558 .0003 m
.30558 .00655 L
s
[(50)] .30558 -0.0122 0 1 Mshowa
.44646 .0003 m
.44646 .00655 L
s
[(75)] .44646 -0.0122 0 1 Mshowa
.58735 .0003 m
.58735 .00655 L
s
[(100)] .58735 -0.0122 0 1 Mshowa
.72823 .0003 m
.72823 .00655 L
s
[(125)] .72823 -0.0122 0 1 Mshowa
.86912 .0003 m
.86912 .00655 L
s
[(150)] .86912 -0.0122 0 1 Mshowa
.125 Mabswid
.05199 .0003 m
.05199 .00405 L
s
.08016 .0003 m
.08016 .00405 L
s
.10834 .0003 m
.10834 .00405 L
s
.13652 .0003 m
.13652 .00405 L
s
.19287 .0003 m
.19287 .00405 L
s
.22105 .0003 m
.22105 .00405 L
s
.24923 .0003 m
.24923 .00405 L
s
.2774 .0003 m
.2774 .00405 L
s
.33376 .0003 m
.33376 .00405 L
s
.36193 .0003 m
.36193 .00405 L
s
.39011 .0003 m
.39011 .00405 L
s
.41829 .0003 m
.41829 .00405 L
s
.47464 .0003 m
.47464 .00405 L
s
.50282 .0003 m
.50282 .00405 L
s
.53099 .0003 m
.53099 .00405 L
s
.55917 .0003 m
.55917 .00405 L
s
.61553 .0003 m
.61553 .00405 L
s
.6437 .0003 m
.6437 .00405 L
s
.67188 .0003 m
.67188 .00405 L
s
.70006 .0003 m
.70006 .00405 L
s
.75641 .0003 m
.75641 .00405 L
s
.78459 .0003 m
.78459 .00405 L
s
.81276 .0003 m
.81276 .00405 L
s
.84094 .0003 m
.84094 .00405 L
s
.8973 .0003 m
.8973 .00405 L
s
.92547 .0003 m
.92547 .00405 L
s
.95365 .0003 m
.95365 .00405 L
s
.98183 .0003 m
.98183 .00405 L
s
.25 Mabswid
0 .0003 m
1 .0003 L
s
.02381 .08799 m
.03006 .08799 L
s
[(-122.5)] .01131 .08799 1 0 Mshowa
.02381 .17567 m
.03006 .17567 L
s
[(-120)] .01131 .17567 1 0 Mshowa
.02381 .26336 m
.03006 .26336 L
s
[(-117.5)] .01131 .26336 1 0 Mshowa
.02381 .35104 m
.03006 .35104 L
s
[(-115)] .01131 .35104 1 0 Mshowa
.02381 .43873 m
.03006 .43873 L
s
[(-112.5)] .01131 .43873 1 0 Mshowa
.02381 .52641 m
.03006 .52641 L
s
[(-110)] .01131 .52641 1 0 Mshowa
.02381 .6141 m
.03006 .6141 L
s
[(-107.5)] .01131 .6141 1 0 Mshowa
.125 Mabswid
.02381 .01784 m
.02756 .01784 L
s
.02381 .03538 m
.02756 .03538 L
s
.02381 .05291 m
.02756 .05291 L
s
.02381 .07045 m
.02756 .07045 L
s
.02381 .10553 m
.02756 .10553 L
s
.02381 .12306 m
.02756 .12306 L
s
.02381 .1406 m
.02756 .1406 L
s
.02381 .15814 m
.02756 .15814 L
s
.02381 .19321 m
.02756 .19321 L
s
.02381 .21075 m
.02756 .21075 L
s
.02381 .22828 m
.02756 .22828 L
s
.02381 .24582 m
.02756 .24582 L
s
.02381 .2809 m
.02756 .2809 L
s
.02381 .29843 m
.02756 .29843 L
s
.02381 .31597 m
.02756 .31597 L
s
.02381 .33351 m
.02756 .33351 L
s
.02381 .36858 m
.02756 .36858 L
s
.02381 .38612 m
.02756 .38612 L
s
.02381 .40365 m
.02756 .40365 L
s
.02381 .42119 m
.02756 .42119 L
s
.02381 .45627 m
.02756 .45627 L
s
.02381 .4738 m
.02756 .4738 L
s
.02381 .49134 m
.02756 .49134 L
s
.02381 .50888 m
.02756 .50888 L
s
.02381 .54395 m
.02756 .54395 L
s
.02381 .56149 m
.02756 .56149 L
s
.02381 .57902 m
.02756 .57902 L
s
.02381 .59656 m
.02756 .59656 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02944 .01472 m
.03508 .30052 L
.04072 .30052 L
.04635 .60332 L
.05199 .30052 L
.05762 .30052 L
.06326 .60332 L
.06889 .30052 L
.07453 .60332 L
.08016 .30052 L
.0858 .30052 L
.09143 .30052 L
.09707 .30052 L
.1027 .30052 L
.10834 .30052 L
.11398 .30052 L
.11961 .30052 L
.12525 .30052 L
.13088 .30052 L
.13652 .30052 L
.14215 .30052 L
.14779 .30052 L
.15342 .30052 L
.15906 .30052 L
.16469 .30052 L
.17033 .30052 L
.17597 .30052 L
.1816 .60332 L
.18724 .30052 L
.19287 .60332 L
.19851 .30052 L
.20414 .60332 L
.20978 .30052 L
.21541 .60332 L
.22105 .30052 L
.22668 .60332 L
.23232 .30052 L
.23795 .60332 L
.24359 .30052 L
.24923 .30052 L
.25486 .30052 L
.2605 .30052 L
.26613 .30052 L
.27177 .30052 L
.2774 .30052 L
.28304 .30052 L
.28867 .30052 L
.29431 .30052 L
.29994 .30052 L
.30558 .30052 L
Mistroke
.31121 .30052 L
.31685 .30052 L
.32249 .30052 L
.32812 .30052 L
.33376 .60332 L
.33939 .30052 L
.34503 .60332 L
.35066 .30052 L
.3563 .60332 L
.36193 .30052 L
.36757 .60332 L
.3732 .30052 L
.37884 .60332 L
.38447 .30052 L
.39011 .60332 L
.39575 .30052 L
.40138 .60332 L
.40702 .30052 L
.41265 .30052 L
.41829 .30052 L
.42392 .30052 L
.42956 .30052 L
.43519 .30052 L
.44083 .30052 L
.44646 .30052 L
.4521 .30052 L
.45773 .30052 L
.46337 .30052 L
.46901 .30052 L
.47464 .30052 L
.48028 .30052 L
.48591 .60332 L
.49155 .30052 L
.49718 .60332 L
.50282 .30052 L
.50845 .60332 L
.51409 .30052 L
.51972 .60332 L
.52536 .30052 L
.53099 .60332 L
.53663 .30052 L
.54227 .60332 L
.5479 .30052 L
.55354 .60332 L
.55917 .30052 L
.56481 .60332 L
.57044 .30052 L
.57608 .60332 L
.58171 .30052 L
.58735 .30052 L
Mistroke
.59298 .30052 L
.59862 .30052 L
.60425 .30052 L
.60989 .30052 L
.61553 .30052 L
.62116 .30052 L
.6268 .30052 L
.63243 .30052 L
.63807 .60332 L
.6437 .30052 L
.64934 .60332 L
.65497 .30052 L
.66061 .60332 L
.66624 .30052 L
.67188 .60332 L
.67751 .30052 L
.68315 .30052 L
.68879 .30052 L
.69442 .60332 L
.70006 .30052 L
.70569 .60332 L
.71133 .30052 L
.71696 .60332 L
.7226 .30052 L
.72823 .60332 L
.73387 .30052 L
.7395 .30052 L
.74514 .30052 L
.75077 .30052 L
.75641 .30052 L
.76205 .30052 L
.76768 .30052 L
.77332 .30052 L
.77895 .30052 L
.78459 .30052 L
.79022 .30052 L
.79586 .30052 L
.80149 .60332 L
.80713 .30052 L
.81276 .60332 L
.8184 .30052 L
.82403 .30052 L
.82967 .30052 L
.83531 .30052 L
.84094 .30052 L
.84658 .60332 L
.85221 .30052 L
.85785 .60332 L
.86348 .30052 L
.86912 .60332 L
Mistroke
.87475 .30052 L
.88039 .60332 L
.88602 .30052 L
.89166 .30052 L
.8973 .30052 L
.90293 .30052 L
.90857 .30052 L
.9142 .30052 L
.91984 .30052 L
.92547 .30052 L
.93111 .60332 L
.93674 .30052 L
.94238 .60332 L
.94801 .30052 L
.95365 .60332 L
.95928 .30052 L
.96492 .60332 L
.97056 .30052 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[42]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo003ooooo8Oooo`00A_ooo`<00003oooo00<0003oooooool07?ooo`030000oooooooo
00;oool00`000?ooooooo`0Loooo00<0003oooooool00_ooo`030000oooooooo01Ooool500000_oo
o`030000oooooooo00;oool00`000?ooooooo`0Eoooo1@000004oooo0000000000000oooo`030000
oooooooo01Goool500000_ooo`030000oooooooo00;oool00`000?ooooooo`0Koooo0016oooo00<0
003oooooool00_ooo`030000oooo000001coool00`000?ooo`000002oooo00<0003oool000007Ooo
o`070000oooooooooooo0000oooo000001[oool01`000?ooooooooooo`000?ooo`000002oooo00<0
003oool000006?ooo`050000oooooooooooo000000Coool00`000?ooo`00000Hoooo00L0003ooooo
ooooool0003oool000000_ooo`030000oooo000001coool004Ooool00`000?ooooooo`03oooo00<0
003oooooool07?ooo`060000oooooooo0000oooo00007Oooo`030000oooooooo00?oool00`000?oo
ooooo`0Hoooo00L0003oooooooooool0003oool000000_ooo`030000oooo000001Soool00`000?oo
ooooo`02oooo00<0003oooooool00oooo`030000oooooooo01Koool00`000?ooooooo`03oooo00H0
003oooooool0003oool0000Loooo0017oooo00@0003oooooooooool200007Oooo`800003oooo00<0
003oool000007_ooo`030000oooooooo0080000Koooo00L0003oooooooooool0003oool000000_oo
o`030000oooo000001Soool00`000?ooooooo`02oooo00@0003oooooooooool200006Oooo`040000
oooooooooooo0P0000?oool00`000?ooo`00000Loooo0016oooo00<0003oool000000_ooo`030000
oooooooo01coool00`000?ooooooo`02oooo00<0003oool000007?ooo`030000oooo000000;oool0
0`000?ooooooo`0Joooo00L0003oooooooooool0003oool000000_ooo`030000oooo000001Soool0
1`000?ooooooooooo`000?ooo`000002oooo00<0003oooooool06?ooo`050000oooooooooooo0000
00Coool00`000?ooo`00000Loooo0017oooo00@0003oooooooooool300007?ooo`<00003oooo00<0
003oooooool06oooo`<00002oooo0`0001Woool200001?ooo`030000oooooooo00;oool00`000?oo
ooooo`0Foooo0P0000Coool010000?ooooooooooo`<0000Goooo0P0000?oool300000oooo`030000
oooooooo01_oool00?oooolQoooo003ooooo8Oooo`00ooooob7oool00?oooolQoooo003ooooo8Ooo
o`008Oooool0000002Ooool00`000?ooooooo`04oooo00<0003oooooool01?ooo`030000oooooooo
00Coool00`000?ooooooo`04oooo00<0003oooooool01?ooo`030000oooooooo00Goool00`000?oo
ooooo`04oooo00<0003oooooool01?ooo`030000oooooooo00Coool00`000?ooooooo`04oooo00<0
003oooooool01?ooo`030000oooooooo00Goool00`000?ooooooo`04oooo00<0003oooooool01?oo
o`030000oooooooo00Coool00`000?ooooooo`04oooo00<0003oooooool01?ooo`030000oooooooo
00Coool00`000?ooooooo`05oooo00<0003oooooool01?ooo`030000oooooooo00Coool00`000?oo
ooooo`04oooo00<0003oooooool01?ooo`030000oooooooo00Coool00`000?ooooooo`05oooo00<0
003oooooool01?ooo`030000oooooooo00Coool00`000?ooooooo`04oooo00<0003oooooool01?oo
o`030000oooooooo00Coool00`000?ooooooo`04oooo00<0003oooooool01Oooo`030000oooooooo
00Coool00`000?ooooooo`04oooo00<0003oooooool00oooo`009oooo`030000oooooooo023oool0
0`000?ooooooo`0Qoooo00<0003oooooool08Oooo`030000oooooooo027oool00`000?ooooooo`0Q
oooo00<0003oooooool08?ooo`030000oooooooo023oool002Ooool00`000?ooooooo`3foooo000W
oooo00<000000?ooool0m_ooo`009oooo`030000003ooooo0?Koool002Ooool00`000000ooooo`3f
oooo000Woooo00<000000?ooool0m_ooo`009oooo`030000003ooooo0?Koool002Ooool00`000000
ooooo`3foooo000Woooo00<000000?ooool0m_ooo`009oooo`030000003ooooo0?Koool002Ooool0
0`000000ooooo`3foooo000Woooo00<000000?ooool0m_ooo`009oooo`030000003ooooo0?Koool0
02Ooool00`000000ooooo`3foooo000Woooo00<000000?ooool0m_ooo`009oooo`030000003ooooo
0?Koool002Ooool00`000000ooooo`3foooo000Woooo00<000000?ooool0m_ooo`002oooo`D00000
1?ooo`000000000000;oool300000oooo`030000oooooooo00;oool00`000?ooooooo`03oooo00<0
00000?ooool0m_ooo`003Oooo`050000oooooooooooo000000Coool00`000?ooooooo`07oooo00<0
003oool000001?ooo`030000003ooooo0?Koool000Ooool300000oooo`030000oooooooo00;oool0
0`000?ooooooo`02oooo00<0003oooooool02?ooo`030000oooooooo00;oool2000000<00?oooooo
ool0m?ooo`003Oooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0003oooooool01_oo
o`800005oooo00<0003oool00?l0m_ooo`003Oooo`070000oooooooooooo0000oooo000000;oool0
0`000?ooo`000007oooo00<0003oooooool01?ooo`030000oooo003o0?Koool000coool200001?oo
o`030000oooooooo00;oool00`000?ooooooo`06oooo0`0000Coool00`000?ooo`00o`3foooo000W
oooo00<0003oool00?l0m_ooo`009oooo`8000000`00ooooooooo`3doooo000Woooo00<0003oool0
0?l0m_ooo`009oooo`030000oooo003o0?Koool002Ooool00`000?ooo`00o`3foooo000Woooo0P00
0003003ooooooooo0?Coool002Ooool00`000?ooo`00o`3foooo000Woooo00<0003oool00?l0m_oo
o`009oooo`030000oooo003o0?Koool002Ooool00`000?ooo`00o`3foooo000Woooo0P000003003o
oooooooo0?Coool002Ooool00`000?ooo`00o`3foooo000Woooo00<0003oool00?l0m_ooo`009ooo
o`030000oooo003o0?Koool002Ooool2000000<00?ooooooool0m?ooo`009oooo`030000oooo003o
0?Koool001Goool5000000Coool0000000000003oooo00<0003oooooool00oooo`030000oooo003o
0?Koool001Ooool01@000?ooooooooooo`000004oooo00<0003oool000001?ooo`030000oooo003o
0?Koool0017oool300000oooo`030000oooooooo00;oool01`000?ooooooooooo`000?ooo`000004
oooo0P000003003ooooooooo0?Coool001Ooool00`000?ooooooo`02oooo00L0003oooooooooool0
003oool000001?ooo`030000oooo003o0?Koool001Ooool01`000?ooooooooooo`000?ooo`000002
oooo00<0003oool000001?ooo`030000oooo003o0?Koool001Koool200001?ooo`030000oooooooo
00;oool00`000?ooooooo`03oooo00<0003oool00?l0m_ooo`009oooo`030000oooo003o0?Koool0
02Ooool2000000<00?ooooooool0m?ooo`009oooo`030000oooo003o0?Koool002Ooool00`000?oo
o`00o`3foooo000Woooo00<0003oool00?l0m_ooo`009oooo`8000000`00ooooooooo`3doooo000W
oooo00<0003oool00?l0m_ooo`009oooo`030000oooo003o0?Koool002Ooool00`000?ooo`00o`3f
oooo000Woooo00<0003oool00?l0m_ooo`009oooo`8000000oooo`00ooooo`3doooo000Woooo00@0
003oooooool00?oeoooo000Woooo00@0003oooooool00?oeoooo000Woooo00@0003oooooool00?oe
oooo000Woooo0P000003oooo003ooooo0?Coool002Ooool010000?ooooooo`00ooGoool002Ooool0
10000?ooooooo`00ooGoool000_oool:00000_ooo`030000oooooooo00;oool00`000?ooooooo`02
oooo00<0003oooooool00oooo`040000oooooooo003omOooo`003Oooo`030000oooooooo00;oool0
0`000?ooooooo`02oooo00<0003oooooool01_ooo`030000oooo000000Coool010000?ooooooo`00
ooGoool000Ooool300000oooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0003ooooo
ool02?ooo`030000oooooooo00;oool2000000?oool00?ooool0m?ooo`003Oooo`030000oooooooo
00;oool00`000?ooooooo`03oooo00<0003oooooool01Oooo`800005oooo00@0003oooooool00?oe
oooo000=oooo00<0003oooooool00_ooo`070000oooooooooooo0000oooo000000Ooool00`000?oo
ooooo`04oooo00@0003oooooool00?oeoooo000<oooo0P0000?oool200000oooo`<00007oooo0`00
00Coool010000?ooooooo`00ooGoool002Ooool2000000?oool00?ooool0m?ooo`009oooo`040000
oooooooo003omOooo`009oooo`040000oooooooo003omOooo`009oooo`040000oooooooo003omOoo
o`009oooo`040000oooooooo003omOooo`009oooo`8000000oooo`00o`00o`02oooo0P00o`;oool0
0`00ooooooooo`0I003o0_ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003o
oooo003o01H00?l2oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_ooo`04003ooooooooo
003o0_oooa@00?l01Oooo`00ooooooooo`00o`02oooo00@00?ooooooool00?l2oooo00@00?oooooo
ool00?l2oooo00<00?ooool00?l00_ooo`h00?l2oooo00@00?ooooooool00?l2oooo00<00?oooooo
ool00`00o`;oool01000ooooooooo`00o`;oool00`00ooooooooo`0A003o0_ooo`03003ooooo003o
00H00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool02`00o`05oooo003ooooooooo003o
00;oool01000ooooooooo`00o`Soool002Ooool01@000?ooooooooooo`00o`02oooo0P00o`;oool0
1000ooooooooo`00oaOoool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool01P00oooo
ooooo`00ooooo`00oaGoool01000ooooooooo`00o`;oool01P00ooooooooo`00ooooo`00o`;oool0
1000ooooooooo`00o`;oool00`00ooooooooo`0@oooo00<00?ooool00?l00_ooo`04003ooooooooo
003o0_ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo003o0_ooo`03003ooooooooo
00[oool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool00`00ooooo`00o`02oooo00@0
0?ooooooool00?l2oooo00@00?ooooooool00?l?oooo00H00?ooooooool00?ooool00?l5oooo00@0
0?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool01oooo`03003ooooo003o
00;oool01000ooooooooo`00o`;oool00`00ooooooooo`06oooo000Woooo00D0003oooooooooool0
0?l00_ooo`800?l2oooo00@00?ooooooool00?lGoooo00@00?ooooooool00?l2oooo00@00?oooooo
ool00?l2oooo00H00?ooooooool00?ooool00?lEoooo00@00?ooooooool00?l2oooo00H00?oooooo
ool00?ooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool04?ooo`03003ooooo003o
00;oool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool01P00ooooooooo`00ooooo`00
o`;oool00`00ooooooooo`0:oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<0
0?ooool00?l00_ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o3oooo`06003ooooooooo
003ooooo003o1Oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo
00Ooool00`00ooooo`00o`02oooo00@00?ooooooool00?l2oooo00<00?ooooooool01_ooo`009ooo
o`050000oooooooooooo003o00;oool2003o0_ooo`04003ooooooooo003o5oooo`04003ooooooooo
003o0_ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo003o5Oooo`04003ooooooooo
003o0_ooo`06003ooooooooo003ooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo
013oool00`00ooooo`00o`02oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00H0
0?ooooooool00?ooool00?l2oooo00<00?ooooooool02_ooo`04003ooooooooo003o0_ooo`04003o
oooooooo003o0_ooo`03003ooooo003o00;oool01000ooooooooo`00o`;oool01000ooooooooo`00
o`ooool01P00ooooooooo`00ooooo`00o`Goool01000ooooooooo`00o`;oool01000ooooooooo`00
o`;oool00`00ooooooooo`07oooo00<00?ooool00?l00_ooo`04003ooooooooo003o0_ooo`03003o
oooooooo00Koool002Ooool200000_ooo`03003ooooooooo00800?l2oooo00@00?ooooooool00?lG
oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?lE
oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l2oooo00@00?ooooooool00?l2
oooo00<00?ooooooool04?ooo`03003ooooo003o00;oool01000ooooooooo`00o`;oool01000oooo
ooooo`00o`;oool01P00ooooooooo`00ooooo`00o`;oool00`00ooooooooo`0:oooo00@00?oooooo
ool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_ooo`04003ooooooooo003o0_oo
o`04003ooooooooo003o3oooo`06003ooooooooo003ooooo003o1Oooo`04003ooooooooo003o0_oo
o`04003ooooooooo003o0_ooo`03003ooooooooo00Ooool00`00ooooo`00o`02oooo00@00?oooooo
ool00?l2oooo00<00?ooooooool01_ooo`009oooo`050000oooooooooooo003o00;oool2003o0_oo
o`04003ooooooooo003o5oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`06003o
oooooooo003ooooo003o5Oooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo003o0_oo
o`04003ooooooooo003o0_ooo`03003ooooooooo013oool00`00ooooo`00o`02oooo00@00?oooooo
ool00?l2oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l2oooo00<00?oooooo
ool02_ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooo003o00;oool0
1000ooooooooo`00o`;oool01000ooooooooo`00o`ooool01P00ooooooooo`00ooooo`00o`Goool0
1000ooooooooo`00o`;oool01000ooooooooo`00o`;oool00`00ooooooooo`07oooo00<00?ooool0
0?l00_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00Koool002Ooool01@000?oooooooooo
o`00o`02oooo0P00o`;oool01000ooooooooo`00oaOoool01000ooooooooo`00o`;oool01000oooo
ooooo`00o`;oool01P00ooooooooo`00ooooo`00oaGoool01000ooooooooo`00o`;oool01P00oooo
ooooo`00ooooo`00o`;oool01000ooooooooo`00o`;oool00`00ooooooooo`0@oooo00<00?ooool0
0?l00_ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo
003o0_ooo`03003ooooooooo00[oool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool0
0`00ooooo`00o`02oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l?oooo00H00?oooooo
ool00?ooool00?l5oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<00?oooooo
ool01oooo`03003ooooo003o00;oool01000ooooooooo`00o`;oool00`00ooooooooo`06oooo000W
oooo00D0003oooooooooool00?l00_ooo`800?l2oooo00@00?ooooooool00?lGoooo00@00?oooooo
ool00?l2oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?lEoooo00@00?oooooo
ool00?l2oooo00H00?ooooooool00?ooool00?l2oooo00@00?ooooooool00?l2oooo00<00?oooooo
ool04?ooo`03003ooooo003o00;oool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool0
1P00ooooooooo`00ooooo`00o`;oool00`00ooooooooo`0:oooo00@00?ooooooool00?l2oooo00@0
0?ooooooool00?l2oooo00<00?ooool00?l00_ooo`04003ooooooooo003o0_ooo`04003ooooooooo
003o3oooo`06003ooooooooo003ooooo003o1Oooo`04003ooooooooo003o0_ooo`04003ooooooooo
003o0_ooo`03003ooooooooo00Ooool00`00ooooo`00o`02oooo00@00?ooooooool00?l2oooo00<0
0?ooooooool01_ooo`009oooo`050000oooooooooooo003o00;oool2003o0_ooo`04003ooooooooo
003o5oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo
003o5Oooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo003o0_ooo`04003ooooooooo
003o0_ooo`03003ooooooooo013oool00`00ooooo`00o`02oooo00@00?ooooooool00?l2oooo00@0
0?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l2oooo00<00?ooooooool02_ooo`04003o
oooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooo003o00;oool01000ooooooooo`00
o`;oool01000ooooooooo`00o`ooool01P00ooooooooo`00ooooo`00o`Goool01000ooooooooo`00
o`;oool01000ooooooooo`00o`;oool00`00ooooooooo`07oooo00<00?ooool00?l00_ooo`04003o
oooooooo003o0_ooo`03003ooooooooo00Koool002Ooool200000_ooo`03003ooooooooo00800?l2
oooo00@00?ooooooool00?lGoooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00H0
0?ooooooool00?ooool00?lEoooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l2
oooo00@00?ooooooool00?l2oooo00<00?ooooooool04?ooo`03003ooooo003o00;oool01000oooo
ooooo`00o`;oool01000ooooooooo`00o`;oool01P00ooooooooo`00ooooo`00o`;oool00`00oooo
ooooo`0:oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_oo
o`04003ooooooooo003o0_ooo`04003ooooooooo003o3oooo`06003ooooooooo003ooooo003o1Ooo
o`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00Ooool00`00oooo
o`00o`02oooo00@00?ooooooool00?l2oooo00<00?ooooooool01_ooo`009oooo`050000oooooooo
oooo003o00;oool2003o0_ooo`04003ooooooooo003o5oooo`04003ooooooooo003o0_ooo`04003o
oooooooo003o0_ooo`06003ooooooooo003ooooo003o5Oooo`04003ooooooooo003o0_ooo`06003o
oooooooo003ooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo013oool00`00oooo
o`00o`02oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?oo
ool00?l2oooo00<00?ooooooool02_ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_oo
o`03003ooooo003o00;oool01000ooooooooo`00o`;oool01000ooooooooo`00o`ooool01P00oooo
ooooo`00ooooo`00o`Goool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool00`00oooo
ooooo`07oooo00<00?ooool00?l00_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00Koool0
01Goool:00000_ooo`030000oooooooo00?oool01@000?ooooooooooo`00o`02oooo0P00o`;oool0
1000ooooooooo`00oaOoool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool01P00oooo
ooooo`00ooooo`00oaGoool01000ooooooooo`00o`;oool01P00ooooooooo`00ooooo`00o`;oool0
1000ooooooooo`00o`;oool00`00ooooooooo`0@oooo00<00?ooool00?l00_ooo`04003ooooooooo
003o0_ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo003o0_ooo`03003ooooooooo
00[oool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool00`00ooooo`00o`02oooo00@0
0?ooooooool00?l2oooo00@00?ooooooool00?l?oooo00H00?ooooooool00?ooool00?l5oooo00@0
0?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool01oooo`03003ooooo003o
00;oool01000ooooooooo`00o`;oool00`00ooooooooo`06oooo000Goooo00<0003oooooool00_oo
o`070000oooooooooooo0000oooo000000Coool01@000?ooooooooooo`00o`02oooo0P00o`;oool0
1000ooooooooo`00oaOoool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool01P00oooo
ooooo`00ooooo`00oaGoool01000ooooooooo`00o`;oool01P00ooooooooo`00ooooo`00o`;oool0
1000ooooooooo`00o`;oool00`00ooooooooo`0@oooo00<00?ooool00?l00_ooo`04003ooooooooo
003o0_ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo003o0_ooo`03003ooooooooo
00[oool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool00`00ooooo`00o`02oooo00@0
0?ooooooool00?l2oooo00@00?ooooooool00?l?oooo00H00?ooooooool00?ooool00?l5oooo00@0
0?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool01oooo`03003ooooo003o
00;oool01000ooooooooo`00o`;oool00`00ooooooooo`06oooo000Aoooo0`0000?oool00`000?oo
ooooo`02oooo00<0003oooooool00oooo`030000oooooooo00;oool200000_ooo`03003ooooooooo
00800?l2oooo00@00?ooooooool00?lGoooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2
oooo00H00?ooooooool00?ooool00?lEoooo00@00?ooooooool00?l2oooo00H00?ooooooool00?oo
ool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool04?ooo`03003ooooo003o00;oool0
1000ooooooooo`00o`;oool01000ooooooooo`00o`;oool01P00ooooooooo`00ooooo`00o`;oool0
0`00ooooooooo`0:oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooool0
0?l00_ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o3oooo`06003ooooooooo003ooooo
003o1Oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00Ooool0
0`00ooooo`00o`02oooo00@00?ooooooool00?l2oooo00<00?ooooooool01_ooo`005oooo`030000
oooooooo00;oool010000?ooooooooooo`800005oooo00D0003oooooooooool00?l00_ooo`800?l2
oooo00@00?ooooooool00?lGoooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00H0
0?ooooooool00?ooool00?lEoooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l2
oooo00@00?ooooooool00?l2oooo00<00?ooooooool04?ooo`03003ooooo003o00;oool01000oooo
ooooo`00o`;oool01000ooooooooo`00o`;oool01P00ooooooooo`00ooooo`00o`;oool00`00oooo
ooooo`0:oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_oo
o`04003ooooooooo003o0_ooo`04003ooooooooo003o3oooo`06003ooooooooo003ooooo003o1Ooo
o`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00Ooool00`00oooo
o`00o`02oooo00@00?ooooooool00?l2oooo00<00?ooooooool01_ooo`005oooo`030000oooooooo
00;oool01@000?ooooooooooo`000006oooo00D0003oooooooooool00?l00_ooo`800?l2oooo00@0
0?ooooooool00?lGoooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00H00?oooooo
ool00?ooool00?lEoooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l2oooo00@0
0?ooooooool00?l2oooo00<00?ooooooool04?ooo`03003ooooo003o00;oool01000ooooooooo`00
o`;oool01000ooooooooo`00o`;oool01P00ooooooooo`00ooooo`00o`;oool00`00ooooooooo`0:
oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_ooo`04003o
oooooooo003o0_ooo`04003ooooooooo003o3oooo`06003ooooooooo003ooooo003o1Oooo`04003o
oooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00Ooool00`00ooooo`00o`02
oooo00@00?ooooooool00?l2oooo00<00?ooooooool01_ooo`005_ooo`800003oooo0P0000?oool3
00001?ooo`050000oooooooooooo003o00;oool2003o0_ooo`04003ooooooooo003o5oooo`04003o
oooooooo003o0_ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo003o5Oooo`04003o
oooooooo003o0_ooo`06003ooooooooo003ooooo003o0_ooo`04003ooooooooo003o0_ooo`03003o
oooooooo013oool00`00ooooo`00o`02oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2
oooo00H00?ooooooool00?ooool00?l2oooo00<00?ooooooool02_ooo`04003ooooooooo003o0_oo
o`04003ooooooooo003o0_ooo`03003ooooo003o00;oool01000ooooooooo`00o`;oool01000oooo
ooooo`00o`ooool01P00ooooooooo`00ooooo`00o`Goool01000ooooooooo`00o`;oool01000oooo
ooooo`00o`;oool00`00ooooooooo`07oooo00<00?ooool00?l00_ooo`04003ooooooooo003o0_oo
o`03003ooooooooo00Koool002Ooool200000_ooo`03003ooooooooo00800?l2oooo00@00?oooooo
ool00?lGoooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?oo
ool00?lEoooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l2oooo00@00?oooooo
ool00?l2oooo00<00?ooooooool04?ooo`03003ooooo003o00;oool01000ooooooooo`00o`;oool0
1000ooooooooo`00o`;oool01P00ooooooooo`00ooooo`00o`;oool00`00ooooooooo`0:oooo00@0
0?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooool00?l00_ooo`04003ooooooooo
003o0_ooo`04003ooooooooo003o3oooo`06003ooooooooo003ooooo003o1Oooo`04003ooooooooo
003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00Ooool00`00ooooo`00o`02oooo00@0
0?ooooooool00?l2oooo00<00?ooooooool01_ooo`009oooo`050000oooooooooooo003o00;oool2
003o0_ooo`04003ooooooooo003o5oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_oo
o`06003ooooooooo003ooooo003o5Oooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo
003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo013oool00`00ooooo`00o`02oooo00@0
0?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l2oooo00<0
0?ooooooool02_ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooo003o
00;oool01000ooooooooo`00o`;oool01000ooooooooo`00o`ooool01P00ooooooooo`00ooooo`00
o`Goool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool00`00ooooooooo`07oooo00<0
0?ooool00?l00_ooo`04003ooooooooo003o0_ooo`03003ooooooooo00Koool002Ooool01@000?oo
ooooooooo`00o`02oooo0P00o`;oool01000ooooooooo`00oaOoool01000ooooooooo`00o`;oool0
1000ooooooooo`00o`;oool01P00ooooooooo`00ooooo`00oaGoool01000ooooooooo`00o`;oool0
1P00ooooooooo`00ooooo`00o`;oool01000ooooooooo`00o`;oool00`00ooooooooo`0@oooo00<0
0?ooool00?l00_ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`06003ooooooooo
003ooooo003o0_ooo`03003ooooooooo00[oool01000ooooooooo`00o`;oool01000ooooooooo`00
o`;oool00`00ooooo`00o`02oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l?oooo00H0
0?ooooooool00?ooool00?l5oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<0
0?ooooooool01oooo`03003ooooo003o00;oool01000ooooooooo`00o`;oool00`00ooooooooo`06
oooo000Woooo00L0003oooooooooool00?ooool00?l00_ooo`06003ooooo003o003ooooo003o6?oo
o`07003ooooo003o003ooooo003ooooo00800?l01?ooo`00o`00ooooo`800?l00oooo`00ooooo`0D
oooo00D00?ooool00?l00?ooool00P00o`04oooo003o003ooooo0P00o`04oooo003o003ooooo0P00
o`03oooo003ooooo017oool01@00ooooo`00o`00ooooo`02003o00Koool00?l00?ooool00?ooool2
003o00Coool00?l00?ooool2003o00Goool00?l00?ooool00?l03Oooo`04003ooooo003ooooo0P00
o`05oooo003o003ooooo003o00?oool01@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool0
0?l03oooo`06003ooooo003o003ooooo003o1_ooo`04003ooooo003ooooo0P00o`05oooo003o003o
oooo003o00[oool01@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool00?l02?ooo`009ooo
o`070000oooooooooooo003ooooo003o00;oool01P00ooooo`00o`00ooooo`00oaSoool01`00oooo
o`00o`00ooooo`00ooooo`02003o00Coool00?l00?ooool2003o00?oool00?ooool05?ooo`05003o
oooo003o003ooooo00800?l01?ooo`00o`00ooooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00
ooooo`0Aoooo00D00?ooool00?l00?ooool00P00o`06oooo003o003ooooo003ooooo0P00o`04oooo
003o003ooooo0P00o`05oooo003o003ooooo003o00goool01000ooooo`00ooooo`800?l01Oooo`00
o`00ooooo`00o`03oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o00ooool0
1P00ooooo`00o`00ooooo`00o`Koool01000ooooo`00ooooo`800?l01Oooo`00o`00ooooo`00o`0:
oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o00Soool002Ooool200000_oo
o`03003ooooo003o00;oool01P00ooooo`00o`00ooooo`00oaSoool01`00ooooo`00o`00ooooo`00
ooooo`02003o00Coool00?l00?ooool2003o00?oool00?ooool05?ooo`05003ooooo003o003ooooo
00800?l01?ooo`00o`00ooooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00ooooo`0Aoooo00D0
0?ooool00?l00?ooool00P00o`06oooo003o003ooooo003ooooo0P00o`04oooo003o003ooooo0P00
o`05oooo003o003ooooo003o00goool01000ooooo`00ooooo`800?l01Oooo`00o`00ooooo`00o`03
oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o00ooool01P00ooooo`00o`00
ooooo`00o`Koool01000ooooo`00ooooo`800?l01Oooo`00o`00ooooo`00o`0:oooo00D00?ooool0
0?l00?ooool00P00o`05oooo003o003ooooo003o00Soool002Ooool01`000?ooooooooooo`00oooo
o`00o`02oooo00H00?ooool00?l00?ooool00?lHoooo00L00?ooool00?l00?ooool00?ooool00P00
o`04oooo003o003ooooo0P00o`03oooo003ooooo01Coool01@00ooooo`00o`00ooooo`02003o00Co
ool00?l00?ooool2003o00Coool00?l00?ooool2003o00?oool00?ooool04Oooo`05003ooooo003o
003ooooo00800?l01_ooo`00o`00ooooo`00ooooo`800?l01?ooo`00o`00ooooo`800?l01Oooo`00
o`00ooooo`00o`0=oooo00@00?ooool00?ooool2003o00Goool00?l00?ooool00?l00oooo`05003o
oooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`0?oooo00H00?ooool00?l00?ooool00?l6
oooo00@00?ooool00?ooool2003o00Goool00?l00?ooool00?l02_ooo`05003ooooo003o003ooooo
00800?l01Oooo`00o`00ooooo`00o`08oooo000Woooo00L0003oooooooooool00?ooool00?l00_oo
o`06003ooooo003o003ooooo003o6?ooo`07003ooooo003o003ooooo003ooooo00800?l01?ooo`00
o`00ooooo`800?l00oooo`00ooooo`0Doooo00D00?ooool00?l00?ooool00P00o`04oooo003o003o
oooo0P00o`04oooo003o003ooooo0P00o`03oooo003ooooo017oool01@00ooooo`00o`00ooooo`02
003o00Koool00?l00?ooool00?ooool2003o00Coool00?l00?ooool2003o00Goool00?l00?ooool0
0?l03Oooo`04003ooooo003ooooo0P00o`05oooo003o003ooooo003o00?oool01@00ooooo`00o`00
ooooo`02003o00Goool00?l00?ooool00?l03oooo`06003ooooo003o003ooooo003o1_ooo`04003o
oooo003ooooo0P00o`05oooo003o003ooooo003o00[oool01@00ooooo`00o`00ooooo`02003o00Go
ool00?l00?ooool00?l02?ooo`009oooo`070000oooooooooooo003ooooo003o00;oool01P00oooo
o`00o`00ooooo`00oaSoool01`00ooooo`00o`00ooooo`00ooooo`02003o00Coool00?l00?ooool2
003o00?oool00?ooool05?ooo`05003ooooo003o003ooooo00800?l01?ooo`00o`00ooooo`800?l0
1?ooo`00o`00ooooo`800?l00oooo`00ooooo`0Aoooo00D00?ooool00?l00?ooool00P00o`06oooo
003o003ooooo003ooooo0P00o`04oooo003o003ooooo0P00o`05oooo003o003ooooo003o00goool0
1000ooooo`00ooooo`800?l01Oooo`00o`00ooooo`00o`03oooo00D00?ooool00?l00?ooool00P00
o`05oooo003o003ooooo003o00ooool01P00ooooo`00o`00ooooo`00o`Koool01000ooooo`00oooo
o`800?l01Oooo`00o`00ooooo`00o`0:oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003o
oooo003o00Soool002Ooool200000_ooo`03003ooooo003o00;oool01P00ooooo`00o`00ooooo`00
oaSoool01`00ooooo`00o`00ooooo`00ooooo`02003o00Coool00?l00?ooool2003o00?oool00?oo
ool05?ooo`05003ooooo003o003ooooo00800?l01?ooo`00o`00ooooo`800?l01?ooo`00o`00oooo
o`800?l00oooo`00ooooo`0Aoooo00D00?ooool00?l00?ooool00P00o`06oooo003o003ooooo003o
oooo0P00o`04oooo003o003ooooo0P00o`05oooo003o003ooooo003o00goool01000ooooo`00oooo
o`800?l01Oooo`00o`00ooooo`00o`03oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003o
oooo003o00ooool01P00ooooo`00o`00ooooo`00o`Koool01000ooooo`00ooooo`800?l01Oooo`00
o`00ooooo`00o`0:oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o00Soool0
02Ooool01`000?ooooooooooo`00ooooo`00o`02oooo00H00?ooool00?l00?ooool00?lHoooo00L0
0?ooool00?l00?ooool00?ooool00P00o`04oooo003o003ooooo0P00o`03oooo003ooooo01Coool0
1@00ooooo`00o`00ooooo`02003o00Coool00?l00?ooool2003o00Coool00?l00?ooool2003o00?o
ool00?ooool04Oooo`05003ooooo003o003ooooo00800?l01_ooo`00o`00ooooo`00ooooo`800?l0
1?ooo`00o`00ooooo`800?l01Oooo`00o`00ooooo`00o`0=oooo00@00?ooool00?ooool2003o00Go
ool00?l00?ooool00?l00oooo`05003ooooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`0?
oooo00H00?ooool00?l00?ooool00?l6oooo00@00?ooool00?ooool2003o00Goool00?l00?ooool0
0?l02_ooo`05003ooooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`08oooo000Woooo00L0
003oooooooooool00?ooool00?l00_ooo`06003ooooo003o003ooooo003o6?ooo`07003ooooo003o
003ooooo003ooooo00800?l01?ooo`00o`00ooooo`800?l00oooo`00ooooo`0Doooo00D00?ooool0
0?l00?ooool00P00o`04oooo003o003ooooo0P00o`04oooo003o003ooooo0P00o`03oooo003ooooo
017oool01@00ooooo`00o`00ooooo`02003o00Koool00?l00?ooool00?ooool2003o00Coool00?l0
0?ooool2003o00Goool00?l00?ooool00?l03Oooo`04003ooooo003ooooo0P00o`05oooo003o003o
oooo003o00?oool01@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool00?l03oooo`06003o
oooo003o003ooooo003o1_ooo`04003ooooo003ooooo0P00o`05oooo003o003ooooo003o00[oool0
1@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool00?l02?ooo`009oooo`070000oooooooo
oooo003ooooo003o00;oool01P00ooooo`00o`00ooooo`00oaSoool01`00ooooo`00o`00ooooo`00
ooooo`02003o00Coool00?l00?ooool2003o00?oool00?ooool05?ooo`05003ooooo003o003ooooo
00800?l01?ooo`00o`00ooooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00ooooo`0Aoooo00D0
0?ooool00?l00?ooool00P00o`06oooo003o003ooooo003ooooo0P00o`04oooo003o003ooooo0P00
o`05oooo003o003ooooo003o00goool01000ooooo`00ooooo`800?l01Oooo`00o`00ooooo`00o`03
oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o00ooool01P00ooooo`00o`00
ooooo`00o`Koool01000ooooo`00ooooo`800?l01Oooo`00o`00ooooo`00o`0:oooo00D00?ooool0
0?l00?ooool00P00o`05oooo003o003ooooo003o00Soool002Ooool01`000?ooooooooooo`00oooo
o`00o`02oooo00H00?ooool00?l00?ooool00?lHoooo00L00?ooool00?l00?ooool00?ooool00P00
o`04oooo003o003ooooo0P00o`03oooo003ooooo01Coool01@00ooooo`00o`00ooooo`02003o00Co
ool00?l00?ooool2003o00Coool00?l00?ooool2003o00?oool00?ooool04Oooo`05003ooooo003o
003ooooo00800?l01_ooo`00o`00ooooo`00ooooo`800?l01?ooo`00o`00ooooo`800?l01Oooo`00
o`00ooooo`00o`0=oooo00@00?ooool00?ooool2003o00Goool00?l00?ooool00?l00oooo`05003o
oooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`0?oooo00H00?ooool00?l00?ooool00?l6
oooo00@00?ooool00?ooool2003o00Goool00?l00?ooool00?l02_ooo`05003ooooo003o003ooooo
00800?l01Oooo`00o`00ooooo`00o`08oooo000Woooo0P0000;oool00`00ooooo`00o`02oooo00H0
0?ooool00?l00?ooool00?lHoooo00L00?ooool00?l00?ooool00?ooool00P00o`04oooo003o003o
oooo0P00o`03oooo003ooooo01Coool01@00ooooo`00o`00ooooo`02003o00Coool00?l00?ooool2
003o00Coool00?l00?ooool2003o00?oool00?ooool04Oooo`05003ooooo003o003ooooo00800?l0
1_ooo`00o`00ooooo`00ooooo`800?l01?ooo`00o`00ooooo`800?l01Oooo`00o`00ooooo`00o`0=
oooo00@00?ooool00?ooool2003o00Goool00?l00?ooool00?l00oooo`05003ooooo003o003ooooo
00800?l01Oooo`00o`00ooooo`00o`0?oooo00H00?ooool00?l00?ooool00?l6oooo00@00?ooool0
0?ooool2003o00Goool00?l00?ooool00?l02_ooo`05003ooooo003o003ooooo00800?l01Oooo`00
o`00ooooo`00o`08oooo000Woooo00L0003oooooooooool00?ooool00?l00_ooo`06003ooooo003o
003ooooo003o6?ooo`07003ooooo003o003ooooo003ooooo00800?l01?ooo`00o`00ooooo`800?l0
0oooo`00ooooo`0Doooo00D00?ooool00?l00?ooool00P00o`04oooo003o003ooooo0P00o`04oooo
003o003ooooo0P00o`03oooo003ooooo017oool01@00ooooo`00o`00ooooo`02003o00Koool00?l0
0?ooool00?ooool2003o00Coool00?l00?ooool2003o00Goool00?l00?ooool00?l03Oooo`04003o
oooo003ooooo0P00o`05oooo003o003ooooo003o00?oool01@00ooooo`00o`00ooooo`02003o00Go
ool00?l00?ooool00?l03oooo`06003ooooo003o003ooooo003o1_ooo`04003ooooo003ooooo0P00
o`05oooo003o003ooooo003o00[oool01@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool0
0?l02?ooo`002oooo`X000001?ooo`000000000000?oool00`000?ooooooo`02oooo00<0003ooooo
ool00oooo`070000oooooooooooo003ooooo003o00;oool01P00ooooo`00o`00ooooo`00oaSoool0
1`00ooooo`00o`00ooooo`00ooooo`02003o00Coool00?l00?ooool2003o00?oool00?ooool05?oo
o`05003ooooo003o003ooooo00800?l01?ooo`00o`00ooooo`800?l01?ooo`00o`00ooooo`800?l0
0oooo`00ooooo`0Aoooo00D00?ooool00?l00?ooool00P00o`06oooo003o003ooooo003ooooo0P00
o`04oooo003o003ooooo0P00o`05oooo003o003ooooo003o00goool01000ooooo`00ooooo`800?l0
1Oooo`00o`00ooooo`00o`03oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o
00ooool01P00ooooo`00o`00ooooo`00o`Koool01000ooooo`00ooooo`800?l01Oooo`00o`00oooo
o`00o`0:oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o00Soool000goool0
0`000?ooooooo`02oooo00D0003oooooooooool000002Oooo`030000oooo000000Coool01`000?oo
ooooooooo`00ooooo`00o`02oooo00H00?ooool00?l00?ooool00?lHoooo00L00?ooool00?l00?oo
ool00?ooool00P00o`04oooo003o003ooooo0P00o`03oooo003ooooo01Coool01@00ooooo`00o`00
ooooo`02003o00Coool00?l00?ooool2003o00Coool00?l00?ooool2003o00?oool00?ooool04Ooo
o`05003ooooo003o003ooooo00800?l01_ooo`00o`00ooooo`00ooooo`800?l01?ooo`00o`00oooo
o`800?l01Oooo`00o`00ooooo`00o`0=oooo00@00?ooool00?ooool2003o00Goool00?l00?ooool0
0?l00oooo`05003ooooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`0?oooo00H00?ooool0
0?l00?ooool00?l6oooo00@00?ooool00?ooool2003o00Goool00?l00?ooool00?l02_ooo`05003o
oooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`08oooo0007oooo0`0000?oool00`000?oo
ooooo`02oooo00<0003oooooool00_ooo`030000oooooooo00Soool00`000?ooooooo`02oooo0P00
00;oool00`00ooooo`00o`02oooo00H00?ooool00?l00?ooool00?lHoooo00L00?ooool00?l00?oo
ool00?ooool00P00o`04oooo003o003ooooo0P00o`03oooo003ooooo01Coool01@00ooooo`00o`00
ooooo`02003o00Coool00?l00?ooool2003o00Coool00?l00?ooool2003o00?oool00?ooool04Ooo
o`05003ooooo003o003ooooo00800?l01_ooo`00o`00ooooo`00ooooo`800?l01?ooo`00o`00oooo
o`800?l01Oooo`00o`00ooooo`00o`0=oooo00@00?ooool00?ooool2003o00Goool00?l00?ooool0
0?l00oooo`05003ooooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`0?oooo00H00?ooool0
0?l00?ooool00?l6oooo00@00?ooool00?ooool2003o00Goool00?l00?ooool00?l02_ooo`05003o
oooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`08oooo000=oooo00<0003oooooool00_oo
o`030000oooooooo00;oool00`000?ooooooo`06oooo0P0000Goool01`000?ooooooooooo`00oooo
o`00o`02oooo00H00?ooool00?l00?ooool00?lHoooo00L00?ooool00?l00?ooool00?ooool00P00
o`04oooo003o003ooooo0P00o`03oooo003ooooo01Coool01@00ooooo`00o`00ooooo`02003o00Co
ool00?l00?ooool2003o00Coool00?l00?ooool2003o00?oool00?ooool04Oooo`05003ooooo003o
003ooooo00800?l01_ooo`00o`00ooooo`00ooooo`800?l01?ooo`00o`00ooooo`800?l01Oooo`00
o`00ooooo`00o`0=oooo00@00?ooool00?ooool2003o00Goool00?l00?ooool00?l00oooo`05003o
oooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`0?oooo00H00?ooool00?l00?ooool00?l6
oooo00@00?ooool00?ooool2003o00Goool00?l00?ooool00?l02_ooo`05003ooooo003o003ooooo
00800?l01Oooo`00o`00ooooo`00o`08oooo000=oooo00<0003oooooool00_ooo`070000oooooooo
oooo0000oooo000000Ooool00`000?ooooooo`04oooo00L0003oooooooooool00?ooool00?l00_oo
o`06003ooooo003o003ooooo003o6?ooo`07003ooooo003o003ooooo003ooooo00800?l01?ooo`00
o`00ooooo`800?l00oooo`00ooooo`0Doooo00D00?ooool00?l00?ooool00P00o`04oooo003o003o
oooo0P00o`04oooo003o003ooooo0P00o`03oooo003ooooo017oool01@00ooooo`00o`00ooooo`02
003o00Koool00?l00?ooool00?ooool2003o00Coool00?l00?ooool2003o00Goool00?l00?ooool0
0?l03Oooo`04003ooooo003ooooo0P00o`05oooo003o003ooooo003o00?oool01@00ooooo`00o`00
ooooo`02003o00Goool00?l00?ooool00?l03oooo`06003ooooo003o003ooooo003o1_ooo`04003o
oooo003ooooo0P00o`05oooo003o003ooooo003o00[oool01@00ooooo`00o`00ooooo`02003o00Go
ool00?l00?ooool00?l02?ooo`003?ooo`800003oooo0P0000Coool00`000?ooooooo`06oooo0`00
00Coool01`000?ooooooooooo`00ooooo`00o`02oooo00H00?ooool00?l00?ooool00?lHoooo00L0
0?ooool00?l00?ooool00?ooool00P00o`04oooo003o003ooooo0P00o`03oooo003ooooo01Coool0
1@00ooooo`00o`00ooooo`02003o00Coool00?l00?ooool2003o00Coool00?l00?ooool2003o00?o
ool00?ooool04Oooo`05003ooooo003o003ooooo00800?l01_ooo`00o`00ooooo`00ooooo`800?l0
1?ooo`00o`00ooooo`800?l01Oooo`00o`00ooooo`00o`0=oooo00@00?ooool00?ooool2003o00Go
ool00?l00?ooool00?l00oooo`05003ooooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`0?
oooo00H00?ooool00?l00?ooool00?l6oooo00@00?ooool00?ooool2003o00Goool00?l00?ooool0
0?l02_ooo`05003ooooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`08oooo000Woooo00<0
003oooooool00_ooo`800?l2oooo0P00o`03oooo003o003o01Woool2003o00Coool00?l00?ooool2
003o00Coool00?l00?ooool2003o00?oool00?ooool05_ooo`800?l01?ooo`00o`00ooooo`800?l0
0oooo`00ooooo`02003o00Coool00?l00?ooool2003o5?ooo`05003ooooo003o003ooooo00800?l0
1?ooo`00o`00ooooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00ooooo`02003o3_ooo`800?l0
1?ooo`00o`00ooooo`800?l00oooo`00o`00o`03oooo0P00o`04oooo003o003ooooo0P00o`03oooo
003o003o017oool2003o00?oool00?ooool01_ooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00
o`00o`0;oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o00Ooool002Ooool2
00000oooo`800?l2oooo0P00o`03oooo003o003o01Woool2003o00Coool00?l00?ooool2003o00Co
ool00?l00?ooool2003o00?oool00?ooool05_ooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00
ooooo`02003o00Coool00?l00?ooool2003o5?ooo`05003ooooo003o003ooooo00800?l01?ooo`00
o`00ooooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00ooooo`02003o3_ooo`800?l01?ooo`00
o`00ooooo`800?l00oooo`00o`00o`03oooo0P00o`04oooo003o003ooooo0P00o`03oooo003o003o
017oool2003o00?oool00?ooool01_ooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00o`00o`0;
oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o00Ooool002Ooool00`000?oo
ooooo`02oooo0P00o`;oool2003o00?oool00?l00?l06Oooo`800?l01?ooo`00o`00ooooo`800?l0
1?ooo`00o`00ooooo`800?l00oooo`00ooooo`0Foooo0P00o`04oooo003o003ooooo0P00o`03oooo
003ooooo00800?l01?ooo`00o`00ooooo`800?lDoooo00D00?ooool00?l00?ooool00P00o`04oooo
003o003ooooo0P00o`04oooo003o003ooooo0P00o`03oooo003ooooo00800?l>oooo0P00o`04oooo
003o003ooooo0P00o`03oooo003o003o00?oool2003o00Coool00?l00?ooool2003o00?oool00?l0
0?l04Oooo`800?l00oooo`00ooooo`06oooo0P00o`04oooo003o003ooooo0P00o`03oooo003o003o
00_oool01@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool00?l01oooo`009oooo`030000
oooooooo00;oool2003o0_ooo`800?l00oooo`00o`00o`0Ioooo0P00o`04oooo003o003ooooo0P00
o`04oooo003o003ooooo0P00o`03oooo003ooooo01Koool2003o00Coool00?l00?ooool2003o00?o
ool00?ooool00P00o`04oooo003o003ooooo0P00oaCoool01@00ooooo`00o`00ooooo`02003o00Co
ool00?l00?ooool2003o00Coool00?l00?ooool2003o00?oool00?ooool00P00o`koool2003o00Co
ool00?l00?ooool2003o00?oool00?l00?l00oooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00
o`00o`0Aoooo0P00o`03oooo003ooooo00Koool2003o00Coool00?l00?ooool2003o00?oool00?l0
0?l02oooo`05003ooooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`07oooo000Woooo00<0
003oooooool00_ooo`800?l2oooo0P00o`03oooo003o003o01Woool2003o00Coool00?l00?ooool2
003o00Coool00?l00?ooool2003o00?oool00?ooool05_ooo`800?l01?ooo`00o`00ooooo`800?l0
0oooo`00ooooo`02003o00Coool00?l00?ooool2003o5?ooo`05003ooooo003o003ooooo00800?l0
1?ooo`00o`00ooooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00ooooo`02003o3_ooo`800?l0
1?ooo`00o`00ooooo`800?l00oooo`00o`00o`03oooo0P00o`04oooo003o003ooooo0P00o`03oooo
003o003o017oool2003o00?oool00?ooool01_ooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00
o`00o`0;oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o00Ooool002Ooool2
00000oooo`800?l2oooo0P00o`03oooo003o003o01Woool2003o00Coool00?l00?ooool2003o00Co
ool00?l00?ooool2003o00?oool00?ooool05_ooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00
ooooo`02003o00Coool00?l00?ooool2003o5?ooo`05003ooooo003o003ooooo00800?l01?ooo`00
o`00ooooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00ooooo`02003o3_ooo`800?l01?ooo`00
o`00ooooo`800?l00oooo`00o`00o`03oooo0P00o`04oooo003o003ooooo0P00o`03oooo003o003o
017oool2003o00?oool00?ooool01_ooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00o`00o`0;
oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o00Ooool002Ooool00`000?oo
ooooo`02oooo0P00o`;oool2003o00?oool00?l00?l06Oooo`800?l01?ooo`00o`00ooooo`800?l0
1?ooo`00o`00ooooo`800?l00oooo`00ooooo`0Foooo0P00o`04oooo003o003ooooo0P00o`03oooo
003ooooo00800?l01?ooo`00o`00ooooo`800?lDoooo00D00?ooool00?l00?ooool00P00o`04oooo
003o003ooooo0P00o`04oooo003o003ooooo0P00o`03oooo003ooooo00800?l>oooo0P00o`04oooo
003o003ooooo0P00o`03oooo003o003o00?oool2003o00Coool00?l00?ooool2003o00?oool00?l0
0?l04Oooo`800?l00oooo`00ooooo`06oooo0P00o`04oooo003o003ooooo0P00o`03oooo003o003o
00_oool01@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool00?l01oooo`009oooo`030000
oooooooo00;oool2003o0_ooo`800?l00oooo`00o`00o`0Ioooo0P00o`04oooo003o003ooooo0P00
o`04oooo003o003ooooo0P00o`03oooo003ooooo01Koool2003o00Coool00?l00?ooool2003o00?o
ool00?ooool00P00o`04oooo003o003ooooo0P00oaCoool01@00ooooo`00o`00ooooo`02003o00Co
ool00?l00?ooool2003o00Coool00?l00?ooool2003o00?oool00?ooool00P00o`koool2003o00Co
ool00?l00?ooool2003o00?oool00?l00?l00oooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00
o`00o`0Aoooo0P00o`03oooo003ooooo00Koool2003o00Coool00?l00?ooool2003o00?oool00?l0
0?l02oooo`05003ooooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`07oooo000Woooo00<0
003oooooool00_ooo`800?l2oooo0P00o`03oooo003o003o01Woool2003o00Coool00?l00?ooool2
003o00Coool00?l00?ooool2003o00?oool00?ooool05_ooo`800?l01?ooo`00o`00ooooo`800?l0
0oooo`00ooooo`02003o00Coool00?l00?ooool2003o5?ooo`05003ooooo003o003ooooo00800?l0
1?ooo`00o`00ooooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00ooooo`02003o3_ooo`800?l0
1?ooo`00o`00ooooo`800?l00oooo`00o`00o`03oooo0P00o`04oooo003o003ooooo0P00o`03oooo
003o003o017oool2003o00?oool00?ooool01_ooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00
o`00o`0;oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o00Ooool002Ooool0
0`000?ooooooo`02oooo0P00o`;oool2003o00?oool00?l00?l06Oooo`800?l01?ooo`00o`00oooo
o`800?l01?ooo`00o`00ooooo`800?l00oooo`00ooooo`0Foooo0P00o`04oooo003o003ooooo0P00
o`03oooo003ooooo00800?l01?ooo`00o`00ooooo`800?lDoooo00D00?ooool00?l00?ooool00P00
o`04oooo003o003ooooo0P00o`04oooo003o003ooooo0P00o`03oooo003ooooo00800?l>oooo0P00
o`04oooo003o003ooooo0P00o`03oooo003o003o00?oool2003o00Coool00?l00?ooool2003o00?o
ool00?l00?l04Oooo`800?l00oooo`00ooooo`06oooo0P00o`04oooo003o003ooooo0P00o`03oooo
003o003o00_oool01@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool00?l01oooo`009ooo
o`800003oooo0P00o`;oool2003o00?oool00?l00?l06Oooo`800?l01?ooo`00o`00ooooo`800?l0
1?ooo`00o`00ooooo`800?l00oooo`00ooooo`0Foooo0P00o`04oooo003o003ooooo0P00o`03oooo
003ooooo00800?l01?ooo`00o`00ooooo`800?lDoooo00D00?ooool00?l00?ooool00P00o`04oooo
003o003ooooo0P00o`04oooo003o003ooooo0P00o`03oooo003ooooo00800?l>oooo0P00o`04oooo
003o003ooooo0P00o`03oooo003o003o00?oool2003o00Coool00?l00?ooool2003o00?oool00?l0
0?l04Oooo`800?l00oooo`00ooooo`06oooo0P00o`04oooo003o003ooooo0P00o`03oooo003o003o
00_oool01@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool00?l01oooo`009oooo`030000
oooooooo00;oool2003o0_ooo`800?l00oooo`00o`00o`0Ioooo0P00o`04oooo003o003ooooo0P00
o`04oooo003o003ooooo0P00o`03oooo003ooooo01Koool2003o00Coool00?l00?ooool2003o00?o
ool00?ooool00P00o`04oooo003o003ooooo0P00oaCoool01@00ooooo`00o`00ooooo`02003o00Co
ool00?l00?ooool2003o00Coool00?l00?ooool2003o00?oool00?ooool00P00o`koool2003o00Co
ool00?l00?ooool2003o00?oool00?l00?l00oooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00
o`00o`0Aoooo0P00o`03oooo003ooooo00Koool2003o00Coool00?l00?ooool2003o00?oool00?l0
0?l02oooo`05003ooooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`07oooo000Woooo00<0
003oooooool00_ooo`800?l2oooo0P00o`03oooo003o003o01Woool2003o00Coool00?l00?ooool2
003o00Coool00?l00?ooool2003o00?oool00?ooool05_ooo`800?l01?ooo`00o`00ooooo`800?l0
0oooo`00ooooo`02003o00Coool00?l00?ooool2003o5?ooo`05003ooooo003o003ooooo00800?l0
1?ooo`00o`00ooooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00ooooo`02003o3_ooo`800?l0
1?ooo`00o`00ooooo`800?l00oooo`00o`00o`03oooo0P00o`04oooo003o003ooooo0P00o`03oooo
003o003o017oool2003o00?oool00?ooool01_ooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00
o`00o`0;oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o00Ooool002Ooool0
0`000?ooooooo`02oooo0P00o`;oool2003o00?oool00?l00?l06Oooo`800?l01?ooo`00o`00oooo
o`800?l01?ooo`00o`00ooooo`800?l00oooo`00ooooo`0Foooo0P00o`04oooo003o003ooooo0P00
o`03oooo003ooooo00800?l01?ooo`00o`00ooooo`800?lDoooo00D00?ooool00?l00?ooool00P00
o`04oooo003o003ooooo0P00o`04oooo003o003ooooo0P00o`03oooo003ooooo00800?l>oooo0P00
o`04oooo003o003ooooo0P00o`03oooo003o003o00?oool2003o00Coool00?l00?ooool2003o00?o
ool00?l00?l04Oooo`800?l00oooo`00ooooo`06oooo0P00o`04oooo003o003ooooo0P00o`03oooo
003o003o00_oool01@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool00?l01oooo`009ooo
o`800003oooo0P00o`;oool2003o00?oool00?l00?l06Oooo`800?l01?ooo`00o`00ooooo`800?l0
1?ooo`00o`00ooooo`800?l00oooo`00ooooo`0Foooo0P00o`04oooo003o003ooooo0P00o`03oooo
003ooooo00800?l01?ooo`00o`00ooooo`800?lDoooo00D00?ooool00?l00?ooool00P00o`04oooo
003o003ooooo0P00o`04oooo003o003ooooo0P00o`03oooo003ooooo00800?l>oooo0P00o`04oooo
003o003ooooo0P00o`03oooo003o003o00?oool2003o00Coool00?l00?ooool2003o00?oool00?l0
0?l04Oooo`800?l00oooo`00ooooo`06oooo0P00o`04oooo003o003ooooo0P00o`03oooo003o003o
00_oool01@00ooooo`00o`00ooooo`02003o00Goool00?l00?ooool00?l01oooo`009oooo`030000
oooooooo00;oool2003o0_ooo`800?l00oooo`00o`00o`0Ioooo0P00o`04oooo003o003ooooo0P00
o`04oooo003o003ooooo0P00o`03oooo003ooooo01Koool2003o00Coool00?l00?ooool2003o00?o
ool00?ooool00P00o`04oooo003o003ooooo0P00oaCoool01@00ooooo`00o`00ooooo`02003o00Co
ool00?l00?ooool2003o00Coool00?l00?ooool2003o00?oool00?ooool00P00o`koool2003o00Co
ool00?l00?ooool2003o00?oool00?l00?l00oooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00
o`00o`0Aoooo0P00o`03oooo003ooooo00Koool2003o00Coool00?l00?ooool2003o00?oool00?l0
0?l02oooo`05003ooooo003o003ooooo00800?l01Oooo`00o`00ooooo`00o`07oooo000Woooo00<0
003oooooool00_ooo`800?l2oooo0P00o`03oooo003o003o01Woool2003o00Coool00?l00?ooool2
003o00Coool00?l00?ooool2003o00?oool00?ooool05_ooo`800?l01?ooo`00o`00ooooo`800?l0
0oooo`00ooooo`02003o00Coool00?l00?ooool2003o5?ooo`05003ooooo003o003ooooo00800?l0
1?ooo`00o`00ooooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00ooooo`02003o3_ooo`800?l0
1?ooo`00o`00ooooo`800?l00oooo`00o`00o`03oooo0P00o`04oooo003o003ooooo0P00o`03oooo
003o003o017oool2003o00?oool00?ooool01_ooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00
o`00o`0;oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o00Ooool001Goool:
00000_ooo`030000oooooooo00?oool00`000?ooooooo`02oooo0P00o`;oool2003o00?oool00?l0
0?l06Oooo`800?l01?ooo`00o`00ooooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00ooooo`0F
oooo0P00o`04oooo003o003ooooo0P00o`03oooo003ooooo00800?l01?ooo`00o`00ooooo`800?lD
oooo00D00?ooool00?l00?ooool00P00o`04oooo003o003ooooo0P00o`04oooo003o003ooooo0P00
o`03oooo003ooooo00800?l>oooo0P00o`04oooo003o003ooooo0P00o`03oooo003o003o00?oool2
003o00Coool00?l00?ooool2003o00?oool00?l00?l04Oooo`800?l00oooo`00ooooo`06oooo0P00
o`04oooo003o003ooooo0P00o`03oooo003o003o00_oool01@00ooooo`00o`00ooooo`02003o00Go
ool00?l00?ooool00?l01oooo`005oooo`030000oooooooo00;oool01`000?ooooooooooo`000?oo
o`000004oooo00<0003oooooool00_ooo`800?l2oooo0P00o`03oooo003o003o01Woool2003o00Co
ool00?l00?ooool2003o00Coool00?l00?ooool2003o00?oool00?ooool05_ooo`800?l01?ooo`00
o`00ooooo`800?l00oooo`00ooooo`02003o00Coool00?l00?ooool2003o5?ooo`05003ooooo003o
003ooooo00800?l01?ooo`00o`00ooooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00ooooo`02
003o3_ooo`800?l01?ooo`00o`00ooooo`800?l00oooo`00o`00o`03oooo0P00o`04oooo003o003o
oooo0P00o`03oooo003o003o017oool2003o00?oool00?ooool01_ooo`800?l01?ooo`00o`00oooo
o`800?l00oooo`00o`00o`0;oooo00D00?ooool00?l00?ooool00P00o`05oooo003o003ooooo003o
00Ooool0017oool300000oooo`030000oooooooo00;oool01`000?ooooooooooo`000?ooo`000004
oooo0P0000?oool00`00ooooooooo`02oooo00@00?ooooooool00?lJoooo00H00?ooooooool00?oo
ool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool05Oooo`04003ooooooooo003o0_oo
o`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo01;oool01000oooo
ooooo`00o`;oool01P00ooooooooo`00ooooo`00o`;oool01000ooooooooo`00o`;oool01000oooo
ooooo`00o`ooool00`00ooooo`00o`02oooo00@00?ooooooool00?l5oooo00@00?ooooooool00?l2
oooo00@00?ooooooool00?lAoooo00@00?ooooooool00?l8oooo00<00?ooool00?l00_ooo`04003o
oooooooo003o3?ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo003o1oooo`005ooo
o`030000oooooooo00;oool01`000?ooooooooooo`000?ooo`000004oooo00<0003oooooool00_oo
o`03003ooooooooo00;oool01000ooooooooo`00oa[oool01P00ooooooooo`00ooooo`00o`;oool0
1000ooooooooo`00o`;oool00`00ooooooooo`0Eoooo00@00?ooooooool00?l2oooo00@00?oooooo
ool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool04_ooo`04003ooooooooo003o0_oo
o`06003ooooooooo003ooooo003o0_ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o3ooo
o`03003ooooo003o00;oool01000ooooooooo`00o`Goool01000ooooooooo`00o`;oool01000oooo
ooooo`00oa7oool01000ooooooooo`00o`Soool00`00ooooo`00o`02oooo00@00?ooooooool00?l<
oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l7oooo000Goooo00<0003ooooo
ool00_ooo`070000oooooooooooo0000oooo000000Coool00`000?ooooooo`02oooo00<00?oooooo
ool00_ooo`04003ooooooooo003o6_ooo`06003ooooooooo003ooooo003o0_ooo`04003ooooooooo
003o0_ooo`03003ooooooooo01Goool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool0
1000ooooooooo`00o`;oool00`00ooooooooo`0Boooo00@00?ooooooool00?l2oooo00H00?oooooo
ool00?ooool00?l2oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l?oooo00<00?ooool0
0?l00_ooo`04003ooooooooo003o1Oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o4Ooo
o`04003ooooooooo003o2?ooo`03003ooooo003o00;oool01000ooooooooo`00o`coool01000oooo
ooooo`00o`;oool01P00ooooooooo`00ooooo`00o`Ooool001Koool200000oooo`800004oooo00<0
003oooooool00oooo`030000oooooooo00;oool00`00ooooooooo`02oooo00@00?ooooooool00?lJ
oooo00H00?ooooooool00?ooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool05Ooo
o`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003o
oooooooo01;oool01000ooooooooo`00o`;oool01P00ooooooooo`00ooooo`00o`;oool01000oooo
ooooo`00o`;oool01000ooooooooo`00o`ooool00`00ooooo`00o`02oooo00@00?ooooooool00?l5
oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?lAoooo00@00?ooooooool00?l8oooo00<0
0?ooool00?l00_ooo`04003ooooooooo003o3?ooo`04003ooooooooo003o0_ooo`06003ooooooooo
003ooooo003o1oooo`009oooo`800003oooo00<00?ooooooool00_ooo`04003ooooooooo003o6_oo
o`06003ooooooooo003ooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo01Goool0
1000ooooooooo`00o`;oool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool00`00oooo
ooooo`0Boooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l2oooo00@00?oooooo
ool00?l2oooo00@00?ooooooool00?l?oooo00<00?ooool00?l00_ooo`04003ooooooooo003o1Ooo
o`04003ooooooooo003o0_ooo`04003ooooooooo003o4Oooo`04003ooooooooo003o2?ooo`03003o
oooo003o00;oool01000ooooooooo`00o`coool01000ooooooooo`00o`;oool01P00ooooooooo`00
ooooo`00o`Ooool002Ooool00`000?ooooooo`02oooo00<00?ooooooool00_ooo`04003ooooooooo
003o6_ooo`06003ooooooooo003ooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo
01Goool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool0
0`00ooooooooo`0Boooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l2oooo00@0
0?ooooooool00?l2oooo00@00?ooooooool00?l?oooo00<00?ooool00?l00_ooo`04003ooooooooo
003o1Oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o4Oooo`04003ooooooooo003o2?oo
o`03003ooooo003o00;oool01000ooooooooo`00o`coool01000ooooooooo`00o`;oool01P00oooo
ooooo`00ooooo`00o`Ooool002Ooool00`000?ooooooo`02oooo00<00?ooooooool00_ooo`04003o
oooooooo003o6_ooo`06003ooooooooo003ooooo003o0_ooo`04003ooooooooo003o0_ooo`03003o
oooooooo01Goool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool01000ooooooooo`00
o`;oool00`00ooooooooo`0Boooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l2
oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l?oooo00<00?ooool00?l00_ooo`04003o
oooooooo003o1Oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o4Oooo`04003ooooooooo
003o2?ooo`03003ooooo003o00;oool01000ooooooooo`00o`coool01000ooooooooo`00o`;oool0
1P00ooooooooo`00ooooo`00o`Ooool002Ooool00`000?ooooooo`02oooo00<00?ooooooool00_oo
o`04003ooooooooo003o6_ooo`06003ooooooooo003ooooo003o0_ooo`04003ooooooooo003o0_oo
o`03003ooooooooo01Goool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool01000oooo
ooooo`00o`;oool00`00ooooooooo`0Boooo00@00?ooooooool00?l2oooo00H00?ooooooool00?oo
ool00?l2oooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l?oooo00<00?ooool00?l00_oo
o`04003ooooooooo003o1Oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o4Oooo`04003o
oooooooo003o2?ooo`03003ooooo003o00;oool01000ooooooooo`00o`coool01000ooooooooo`00
o`;oool01P00ooooooooo`00ooooo`00o`Ooool002Ooool200000oooo`03003ooooooooo00;oool0
1000ooooooooo`00oa[oool01P00ooooooooo`00ooooo`00o`;oool01000ooooooooo`00o`;oool0
0`00ooooooooo`0Eoooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00@00?oooooo
ool00?l2oooo00<00?ooooooool04_ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo
003o0_ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o3oooo`03003ooooo003o00;oool0
1000ooooooooo`00o`Goool01000ooooooooo`00o`;oool01000ooooooooo`00oa7oool01000oooo
ooooo`00o`Soool00`00ooooo`00o`02oooo00@00?ooooooool00?l<oooo00@00?ooooooool00?l2
oooo00H00?ooooooool00?ooool00?l7oooo000Woooo00<0003oooooool00_ooo`03003ooooooooo
00;oool01000ooooooooo`00oa[oool01P00ooooooooo`00ooooo`00o`;oool01000ooooooooo`00
o`;oool00`00ooooooooo`0Eoooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00@0
0?ooooooool00?l2oooo00<00?ooooooool04_ooo`04003ooooooooo003o0_ooo`06003ooooooooo
003ooooo003o0_ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o3oooo`03003ooooo003o
00;oool01000ooooooooo`00o`Goool01000ooooooooo`00o`;oool01000ooooooooo`00oa7oool0
1000ooooooooo`00o`Soool00`00ooooo`00o`02oooo00@00?ooooooool00?l<oooo00@00?oooooo
ool00?l2oooo00H00?ooooooool00?ooool00?l7oooo000Woooo00<0003oooooool00_ooo`03003o
oooooooo00;oool01000ooooooooo`00oa[oool01P00ooooooooo`00ooooo`00o`;oool01000oooo
ooooo`00o`;oool00`00ooooooooo`0Eoooo00@00?ooooooool00?l2oooo00@00?ooooooool00?l2
oooo00@00?ooooooool00?l2oooo00<00?ooooooool04_ooo`04003ooooooooo003o0_ooo`06003o
oooooooo003ooooo003o0_ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o3oooo`03003o
oooo003o00;oool01000ooooooooo`00o`Goool01000ooooooooo`00o`;oool01000ooooooooo`00
oa7oool01000ooooooooo`00o`Soool00`00ooooo`00o`02oooo00@00?ooooooool00?l<oooo00@0
0?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l7oooo000Woooo00<0003oooooool00_oo
o`03003ooooooooo00;oool01000ooooooooo`00oa[oool01P00ooooooooo`00ooooo`00o`;oool0
1000ooooooooo`00o`;oool00`00ooooooooo`0Eoooo00@00?ooooooool00?l2oooo00@00?oooooo
ool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool04_ooo`04003ooooooooo003o0_oo
o`06003ooooooooo003ooooo003o0_ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o3ooo
o`03003ooooo003o00;oool01000ooooooooo`00o`Goool01000ooooooooo`00o`;oool01000oooo
ooooo`00oa7oool01000ooooooooo`00o`Soool00`00ooooo`00o`02oooo00@00?ooooooool00?l<
oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l7oooo000Woooo00<0003ooooo
ool00_ooo`03003ooooooooo00;oool01000ooooooooo`00oa[oool01P00ooooooooo`00ooooo`00
o`;oool01000ooooooooo`00o`;oool00`00ooooooooo`0Eoooo00@00?ooooooool00?l2oooo00@0
0?ooooooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool04_ooo`04003ooooooooo
003o0_ooo`06003ooooooooo003ooooo003o0_ooo`04003ooooooooo003o0_ooo`04003ooooooooo
003o3oooo`03003ooooo003o00;oool01000ooooooooo`00o`Goool01000ooooooooo`00o`;oool0
1000ooooooooo`00oa7oool01000ooooooooo`00o`Soool00`00ooooo`00o`02oooo00@00?oooooo
ool00?l<oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l7oooo000Woooo0P00
00?oool00`00ooooooooo`02oooo00@00?ooooooool00?lJoooo00H00?ooooooool00?ooool00?l2
oooo00@00?ooooooool00?l2oooo00<00?ooooooool05Oooo`04003ooooooooo003o0_ooo`04003o
oooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo01;oool01000ooooooooo`00
o`;oool01P00ooooooooo`00ooooo`00o`;oool01000ooooooooo`00o`;oool01000ooooooooo`00
o`ooool00`00ooooo`00o`02oooo00@00?ooooooool00?l5oooo00@00?ooooooool00?l2oooo00@0
0?ooooooool00?lAoooo00@00?ooooooool00?l8oooo00<00?ooool00?l00_ooo`04003ooooooooo
003o3?ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo003o1oooo`009oooo`030000
oooooooo00;oool00`00ooooooooo`02oooo00@00?ooooooool00?lJoooo00H00?ooooooool00?oo
ool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool05Oooo`04003ooooooooo003o0_oo
o`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo01;oool01000oooo
ooooo`00o`;oool01P00ooooooooo`00ooooo`00o`;oool01000ooooooooo`00o`;oool01000oooo
ooooo`00o`ooool00`00ooooo`00o`02oooo00@00?ooooooool00?l5oooo00@00?ooooooool00?l2
oooo00@00?ooooooool00?lAoooo00@00?ooooooool00?l8oooo00<00?ooool00?l00_ooo`04003o
oooooooo003o3?ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo003o1oooo`009ooo
o`030000oooooooo00;oool00`00ooooooooo`02oooo00@00?ooooooool00?lJoooo00H00?oooooo
ool00?ooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool05Oooo`04003ooooooooo
003o0_ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo01;oool0
1000ooooooooo`00o`;oool01P00ooooooooo`00ooooo`00o`;oool01000ooooooooo`00o`;oool0
1000ooooooooo`00o`ooool00`00ooooo`00o`02oooo00@00?ooooooool00?l5oooo00@00?oooooo
ool00?l2oooo00@00?ooooooool00?lAoooo00@00?ooooooool00?l8oooo00<00?ooool00?l00_oo
o`04003ooooooooo003o3?ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo003o1ooo
o`009oooo`030000oooooooo00;oool00`00ooooooooo`02oooo00@00?ooooooool00?lJoooo00H0
0?ooooooool00?ooool00?l2oooo00@00?ooooooool00?l2oooo00<00?ooooooool05Oooo`04003o
oooooooo003o0_ooo`04003ooooooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo
01;oool01000ooooooooo`00o`;oool01P00ooooooooo`00ooooo`00o`;oool01000ooooooooo`00
o`;oool01000ooooooooo`00o`ooool00`00ooooo`00o`02oooo00@00?ooooooool00?l5oooo00@0
0?ooooooool00?l2oooo00@00?ooooooool00?lAoooo00@00?ooooooool00?l8oooo00<00?ooool0
0?l00_ooo`04003ooooooooo003o3?ooo`04003ooooooooo003o0_ooo`06003ooooooooo003ooooo
003o1oooo`009oooo`800003oooo00<00?ooooooool00_ooo`04003ooooooooo003o6_ooo`06003o
oooooooo003ooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo01Goool01000oooo
ooooo`00o`;oool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool00`00ooooooooo`0B
oooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l2oooo00@00?ooooooool00?l2
oooo00@00?ooooooool00?l?oooo00<00?ooool00?l00_ooo`04003ooooooooo003o1Oooo`04003o
oooooooo003o0_ooo`04003ooooooooo003o4Oooo`04003ooooooooo003o2?ooo`03003ooooo003o
00;oool01000ooooooooo`00o`coool01000ooooooooo`00o`;oool01P00ooooooooo`00ooooo`00
o`Ooool002Ooool00`000?ooooooo`02oooo00<00?ooooooool00_ooo`04003ooooooooo003o6_oo
o`06003ooooooooo003ooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo01Goool0
1000ooooooooo`00o`;oool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool00`00oooo
ooooo`0Boooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l2oooo00@00?oooooo
ool00?l2oooo00@00?ooooooool00?l?oooo00<00?ooool00?l00_ooo`04003ooooooooo003o1Ooo
o`04003ooooooooo003o0_ooo`04003ooooooooo003o4Oooo`04003ooooooooo003o2?ooo`03003o
oooo003o00;oool01000ooooooooo`00o`coool01000ooooooooo`00o`;oool01P00ooooooooo`00
ooooo`00o`Ooool002Ooool00`000?ooooooo`02oooo00<00?ooooooool00_ooo`04003ooooooooo
003o6_ooo`06003ooooooooo003ooooo003o0_ooo`04003ooooooooo003o0_ooo`03003ooooooooo
01Goool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool01000ooooooooo`00o`;oool0
0`00ooooooooo`0Boooo00@00?ooooooool00?l2oooo00H00?ooooooool00?ooool00?l2oooo00@0
0?ooooooool00?l2oooo00@00?ooooooool00?l?oooo00<00?ooool00?l00_ooo`04003ooooooooo
003o1Oooo`04003ooooooooo003o0_ooo`04003ooooooooo003o4Oooo`04003ooooooooo003o2?oo
o`03003ooooo003o00;oool01000ooooooooo`00o`coool01000ooooooooo`00o`;oool01P00oooo
ooooo`00ooooo`00o`Ooool000_oool500000_ooo`030000oooooooo00;oool00`000?ooooooo`02
oooo00<0003oooooool00_ooo`030000oooooooo00?oool00`000?ooooooo`3foooo000=oooo00L0
003oooooooooool0003oool000000oooo`030000oooooooo00Koool00`000?ooo`000004oooo00<0
003oooooool0m_ooo`001oooo`<00003oooo00L0003oooooooooool0003oool000000oooo`030000
oooooooo00Soool00`000?ooooooo`02oooo0P000?Ooool000goool01`000?ooooooooooo`000?oo
o`000004oooo00<0003oooooool01Oooo`800005oooo00<0003oooooool0m_ooo`003Oooo`070000
oooooooooooo0000oooo000000;oool00`000?ooo`000007oooo00<0003oooooool0oOooo`003?oo
o`800004oooo00@0003oooooooooool300001oooo`<0003moooo003ooooo8Oooo`00ooooob7oool0
0?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-27.3823, -126.616, 
  0.698983, 0.112307}}]
}, Open  ]],

Cell[TextData[
"Warto\.9c\[CAcute] \.9crednia miary b\[LSlash]\:0119du"], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mean[Abs[B\[LSlash]\[SHacek]d]]\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \(TraditionalForm\`114.24101904564381`\)], "Output",
  CellLabel->"Out[43]="]
}, Open  ]],

Cell[TextData[
"Warto\.9c\[CAcute] miary poprawno\.9cci detekcji cz\:0119stotliwo\.9cci \
podstawowej"], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[DFpr[FS, RzCzPodst]]\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \(TraditionalForm\`0\)], "Output",
  CellLabel->"Out[44]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Badanie dla r\[OAcute]\:017cnych warto\.9cci wagi W"], "Subsection"],

Cell[BoxData[
    \(B\[LSlash]\:0119dy = {}; \n
    For[i = \(-10\), i <= 10, \(i++\), \n\tES = e1 + 2^i\ e2; \n\t
      FS = DetMinK[ES]; \n\t
      B\[LSlash]\[SHacek]d = FB\[LSlash]\:0119du[FS, RzCzPodst]; \n\t
      AppendTo[B\[LSlash]\:0119dy, {i, Mean[Abs[B\[LSlash]\[SHacek]d]], 
          N[DFpr[FS, RzCzPodst]]}]]; \)], "Input",
  CellLabel->"In[45]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(B\[LSlash]\:0119dy\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(-10\), "35.4531521975159069`", "91.7159763313609488`"},
            {\(-9\), "35.9720628312203727`", "91.1242603550295982`"},
            {\(-8\), "37.0098840986292954`", "89.9408284023668613`"},
            {\(-7\), "42.0968229329181564`", "84.0236686390532661`"},
            {\(-6\), "54.9674212727739686`", "69.2307692307692335`"},
            {\(-5\), "113.451071627244348`", "2.36686390532544388`"},
            {\(-4\), "114.956719776979809`", "0.591715976331360948`"},
            {\(-3\), "114.956719776979809`", "0.591715976331360948`"},
            {\(-2\), "115.51811283009159`", "0"},
            {\(-1\), "115.467029078713667`", "0"},
            {"0", "115.415945327335744`", "0"},
            {"1", "115.160526570446197`", "0"},
            {"2", "114.802940310800827`", "0"},
            {"3", "114.496437802533379`", "0"},
            {"4", "114.445354051155456`", "0"},
            {"5", "114.394270299777534`", "0"},
            {"6", "114.292102797021732`", "0"},
            {"7", "114.24101904564381`", "0"},
            {"8", "114.24101904564381`", "0"},
            {"9", "114.24101904564381`", "0"},
            {"10", "114.24101904564381`", "0"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output",
  CellLabel->"Out[46]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 712}},
WindowToolbars->"RulerBar",
WindowSize->{739, 542},
WindowMargins->{{1, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
Magnification->1,
StyleDefinitions -> "Textbook.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 36, 0, 59, "Title"],
Cell[1770, 53, 63, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[1858, 57, 32, 0, 85, "Section"],
Cell[1893, 59, 42, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[1960, 63, 176, 3, 90, "Input"],
Cell[2139, 68, 279, 6, 28, "Message"],
Cell[2421, 76, 479, 10, 47, "Message"],
Cell[2903, 88, 82, 2, 25, "Output"]
}, Open  ]],
Cell[3000, 93, 58, 0, 31, "MathCaption"],
Cell[3061, 95, 135, 3, 50, "Input"],

Cell[CellGroupData[{
Cell[3221, 102, 77, 0, 40, "Subsection"],
Cell[3301, 104, 83, 1, 31, "MathCaption"],
Cell[3387, 107, 163, 5, 30, "Input"],
Cell[3553, 114, 45, 0, 31, "MathCaption"],
Cell[3601, 116, 164, 5, 30, "Input"],
Cell[3768, 123, 49, 0, 31, "MathCaption"],
Cell[3820, 125, 269, 8, 42, "Input"],
Cell[4092, 135, 74, 0, 31, "MathCaption"],
Cell[4169, 137, 160, 5, 30, "Input"],
Cell[4332, 144, 62, 0, 31, "MathCaption"],
Cell[4397, 146, 274, 8, 50, "Input"],
Cell[4674, 156, 68, 0, 31, "MathCaption"],
Cell[4745, 158, 165, 5, 30, "Input"],
Cell[4913, 165, 50, 0, 31, "MathCaption"],
Cell[4966, 167, 165, 5, 30, "Input"],
Cell[5134, 174, 79, 0, 31, "MathCaption"],
Cell[5216, 176, 166, 5, 30, "Input"],
Cell[5385, 183, 114, 4, 31, "MathCaption"],
Cell[5502, 189, 158, 5, 30, "Input"],
Cell[5663, 196, 74, 0, 31, "MathCaption"],
Cell[5740, 198, 273, 8, 50, "Input"],
Cell[6016, 208, 111, 2, 31, "MathCaption"],
Cell[6130, 212, 98, 2, 30, "Input"],
Cell[6231, 216, 86, 1, 31, "MathCaption"],
Cell[6320, 219, 100, 2, 36, "Input"],
Cell[6423, 223, 99, 2, 31, "MathCaption"],
Cell[6525, 227, 171, 3, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6745, 236, 76, 0, 85, "Section"],
Cell[6824, 238, 47, 0, 31, "MathCaption"],
Cell[6874, 240, 124, 3, 50, "Input"],
Cell[7001, 245, 34, 0, 31, "MathCaption"],
Cell[7038, 247, 224, 5, 110, "Input"],
Cell[7265, 254, 38, 0, 31, "MathCaption"],
Cell[7306, 256, 403, 9, 146, "Input"],
Cell[7712, 267, 94, 1, 31, "MathCaption"],
Cell[7809, 270, 2106, 38, 405, "Input"],
Cell[9918, 310, 132, 4, 31, "MathCaption"],
Cell[10053, 316, 946, 18, 301, "Input"],
Cell[11002, 336, 132, 4, 31, "MathCaption"],
Cell[11137, 342, 988, 18, 341, "Input"],
Cell[12128, 362, 73, 0, 31, "MathCaption"],
Cell[12204, 364, 793, 17, 189, "Input"],
Cell[13000, 383, 69, 0, 31, "MathCaption"],
Cell[13072, 385, 381, 8, 110, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13490, 398, 29, 0, 85, "Section"],
Cell[13522, 400, 39, 0, 31, "MathCaption"],
Cell[13564, 402, 483, 10, 207, "Input"],
Cell[14050, 414, 54, 0, 31, "MathCaption"],
Cell[14107, 416, 105, 2, 30, "Input"],
Cell[14215, 420, 132, 4, 31, "MathCaption"],
Cell[14350, 426, 84, 2, 30, "Input"],
Cell[14437, 430, 84, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[14546, 436, 120, 3, 30, "Input"],
Cell[14669, 441, 959541, 20997, 446, 699704, 17784, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[974225, 21441, 77, 0, 31, "MathCaption"],
Cell[974305, 21443, 79, 2, 30, "Input"],
Cell[974387, 21447, 65, 0, 31, "MathCaption"],
Cell[974455, 21449, 80, 2, 30, "Input"],
Cell[974538, 21453, 45, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[974608, 21457, 153, 3, 30, "Input"],
Cell[974764, 21462, 51601, 1022, 186, 6706, 463, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[1026380, 22487, 71, 0, 31, "MathCaption"],
Cell[1026454, 22489, 124, 3, 30, "Input"],
Cell[1026581, 22494, 58, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[1026664, 22498, 153, 3, 30, "Input"],
Cell[1026820, 22503, 62752, 1165, 186, 6819, 469, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[1089587, 23671, 88, 1, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[1089700, 23676, 89, 2, 30, "Input"],
Cell[1089792, 23680, 95, 2, 24, "Output"]
}, Open  ]],
Cell[1089902, 23685, 119, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[1090046, 23691, 80, 2, 30, "Input"],
Cell[1090129, 23695, 77, 2, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1090243, 23702, 84, 1, 40, "Subsection"],
Cell[1090330, 23705, 362, 7, 130, "Input"],

Cell[CellGroupData[{
Cell[1090717, 23716, 76, 2, 30, "Input"],
Cell[1090796, 23720, 1359, 26, 381, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

